

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'LATIN1';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET client_min_messages = warning;
SET row_security = off;

SET default_tablespace = '';

SET default_with_oids = false;


CREATE TABLE public.aliases (
    format text NOT NULL,
    alias text NOT NULL,
    name text NOT NULL
);



CREATE TABLE public.constants (
    index integer NOT NULL,
    name text NOT NULL,
    phase double precision NOT NULL,
    amp double precision NOT NULL,
    CONSTRAINT constants_amp_check CHECK ((amp >= (0.00005)::double precision)),
    CONSTRAINT constants_phase_check CHECK (((phase >= (0)::double precision) AND (phase < (360)::double precision)))
);



CREATE TABLE public.constituents (
    name text NOT NULL,
    definition text NOT NULL,
    speed double precision NOT NULL,
    CONSTRAINT constituents_speed_check CHECK ((speed > (0)::double precision))
);



CREATE TABLE public.data_sets (
    index integer NOT NULL,
    name text NOT NULL,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text NOT NULL,
    country text,
    units text NOT NULL,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text NOT NULL,
    date_imported date DEFAULT ('now'::text)::date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text,
    CONSTRAINT data_sets_check CHECK ((((lat IS NULL) AND (lng IS NULL)) OR ((lat IS NOT NULL) AND (lng IS NOT NULL)))),
    CONSTRAINT data_sets_check2 CHECK ((((datum IS NULL) AND (meridian IS NULL)) OR ((datum IS NOT NULL) AND (meridian IS NOT NULL)))),
    CONSTRAINT data_sets_check3 CHECK (((datum IS NOT NULL) OR (ref_index IS NOT NULL))),
    CONSTRAINT data_sets_lat_check CHECK (((lat >= ('-90'::integer)::double precision) AND (lat <= (90)::double precision))),
    CONSTRAINT data_sets_lng_check CHECK (((lng >= ('-180'::integer)::double precision) AND (lng <= (180)::double precision))),
    CONSTRAINT data_sets_max_dir_check CHECK (((max_dir >= (0)::double precision) AND (max_dir < (360)::double precision))),
    CONSTRAINT data_sets_max_level_multiply_check CHECK ((max_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_min_dir_check CHECK (((min_dir >= (0)::double precision) AND (min_dir < (360)::double precision))),
    CONSTRAINT data_sets_min_level_multiply_check CHECK ((min_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_units_check CHECK (((units = 'feet'::text) OR (units = 'meters'::text) OR (units = 'knots'::text) OR (units = 'knots^2'::text)))
);



CREATE SEQUENCE public.data_sets_index_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



ALTER SEQUENCE public.data_sets_index_seq OWNED BY public.data_sets.index;



CREATE TABLE public.data_sets_old (
    index integer,
    name text,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text,
    country text,
    units text,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text,
    date_imported date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text
);



CREATE VIEW public.reference_stations AS
 SELECT data_sets.index,
    data_sets.name,
    data_sets.original_name,
    data_sets.station_id_context,
    data_sets.station_id,
    data_sets.lat,
    data_sets.lng,
    data_sets.timezone,
    data_sets.country,
    data_sets.state,
    data_sets.units,
    data_sets.min_dir,
    data_sets.max_dir,
    data_sets.legalese,
    data_sets.notes,
    data_sets.comments,
    data_sets.source,
    data_sets.restriction,
    data_sets.date_imported,
    data_sets.xfields,
    data_sets.meridian,
    data_sets.datumkind,
    data_sets.datum,
    data_sets.months_on_station,
    data_sets.last_date_on_station
   FROM public.data_sets
  WHERE (data_sets.datum IS NOT NULL);



CREATE VIEW public.subordinate_stations AS
 SELECT data_sets.index,
    data_sets.name,
    data_sets.original_name,
    data_sets.station_id_context,
    data_sets.station_id,
    data_sets.lat,
    data_sets.lng,
    data_sets.timezone,
    data_sets.country,
    data_sets.state,
    data_sets.units,
    data_sets.min_dir,
    data_sets.max_dir,
    data_sets.legalese,
    data_sets.notes,
    data_sets.comments,
    data_sets.source,
    data_sets.restriction,
    data_sets.date_imported,
    data_sets.xfields,
    data_sets.ref_index,
    data_sets.min_time_add,
    data_sets.min_level_add,
    data_sets.min_level_multiply,
    data_sets.max_time_add,
    data_sets.max_level_add,
    data_sets.max_level_multiply,
    data_sets.flood_begins,
    data_sets.ebb_begins
   FROM public.data_sets
  WHERE (data_sets.datum IS NULL);



ALTER TABLE ONLY public.data_sets ALTER COLUMN index SET DEFAULT nextval('public.data_sets_index_seq'::regclass);



COPY public.aliases (format, alias, name) FROM stdin;
N	SM	MSF
N	OQ2	OQ2-HORN
N	LABDA2	LDA2
N	3MSN10	3MNS10
N	4MSN12	4MNS12
G	OQ2	OQ2-HORN
G	LAM2	LDA2
G	4MSN12	4MNS12
G	MQ3	NO3
G	3M(SK2	3MKS2
G	3M2S2	3MS2
G	2MV6	2MNU6
G	MVS2	MNUS2
GI	SA	SA-IOS
GI	MF	MF-IOS
GI	S1	S1-IOS
GI	OO1	OO1-IOS
GI	R2	R2-IOS
NOS	LAM2	LDA2
NOS	RHO	RHO1
NOS	SIGMA1	SIG1
NOS	2MLNS6	2MNLS6
NOS	2MS8	2(MS)8
NOS	2MN8	2(MN)8
NOS	M2KS2	M2(KS)2
NOS	2SNMK2	2SN(MK)2
NOS	2KMSN2	2KM(SN)2
NOS	THETA1	THE1
NOS	OO2	OQ2-HORN
NOS	RP1	PSI1
NOS	KJ2	KJ2-IHO
\.



COPY public.constants (index, name, phase, amp) FROM stdin;
16143	M2	105.599999999999994	0.309999999999999998
16143	S2	82.0999999999999943	0.0950000000000000011
16143	N2	79.7999999999999972	0.0709999999999999937
16143	K1	282.899999999999977	0.957999999999999963
16143	M4	184.900000000000006	0.0570000000000000021
16143	O1	275.5	0.884000000000000008
16143	M6	282.199999999999989	0.0100000000000000002
16143	S4	167.199999999999989	0.0290000000000000015
16143	NU2	83.2999999999999972	0.0140000000000000003
16143	S6	191.300000000000011	0.0109999999999999994
16143	2N2	54	0.00899999999999999932
16143	OO1	290.399999999999977	0.0379999999999999991
16143	LDA2	94.7000000000000028	0.00200000000000000004
16143	M1	279.199999999999989	0.0630000000000000004
16143	J1	286.699999999999989	0.0700000000000000067
16143	RHO1	272.300000000000011	0.0340000000000000024
16143	Q1	271.699999999999989	0.171999999999999986
16143	T2	83.0999999999999943	0.00600000000000000012
16143	R2	81.2000000000000028	0.00100000000000000002
16143	2Q1	268.100000000000023	0.0229999999999999996
16143	P1	282.399999999999977	0.317000000000000004
16143	L2	79.7999999999999972	0.0100000000000000002
16143	K2	80.2000000000000028	0.0259999999999999988
16143	M8	38.8999999999999986	0.00200000000000000004
16144	M2	149.199999999999989	0.753000000000000003
16144	S2	165.300000000000011	0.106999999999999998
16144	N2	101.700000000000003	0.106999999999999998
16144	K1	215	0.25
16144	O1	234.599999999999994	0.145999999999999991
16144	NU2	108.099999999999994	0.0200000000000000004
16144	2N2	54.2999999999999972	0.0140000000000000003
16144	J1	205.099999999999994	0.0120000000000000002
16144	Q1	244.5	0.0280000000000000006
16144	P1	215.400000000000006	0.0820000000000000034
16144	L2	196.699999999999989	0.0210000000000000013
16144	K2	164.900000000000006	0.0290000000000000015
16145	M2	144.800000000000011	1.53299999999999992
16145	S2	178.099999999999994	0.290999999999999981
16145	N2	134.400000000000006	0.276000000000000023
16145	K1	6.5	0.0990000000000000047
16145	M4	263.600000000000023	0.159000000000000002
16145	O1	5.09999999999999964	0.0439999999999999974
16145	M6	2.20000000000000018	0.129000000000000004
16145	MK3	192.5	0.00899999999999999932
16145	S4	34.2000000000000028	0.0729999999999999954
16145	MN4	267.300000000000011	0.0630000000000000004
16145	NU2	129.599999999999994	0.107999999999999999
16145	S6	165.599999999999994	0.0299999999999999989
16145	MU2	234	0.0690000000000000058
16145	2N2	166	0.0359999999999999973
16145	OO1	160.900000000000006	0.0149999999999999994
16145	LDA2	122.5	0.0589999999999999969
16145	M1	186.800000000000011	0.00800000000000000017
16145	J1	21.6000000000000014	0.0109999999999999994
16145	RHO1	36.7000000000000028	0.00400000000000000008
16145	Q1	83.4000000000000057	0.0179999999999999986
16145	2Q1	120.700000000000003	0.00300000000000000006
16145	P1	23.3000000000000007	0.0459999999999999992
16145	2SM2	246.400000000000006	0.0189999999999999995
16145	M3	153.5	0.0429999999999999966
16145	L2	141.599999999999994	0.105999999999999997
16145	2MK3	102.299999999999997	0.0299999999999999989
16145	K2	173.699999999999989	0.0719999999999999946
16145	M8	93.5999999999999943	0.0379999999999999991
16145	MS4	259.800000000000011	0.086999999999999994
16146	M2	137	0.685000000000000053
16146	S2	125.099999999999994	0.183999999999999997
16146	N2	105.799999999999997	0.169000000000000011
16146	K1	286.100000000000023	0.994999999999999996
16146	M4	241.599999999999994	0.0690000000000000058
16146	O1	280.399999999999977	0.917000000000000037
16146	M6	271.300000000000011	0.00800000000000000017
16146	MK3	333	0.0529999999999999985
16146	MN4	217.800000000000011	0.0280000000000000006
16146	NU2	106.400000000000006	0.0379999999999999991
16146	MU2	28.6999999999999993	0.0420000000000000026
16146	2N2	157.900000000000006	0.0859999999999999931
16146	OO1	292.699999999999989	0.173999999999999988
16146	LDA2	165.300000000000011	0.0340000000000000024
16146	S1	19.8000000000000007	0.00700000000000000015
16146	M1	13.3000000000000007	0.0160000000000000003
16146	J1	65.4000000000000057	0.0410000000000000017
16146	RHO1	295.399999999999977	0.0509999999999999967
16146	Q1	268.100000000000023	0.209999999999999992
16146	T2	142.300000000000011	0.0100000000000000002
16146	R2	329.399999999999977	0.00600000000000000012
16146	2Q1	262.800000000000011	0.0519999999999999976
16146	P1	283.199999999999989	0.241999999999999993
16146	2SM2	111.599999999999994	0.0050000000000000001
16146	M3	354.899999999999977	0.0120000000000000002
16146	L2	212.800000000000011	0.0369999999999999982
16146	2MK3	317.199999999999989	0.0459999999999999992
16146	K2	179.699999999999989	0.165000000000000008
16146	M8	30.3000000000000007	0.0050000000000000001
16146	MS4	232.300000000000011	0.0400000000000000008
16148	M2	152.400000000000006	1.84299999999999997
16148	S2	175.199999999999989	0.325000000000000011
16148	N2	143.199999999999989	0.396000000000000019
16148	K1	44.5	0.143999999999999989
16148	M4	162.900000000000006	0.190000000000000002
16148	O1	53	0.102999999999999994
16148	M6	348.699999999999989	0.0560000000000000012
16148	MK3	354	0.0539999999999999994
16148	MN4	126.5	0.0709999999999999937
16148	NU2	135.199999999999989	0.0690000000000000058
16148	MU2	176.800000000000011	0.0630000000000000004
16148	2N2	130.699999999999989	0.0709999999999999937
16148	OO1	36	0.00400000000000000008
16148	LDA2	131.699999999999989	0.0309999999999999998
16148	S1	351.5	0.0309999999999999998
16148	M1	138.099999999999994	0.0100000000000000002
16148	J1	49.7999999999999972	0.0129999999999999994
16148	MM	193.699999999999989	0.0229999999999999996
16148	SA	325.699999999999989	0.0200000000000000004
16148	MSF	161.199999999999989	0.0140000000000000003
16148	RHO1	56.6000000000000014	0.00400000000000000008
16148	Q1	55.6000000000000014	0.0259999999999999988
16148	T2	158.300000000000011	0.0309999999999999998
16148	R2	77.5	0.0170000000000000012
16148	2Q1	61.3999999999999986	0.00300000000000000006
16148	P1	50.3999999999999986	0.0490000000000000019
16148	2SM2	195.300000000000011	0.0140000000000000003
16148	M3	179.400000000000006	0.0529999999999999985
16148	L2	137.699999999999989	0.0640000000000000013
16148	2MK3	7.70000000000000018	0.0509999999999999967
16148	K2	177.400000000000006	0.0879999999999999949
16148	M8	133.400000000000006	0.0379999999999999991
16148	MS4	157.699999999999989	0.0599999999999999978
16149	M2	5.79999999999999982	34.6409999999999982
16149	S2	31.8999999999999986	10.3780000000000001
16149	N2	324.699999999999989	5.79600000000000026
16149	K1	24	8.22499999999999964
16149	M4	95	0.717999999999999972
16149	O1	2.79999999999999982	4.19500000000000028
16149	M6	335.5	1.69300000000000006
16149	NU2	330.199999999999989	1.12200000000000011
16149	2N2	283.5	0.77300000000000002
16149	LDA2	17.8999999999999986	0.23899999999999999
16149	M1	18.3999999999999986	0.293999999999999984
16149	J1	49.6000000000000014	0.331000000000000016
16149	Q1	347.399999999999977	0.810000000000000053
16149	T2	31.8999999999999986	0.606999999999999984
16149	P1	33.8999999999999986	2.72299999999999986
16149	L2	47	0.92000000000000004
16149	K2	42.2000000000000028	5.37300000000000022
16150	M2	301.800000000000011	2.26500000000000012
16150	S2	324.5	0.591999999999999971
16150	N2	289	0.457000000000000017
16150	K1	48.2000000000000028	0.56899999999999995
16150	M4	57.8999999999999986	0.153999999999999998
16150	O1	47.2999999999999972	0.295999999999999985
16150	M6	344.5	0.0790000000000000008
16150	NU2	290.699999999999989	0.0889999999999999958
16150	2N2	276.300000000000011	0.0609999999999999987
16150	OO1	49.1000000000000014	0.0129999999999999994
16150	LDA2	312.300000000000011	0.0160000000000000003
16150	M1	47.7999999999999972	0.0210000000000000013
16150	J1	48.6000000000000014	0.0229999999999999996
16150	RHO1	46.8999999999999986	0.0109999999999999994
16150	Q1	46.7000000000000028	0.0580000000000000029
16150	T2	324.899999999999977	0.0350000000000000033
16150	P1	48.7999999999999972	0.188
16150	L2	314.5	0.0640000000000000013
16150	K2	323.899999999999977	0.161000000000000004
16150	M8	49.8999999999999986	0.0309999999999999998
16151	M2	198.300000000000011	15.6890000000000001
16151	S2	220.400000000000006	2.79499999999999993
16151	N2	180.5	3.23099999999999987
16151	K1	19.8999999999999986	0.257000000000000006
16151	M4	106.599999999999994	0.566999999999999948
16151	O1	36.2000000000000028	0.5
16151	M6	111	0.474999999999999978
16151	NU2	202.699999999999989	0.421999999999999986
16151	MU2	187	0.369999999999999996
16151	2N2	159.699999999999989	0.418999999999999984
16151	LDA2	192	0.17599999999999999
16151	M1	28.1000000000000014	0.0350000000000000033
16151	J1	11.8000000000000007	0.0389999999999999999
16151	SSA	7.59999999999999964	0.560000000000000053
16151	SA	151.199999999999989	0.387000000000000011
16151	Q1	50	0.127000000000000002
16151	T2	220.599999999999994	0.165000000000000008
16151	P1	52.8999999999999986	0.179999999999999993
16151	L2	220.099999999999994	1.30200000000000005
16151	K2	229	0.731999999999999984
16152	M2	80.2999999999999972	10.0920000000000005
16152	S2	87.0999999999999943	1.89599999999999991
16152	N2	46.7000000000000028	2.94600000000000017
16152	K1	95	2.95800000000000018
16152	M4	31.6999999999999993	0.371999999999999997
16152	O1	96.2999999999999972	1.37400000000000011
16152	M6	151.300000000000011	0.281999999999999973
16152	NU2	48.5	0.552000000000000046
16152	2N2	35.2000000000000028	0.252000000000000002
16152	LDA2	83.5	0.0719999999999999946
16152	M1	93.2000000000000028	0.215999999999999998
16152	J1	94.2999999999999972	0.107999999999999999
16152	Q1	78.4000000000000057	0.215999999999999998
16152	T2	87.4000000000000057	0.114000000000000004
16152	P1	85.7999999999999972	0.971999999999999975
16152	M3	167	0.239999999999999991
16152	L2	278.600000000000023	0.222000000000000003
16152	K2	71.2999999999999972	0.485999999999999988
16154	M2	8	2.46099999999999985
16154	S2	148	0.0410000000000000017
16154	N2	294	0.47699999999999998
16154	K1	191	0.508000000000000007
16154	M4	352	0.35299999999999998
16154	O1	186	0.213999999999999996
16154	M6	261	0.184999999999999998
16154	NU2	304	0.122999999999999998
16154	2N2	218	0.0850000000000000061
16154	LDA2	73	0.0170000000000000012
16154	M1	189	0.0160000000000000003
16154	J1	193	0.0170000000000000012
16154	Q1	183	0.0410000000000000017
16154	P1	192	0.16800000000000001
16154	L2	84	0.0690000000000000058
16154	K2	148	0.0109999999999999994
16154	M8	219	0.0810000000000000026
16157	M2	177.400000000000006	1.81800000000000006
16157	S2	206.300000000000011	0.270000000000000018
16157	N2	140.300000000000011	0.291999999999999982
16157	K1	310.600000000000023	0.101999999999999993
16157	M4	106.400000000000006	0.0800000000000000017
16157	O1	254.900000000000006	0.0739999999999999963
16157	M6	6.90000000000000036	0.0459999999999999992
16157	NU2	145.199999999999989	0.0570000000000000021
16157	MU2	343.100000000000023	0.0700000000000000067
16157	2N2	103.099999999999994	0.0389999999999999999
16157	LDA2	190.800000000000011	0.0129999999999999994
16157	Q1	227	0.0140000000000000003
16157	T2	206.5	0.0160000000000000003
16157	P1	311	0.0340000000000000024
16157	L2	226.5	0.198000000000000009
16157	K2	205	0.0940000000000000002
16159	M2	198	1.28000000000000003
16159	S2	183.599999999999994	0.555000000000000049
16159	N2	182.699999999999989	0.28999999999999998
16159	K1	11.4000000000000004	0.406999999999999973
16159	M4	179.099999999999994	0.0539999999999999994
16159	O1	359.5	0.252000000000000002
16159	NU2	184.800000000000011	0.0560000000000000012
16159	2N2	167.5	0.0389999999999999999
16159	OO1	23.3000000000000007	0.0109999999999999994
16159	M1	5.5	0.0179999999999999986
16159	J1	17.3999999999999986	0.0200000000000000004
16159	Q1	353.399999999999977	0.0490000000000000019
16159	T2	183.900000000000006	0.0330000000000000016
16159	P1	12.0999999999999996	0.135000000000000009
16159	L2	213.199999999999989	0.0359999999999999973
16159	K2	182.900000000000006	0.150999999999999995
16162	M2	174	1.9830000000000001
16162	S2	195.599999999999994	0.270000000000000018
16162	N2	157.900000000000006	0.405000000000000027
16162	K1	44.3999999999999986	0.141999999999999987
16162	M4	253.699999999999989	0.13600000000000001
16162	O1	68.7000000000000028	0.133000000000000007
16162	M6	15.0999999999999996	0.105999999999999997
16162	MK3	77.5999999999999943	0.0229999999999999996
16162	S4	66.2999999999999972	0.0160000000000000003
16162	MN4	189.699999999999989	0.0359999999999999973
16162	NU2	110.700000000000003	0.113000000000000003
16162	2N2	112.700000000000003	0.0149999999999999994
16162	OO1	312.300000000000011	0.0189999999999999995
16162	LDA2	34.5	0.0389999999999999999
16162	M1	101	0.0170000000000000012
16162	J1	94.5999999999999943	0.0100000000000000002
16162	RHO1	79.0999999999999943	0.0050000000000000001
16162	Q1	58.6000000000000014	0.0449999999999999983
16162	T2	194.699999999999989	0.0160000000000000003
16162	R2	196.5	0.00200000000000000004
16162	2Q1	92.7000000000000028	0.00300000000000000006
16162	P1	28.8000000000000007	0.0470000000000000001
16162	2SM2	301.199999999999989	0.0229999999999999996
16162	M3	242.300000000000011	0.0660000000000000031
16162	L2	156.099999999999994	0.102999999999999994
16162	K2	174.300000000000011	0.0970000000000000029
16162	M8	312	0.0210000000000000013
16162	MS4	269.899999999999977	0.0359999999999999973
16163	M2	212	2.00800000000000001
16163	S2	229.5	0.235999999999999988
16163	N2	188.199999999999989	0.401000000000000023
16163	K1	80.5999999999999943	0.209999999999999992
16163	M4	81.4000000000000057	0.131000000000000005
16163	O1	103.200000000000003	0.172999999999999987
16163	M6	148.900000000000006	0.114000000000000004
16163	MK3	261	0.0189999999999999995
16163	S4	31.6999999999999993	0.0250000000000000014
16163	MN4	81.5999999999999943	0.0350000000000000033
16163	NU2	190.5	0.0739999999999999963
16163	MU2	273.300000000000011	0.0259999999999999988
16163	2N2	164.400000000000006	0.0529999999999999985
16163	OO1	32.7000000000000028	0.0229999999999999996
16163	LDA2	253.300000000000011	0.0690000000000000058
16163	M1	91.9000000000000057	0.0120000000000000002
16163	J1	56	0.0120000000000000002
16163	RHO1	180.900000000000006	0.0210000000000000013
16163	Q1	90.7000000000000028	0.0330000000000000016
16163	T2	228.800000000000011	0.0140000000000000003
16163	R2	230.199999999999989	0.00200000000000000004
16163	2Q1	290.300000000000011	0.0129999999999999994
16163	P1	89.4000000000000057	0.0759999999999999981
16163	2SM2	204.800000000000011	0.0259999999999999988
16163	M3	332.5	0.0280000000000000006
16163	L2	228.199999999999989	0.140000000000000013
16163	2MK3	291.899999999999977	0.0320000000000000007
16163	K2	251.699999999999989	0.100000000000000006
16163	M8	72.5	0.0269999999999999997
16163	MS4	164.5	0.0389999999999999999
16165	M2	337.600000000000023	1.04499999999999993
16165	S2	343.899999999999977	0.367999999999999994
16165	N2	333.899999999999977	0.187
16165	K1	250.699999999999989	0.610999999999999988
16165	M4	14.4000000000000004	0.0429999999999999966
16165	O1	247.099999999999994	0.515000000000000013
16165	MK3	261.199999999999989	0.0420000000000000026
16165	S4	281	0.0200000000000000004
16165	MN4	21.3999999999999986	0.0149999999999999994
16165	NU2	351.399999999999977	0.0359999999999999973
16165	MU2	205.199999999999989	0.0400000000000000008
16165	2N2	330.199999999999989	0.0250000000000000014
16165	OO1	254.199999999999989	0.0219999999999999987
16165	LDA2	42.2999999999999972	0.0299999999999999989
16165	S1	329	0.0779999999999999999
16165	M1	248.900000000000006	0.0369999999999999982
16165	J1	248.900000000000006	0.0299999999999999989
16165	RHO1	245.599999999999994	0.0200000000000000004
16165	Q1	246.400000000000006	0.101999999999999993
16165	T2	344.100000000000023	0.0219999999999999987
16165	R2	343.699999999999989	0.00300000000000000006
16165	2Q1	243.599999999999994	0.0129999999999999994
16165	P1	251.400000000000006	0.190000000000000002
16165	2SM2	256	0.0299999999999999989
16165	M3	120.099999999999994	0.0129999999999999994
16165	L2	3.20000000000000018	0.0509999999999999967
16165	2MK3	277.199999999999989	0.0389999999999999999
16165	K2	345.899999999999977	0.145999999999999991
16165	MS4	0.400000000000000022	0.0269999999999999997
16171	M2	326	0.606999999999999984
16171	S2	9.59999999999999964	0.0640000000000000013
16171	N2	302.600000000000023	0.117000000000000007
16171	K1	100.799999999999997	0.19900000000000001
16171	O1	123.900000000000006	0.107999999999999999
16171	NU2	305.699999999999989	0.0229999999999999996
16171	2N2	279.199999999999989	0.0160000000000000003
16171	Q1	135.5	0.0210000000000000013
16171	P1	101.099999999999994	0.0660000000000000031
16171	L2	349.399999999999977	0.0170000000000000012
16171	K2	9.30000000000000071	0.0179999999999999986
25446	M2	301.800000000000011	2.50800000000000001
25446	S2	330.300000000000011	0.85299999999999998
25446	N2	282.199999999999989	0.456000000000000016
25446	K1	38.3999999999999986	0.284999999999999976
25446	M4	266.399999999999977	0.359999999999999987
25446	O1	10.6999999999999993	0.14499999999999999
25446	M6	281.899999999999977	0.076999999999999999
25446	S4	48.1000000000000014	0.0219999999999999987
25446	NU2	284.800000000000011	0.0879999999999999949
25446	S6	128.900000000000006	0.00700000000000000015
25446	2N2	262.5	0.0609999999999999987
25446	OO1	66	0.00600000000000000012
25446	LDA2	315.100000000000023	0.0179999999999999986
25446	M1	24.5	0.0100000000000000002
25446	J1	52.1000000000000014	0.0109999999999999994
25446	RHO1	358.899999999999977	0.0050000000000000001
25446	Q1	357	0.0280000000000000006
25446	T2	329.199999999999989	0.0500000000000000028
25446	R2	331.5	0.00700000000000000015
25446	2Q1	343.300000000000011	0.00400000000000000008
25446	P1	36.2999999999999972	0.0940000000000000002
25446	L2	272.399999999999977	0.0650000000000000022
25446	K2	332.600000000000023	0.232000000000000012
25446	M8	350.5	0.086999999999999994
60135	M2	44.1000000000000014	0.52200000000000002
60135	S2	38.2999999999999972	0.216999999999999998
60135	N2	38.2999999999999972	0.0980000000000000038
60135	K1	226.5	0.538000000000000034
60135	O1	221.5	0.281999999999999973
60135	NU2	25.1999999999999993	0.0160000000000000003
60135	MU2	356	0.0129999999999999994
60135	2N2	45	0.0100000000000000002
60135	OO1	263.100000000000023	0.0229999999999999996
60135	LDA2	41.3999999999999986	0.00300000000000000006
60135	M1	247.199999999999989	0.0160000000000000003
60135	J1	237.599999999999994	0.0359999999999999973
60135	SA	192.099999999999994	0.161000000000000004
60135	RHO1	219.400000000000006	0.0100000000000000002
60135	Q1	215.699999999999989	0.0490000000000000019
60135	T2	38.2000000000000028	0.0160000000000000003
60135	R2	38.1000000000000014	0.00300000000000000006
60135	2Q1	216.400000000000006	0.00700000000000000015
60135	P1	223.300000000000011	0.16700000000000001
60135	L2	35.1000000000000014	0.0129999999999999994
60135	K2	34	0.0619999999999999996
60136	M2	48.2999999999999972	0.48899999999999999
60136	S2	45.7999999999999972	0.179999999999999993
60136	N2	38.7999999999999972	0.0919999999999999984
60136	K1	229.900000000000006	0.481999999999999984
60136	M4	203.800000000000011	0.0129999999999999994
60136	O1	221.800000000000011	0.276000000000000023
60136	NU2	40.7000000000000028	0.0160000000000000003
60136	MU2	354.600000000000023	0.0160000000000000003
60136	2N2	39.7000000000000028	0.0100000000000000002
60136	OO1	258.5	0.0229999999999999996
60136	LDA2	47.1000000000000014	0.00300000000000000006
60136	M1	253.900000000000006	0.0160000000000000003
60136	J1	245.800000000000011	0.0299999999999999989
60136	SA	193.099999999999994	0.138000000000000012
60136	RHO1	221.400000000000006	0.0100000000000000002
60136	Q1	213.800000000000011	0.0429999999999999966
60136	T2	45.7999999999999972	0.0100000000000000002
60136	2Q1	213.800000000000011	0.00700000000000000015
60136	P1	227.099999999999994	0.147999999999999993
60136	L2	48	0.0129999999999999994
60136	K2	32.8999999999999986	0.0490000000000000019
60137	M2	59.5	0.583999999999999964
60137	S2	53.7999999999999972	0.187
60137	N2	49.5	0.112000000000000002
60137	K1	227	0.518000000000000016
60137	O1	215.699999999999989	0.284999999999999976
60137	NU2	60.7999999999999972	0.0200000000000000004
60137	MU2	8.80000000000000071	0.0160000000000000003
60137	2N2	37.6000000000000014	0.0129999999999999994
60137	OO1	252.800000000000011	0.0200000000000000004
60137	LDA2	56.8999999999999986	0.00300000000000000006
60137	M1	240.300000000000011	0.0160000000000000003
60137	J1	239.5	0.0330000000000000016
60137	SA	191.5	0.131000000000000005
60137	MF	48.2000000000000028	0.0229999999999999996
60137	RHO1	211	0.0100000000000000002
60137	Q1	208.300000000000011	0.0459999999999999992
60137	T2	53.8999999999999986	0.0100000000000000002
60137	2Q1	204.599999999999994	0.00700000000000000015
60137	P1	226.199999999999989	0.157000000000000001
60137	L2	69.2999999999999972	0.0160000000000000003
60137	K2	47.8999999999999986	0.0519999999999999976
60138	M2	64.0999999999999943	0.525000000000000022
60138	S2	57.5	0.179999999999999993
60138	N2	50.1000000000000014	0.104999999999999996
60138	K1	223.599999999999994	0.505000000000000004
60138	M4	268.100000000000023	0.0129999999999999994
60138	O1	215.900000000000006	0.266000000000000014
60138	S4	42.2000000000000028	0.00300000000000000006
60138	NU2	52	0.0200000000000000004
60138	S6	264.800000000000011	0.00300000000000000006
60138	MU2	114.700000000000003	0.0129999999999999994
60138	2N2	35.6000000000000014	0.0129999999999999994
60138	OO1	231.300000000000011	0.0100000000000000002
60138	LDA2	61	0.00300000000000000006
60138	M1	219.800000000000011	0.0200000000000000004
60138	J1	227.400000000000006	0.0200000000000000004
60138	SA	191.5	0.131000000000000005
60138	MF	48.2000000000000028	0.0229999999999999996
60138	RHO1	212.599999999999994	0.0100000000000000002
60138	Q1	212.099999999999994	0.0519999999999999976
60138	T2	57.7999999999999972	0.0100000000000000002
60138	2Q1	208.300000000000011	0.00700000000000000015
60138	P1	223	0.16700000000000001
60138	L2	77.7999999999999972	0.0129999999999999994
60138	K2	57	0.0490000000000000019
60138	M8	334.5	0.00300000000000000006
60139	M2	64.9000000000000057	0.535000000000000031
60139	S2	58.3999999999999986	0.183999999999999997
60139	N2	50.1000000000000014	0.104999999999999996
60139	K1	223.699999999999989	0.505000000000000004
60139	M4	286.600000000000023	0.0129999999999999994
60139	O1	215.5	0.266000000000000014
60139	S4	35	0.00300000000000000006
60139	NU2	52.1000000000000014	0.0200000000000000004
60139	S6	282.399999999999977	0.00300000000000000006
60139	MU2	115.5	0.0129999999999999994
60139	2N2	34.7999999999999972	0.0129999999999999994
60139	OO1	232	0.0100000000000000002
60139	LDA2	61.8999999999999986	0.00300000000000000006
60139	M1	219.699999999999989	0.0200000000000000004
60139	J1	227.900000000000006	0.0200000000000000004
60139	SA	191.5	0.131000000000000005
60139	RHO1	212	0.0100000000000000002
60139	Q1	211.400000000000006	0.0519999999999999976
60139	T2	58.7000000000000028	0.0100000000000000002
60139	2Q1	207.199999999999989	0.00700000000000000015
60139	P1	223.099999999999994	0.16700000000000001
60139	L2	79.5999999999999943	0.0160000000000000003
60139	K2	57.8999999999999986	0.0490000000000000019
60139	M8	17	0.00300000000000000006
60140	M2	13.9000000000000004	0.528000000000000025
60140	S2	15.5	0.262000000000000011
60140	N2	9.80000000000000071	0.107999999999999999
60140	K1	236.400000000000006	0.580999999999999961
60140	O1	227.199999999999989	0.328000000000000014
60140	NU2	24.5	0.0200000000000000004
60140	MU2	339.699999999999989	0.0229999999999999996
60140	2N2	358.699999999999989	0.0129999999999999994
60140	OO1	266.600000000000023	0.0229999999999999996
60140	LDA2	14.5999999999999996	0.00300000000000000006
60140	M1	258.699999999999989	0.0200000000000000004
60140	J1	253.099999999999994	0.0330000000000000016
60140	RHO1	231.800000000000011	0.0100000000000000002
60140	Q1	220.900000000000006	0.0519999999999999976
60140	T2	36.2999999999999972	0.0200000000000000004
60140	R2	15.5999999999999996	0.00300000000000000006
60140	2Q1	218.099999999999994	0.0100000000000000002
60140	P1	232.800000000000011	0.176999999999999991
60140	L2	8	0.0160000000000000003
60140	K2	6	0.0749999999999999972
60141	M2	55.8999999999999986	0.603999999999999981
60141	S2	59.6000000000000014	0.220000000000000001
60141	N2	44	0.112000000000000002
60141	K1	227.699999999999989	0.525000000000000022
60141	M4	227.300000000000011	0.00700000000000000015
60141	O1	216.5	0.291999999999999982
60141	S4	157.599999999999994	0.00300000000000000006
60141	MN4	148.599999999999994	0.00300000000000000006
60141	NU2	43.7999999999999972	0.0200000000000000004
60141	MU2	15.0999999999999996	0.0200000000000000004
60141	2N2	49.1000000000000014	0.0160000000000000003
60141	OO1	243.099999999999994	0.0160000000000000003
60141	LDA2	61.3999999999999986	0.0100000000000000002
60141	S1	149.900000000000006	0.00700000000000000015
60141	M1	227.5	0.0200000000000000004
60141	J1	236.800000000000011	0.0330000000000000016
60141	SA	181.5	0.131000000000000005
60141	MF	48.2000000000000028	0.0229999999999999996
60141	RHO1	171.699999999999989	0.00700000000000000015
60141	Q1	218.699999999999989	0.0429999999999999966
60141	T2	38.7999999999999972	0.0229999999999999996
60141	R2	59	0.0259999999999999988
60141	2Q1	245.699999999999989	0.00700000000000000015
60141	P1	222.800000000000011	0.16700000000000001
60141	2SM2	174.300000000000011	0.00300000000000000006
60141	M3	180.400000000000006	0.00300000000000000006
60141	L2	88.4000000000000057	0.0100000000000000002
60141	2MK3	86.0999999999999943	0.00300000000000000006
60141	K2	56.2999999999999972	0.0589999999999999969
60142	M2	8.59999999999999964	0.61399999999999999
60142	S2	15.5	0.322000000000000008
60142	N2	0.599999999999999978	0.115000000000000005
60142	K1	233.400000000000006	0.567999999999999949
60142	O1	220.099999999999994	0.322000000000000008
60142	NU2	4.29999999999999982	0.0200000000000000004
60142	MU2	342.399999999999977	0.0259999999999999988
60142	2N2	355.100000000000023	0.0160000000000000003
60142	OO1	251.800000000000011	0.0229999999999999996
60142	LDA2	11.8000000000000007	0.00300000000000000006
60142	M1	254.800000000000011	0.0200000000000000004
60142	J1	239.199999999999989	0.0359999999999999973
60142	SA	199.5	0.125
60142	MF	34.7000000000000028	0.0200000000000000004
60142	RHO1	221	0.0129999999999999994
60142	Q1	210.099999999999994	0.0490000000000000019
60142	T2	13.1999999999999993	0.0200000000000000004
60142	R2	15.8000000000000007	0.00300000000000000006
60142	2Q1	207	0.00700000000000000015
60142	P1	230.199999999999989	0.176999999999999991
60142	L2	0.599999999999999978	0.0160000000000000003
60142	K2	8.80000000000000071	0.0919999999999999984
60143	M2	58.2000000000000028	0.656000000000000028
60143	S2	64.0999999999999943	0.212999999999999995
60143	N2	49.6000000000000014	0.117999999999999994
60143	K1	226.300000000000011	0.518000000000000016
60143	O1	214	0.291999999999999982
60143	NU2	57.3999999999999986	0.0200000000000000004
60143	MU2	23	0.0160000000000000003
60143	2N2	48.7999999999999972	0.0160000000000000003
60143	OO1	259.300000000000011	0.0200000000000000004
60143	LDA2	60.8999999999999986	0.00700000000000000015
60143	S1	217.099999999999994	0.0129999999999999994
60143	M1	250.300000000000011	0.0160000000000000003
60143	J1	240.900000000000006	0.0299999999999999989
60143	MF	32.7999999999999972	0.0259999999999999988
60143	RHO1	208.699999999999989	0.0100000000000000002
60143	Q1	204.300000000000011	0.0429999999999999966
60143	T2	79.2000000000000028	0.0160000000000000003
60143	R2	64.4000000000000057	0.00300000000000000006
60143	2Q1	201.800000000000011	0.00700000000000000015
60143	P1	223.699999999999989	0.161000000000000004
60143	L2	53.3999999999999986	0.0160000000000000003
60143	K2	55.6000000000000014	0.0660000000000000031
60144	M2	29.3999999999999986	0.755000000000000004
60144	S2	34.1000000000000014	0.301999999999999991
60144	N2	21.3999999999999986	0.143999999999999989
60144	K1	233.400000000000006	0.548000000000000043
60144	O1	223.199999999999989	0.301999999999999991
60144	NU2	23.1000000000000014	0.0299999999999999989
60144	MU2	358.300000000000011	0.0259999999999999988
60144	2N2	13.5999999999999996	0.0200000000000000004
60144	OO1	263	0.0229999999999999996
60144	LDA2	31.6000000000000014	0.00700000000000000015
60144	S1	222.900000000000006	0.0100000000000000002
60144	M1	252	0.0160000000000000003
60144	J1	245.300000000000011	0.0359999999999999973
60144	SA	208.199999999999989	0.140999999999999986
60144	MF	38	0.0229999999999999996
60144	RHO1	218.800000000000011	0.0100000000000000002
60144	Q1	213.199999999999989	0.0519999999999999976
60144	T2	33	0.0200000000000000004
60144	R2	34.2999999999999972	0.00300000000000000006
60144	2Q1	213.099999999999994	0.00700000000000000015
60144	P1	231.800000000000011	0.16700000000000001
60144	L2	23.1000000000000014	0.0160000000000000003
60144	K2	26.1999999999999993	0.0919999999999999984
60145	M2	100.400000000000006	0.889000000000000012
60145	S2	122.099999999999994	0.343999999999999972
60145	N2	99.7999999999999972	0.164000000000000007
60145	K1	214.800000000000011	0.269000000000000017
60145	O1	223.900000000000006	0.115000000000000005
60145	NU2	96.5	0.0299999999999999989
60145	MU2	106	0.0200000000000000004
60145	2N2	95.0999999999999943	0.0229999999999999996
60145	OO1	239.099999999999994	0.0129999999999999994
60145	LDA2	110.400000000000006	0.00700000000000000015
60145	S1	250.900000000000006	0.0129999999999999994
60145	M1	219.300000000000011	0.00700000000000000015
60145	J1	223.800000000000011	0.0200000000000000004
60145	SA	204.300000000000011	0.176999999999999991
60145	MF	30.3999999999999986	0.0299999999999999989
60145	RHO1	227.800000000000011	0.00300000000000000006
60145	Q1	229.099999999999994	0.0160000000000000003
60145	T2	129.300000000000011	0.0299999999999999989
60145	R2	122.900000000000006	0.00300000000000000006
60145	2Q1	232.900000000000006	0.00300000000000000006
60145	P1	212.199999999999989	0.0790000000000000008
60145	L2	93.9000000000000057	0.0229999999999999996
60145	K2	117.900000000000006	0.0919999999999999984
60145	MS4	13.8000000000000007	0.0100000000000000002
60146	M2	92.5	0.404000000000000026
60146	S2	167.300000000000011	0.0690000000000000058
60146	N2	57.1000000000000014	0.0790000000000000008
60146	K1	274.800000000000011	0.248999999999999999
60146	O1	278.300000000000011	0.187
60146	NU2	66.0999999999999943	0.0160000000000000003
60146	2N2	21.6999999999999993	0.0100000000000000002
60146	OO1	282.300000000000011	0.0100000000000000002
60146	LDA2	127.200000000000003	0.00300000000000000006
60146	M1	299.899999999999977	0.0129999999999999994
60146	J1	273.699999999999989	0.0129999999999999994
60146	SSA	287.800000000000011	0.115000000000000005
60146	SA	232.5	0.128000000000000003
60146	RHO1	279.800000000000011	0.00700000000000000015
60146	Q1	283.399999999999977	0.0359999999999999973
60146	T2	164.300000000000011	0.00300000000000000006
60146	2Q1	295.199999999999989	0.0100000000000000002
60146	P1	273.800000000000011	0.0790000000000000008
60146	M3	244.5	0.0100000000000000002
60146	L2	130.800000000000011	0.0100000000000000002
60146	K2	174.400000000000006	0.0200000000000000004
60147	M2	290.899999999999977	0.76100000000000001
60147	S2	311.100000000000023	0.194000000000000006
60147	N2	276.300000000000011	0.157000000000000001
60147	K1	65.0999999999999943	0.567999999999999949
60147	M4	151.599999999999994	0.0160000000000000003
60147	O1	44.2000000000000028	0.400000000000000022
60147	NU2	276.399999999999977	0.0359999999999999973
60147	MU2	294	0.0160000000000000003
60147	2N2	251.300000000000011	0.0200000000000000004
60147	OO1	92.2999999999999972	0.0229999999999999996
60147	LDA2	300.199999999999989	0.00700000000000000015
60147	S1	221.300000000000011	0.0100000000000000002
60147	M1	79.0999999999999943	0.0259999999999999988
60147	J1	84.2000000000000028	0.0359999999999999973
60147	MF	13.0999999999999996	0.0330000000000000016
60147	RHO1	29.3000000000000007	0.0160000000000000003
60147	Q1	34.2000000000000028	0.0820000000000000034
60147	T2	285.300000000000011	0.0160000000000000003
60147	2Q1	23.5	0.0100000000000000002
60147	P1	64.2000000000000028	0.183999999999999997
60147	L2	326.699999999999989	0.0229999999999999996
60147	K2	308.5	0.0519999999999999976
60147	MS4	202.900000000000006	0.0129999999999999994
60148	M2	276.199999999999989	0.466000000000000025
60148	S2	282.899999999999977	0.0850000000000000061
60148	N2	253.400000000000006	0.117999999999999994
60148	K1	61.2999999999999972	0.463000000000000023
60148	M4	119.299999999999997	0.0100000000000000002
60148	O1	42.6000000000000014	0.33500000000000002
60148	MK3	325.100000000000023	0.00700000000000000015
60148	S4	227.199999999999989	0.00300000000000000006
60148	MN4	101.599999999999994	0.00700000000000000015
60148	NU2	300.399999999999977	0.0200000000000000004
60148	MU2	171.099999999999994	0.00300000000000000006
60148	2N2	209.900000000000006	0.0129999999999999994
60148	OO1	95.7999999999999972	0.0160000000000000003
60148	LDA2	295.300000000000011	0.00700000000000000015
60148	S1	267	0.0259999999999999988
60148	M1	90.5	0.0160000000000000003
60148	J1	90.5	0.0299999999999999989
60148	MF	355.199999999999989	0.0429999999999999966
60148	RHO1	37.2999999999999972	0.0129999999999999994
60148	Q1	33.8999999999999986	0.0619999999999999996
60148	T2	27.5	0.0100000000000000002
60148	R2	190.900000000000006	0.0129999999999999994
60148	2Q1	31.6999999999999993	0.00300000000000000006
60148	P1	62.7999999999999972	0.147999999999999993
60148	2SM2	205.300000000000011	0.00300000000000000006
60148	M3	38.7999999999999972	0.0129999999999999994
60148	L2	43.5	0.00300000000000000006
60148	2MK3	267.100000000000023	0.00300000000000000006
60148	K2	265.5	0.0259999999999999988
60148	M8	343.5	0.00300000000000000006
60148	MS4	168.300000000000011	0.0100000000000000002
60149	M2	296.199999999999989	0.616999999999999993
60149	S2	305.300000000000011	0.140999999999999986
60149	N2	278.899999999999977	0.150999999999999995
60149	K1	64.9000000000000057	0.548000000000000043
60149	M4	242.400000000000006	0.00300000000000000006
60149	O1	45.6000000000000014	0.370999999999999996
60149	MK3	272.100000000000023	0.00300000000000000006
60149	S4	189.699999999999989	0.00700000000000000015
60149	MN4	130.300000000000011	0.00300000000000000006
60149	NU2	287.399999999999977	0.0259999999999999988
60149	S6	279.199999999999989	0.00300000000000000006
60149	MU2	283.199999999999989	0.0129999999999999994
60149	2N2	228.599999999999994	0.0200000000000000004
60149	OO1	110.599999999999994	0.0160000000000000003
60149	LDA2	334	0.0100000000000000002
60149	S1	80.4000000000000057	0.0229999999999999996
60149	M1	59.5	0.0160000000000000003
60149	J1	70.9000000000000057	0.0389999999999999999
60149	RHO1	21.3999999999999986	0.0160000000000000003
60149	Q1	33.2999999999999972	0.0820000000000000034
60149	T2	280.100000000000023	0.0160000000000000003
60149	R2	108.700000000000003	0.0229999999999999996
60149	2Q1	38	0.0129999999999999994
60149	P1	66.7000000000000028	0.200000000000000011
60149	2SM2	161.5	0.00300000000000000006
60149	M3	350.300000000000011	0.00700000000000000015
60149	L2	316.399999999999977	0.0160000000000000003
60149	K2	300.699999999999989	0.0490000000000000019
60149	MS4	261.600000000000023	0.0100000000000000002
60150	M2	180.199999999999989	1.21999999999999997
60150	S2	163.800000000000011	0.197000000000000008
60150	N2	161.300000000000011	0.341000000000000025
60150	K1	83.5	0.135000000000000009
60150	O1	66.4000000000000057	0.0919999999999999984
60150	NU2	165.099999999999994	0.0660000000000000031
60150	MU2	138.300000000000011	0.0589999999999999969
60150	2N2	140.699999999999989	0.0519999999999999976
60150	OO1	100.700000000000003	0.00300000000000000006
60150	LDA2	172.599999999999994	0.0100000000000000002
60150	M1	75	0.00700000000000000015
60150	J1	92	0.00700000000000000015
60150	MM	10.1999999999999993	0.0160000000000000003
60150	MF	23.5	0.0299999999999999989
60150	RHO1	59.1000000000000014	0.00300000000000000006
60150	Q1	47.6000000000000014	0.0160000000000000003
60150	T2	164.599999999999994	0.0129999999999999994
60150	R2	163	0.00300000000000000006
60150	2Q1	49.3999999999999986	0.00300000000000000006
60150	P1	71.0999999999999943	0.0389999999999999999
60150	M3	15.8000000000000007	0.0129999999999999994
60150	L2	186.5	0.0129999999999999994
60150	K2	158.199999999999989	0.0560000000000000012
60151	M2	127.400000000000006	1.59099999999999997
60151	S2	149.300000000000011	0.883000000000000007
60151	N2	127.099999999999994	0.301999999999999991
60151	K1	66	0.341000000000000025
60151	O1	38.7000000000000028	0.212999999999999995
60151	NU2	125.099999999999994	0.0560000000000000012
60151	MU2	127.900000000000006	0.0519999999999999976
60151	2N2	122.900000000000006	0.0429999999999999966
60151	OO1	125.200000000000003	0.0129999999999999994
60151	LDA2	123.599999999999994	0.0129999999999999994
60151	S1	275	0.0100000000000000002
60151	M1	72.4000000000000057	0.0129999999999999994
60151	J1	90.7999999999999972	0.0200000000000000004
60151	MM	12.9000000000000004	0.0229999999999999996
60151	MF	19.8999999999999986	0.0359999999999999973
60151	RHO1	27	0.00700000000000000015
60151	Q1	22.6000000000000014	0.0429999999999999966
60151	T2	149.699999999999989	0.0589999999999999969
60151	R2	150.199999999999989	0.00700000000000000015
60151	2Q1	11.6999999999999993	0.00700000000000000015
60151	P1	65.4000000000000057	0.104999999999999996
60151	L2	126.599999999999994	0.0490000000000000019
60151	K2	145.900000000000006	0.23899999999999999
60152	M2	129.199999999999989	0.235999999999999988
60152	S2	147.5	0.343999999999999972
60152	N2	185	0.0519999999999999976
60152	K1	64.7999999999999972	0.616999999999999993
60152	O1	44	0.390000000000000013
60152	NU2	177.400000000000006	0.0100000000000000002
60152	MU2	133.400000000000006	0.0200000000000000004
60152	2N2	240.699999999999989	0.00700000000000000015
60152	OO1	85.5999999999999943	0.0160000000000000003
60152	LDA2	137.699999999999989	0.00300000000000000006
60152	S1	253	0.0129999999999999994
60152	M1	54.3999999999999986	0.0299999999999999989
60152	J1	81.2000000000000028	0.0359999999999999973
60152	SSA	25.6999999999999993	0.104999999999999996
60152	SA	62.6000000000000014	0.107999999999999999
60152	MF	16.6999999999999993	0.0429999999999999966
60152	RHO1	35.1000000000000014	0.0129999999999999994
60152	Q1	34.2000000000000028	0.0749999999999999972
60152	T2	147.5	0.0200000000000000004
60152	R2	147.400000000000006	0.00300000000000000006
60152	2Q1	23.1999999999999993	0.0100000000000000002
60152	P1	64.2000000000000028	0.200000000000000011
60152	M3	30.6000000000000014	0.0129999999999999994
60152	L2	73.5999999999999943	0.00700000000000000015
60152	K2	143.199999999999989	0.0980000000000000038
60153	M2	115.099999999999994	0.944999999999999951
60153	S2	150.099999999999994	0.478999999999999981
60153	N2	106.400000000000006	0.157000000000000001
60153	K1	45.1000000000000014	0.20699999999999999
60153	O1	14.6999999999999993	0.16700000000000001
60153	NU2	102.700000000000003	0.0299999999999999989
60153	MU2	129.400000000000006	0.0229999999999999996
60153	2N2	104.700000000000003	0.0200000000000000004
60153	OO1	75.4000000000000057	0.00700000000000000015
60153	LDA2	119.799999999999997	0.0100000000000000002
60153	M1	29.8999999999999986	0.0100000000000000002
60153	J1	85	0.0100000000000000002
60153	SA	165.5	0.183999999999999997
60153	MF	14.3000000000000007	0.0200000000000000004
60153	RHO1	1.69999999999999996	0.00700000000000000015
60153	Q1	3.89999999999999991	0.0429999999999999966
60153	T2	135.300000000000011	0.0330000000000000016
60153	R2	151.5	0.00300000000000000006
60153	2Q1	344.600000000000023	0.00300000000000000006
60153	P1	43.6000000000000014	0.0660000000000000031
60153	M3	313	0.0129999999999999994
60153	L2	121.700000000000003	0.0299999999999999989
60153	K2	144	0.138000000000000012
60154	M2	98.7000000000000028	8.81600000000000072
60154	S2	139.300000000000011	1.37799999999999989
60154	N2	69.4000000000000057	1.78099999999999992
60154	K1	196.400000000000006	0.512000000000000011
60154	M4	86.5	0.197000000000000008
60154	O1	176.900000000000006	0.390000000000000013
60154	M6	277.199999999999989	0.16700000000000001
60154	MN4	55.7999999999999972	0.0749999999999999972
60154	NU2	73.5	0.412999999999999978
60154	MU2	163.900000000000006	0.0660000000000000031
60154	2N2	46.5	0.212999999999999995
60154	OO1	230.599999999999994	0.0160000000000000003
60154	LDA2	122.799999999999997	0.173999999999999988
60154	S1	110.200000000000003	0.0330000000000000016
60154	M1	206.800000000000011	0.0200000000000000004
60154	J1	208.599999999999994	0.0299999999999999989
60154	SSA	127.599999999999994	0.0519999999999999976
60154	RHO1	154	0.0100000000000000002
60154	Q1	163	0.0660000000000000031
60154	T2	115.799999999999997	0.120999999999999996
60154	R2	356.5	0.0299999999999999989
60154	2Q1	157.5	0.0100000000000000002
60154	P1	195.5	0.171000000000000013
60154	2SM2	83.9000000000000057	0.0160000000000000003
60154	L2	134.5	0.443000000000000005
60154	2MK3	331.600000000000023	0.0160000000000000003
60154	K2	138.300000000000011	0.381000000000000005
60154	M8	253.699999999999989	0.0160000000000000003
60154	MS4	131.900000000000006	0.0589999999999999969
60155	M2	117.299999999999997	7.93299999999999983
60155	S2	161.400000000000006	1.17799999999999994
60155	N2	94.5999999999999943	1.57200000000000006
60155	K1	216.099999999999994	0.475999999999999979
60155	M4	136.199999999999989	0.256000000000000005
60155	O1	192.300000000000011	0.370999999999999996
60155	M6	339.699999999999989	0.331000000000000016
60155	S4	314.600000000000023	0.0100000000000000002
60155	NU2	97.5999999999999943	0.304999999999999993
60155	S6	251.199999999999989	0.0129999999999999994
60155	MU2	299	0.190000000000000002
60155	2N2	71.7999999999999972	0.209999999999999992
60155	OO1	240.099999999999994	0.0160000000000000003
60155	LDA2	137.800000000000011	0.0560000000000000012
60155	M1	204.300000000000011	0.0259999999999999988
60155	J1	228	0.0299999999999999989
60155	SSA	127.599999999999994	0.0519999999999999976
60155	RHO1	182	0.0129999999999999994
60155	Q1	180.400000000000006	0.0719999999999999946
60155	T2	159.699999999999989	0.0690000000000000058
60155	R2	163.199999999999989	0.0100000000000000002
60155	2Q1	168.5	0.0100000000000000002
60155	P1	214.300000000000011	0.157000000000000001
60155	L2	140	0.223000000000000004
60155	K2	165	0.322000000000000008
60155	M8	329.699999999999989	0.0429999999999999966
60156	M2	106.700000000000003	8.9659999999999993
60156	S2	147	1.45999999999999996
60156	N2	83.7999999999999972	1.85400000000000009
60156	K1	202	0.528000000000000025
60156	M4	97.2999999999999972	0.245999999999999996
60156	O1	180.300000000000011	0.404000000000000026
60156	M6	311.399999999999977	0.266000000000000014
60156	S4	271.800000000000011	0.00700000000000000015
60156	NU2	86.9000000000000057	0.360999999999999988
60156	S6	205.5	0.00700000000000000015
60156	MU2	292	0.216999999999999998
60156	2N2	61	0.245999999999999996
60156	OO1	223.599999999999994	0.0160000000000000003
60156	LDA2	125.400000000000006	0.0619999999999999996
60156	M1	191.199999999999989	0.0299999999999999989
60156	J1	212.699999999999989	0.0330000000000000016
60156	SSA	127.599999999999994	0.0519999999999999976
60156	RHO1	170.900000000000006	0.0160000000000000003
60156	Q1	169.5	0.0790000000000000008
60156	T2	145.400000000000006	0.0850000000000000061
60156	R2	148.599999999999994	0.0129999999999999994
60156	2Q1	158.699999999999989	0.0100000000000000002
60156	P1	200.300000000000011	0.173999999999999988
60156	L2	129.5	0.248999999999999999
60156	K2	150.300000000000011	0.39700000000000002
60156	M8	306.800000000000011	0.0389999999999999999
60157	M2	105.099999999999994	9.13400000000000034
60157	S2	147.599999999999994	1.40399999999999991
60157	N2	75.9000000000000057	1.94900000000000007
60157	K1	199.699999999999989	0.505000000000000004
60157	M4	111.400000000000006	0.269000000000000017
60157	O1	178.900000000000006	0.390000000000000013
60157	M6	282	0.331000000000000016
60157	MN4	81	0.107999999999999999
60157	NU2	85.7999999999999972	0.443000000000000005
60157	MU2	172.800000000000011	0.125
60157	2N2	78.2999999999999972	0.212999999999999995
60157	OO1	238.900000000000006	0.0259999999999999988
60157	LDA2	125.799999999999997	0.16700000000000001
60157	S1	160	0.0299999999999999989
60157	M1	191.599999999999994	0.0259999999999999988
60157	J1	221.099999999999994	0.0299999999999999989
60157	SSA	127.599999999999994	0.0519999999999999976
60157	Q1	170.400000000000006	0.0560000000000000012
60157	T2	126.5	0.128000000000000003
60157	2Q1	165	0.0129999999999999994
60157	P1	199.400000000000006	0.150999999999999995
60157	2SM2	48.5	0.0229999999999999996
60157	L2	145.199999999999989	0.737999999999999989
60157	K2	148.5	0.406999999999999973
60157	M8	294	0.0589999999999999969
60157	MS4	162	0.0790000000000000008
60158	M2	135.5	7.87699999999999978
60158	S2	185.599999999999994	1.129
60158	N2	110.5	1.57499999999999996
60158	K1	226.099999999999994	0.453000000000000014
60158	M4	182.099999999999994	0.440000000000000002
60158	O1	204.800000000000011	0.353999999999999981
60158	M6	24.3999999999999986	0.463000000000000023
60158	MK3	244.699999999999989	0.0429999999999999966
60158	S4	284.199999999999989	0.0100000000000000002
60158	MN4	156.199999999999989	0.187
60158	NU2	111.599999999999994	0.387000000000000011
60158	MU2	216.900000000000006	0.279000000000000026
60158	2N2	133.900000000000006	0.190000000000000002
60158	OO1	267.300000000000011	0.0200000000000000004
60158	LDA2	143.099999999999994	0.16700000000000001
60158	S1	150	0.0259999999999999988
60158	M1	223.300000000000011	0.0259999999999999988
60158	J1	262.5	0.0259999999999999988
60158	SSA	127.599999999999994	0.0519999999999999976
60158	RHO1	154.800000000000011	0.0129999999999999994
60158	Q1	199.300000000000011	0.0519999999999999976
60158	T2	162	0.112000000000000002
60158	R2	0.800000000000000044	0.0259999999999999988
60158	2Q1	204.400000000000006	0.0160000000000000003
60158	P1	227.400000000000006	0.138000000000000012
60158	2SM2	65.9000000000000057	0.0229999999999999996
60158	M3	156.199999999999989	0.0129999999999999994
60158	L2	160.5	0.862999999999999989
60158	2MK3	222.300000000000011	0.0359999999999999973
60158	K2	185.400000000000006	0.318000000000000005
60158	M8	62.7000000000000028	0.0950000000000000011
60158	MS4	232	0.125
60159	M2	93.7000000000000028	6.62100000000000044
60159	S2	131.699999999999989	1.0169999999999999
60159	N2	62.6000000000000014	1.35499999999999998
60159	K1	192.300000000000011	0.475999999999999979
60159	M4	157.300000000000011	0.0589999999999999969
60159	O1	173.599999999999994	0.373999999999999999
60159	M6	230.800000000000011	0.0359999999999999973
60159	MK3	326.699999999999989	0.0100000000000000002
60159	S4	279.600000000000023	0.00300000000000000006
60159	MN4	142.900000000000006	0.0200000000000000004
60159	NU2	69.2000000000000028	0.325000000000000011
60159	MU2	129.099999999999994	0.0129999999999999994
60159	2N2	39.5	0.143999999999999989
60159	OO1	216.099999999999994	0.0299999999999999989
60159	LDA2	125.5	0.117999999999999994
60159	S1	169.099999999999994	0.0229999999999999996
60159	M1	214.5	0.0160000000000000003
60159	J1	199.099999999999994	0.0229999999999999996
60159	SSA	127.599999999999994	0.0519999999999999976
60159	RHO1	192.300000000000011	0.0160000000000000003
60159	Q1	158.300000000000011	0.0560000000000000012
60159	T2	110	0.0919999999999999984
60159	R2	348.600000000000023	0.0299999999999999989
60159	2Q1	137.599999999999994	0.00300000000000000006
60159	P1	193.199999999999989	0.153999999999999998
60159	2SM2	57.2000000000000028	0.0200000000000000004
60159	M3	110.5	0.00300000000000000006
60159	L2	142.5	0.350999999999999979
60159	2MK3	294.600000000000023	0.0200000000000000004
60159	K2	131.099999999999994	0.279000000000000026
60159	M8	276.600000000000023	0.00300000000000000006
60159	MS4	215.800000000000011	0.0229999999999999996
60160	M2	92.9000000000000057	6.10899999999999999
60160	S2	129.800000000000011	0.941999999999999948
60160	N2	62.7999999999999972	1.28600000000000003
60160	K1	193.699999999999989	0.463000000000000023
60160	M4	108.5	0.0389999999999999999
60160	O1	173.5	0.360999999999999988
60160	M6	255.300000000000011	0.0259999999999999988
60160	MN4	81.5	0.0100000000000000002
60160	NU2	69.4000000000000057	0.279000000000000026
60160	2N2	40.8999999999999986	0.161000000000000004
60160	OO1	228.5	0.0160000000000000003
60160	LDA2	124.200000000000003	0.107999999999999999
60160	S1	158.800000000000011	0.0229999999999999996
60160	M1	205.900000000000006	0.0200000000000000004
60160	J1	204.800000000000011	0.0259999999999999988
60160	RHO1	142.199999999999989	0.0100000000000000002
60160	Q1	159.199999999999989	0.0619999999999999996
60160	T2	103.700000000000003	0.0850000000000000061
60160	R2	329.899999999999977	0.0299999999999999989
60160	2Q1	153.400000000000006	0.0100000000000000002
60160	P1	193.099999999999994	0.157000000000000001
60160	2SM2	77.7000000000000028	0.0160000000000000003
60160	L2	136	0.276000000000000023
60160	2MK3	295.899999999999977	0.0160000000000000003
60160	K2	128.699999999999989	0.256000000000000005
60160	MS4	186.400000000000006	0.0100000000000000002
60161	M2	98.2000000000000028	5.35099999999999998
60161	S2	138.400000000000006	0.724999999999999978
60161	N2	64.7999999999999972	1.08299999999999996
60161	K1	192.800000000000011	0.481999999999999984
60161	M4	106.5	0.276000000000000023
60161	O1	180.099999999999994	0.400000000000000022
60161	M6	356.5	0.0519999999999999976
60161	NU2	69.2999999999999972	0.209999999999999992
60161	S6	59.7000000000000028	0.0100000000000000002
60161	MU2	282.199999999999989	0.128000000000000003
60161	2N2	31.5	0.143999999999999989
60161	OO1	205.5	0.0160000000000000003
60161	LDA2	116.900000000000006	0.0359999999999999973
60161	M1	186.5	0.0299999999999999989
60161	J1	199.099999999999994	0.0330000000000000016
60161	RHO1	174.699999999999989	0.0160000000000000003
60161	Q1	173.800000000000011	0.0790000000000000008
60161	T2	136.800000000000011	0.0429999999999999966
60161	R2	140	0.00700000000000000015
60161	2Q1	167.5	0.0100000000000000002
60161	P1	191.900000000000006	0.161000000000000004
60161	L2	131.599999999999994	0.150999999999999995
60161	K2	141.699999999999989	0.197000000000000008
60161	M8	162.199999999999989	0.0259999999999999988
60162	M2	91.9000000000000057	5.15700000000000003
60162	S2	128.099999999999994	0.781000000000000028
60162	N2	61.3999999999999986	1.13500000000000001
60162	K1	193.800000000000011	0.463000000000000023
60162	M4	92.7999999999999972	0.0259999999999999988
60162	O1	174.400000000000006	0.360999999999999988
60162	M6	48.2999999999999972	0.0389999999999999999
60162	MK3	260.399999999999977	0.00300000000000000006
60162	MN4	42.8999999999999986	0.00700000000000000015
60162	NU2	67.5999999999999943	0.248999999999999999
60162	MU2	42.7999999999999972	0.0259999999999999988
60162	2N2	37.1000000000000014	0.138000000000000012
60162	OO1	231.5	0.0200000000000000004
60162	LDA2	125.299999999999997	0.0889999999999999958
60162	S1	160.400000000000006	0.0259999999999999988
60162	M1	210	0.0200000000000000004
60162	J1	196.800000000000011	0.0299999999999999989
60162	SSA	133.699999999999989	0.0389999999999999999
60162	SA	135.800000000000011	0.101999999999999993
60162	MSF	86.4000000000000057	0.0389999999999999999
60162	RHO1	143	0.0129999999999999994
60162	Q1	155.199999999999989	0.0660000000000000031
60162	T2	107.700000000000003	0.0719999999999999946
60162	R2	335.199999999999989	0.0160000000000000003
60162	2Q1	174.5	0.00700000000000000015
60162	P1	190.599999999999994	0.157000000000000001
60162	2SM2	68.4000000000000057	0.0129999999999999994
60162	M3	141.400000000000006	0.00300000000000000006
60162	L2	135.400000000000006	0.262000000000000011
60162	2MK3	259.899999999999977	0.0129999999999999994
60162	K2	128.699999999999989	0.209999999999999992
60162	M8	329.100000000000023	0.00300000000000000006
60162	MS4	167	0.0100000000000000002
60163	M2	99.0999999999999943	5.25300000000000011
60163	S2	140.199999999999989	0.747999999999999998
60163	N2	67.2000000000000028	1.14799999999999991
60163	K1	197.800000000000011	0.515000000000000013
60163	M4	80.9000000000000057	0.112000000000000002
60163	O1	178.300000000000011	0.390000000000000013
60163	M6	100.599999999999994	0.115000000000000005
60163	S4	262.5	0.00300000000000000006
60163	NU2	71.4000000000000057	0.223000000000000004
60163	S6	98.5999999999999943	0.0129999999999999994
60163	MU2	281.199999999999989	0.125
60163	2N2	35.2000000000000028	0.153999999999999998
60163	OO1	216.800000000000011	0.0160000000000000003
60163	LDA2	118.099999999999994	0.0359999999999999973
60163	M1	188	0.0259999999999999988
60163	J1	207	0.0299999999999999989
60163	RHO1	170	0.0160000000000000003
60163	Q1	168.699999999999989	0.0749999999999999972
60163	T2	138.5	0.0429999999999999966
60163	R2	141.800000000000011	0.00700000000000000015
60163	2Q1	159.099999999999994	0.0100000000000000002
60163	P1	196.300000000000011	0.171000000000000013
60163	L2	131	0.147999999999999993
60163	K2	143.5	0.203000000000000014
60163	M8	105.099999999999994	0.0459999999999999992
60164	M2	95.5999999999999943	5.0519999999999996
60164	S2	132.099999999999994	0.72799999999999998
60164	N2	71.2000000000000028	1.1319999999999999
60164	K1	199.199999999999989	0.52200000000000002
60164	M4	74.2999999999999972	0.0429999999999999966
60164	O1	174.900000000000006	0.350999999999999979
60164	M6	81	0.0790000000000000008
60164	S4	106.700000000000003	0.00300000000000000006
60164	NU2	74.4000000000000057	0.220000000000000001
60164	S6	310.199999999999989	0.00300000000000000006
60164	MU2	142.400000000000006	0.120999999999999996
60164	2N2	46.7000000000000028	0.150999999999999995
60164	OO1	223.5	0.0160000000000000003
60164	LDA2	112.599999999999994	0.0359999999999999973
60164	M1	187.099999999999994	0.0259999999999999988
60164	J1	211.300000000000011	0.0299999999999999989
60164	RHO1	164.5	0.0129999999999999994
60164	Q1	162.800000000000011	0.0690000000000000058
60164	T2	130.699999999999989	0.0429999999999999966
60164	R2	133.599999999999994	0.00700000000000000015
60164	2Q1	150.800000000000011	0.0100000000000000002
60164	P1	197.400000000000006	0.173999999999999988
60164	L2	120	0.140999999999999986
60164	K2	135.099999999999994	0.197000000000000008
60164	M8	70.0999999999999943	0.0160000000000000003
60165	M2	94.5999999999999943	4.97700000000000031
60165	S2	145.800000000000011	0.76100000000000001
60165	N2	62.5	1.11899999999999999
60165	K1	191.900000000000006	0.432999999999999996
60165	M4	53.6000000000000014	0.0200000000000000004
60165	O1	176.599999999999994	0.370999999999999996
60165	M6	82.4000000000000057	0.0790000000000000008
60165	MK3	237.099999999999994	0.00700000000000000015
60165	S4	158.199999999999989	0.00300000000000000006
60165	MN4	339.800000000000011	0.0129999999999999994
60165	NU2	69.9000000000000057	0.226000000000000006
60165	MU2	7.79999999999999982	0.00700000000000000015
60165	2N2	57.1000000000000014	0.112000000000000002
60165	OO1	223.199999999999989	0.0160000000000000003
60165	LDA2	113.799999999999997	0.0820000000000000034
60165	S1	227.099999999999994	0.0589999999999999969
60165	M1	188.599999999999994	0.0229999999999999996
60165	J1	203.800000000000011	0.0259999999999999988
60165	RHO1	160.300000000000011	0.00300000000000000006
60165	Q1	166.5	0.0560000000000000012
60165	T2	192.699999999999989	0.0719999999999999946
60165	R2	25.6999999999999993	0.223000000000000004
60165	2Q1	165.099999999999994	0.0100000000000000002
60165	P1	181.199999999999989	0.135000000000000009
60165	2SM2	69.2999999999999972	0.0160000000000000003
60165	M3	155.300000000000011	0.0100000000000000002
60165	L2	151	0.338000000000000023
60165	2MK3	232.599999999999994	0.0129999999999999994
60165	K2	109.599999999999994	0.242999999999999994
60165	M8	122.299999999999997	0.0100000000000000002
60165	MS4	180.5	0.0100000000000000002
60166	M2	112.599999999999994	5.99699999999999989
60166	S2	150.699999999999989	0.862999999999999989
60166	N2	74.9000000000000057	1.2370000000000001
60166	K1	206.599999999999994	0.481999999999999984
60166	M4	114.900000000000006	0.443000000000000005
60166	O1	190.400000000000006	0.373999999999999999
60166	M6	246.300000000000011	0.646000000000000019
60166	S4	100.700000000000003	0.0259999999999999988
60166	NU2	79.9000000000000057	0.23899999999999999
60166	S6	250.800000000000011	0.0389999999999999999
60166	MU2	296.899999999999977	0.143999999999999989
60166	2N2	37.2000000000000028	0.164000000000000007
60166	OO1	222.900000000000006	0.0160000000000000003
60166	LDA2	130.300000000000011	0.0429999999999999966
60166	M1	198.599999999999994	0.0259999999999999988
60166	J1	214.699999999999989	0.0299999999999999989
60166	RHO1	183.400000000000006	0.0129999999999999994
60166	Q1	182.300000000000011	0.0719999999999999946
60166	T2	149.199999999999989	0.0519999999999999976
60166	R2	152.300000000000011	0.00700000000000000015
60166	2Q1	174.300000000000011	0.0100000000000000002
60166	P1	205.400000000000006	0.161000000000000004
60166	L2	150.199999999999989	0.16700000000000001
60166	K2	153.800000000000011	0.235999999999999988
60166	M8	303.5	0.0889999999999999958
60167	M2	98.2000000000000028	5.21300000000000008
60167	S2	134.5	0.744999999999999996
60167	N2	63.5	1.16500000000000004
60167	K1	195.900000000000006	0.485999999999999988
60167	M4	58.2000000000000028	0.0389999999999999999
60167	O1	177.900000000000006	0.373999999999999999
60167	M6	118.099999999999994	0.171000000000000013
60167	S4	137.5	0.00300000000000000006
60167	NU2	68.0999999999999943	0.226000000000000006
60167	S6	76.0999999999999943	0.0160000000000000003
60167	MU2	284.100000000000023	0.125
60167	2N2	28.8000000000000007	0.153999999999999998
60167	OO1	214	0.0160000000000000003
60167	LDA2	115.099999999999994	0.0359999999999999973
60167	M1	187	0.0259999999999999988
60167	J1	204.900000000000006	0.0299999999999999989
60167	SSA	105.799999999999997	0.0660000000000000031
60167	SA	128.300000000000011	0.104999999999999996
60167	RHO1	170.199999999999989	0.0129999999999999994
60167	Q1	168.900000000000006	0.0719999999999999946
60167	T2	133	0.0429999999999999966
60167	R2	135.900000000000006	0.00700000000000000015
60167	2Q1	160	0.0100000000000000002
60167	P1	194.599999999999994	0.161000000000000004
60167	L2	132.800000000000011	0.147999999999999993
60167	K2	137.400000000000006	0.203000000000000014
60167	M8	163.599999999999994	0.0160000000000000003
60168	M2	98.2000000000000028	4.90200000000000014
60168	S2	134.099999999999994	0.714999999999999969
60168	N2	65.9000000000000057	1.12200000000000011
60168	K1	197.699999999999989	0.463000000000000023
60168	M4	50.7000000000000028	0.0259999999999999988
60168	O1	178.599999999999994	0.36399999999999999
60168	M6	99.7999999999999972	0.125
60168	S4	237.900000000000006	0.00700000000000000015
60168	NU2	70.2999999999999972	0.216999999999999998
60168	S6	290	0.00300000000000000006
60168	MU2	62.2999999999999972	0.117999999999999994
60168	2N2	33.7000000000000028	0.147999999999999993
60168	OO1	216.699999999999989	0.0160000000000000003
60168	LDA2	114.799999999999997	0.0330000000000000016
60168	M1	188.199999999999989	0.0259999999999999988
60168	J1	207.099999999999994	0.0299999999999999989
60168	RHO1	170.400000000000006	0.0129999999999999994
60168	Q1	169.199999999999989	0.0690000000000000058
60168	T2	132.599999999999994	0.0429999999999999966
60168	R2	135.5	0.00700000000000000015
60168	2Q1	159.699999999999989	0.0100000000000000002
60168	P1	196.199999999999989	0.153999999999999998
60168	L2	130.400000000000006	0.138000000000000012
60168	K2	137	0.194000000000000006
60168	M8	164.800000000000011	0.0129999999999999994
60169	M2	97.9000000000000057	4.92100000000000026
60169	S2	133.199999999999989	0.640000000000000013
60169	N2	65.2999999999999972	1.08299999999999996
60169	K1	201.199999999999989	0.498999999999999999
60169	O1	170.300000000000011	0.387000000000000011
60169	M6	98.2000000000000028	0.115000000000000005
60169	NU2	69.5999999999999943	0.209999999999999992
60169	2N2	32.7000000000000028	0.143999999999999989
60169	OO1	231.900000000000006	0.0160000000000000003
60169	LDA2	114.099999999999994	0.0330000000000000016
60169	M1	185.599999999999994	0.0299999999999999989
60169	J1	216.599999999999994	0.0299999999999999989
60169	RHO1	157	0.0160000000000000003
60169	Q1	154.800000000000011	0.0749999999999999972
60169	T2	133.099999999999994	0.0389999999999999999
60169	2Q1	139.400000000000006	0.0100000000000000002
60169	P1	201.099999999999994	0.16700000000000001
60169	L2	130.400000000000006	0.138000000000000012
60169	K2	133.199999999999989	0.173999999999999988
60169	M8	186.900000000000006	0.0299999999999999989
60170	M2	101.299999999999997	4.54699999999999971
60170	S2	139.199999999999989	0.643000000000000016
60170	N2	72.2999999999999972	1.02000000000000002
60170	K1	186.300000000000011	0.459000000000000019
60170	M4	347	0.0200000000000000004
60170	O1	184.599999999999994	0.360999999999999988
60170	M6	119.200000000000003	0.112000000000000002
60170	S4	0.900000000000000022	0.00700000000000000015
60170	NU2	76.2000000000000028	0.197000000000000008
60170	S6	9.5	0.0100000000000000002
60170	MU2	285	0.107999999999999999
60170	2N2	43.3999999999999986	0.135000000000000009
60170	OO1	184.5	0.0129999999999999994
60170	LDA2	118.900000000000006	0.0330000000000000016
60170	M1	184.699999999999989	0.0259999999999999988
60170	J1	184.800000000000011	0.0259999999999999988
60170	RHO1	184.5	0.0129999999999999994
60170	Q1	184.5	0.0690000000000000058
60170	T2	137.699999999999989	0.0389999999999999999
60170	R2	140.800000000000011	0.00700000000000000015
60170	2Q1	184.5	0.0100000000000000002
60170	P1	186.099999999999994	0.153999999999999998
60170	L2	130.300000000000011	0.128000000000000003
60170	K2	142.300000000000011	0.173999999999999988
60170	M8	99.5	0.0229999999999999996
60171	M2	106.400000000000006	4.44899999999999984
60171	S2	143.599999999999994	0.679000000000000048
60171	N2	78.2000000000000028	0.960999999999999965
60171	K1	205.699999999999989	0.471999999999999975
60171	M4	97.9000000000000057	0.0619999999999999996
60171	O1	184.699999999999989	0.357999999999999985
60171	M6	270.800000000000011	0.0589999999999999969
60171	MK3	215.199999999999989	0.0229999999999999996
60171	S4	147.199999999999989	0.00300000000000000006
60171	MN4	71.2000000000000028	0.0330000000000000016
60171	NU2	87	0.20699999999999999
60171	S6	196.099999999999994	0.00700000000000000015
60171	MU2	112.900000000000006	0.0129999999999999994
60171	2N2	71.7000000000000028	0.135000000000000009
60171	OO1	233	0.0129999999999999994
60171	LDA2	133.599999999999994	0.0719999999999999946
60171	S1	116.5	0.0160000000000000003
60171	M1	81.7999999999999972	0.00300000000000000006
60171	J1	199.699999999999989	0.0299999999999999989
60171	MM	19.6999999999999993	0.0560000000000000012
60171	SSA	239	0.0129999999999999994
60171	SA	125.700000000000003	0.0459999999999999992
60171	RHO1	186.699999999999989	0.0229999999999999996
60171	Q1	157.599999999999994	0.0660000000000000031
60171	T2	114.900000000000006	0.0589999999999999969
60171	R2	321.899999999999977	0.00300000000000000006
60171	2Q1	263.100000000000023	0.0100000000000000002
60171	P1	204.5	0.164000000000000007
60171	2SM2	106.5	0.0100000000000000002
60171	M3	76.5	0.00300000000000000006
60171	L2	146.300000000000011	0.153999999999999998
60171	2MK3	196.099999999999994	0.0229999999999999996
60171	K2	142.300000000000011	0.194000000000000006
60171	M8	262.100000000000023	0.0129999999999999994
60171	MS4	136.099999999999994	0.0200000000000000004
60172	M2	105.799999999999997	4.6980000000000004
60172	S2	146	0.686000000000000054
60172	N2	71.5999999999999943	1.01000000000000001
60172	K1	201.400000000000006	0.481999999999999984
60172	M4	309.899999999999977	0.0719999999999999946
60172	O1	186.199999999999989	0.360999999999999988
60172	M6	218.599999999999994	0.0129999999999999994
60172	S4	353.800000000000011	0.00300000000000000006
60172	NU2	76.0999999999999943	0.194000000000000006
60172	S6	168.599999999999994	0.00300000000000000006
60172	MU2	65.5	0.112000000000000002
60172	2N2	37.2999999999999972	0.135000000000000009
60172	OO1	216.400000000000006	0.0129999999999999994
60172	LDA2	124.5	0.0330000000000000016
60172	M1	193.900000000000006	0.0229999999999999996
60172	J1	208.800000000000011	0.0259999999999999988
60172	SSA	105.799999999999997	0.0660000000000000031
60172	SA	128.300000000000011	0.104999999999999996
60172	RHO1	179.800000000000011	0.0129999999999999994
60172	Q1	178.800000000000011	0.0690000000000000058
60172	T2	144.300000000000011	0.0389999999999999999
60172	R2	147.699999999999989	0.00700000000000000015
60172	2Q1	171.400000000000006	0.0100000000000000002
60172	P1	200.199999999999989	0.161000000000000004
60172	L2	140.099999999999994	0.131000000000000005
60172	K2	149.300000000000011	0.183999999999999997
60172	M8	118	0.0200000000000000004
60173	M2	118.099999999999994	4.35400000000000009
60173	S2	165.099999999999994	0.609999999999999987
60173	N2	82.5	0.883000000000000007
60173	K1	211.5	0.478999999999999981
60173	M4	103	0.0560000000000000012
60173	O1	196.300000000000011	0.315000000000000002
60173	M6	322.199999999999989	0.125
60173	S4	203.099999999999994	0.00700000000000000015
60173	NU2	87.2999999999999972	0.171000000000000013
60173	S6	350.300000000000011	0.00700000000000000015
60173	MU2	71.0999999999999943	0.104999999999999996
60173	2N2	46.8999999999999986	0.117999999999999994
60173	OO1	226.599999999999994	0.0129999999999999994
60173	LDA2	139.900000000000006	0.0299999999999999989
60173	M1	204	0.0229999999999999996
60173	J1	219	0.0259999999999999988
60173	SSA	105.799999999999997	0.0660000000000000031
60173	SA	128.300000000000011	0.104999999999999996
60173	RHO1	189.900000000000006	0.0129999999999999994
60173	Q1	188.800000000000011	0.0619999999999999996
60173	T2	163.199999999999989	0.0359999999999999973
60173	R2	167	0.00300000000000000006
60173	2Q1	181.300000000000011	0.00700000000000000015
60173	P1	210.300000000000011	0.157000000000000001
60173	L2	153.699999999999989	0.120999999999999996
60173	K2	168.900000000000006	0.16700000000000001
60173	M8	259.600000000000023	0.0259999999999999988
60174	M2	209.800000000000011	2.6080000000000001
60174	S2	259.800000000000011	0.288999999999999979
60174	N2	179.699999999999989	0.528000000000000025
60174	K1	283.899999999999977	0.341000000000000025
60174	M4	317.899999999999977	0.220000000000000001
60174	O1	262.5	0.262000000000000011
60174	M6	290.199999999999989	0.157000000000000001
60174	S4	14	0.0229999999999999996
60174	NU2	183.800000000000011	0.101999999999999993
60174	S6	64.4000000000000057	0.0100000000000000002
60174	MU2	20.1999999999999993	0.0619999999999999996
60174	2N2	149.699999999999989	0.0690000000000000058
60174	OO1	305.199999999999989	0.0100000000000000002
60174	LDA2	233	0.0200000000000000004
60174	M1	273.300000000000011	0.0200000000000000004
60174	J1	294.5	0.0200000000000000004
60174	RHO1	253.300000000000011	0.0100000000000000002
60174	Q1	251.900000000000006	0.0490000000000000019
60174	T2	257.800000000000011	0.0160000000000000003
60174	R2	261.800000000000011	0.00300000000000000006
60174	2Q1	241.300000000000011	0.00700000000000000015
60174	P1	282.300000000000011	0.112000000000000002
60174	L2	239.800000000000011	0.0719999999999999946
60174	K2	263.899999999999977	0.0790000000000000008
60174	M8	52.7999999999999972	0.0429999999999999966
60175	M2	221	0.915000000000000036
60175	S2	306.199999999999989	0.125
60175	N2	181.199999999999989	0.187
60175	K1	268.399999999999977	0.140999999999999986
60175	M4	55.7000000000000028	0.27200000000000002
60175	O1	277.5	0.212999999999999995
60175	M6	243.599999999999994	0.0619999999999999996
60175	S4	108.700000000000003	0.0100000000000000002
60175	NU2	186.599999999999994	0.0359999999999999973
60175	S6	27.3999999999999986	0.00300000000000000006
60175	MU2	133.300000000000011	0.0200000000000000004
60175	2N2	141.900000000000006	0.0229999999999999996
60175	OO1	253.5	0.0100000000000000002
60175	LDA2	262.699999999999989	0.00700000000000000015
60175	M1	271.600000000000023	0.0160000000000000003
60175	J1	259.399999999999977	0.0160000000000000003
60175	RHO1	281.399999999999977	0.00700000000000000015
60175	Q1	283.399999999999977	0.0389999999999999999
60175	T2	301.899999999999977	0.00700000000000000015
60175	2Q1	290.399999999999977	0.00300000000000000006
60175	P1	269.399999999999977	0.0459999999999999992
60175	L2	260.199999999999989	0.0259999999999999988
60175	K2	314	0.0330000000000000016
60175	M8	120	0.0129999999999999994
60176	M2	104.799999999999997	4.17600000000000016
60176	S2	137.599999999999994	0.622999999999999998
60176	N2	73.4000000000000057	0.980999999999999983
60176	K1	206.400000000000006	0.468999999999999972
60176	M4	292.199999999999989	0.0359999999999999973
60176	O1	188.400000000000006	0.360999999999999988
60176	M6	357	0.0160000000000000003
60176	S4	301	0.00300000000000000006
60176	NU2	77.5999999999999943	0.190000000000000002
60176	S6	5.09999999999999964	0.00300000000000000006
60176	MU2	292.399999999999977	0.101999999999999993
60176	2N2	42	0.131000000000000005
60176	OO1	224.5	0.0160000000000000003
60176	LDA2	120	0.0299999999999999989
60176	M1	197.5	0.0259999999999999988
60176	J1	215.400000000000006	0.0299999999999999989
60176	RHO1	180.699999999999989	0.0129999999999999994
60176	Q1	179.5	0.0690000000000000058
60176	T2	136.300000000000011	0.0359999999999999973
60176	R2	139	0.00700000000000000015
60176	2Q1	170.5	0.0100000000000000002
60176	P1	205.099999999999994	0.153999999999999998
60176	L2	136.199999999999989	0.117999999999999994
60176	K2	140.300000000000011	0.171000000000000013
60176	M8	134.900000000000006	0.0129999999999999994
60177	M2	190.199999999999989	2.44700000000000006
60177	S2	232.699999999999989	0.288999999999999979
60177	N2	158.400000000000006	0.485999999999999988
60177	K1	271.600000000000023	0.322000000000000008
60177	M4	231.099999999999994	0.0919999999999999984
60177	O1	250.900000000000006	0.259000000000000008
60177	M6	204.400000000000006	0.125
60177	S4	317.5	0.0160000000000000003
60177	NU2	162.699999999999989	0.0950000000000000011
60177	S6	294.600000000000023	0.00300000000000000006
60177	MU2	8.09999999999999964	0.0589999999999999969
60177	2N2	126.700000000000003	0.0660000000000000031
60177	OO1	292.399999999999977	0.0100000000000000002
60177	LDA2	209.900000000000006	0.0160000000000000003
60177	M1	261.300000000000011	0.0200000000000000004
60177	J1	281.899999999999977	0.0200000000000000004
60177	RHO1	242	0.0100000000000000002
60177	Q1	240.599999999999994	0.0490000000000000019
60177	T2	231	0.0160000000000000003
60177	R2	234.400000000000006	0.00300000000000000006
60177	2Q1	230.300000000000011	0.00700000000000000015
60177	P1	270.100000000000023	0.107999999999999999
60177	L2	222	0.0690000000000000058
60177	K2	236.099999999999994	0.0790000000000000008
60177	M8	273.300000000000011	0.0229999999999999996
60178	M2	130.099999999999994	3.52400000000000002
60178	S2	166.300000000000011	0.498999999999999999
60178	N2	96	0.717999999999999972
60178	K1	219.5	0.409999999999999976
60178	M4	120	0.0980000000000000038
60178	O1	204.599999999999994	0.307999999999999996
60178	M6	324.399999999999977	0.0200000000000000004
60178	S4	227.199999999999989	0.0100000000000000002
60178	NU2	100.599999999999994	0.138000000000000012
60178	MU2	314.199999999999989	0.0850000000000000061
60178	2N2	61.8999999999999986	0.0950000000000000011
60178	OO1	234.300000000000011	0.0129999999999999994
60178	LDA2	146.900000000000006	0.0229999999999999996
60178	M1	212	0.0229999999999999996
60178	J1	226.800000000000011	0.0229999999999999996
60178	RHO1	198.199999999999989	0.0129999999999999994
60178	Q1	197.199999999999989	0.0589999999999999969
60178	T2	164.900000000000006	0.0299999999999999989
60178	R2	167.800000000000011	0.00300000000000000006
60178	2Q1	189.800000000000011	0.00700000000000000015
60178	P1	218.300000000000011	0.135000000000000009
60178	L2	164.099999999999994	0.0980000000000000038
60178	K2	169.199999999999989	0.135000000000000009
60178	M8	121.599999999999994	0.0160000000000000003
60179	M2	102.200000000000003	4.51100000000000012
60179	S2	139.099999999999994	0.682000000000000051
60179	N2	70.5	0.983999999999999986
60179	K1	201.400000000000006	0.471999999999999975
60179	M4	5.79999999999999982	0.0359999999999999973
60179	O1	182	0.370999999999999996
60179	M6	123.200000000000003	0.0459999999999999992
60179	MK3	232.300000000000011	0.0129999999999999994
60179	S4	352.199999999999989	0.00300000000000000006
60179	MN4	350.100000000000023	0.0200000000000000004
60179	NU2	77.0999999999999943	0.223000000000000004
60179	S6	160.900000000000006	0.00700000000000000015
60179	MU2	37.8999999999999986	0.0359999999999999973
60179	2N2	47.3999999999999986	0.128000000000000003
60179	OO1	223.400000000000006	0.0229999999999999996
60179	LDA2	137.400000000000006	0.0719999999999999946
60179	S1	206.400000000000006	0.0299999999999999989
60179	M1	224.400000000000006	0.0129999999999999994
60179	J1	214	0.0259999999999999988
60179	SSA	108	0.0490000000000000019
60179	SA	136.199999999999989	0.104999999999999996
60179	RHO1	175.300000000000011	0.0129999999999999994
60179	Q1	164	0.0619999999999999996
60179	T2	111.5	0.0660000000000000031
60179	R2	348.300000000000011	0.0129999999999999994
60179	2Q1	181	0.00300000000000000006
60179	P1	200.099999999999994	0.164000000000000007
60179	2SM2	88.9000000000000057	0.0129999999999999994
60179	M3	106.599999999999994	0.00300000000000000006
60179	L2	155.300000000000011	0.200000000000000011
60179	2MK3	217.699999999999989	0.0160000000000000003
60179	K2	137.599999999999994	0.190000000000000002
60179	M8	129.400000000000006	0.0100000000000000002
60179	MS4	52.6000000000000014	0.0129999999999999994
60180	M2	109.099999999999994	4.21300000000000008
60180	S2	147.5	0.573999999999999955
60180	N2	81.5	0.932000000000000051
60180	K1	208.800000000000011	0.459000000000000019
60180	M4	128.699999999999989	0.0719999999999999946
60180	O1	188.800000000000011	0.350999999999999979
60180	M6	306.399999999999977	0.0259999999999999988
60180	S4	215.099999999999994	0.00700000000000000015
60180	NU2	85.2000000000000028	0.179999999999999993
60180	S6	30.3000000000000007	0.00300000000000000006
60180	MU2	290	0.101999999999999993
60180	2N2	53.8999999999999986	0.125
60180	OO1	228.599999999999994	0.0160000000000000003
60180	LDA2	126.900000000000006	0.0299999999999999989
60180	M1	198.800000000000011	0.0259999999999999988
60180	J1	218.599999999999994	0.0259999999999999988
60180	RHO1	180.199999999999989	0.0129999999999999994
60180	Q1	178.900000000000006	0.0690000000000000058
60180	T2	146	0.0330000000000000016
60180	R2	149	0.00300000000000000006
60180	2Q1	169.099999999999994	0.0100000000000000002
60180	P1	207.300000000000011	0.150999999999999995
60180	L2	136.699999999999989	0.117999999999999994
60180	K2	150.599999999999994	0.157000000000000001
60180	M8	255.199999999999989	0.0200000000000000004
60181	M2	105.299999999999997	4.27799999999999958
60181	S2	143.099999999999994	0.630000000000000004
60181	N2	73.5	0.980999999999999983
60181	K1	204.099999999999994	0.478999999999999981
60181	M4	116.099999999999994	0.0519999999999999976
60181	O1	183.599999999999994	0.373999999999999999
60181	M6	96.2000000000000028	0.0200000000000000004
60181	S4	200.300000000000011	0.00700000000000000015
60181	NU2	77.7999999999999972	0.190000000000000002
60181	S6	56.2999999999999972	0.00300000000000000006
60181	MU2	286.800000000000011	0.101999999999999993
60181	2N2	41.7000000000000028	0.131000000000000005
60181	OO1	224.400000000000006	0.0160000000000000003
60181	LDA2	122.799999999999997	0.0299999999999999989
60181	M1	193.900000000000006	0.0259999999999999988
60181	J1	214.099999999999994	0.0299999999999999989
60181	RHO1	174.900000000000006	0.0129999999999999994
60181	Q1	173.5	0.0719999999999999946
60181	T2	141.599999999999994	0.0359999999999999973
60181	R2	144.599999999999994	0.00700000000000000015
60181	2Q1	163.400000000000006	0.0100000000000000002
60181	P1	202.5	0.157000000000000001
60181	L2	137.099999999999994	0.120999999999999996
60181	K2	146.199999999999989	0.171000000000000013
60181	M8	249.400000000000006	0.0129999999999999994
60182	M2	112.099999999999994	4.30799999999999983
60182	S2	161	1.2629999999999999
60182	N2	79.5999999999999943	1.01000000000000001
60182	K1	209.099999999999994	0.456000000000000016
60182	M4	99.9000000000000057	0.0950000000000000011
60182	O1	188.699999999999989	0.366999999999999993
60182	M6	135.800000000000011	0.0299999999999999989
60182	MK3	247.099999999999994	0.0330000000000000016
60182	S4	200.5	0.00700000000000000015
60182	MN4	54.2000000000000028	0.0560000000000000012
60182	NU2	87.7999999999999972	0.212999999999999995
60182	MU2	357.600000000000023	0.0200000000000000004
60182	2N2	62.3999999999999986	0.190000000000000002
60182	OO1	256.699999999999989	0.0129999999999999994
60182	LDA2	157.699999999999989	0.0820000000000000034
60182	S1	100.099999999999994	0.0299999999999999989
60182	M1	186.199999999999989	0.0299999999999999989
60182	J1	215.5	0.0359999999999999973
60182	SSA	105.799999999999997	0.0660000000000000031
60182	SA	128.300000000000011	1.05000000000000004
60182	RHO1	179.5	0.0259999999999999988
60182	Q1	173.800000000000011	0.0719999999999999946
60182	T2	116.400000000000006	0.298999999999999988
60182	R2	46.1000000000000014	0.673000000000000043
60182	2Q1	226.5	0.0129999999999999994
60182	P1	195.400000000000006	0.150999999999999995
60182	2SM2	57.8999999999999986	0.0100000000000000002
60182	M3	136.5	0.0229999999999999996
60182	L2	168.400000000000006	0.20699999999999999
60182	2MK3	218.099999999999994	0.0359999999999999973
60182	K2	144.699999999999989	0.440000000000000002
60182	M8	295.699999999999989	0.0229999999999999996
60182	MS4	153	0.0459999999999999992
60183	M2	106.5	4.24199999999999999
60183	S2	130.099999999999994	0.791000000000000036
60183	N2	72.9000000000000057	0.97799999999999998
60183	K1	206.800000000000011	0.502000000000000002
60183	M4	352.600000000000023	0.0490000000000000019
60183	O1	184.099999999999994	0.36399999999999999
60183	M6	225.400000000000006	0.0200000000000000004
60183	MK3	248.099999999999994	0.0160000000000000003
60183	S4	178.800000000000011	0.00300000000000000006
60183	MN4	329.5	0.0259999999999999988
60183	NU2	78.9000000000000057	0.187
60183	MU2	30.3000000000000007	0.0330000000000000016
60183	2N2	57.1000000000000014	0.176999999999999991
60183	OO1	245.400000000000006	0.0160000000000000003
60183	LDA2	155.400000000000006	0.0589999999999999969
60183	S1	354.100000000000023	0.0749999999999999972
60183	M1	178.5	0.0259999999999999988
60183	J1	210.099999999999994	0.0359999999999999973
60183	SSA	105.799999999999997	0.0660000000000000031
60183	SA	128.300000000000011	0.104999999999999996
60183	RHO1	177.800000000000011	0.0129999999999999994
60183	Q1	172	0.0719999999999999946
60183	T2	71.4000000000000057	0.104999999999999996
60183	R2	318.100000000000023	0.203000000000000014
60183	2Q1	204.199999999999989	0.0160000000000000003
60183	P1	181.099999999999994	0.150999999999999995
60183	2SM2	142.199999999999989	0.0100000000000000002
60183	M3	124.099999999999994	0.0160000000000000003
60183	L2	162.300000000000011	0.200000000000000011
60183	2MK3	208.900000000000006	0.0200000000000000004
60183	K2	122.099999999999994	0.190000000000000002
60183	M8	108.900000000000006	0.00700000000000000015
60183	MS4	43.8999999999999986	0.0200000000000000004
60184	M2	105.299999999999997	4.36300000000000043
60184	S2	141.699999999999989	0.666000000000000036
60184	N2	71.4000000000000057	0.964999999999999969
60184	K1	203.699999999999989	0.44900000000000001
60184	M4	328.899999999999977	0.0749999999999999972
60184	O1	186.5	0.36399999999999999
60184	M6	193.699999999999989	0.0330000000000000016
60184	MK3	310.399999999999977	0.00300000000000000006
60184	S4	93.9000000000000057	0.00300000000000000006
60184	MN4	301.699999999999989	0.0330000000000000016
60184	NU2	82.5999999999999943	0.220000000000000001
60184	S6	167.599999999999994	0.00300000000000000006
60184	MU2	37.2000000000000028	0.0330000000000000016
60184	2N2	35.8999999999999986	0.16700000000000001
60184	OO1	256.100000000000023	0.0160000000000000003
60184	LDA2	145	0.0719999999999999946
60184	S1	122.299999999999997	0.0160000000000000003
60184	M1	193.900000000000006	0.0100000000000000002
60184	J1	207.5	0.0229999999999999996
60184	SSA	105.799999999999997	0.0660000000000000031
60184	SA	128.300000000000011	0.104999999999999996
60184	RHO1	183.599999999999994	0.0160000000000000003
60184	Q1	182.699999999999989	0.0690000000000000058
60184	T2	114	0.0589999999999999969
60184	R2	16	0.0200000000000000004
60184	2Q1	117.299999999999997	0.0160000000000000003
60184	P1	203.099999999999994	0.157000000000000001
60184	2SM2	129.900000000000006	0.0129999999999999994
60184	M3	100	0.0100000000000000002
60184	L2	150.099999999999994	0.187
60184	2MK3	209.800000000000011	0.0100000000000000002
60184	K2	139.300000000000011	0.176999999999999991
60184	M8	43.2999999999999972	0.00700000000000000015
60184	MS4	9.59999999999999964	0.0299999999999999989
60185	M2	111.599999999999994	3.92700000000000005
60185	S2	143.199999999999989	0.630000000000000004
60185	N2	80.4000000000000057	0.794000000000000039
60185	K1	208.400000000000006	0.409999999999999976
60185	M4	355	0.0519999999999999976
60185	O1	184.800000000000011	0.338000000000000023
60185	M6	179.699999999999989	0.0229999999999999996
60185	S4	56	0.0100000000000000002
60185	NU2	84.5999999999999943	0.153999999999999998
60185	S6	208.300000000000011	0.00700000000000000015
60185	MU2	298.5	0.0950000000000000011
60185	2N2	49.2000000000000028	0.104999999999999996
60185	OO1	232	0.0129999999999999994
60185	LDA2	126.299999999999997	0.0259999999999999988
60185	M1	196.699999999999989	0.0229999999999999996
60185	J1	220.099999999999994	0.0259999999999999988
60185	SSA	101	0.0519999999999999976
60185	SA	125	0.107999999999999999
60185	RHO1	174.699999999999989	0.0129999999999999994
60185	Q1	173.099999999999994	0.0660000000000000031
60185	T2	142	0.0359999999999999973
60185	R2	144.5	0.00700000000000000015
60185	2Q1	161.400000000000006	0.0100000000000000002
60185	P1	206.599999999999994	0.135000000000000009
60185	L2	142.800000000000011	0.112000000000000002
60185	K2	145.800000000000011	0.171000000000000013
60185	M8	0.900000000000000022	0.00300000000000000006
60186	M2	150.099999999999994	3.30399999999999983
60186	S2	189.099999999999994	0.426999999999999991
60186	N2	117.400000000000006	0.627000000000000002
60186	K1	230.800000000000011	0.381000000000000005
60186	M4	108.700000000000003	0.0889999999999999958
60186	O1	220.199999999999989	0.304999999999999993
60186	M6	102.799999999999997	0.0660000000000000031
60186	S4	251.199999999999989	0.00300000000000000006
60186	NU2	121.700000000000003	0.120999999999999996
60186	S6	204	0.00300000000000000006
60186	MU2	329.399999999999977	0.0790000000000000008
60186	2N2	84.5999999999999943	0.0820000000000000034
60186	OO1	241.400000000000006	0.0129999999999999994
60186	LDA2	168.099999999999994	0.0229999999999999996
60186	M1	225.5	0.0229999999999999996
60186	J1	236	0.0229999999999999996
60186	RHO1	215.599999999999994	0.0129999999999999994
60186	Q1	214.900000000000006	0.0589999999999999969
60186	T2	187.599999999999994	0.0259999999999999988
60186	R2	190.699999999999989	0.00300000000000000006
60186	2Q1	209.599999999999994	0.00700000000000000015
60186	P1	230	0.128000000000000003
60186	L2	182.800000000000011	0.0919999999999999984
60186	K2	192.300000000000011	0.115000000000000005
60186	M8	32.2999999999999972	0.0259999999999999988
60187	M2	141.199999999999989	3.14999999999999991
60187	S2	177.400000000000006	0.39700000000000002
60187	N2	108	0.646000000000000019
60187	K1	230.900000000000006	0.377000000000000002
60187	M4	49.1000000000000014	0.0919999999999999984
60187	O1	209.400000000000006	0.318000000000000005
60187	M6	112.299999999999997	0.0389999999999999999
60187	S4	273.199999999999989	0.00300000000000000006
60187	NU2	112.5	0.125
60187	S6	245.699999999999989	0.00300000000000000006
60187	MU2	105.099999999999994	0.0749999999999999972
60187	2N2	74.7999999999999972	0.0850000000000000061
60187	OO1	252.699999999999989	0.0129999999999999994
60187	LDA2	158	0.0229999999999999996
60187	M1	220.300000000000011	0.0229999999999999996
60187	J1	241.800000000000011	0.0259999999999999988
60187	SSA	89.7999999999999972	0.0589999999999999969
60187	SA	126.299999999999997	0.104999999999999996
60187	RHO1	200.300000000000011	0.0129999999999999994
60187	Q1	198.699999999999989	0.0619999999999999996
60187	T2	175.900000000000006	0.0229999999999999996
60187	R2	178.800000000000011	0.00300000000000000006
60187	2Q1	188.300000000000011	0.0100000000000000002
60187	P1	229.300000000000011	0.125
60187	L2	174.400000000000006	0.0889999999999999958
60187	K2	180.300000000000011	0.107999999999999999
60187	M8	343.5	0.0100000000000000002
60188	M2	105.900000000000006	4.31099999999999994
60188	S2	136.199999999999989	0.593999999999999972
60188	N2	76.0999999999999943	0.964999999999999969
60188	K1	203.300000000000011	0.443000000000000005
60188	M4	324.5	0.0589999999999999969
60188	O1	187.099999999999994	0.373999999999999999
60188	M6	134.699999999999989	0.0299999999999999989
60188	MK3	244.900000000000006	0.0129999999999999994
60188	S4	162.900000000000006	0.00300000000000000006
60188	MN4	317.899999999999977	0.0229999999999999996
60188	NU2	85.2000000000000028	0.20699999999999999
60188	MU2	24	0.0299999999999999989
60188	2N2	49.2999999999999972	0.161000000000000004
60188	OO1	247.599999999999994	0.0129999999999999994
60188	LDA2	144.800000000000011	0.0619999999999999996
60188	S1	168.699999999999989	0.0330000000000000016
60188	M1	250.199999999999989	0.0160000000000000003
60188	J1	214.199999999999989	0.0259999999999999988
60188	SSA	105.799999999999997	0.0660000000000000031
60188	SA	128.300000000000011	0.104999999999999996
60188	RHO1	159.400000000000006	0.0129999999999999994
60188	Q1	156.599999999999994	0.0660000000000000031
60188	T2	94.5	0.0749999999999999972
60188	R2	130.699999999999989	0.0889999999999999958
60188	2Q1	38	0.0100000000000000002
60188	P1	204.099999999999994	0.135000000000000009
60188	2SM2	156.599999999999994	0.0229999999999999996
60188	M3	156.199999999999989	0.00300000000000000006
60188	L2	140.300000000000011	0.153999999999999998
60188	2MK3	225.400000000000006	0.0200000000000000004
60188	K2	131.800000000000011	0.209999999999999992
60188	M8	293.199999999999989	0.00700000000000000015
60188	MS4	23.8999999999999986	0.0160000000000000003
60189	M2	132.300000000000011	3.59600000000000009
60189	S2	157.900000000000006	0.478999999999999981
60189	N2	105.799999999999997	0.721999999999999975
60189	K1	225.5	0.409999999999999976
60189	M4	178.199999999999989	0.150999999999999995
60189	O1	210.300000000000011	0.33500000000000002
60189	M6	62.8999999999999986	0.104999999999999996
60189	MK3	255.699999999999989	0.0519999999999999976
60189	S4	245.900000000000006	0.00700000000000000015
60189	MN4	161.300000000000011	0.0690000000000000058
60189	NU2	121.5	0.157000000000000001
60189	S6	234.900000000000006	0.00300000000000000006
60189	MU2	233	0.0719999999999999946
60189	2N2	41.5	0.0490000000000000019
60189	OO1	278.399999999999977	0.0160000000000000003
60189	LDA2	135.800000000000011	0.0619999999999999996
60189	S1	308.199999999999989	0.0589999999999999969
60189	M1	246.800000000000011	0.0259999999999999988
60189	J1	277.399999999999977	0.0129999999999999994
60189	SSA	89.7999999999999972	0.0589999999999999969
60189	SA	126.299999999999997	0.104999999999999996
60189	RHO1	243.800000000000011	0.00300000000000000006
60189	Q1	201.900000000000006	0.0519999999999999976
60189	T2	70.9000000000000057	0.0490000000000000019
60189	2Q1	274.699999999999989	0.0259999999999999988
60189	P1	207.099999999999994	0.0790000000000000008
60189	2SM2	37.1000000000000014	0.0100000000000000002
60189	M3	309.600000000000023	0.0100000000000000002
60189	L2	143.300000000000011	0.269000000000000017
60189	2MK3	224.900000000000006	0.0589999999999999969
60189	K2	159.599999999999994	0.0980000000000000038
60189	M8	68.2000000000000028	0.0299999999999999989
60189	MS4	217.099999999999994	0.0560000000000000012
60190	M2	149.599999999999994	3.19200000000000017
60190	S2	192.199999999999989	0.394000000000000017
60190	N2	130.300000000000011	0.603999999999999981
60190	K1	246.400000000000006	0.390000000000000013
60190	M4	209.900000000000006	0.209999999999999992
60190	O1	219.599999999999994	0.322000000000000008
60190	M6	114	0.131000000000000005
60190	S4	299.800000000000011	0.00300000000000000006
60190	NU2	132.900000000000006	0.117999999999999994
60190	S6	270.699999999999989	0.00700000000000000015
60190	MU2	324.899999999999977	0.0749999999999999972
60190	2N2	111	0.0790000000000000008
60190	OO1	273.199999999999989	0.0129999999999999994
60190	LDA2	169.400000000000006	0.0229999999999999996
60190	M1	233.099999999999994	0.0229999999999999996
60190	J1	259.699999999999989	0.0259999999999999988
60190	SSA	89.7999999999999972	0.0589999999999999969
60190	SA	126.299999999999997	0.104999999999999996
60190	RHO1	208.199999999999989	0.0129999999999999994
60190	Q1	206.400000000000006	0.0619999999999999996
60190	T2	190.5	0.0229999999999999996
60190	R2	193.900000000000006	0.00300000000000000006
60190	2Q1	193.099999999999994	0.0100000000000000002
60190	P1	244.400000000000006	0.131000000000000005
60190	L2	168.800000000000011	0.0889999999999999958
60190	K2	195.699999999999989	0.107999999999999999
60190	M8	145.400000000000006	0.0490000000000000019
60191	M2	115.700000000000003	3.83499999999999996
60191	S2	153	0.541000000000000036
60191	N2	85.5999999999999943	0.78400000000000003
60191	K1	211.199999999999989	0.426999999999999991
60191	M4	133	0.0330000000000000016
60191	O1	194.199999999999989	0.341000000000000025
60191	M6	335.300000000000011	0.0820000000000000034
60191	NU2	89.5999999999999943	0.150999999999999995
60191	S6	174.400000000000006	0.00300000000000000006
60191	MU2	297	0.0919999999999999984
60191	2N2	55.5	0.104999999999999996
60191	OO1	227.900000000000006	0.0129999999999999994
60191	LDA2	133	0.0259999999999999988
60191	M1	202.699999999999989	0.0229999999999999996
60191	J1	219.400000000000006	0.0259999999999999988
60191	SSA	89.7999999999999972	0.0589999999999999969
60191	SA	126.299999999999997	0.104999999999999996
60191	RHO1	187	0.0129999999999999994
60191	Q1	185.800000000000011	0.0660000000000000031
60191	T2	151.599999999999994	0.0330000000000000016
60191	R2	154.5	0.00300000000000000006
60191	2Q1	177.5	0.0100000000000000002
60191	P1	209.900000000000006	0.140999999999999986
60191	L2	145.900000000000006	0.107999999999999999
60191	K2	156.099999999999994	0.147999999999999993
60191	M8	177.900000000000006	0.00700000000000000015
60192	M2	122	3.86500000000000021
60192	S2	166.199999999999989	0.512000000000000011
60192	N2	91.7000000000000028	0.758000000000000007
60192	K1	216.800000000000011	0.416999999999999982
60192	M4	164.199999999999989	0.16700000000000001
60192	O1	203.300000000000011	0.357999999999999985
60192	M6	16.8999999999999986	0.0790000000000000008
60192	S4	246.400000000000006	0.0100000000000000002
60192	NU2	95.7999999999999972	0.147999999999999993
60192	MU2	296	0.0919999999999999984
60192	2N2	61.3999999999999986	0.101999999999999993
60192	OO1	230.300000000000011	0.0160000000000000003
60192	LDA2	142.599999999999994	0.0259999999999999988
60192	M1	210.099999999999994	0.0259999999999999988
60192	J1	223.5	0.0299999999999999989
60192	SSA	89.7999999999999972	0.0589999999999999969
60192	SA	126.299999999999997	0.104999999999999996
60192	RHO1	197.5	0.0129999999999999994
60192	Q1	196.599999999999994	0.0690000000000000058
60192	T2	164.5	0.0299999999999999989
60192	R2	168	0.00300000000000000006
60192	2Q1	189.900000000000006	0.0100000000000000002
60192	P1	215.800000000000011	0.138000000000000012
60192	L2	152.400000000000006	0.107999999999999999
60192	K2	169.800000000000011	0.138000000000000012
60192	M8	356.600000000000023	0.0200000000000000004
60193	M2	176	2.49000000000000021
60193	S2	227.5	0.298999999999999988
60193	N2	151.599999999999994	0.443000000000000005
60193	K1	267.399999999999977	0.318000000000000005
60193	M4	284.600000000000023	0.463000000000000023
60193	O1	240.800000000000011	0.288999999999999979
60193	M6	109.900000000000006	0.0389999999999999999
60193	S4	41.6000000000000014	0.00700000000000000015
60193	NU2	154.900000000000006	0.0850000000000000061
60193	MU2	342.399999999999977	0.0589999999999999969
60193	2N2	127.099999999999994	0.0589999999999999969
60193	OO1	294	0.0129999999999999994
60193	LDA2	199.900000000000006	0.0160000000000000003
60193	M1	254.199999999999989	0.0200000000000000004
60193	J1	280.600000000000023	0.0229999999999999996
60193	SSA	89.7999999999999972	0.0589999999999999969
60193	SA	126.299999999999997	0.104999999999999996
60193	RHO1	229.400000000000006	0.0100000000000000002
60193	Q1	227.599999999999994	0.0560000000000000012
60193	T2	225.5	0.0160000000000000003
60193	R2	229.800000000000011	0.00300000000000000006
60193	2Q1	214.300000000000011	0.00700000000000000015
60193	P1	265.399999999999977	0.104999999999999996
60193	L2	200.400000000000006	0.0690000000000000058
60193	K2	231.699999999999989	0.0820000000000000034
60193	M8	270.899999999999977	0.0519999999999999976
60194	M2	116.900000000000006	4.19299999999999962
60194	S2	159.099999999999994	0.52200000000000002
60194	N2	88.2000000000000028	0.883000000000000007
60194	K1	212.800000000000011	0.432999999999999996
60194	M4	176.599999999999994	0.0619999999999999996
60194	O1	199.900000000000006	0.373999999999999999
60194	M6	345.100000000000023	0.0919999999999999984
60194	NU2	92.0999999999999943	0.171000000000000013
60194	S6	44.8999999999999986	0.00300000000000000006
60194	MU2	293	0.101999999999999993
60194	2N2	59.5	0.115000000000000005
60194	OO1	225.599999999999994	0.0160000000000000003
60194	LDA2	136.5	0.0299999999999999989
60194	M1	206.400000000000006	0.0259999999999999988
60194	J1	219.099999999999994	0.0299999999999999989
60194	SSA	89.7999999999999972	0.0589999999999999969
60194	SA	126.299999999999997	0.104999999999999996
60194	RHO1	194.400000000000006	0.0129999999999999994
60194	Q1	193.599999999999994	0.0719999999999999946
60194	T2	157.400000000000006	0.0299999999999999989
60194	R2	160.699999999999989	0.00300000000000000006
60194	2Q1	187.199999999999989	0.0100000000000000002
60194	P1	211.800000000000011	0.143999999999999989
60194	L2	145.599999999999994	0.117999999999999994
60194	K2	162.5	0.140999999999999986
60194	M8	329.5	0.0229999999999999996
60195	M2	106.599999999999994	4.22599999999999998
60195	S2	144.199999999999989	0.61399999999999999
60195	N2	75.5	0.996999999999999997
60195	K1	204.900000000000006	0.471999999999999975
60195	M4	357.600000000000023	0.0429999999999999966
60195	O1	186	0.384000000000000008
60195	M6	228.599999999999994	0.0160000000000000003
60195	S4	338	0.00300000000000000006
60195	NU2	79.5999999999999943	0.194000000000000006
60195	MU2	287.699999999999989	0.101999999999999993
60195	2N2	44.3999999999999986	0.131000000000000005
60195	OO1	223.5	0.0160000000000000003
60195	LDA2	124.099999999999994	0.0299999999999999989
60195	M1	195.5	0.0259999999999999988
60195	J1	214	0.0299999999999999989
60195	SSA	89.7999999999999972	0.0589999999999999969
60195	SA	126.299999999999997	0.104999999999999996
60195	RHO1	178	0.0129999999999999994
60195	Q1	176.699999999999989	0.0749999999999999972
60195	T2	142.699999999999989	0.0359999999999999973
60195	R2	145.699999999999989	0.00300000000000000006
60195	2Q1	167.400000000000006	0.0100000000000000002
60195	P1	203.400000000000006	0.157000000000000001
60195	L2	137.800000000000011	0.117999999999999994
60195	K2	147.199999999999989	0.16700000000000001
60195	M8	234.099999999999994	0.00700000000000000015
60196	M2	118.400000000000006	4.27799999999999958
60196	S2	169.800000000000011	0.686000000000000054
60196	N2	92.9000000000000057	0.937999999999999945
60196	K1	219.300000000000011	0.466000000000000025
60196	M4	140.599999999999994	0.197000000000000008
60196	O1	196.599999999999994	0.377000000000000002
60196	M6	318	0.0889999999999999958
60196	MK3	232.599999999999994	0.0490000000000000019
60196	S4	247.199999999999989	0.00700000000000000015
60196	MN4	109.799999999999997	0.0790000000000000008
60196	NU2	93.2999999999999972	0.190000000000000002
60196	S6	74.7999999999999972	0.00300000000000000006
60196	MU2	165	0.0490000000000000019
60196	2N2	61.5	0.128000000000000003
60196	OO1	315.5	0.0129999999999999994
60196	LDA2	115.299999999999997	0.0820000000000000034
60196	S1	88.7999999999999972	0.0660000000000000031
60196	M1	224.199999999999989	0.0429999999999999966
60196	J1	248.800000000000011	0.0160000000000000003
60196	SSA	89.7999999999999972	0.0589999999999999969
60196	SA	126.299999999999997	0.104999999999999996
60196	RHO1	273.899999999999977	0.0100000000000000002
60196	Q1	187.900000000000006	0.0560000000000000012
60196	T2	181.5	0.0889999999999999958
60196	2Q1	142.400000000000006	0.0160000000000000003
60196	P1	214.300000000000011	0.179999999999999993
60196	2SM2	94.9000000000000057	0.00300000000000000006
60196	M3	104.599999999999994	0.00300000000000000006
60196	L2	118.5	0.194000000000000006
60196	2MK3	195.199999999999989	0.0429999999999999966
60196	K2	145.900000000000006	0.187
60196	M8	260.199999999999989	0.0790000000000000008
60196	MS4	186.300000000000011	0.0490000000000000019
60197	M2	108.299999999999997	4.26799999999999979
60197	S2	145.599999999999994	0.622999999999999998
60197	N2	77.5999999999999943	1.06299999999999994
60197	K1	206.199999999999989	0.485999999999999988
60197	M4	359.699999999999989	0.0560000000000000012
60197	O1	187.5	0.384000000000000008
60197	M6	275	0.0519999999999999976
60197	S4	33	0.00300000000000000006
60197	NU2	81.7000000000000028	0.20699999999999999
60197	S6	50.2000000000000028	0.00300000000000000006
60197	MU2	289.100000000000023	0.101999999999999993
60197	2N2	46.8999999999999986	0.140999999999999986
60197	OO1	224.5	0.0160000000000000003
60197	LDA2	125.599999999999994	0.0299999999999999989
60197	M1	196.800000000000011	0.0259999999999999988
60197	J1	215.199999999999989	0.0299999999999999989
60197	RHO1	179.5	0.0129999999999999994
60197	Q1	178.300000000000011	0.0749999999999999972
60197	T2	144.099999999999994	0.0359999999999999973
60197	R2	147.099999999999994	0.00700000000000000015
60197	2Q1	169.099999999999994	0.0100000000000000002
60197	P1	204.800000000000011	0.161000000000000004
60197	L2	139	0.117999999999999994
60197	K2	148.599999999999994	0.171000000000000013
60197	M8	178.800000000000011	0.00700000000000000015
60198	M2	109.700000000000003	4.38999999999999968
60198	S2	151.5	0.781000000000000028
60198	N2	78.0999999999999943	1.07600000000000007
60198	K1	208	0.443000000000000005
60198	M4	28.8999999999999986	0.0619999999999999996
60198	O1	185.300000000000011	0.387000000000000011
60198	M6	285.899999999999977	0.0790000000000000008
60198	MK3	244.099999999999994	0.0160000000000000003
60198	MN4	8.30000000000000071	0.0389999999999999999
60198	NU2	83.2000000000000028	0.16700000000000001
60198	S6	347	0.00300000000000000006
60198	MU2	72.4000000000000057	0.0560000000000000012
60198	2N2	61.6000000000000014	0.125
60198	OO1	201.599999999999994	0.0160000000000000003
60198	LDA2	152.099999999999994	0.0719999999999999946
60198	S1	139.900000000000006	0.0619999999999999996
60198	M1	199.599999999999994	0.0259999999999999988
60198	J1	204.300000000000011	0.0389999999999999999
60198	SSA	89.7999999999999972	0.0589999999999999969
60198	SA	126.299999999999997	0.104999999999999996
60198	RHO1	91.9000000000000057	0.0160000000000000003
60198	Q1	186.400000000000006	0.0790000000000000008
60198	T2	146.300000000000011	0.104999999999999996
60198	R2	10.3000000000000007	0.147999999999999993
60198	2Q1	162	0.0129999999999999994
60198	P1	217	0.150999999999999995
60198	2SM2	113.5	0.0200000000000000004
60198	M3	137.400000000000006	0.0160000000000000003
60198	L2	168.300000000000011	0.23899999999999999
60198	2MK3	202.800000000000011	0.0259999999999999988
60198	K2	127	0.197000000000000008
60198	M8	220.5	0.0129999999999999994
60198	MS4	70.7999999999999972	0.0229999999999999996
60199	M2	110.700000000000003	4.52799999999999958
60199	S2	148.900000000000006	0.691999999999999948
60199	N2	82.5999999999999943	1.03000000000000003
60199	K1	203.199999999999989	0.485999999999999988
60199	M4	34.7999999999999972	0.0850000000000000061
60199	O1	189.199999999999989	0.387000000000000011
60199	M6	292.699999999999989	0.115000000000000005
60199	S4	185.400000000000006	0.00700000000000000015
60199	NU2	86.2999999999999972	0.200000000000000011
60199	S6	190.400000000000006	0.00300000000000000006
60199	MU2	290.399999999999977	0.107999999999999999
60199	2N2	54.3999999999999986	0.138000000000000012
60199	OO1	217	0.0160000000000000003
60199	LDA2	128.400000000000006	0.0330000000000000016
60199	M1	196.199999999999989	0.0259999999999999988
60199	J1	210	0.0299999999999999989
60199	SSA	89.7999999999999972	0.0589999999999999969
60199	SA	126.299999999999997	0.104999999999999996
60199	RHO1	183.199999999999989	0.0129999999999999994
60199	Q1	182.199999999999989	0.0749999999999999972
60199	T2	147.400000000000006	0.0389999999999999999
60199	R2	150.5	0.00700000000000000015
60199	2Q1	175.300000000000011	0.0100000000000000002
60199	P1	202.199999999999989	0.161000000000000004
60199	L2	138.800000000000011	0.128000000000000003
60199	K2	152	0.187
60199	M8	249.400000000000006	0.0229999999999999996
60200	M2	111.099999999999994	4.50499999999999989
60200	S2	146.199999999999989	0.666000000000000036
60200	N2	81.0999999999999943	1.05000000000000004
60200	K1	203.800000000000011	0.468999999999999972
60200	M4	19.3999999999999986	0.0719999999999999946
60200	O1	187.199999999999989	0.370999999999999996
60200	M6	290.199999999999989	0.115000000000000005
60200	S4	96.0999999999999943	0.0100000000000000002
60200	NU2	85.0999999999999943	0.203000000000000014
60200	S6	72.4000000000000057	0.00700000000000000015
60200	MU2	293.800000000000011	0.107999999999999999
60200	2N2	51.1000000000000014	0.138000000000000012
60200	OO1	220.300000000000011	0.0160000000000000003
60200	LDA2	127.400000000000006	0.0330000000000000016
60200	M1	195.599999999999994	0.0259999999999999988
60200	J1	212	0.0299999999999999989
60200	SSA	89.7999999999999972	0.0589999999999999969
60200	SA	126.299999999999997	0.104999999999999996
60200	RHO1	180.099999999999994	0.0129999999999999994
60200	Q1	179	0.0719999999999999946
60200	T2	144.800000000000011	0.0389999999999999999
60200	R2	147.599999999999994	0.00700000000000000015
60200	2Q1	170.800000000000011	0.0100000000000000002
60200	P1	202.5	0.153999999999999998
60200	L2	141	0.125
60200	K2	149.099999999999994	0.179999999999999993
60200	M8	236.5	0.0229999999999999996
60201	M2	109.400000000000006	4.58699999999999974
60201	S2	146.199999999999989	0.698999999999999955
60201	N2	78.9000000000000057	1.01400000000000001
60201	K1	205.199999999999989	0.468999999999999972
60201	M4	25.8999999999999986	0.0749999999999999972
60201	O1	186.699999999999989	0.390000000000000013
60201	M6	282.100000000000023	0.112000000000000002
60201	MK3	232.5	0.0160000000000000003
60201	MN4	14.5999999999999996	0.0359999999999999973
60201	NU2	85.5	0.220000000000000001
60201	MU2	69	0.0330000000000000016
60201	2N2	55	0.128000000000000003
60201	OO1	227	0.0160000000000000003
60201	LDA2	143.199999999999989	0.0719999999999999946
60201	S1	122.799999999999997	0.0129999999999999994
60201	M1	214.400000000000006	0.0229999999999999996
60201	J1	213.5	0.0330000000000000016
60201	SSA	89.7999999999999972	0.0589999999999999969
60201	SA	126.299999999999997	0.104999999999999996
60201	RHO1	152.800000000000011	0.0100000000000000002
60201	Q1	171.099999999999994	0.0690000000000000058
60201	T2	123.900000000000006	0.0619999999999999996
60201	R2	8.19999999999999929	0.0160000000000000003
60201	2Q1	168.300000000000011	0.0100000000000000002
60201	P1	202.099999999999994	0.153999999999999998
60201	L2	156.199999999999989	0.179999999999999993
60201	2MK3	207.900000000000006	0.0229999999999999996
60201	K2	144.5	0.194000000000000006
60201	M8	237.099999999999994	0.0200000000000000004
60201	MS4	68.7000000000000028	0.0299999999999999989
60202	M2	108.599999999999994	4.33999999999999986
60202	S2	144.400000000000006	0.666000000000000036
60202	N2	77	1.00099999999999989
60202	K1	204.599999999999994	0.456000000000000016
60202	M4	4.40000000000000036	0.0389999999999999999
60202	O1	187.099999999999994	0.370999999999999996
60202	M6	270	0.0660000000000000031
60202	MK3	247.5	0.0160000000000000003
60202	S4	127.799999999999997	0.00300000000000000006
60202	MN4	2	0.0200000000000000004
60202	NU2	85.4000000000000057	0.223000000000000004
60202	S6	236.900000000000006	0.00700000000000000015
60202	MU2	42.2000000000000028	0.0359999999999999973
60202	2N2	59.2999999999999972	0.135000000000000009
60202	OO1	243.900000000000006	0.0160000000000000003
60202	LDA2	151.099999999999994	0.0719999999999999946
60202	S1	109.299999999999997	0.0259999999999999988
60202	M1	202.900000000000006	0.0160000000000000003
60202	J1	217.699999999999989	0.0299999999999999989
60202	SSA	89.7999999999999972	0.0589999999999999969
60202	SA	126.299999999999997	0.104999999999999996
60202	RHO1	132.699999999999989	0.0100000000000000002
60202	Q1	171.199999999999989	0.0619999999999999996
60202	T2	120.799999999999997	0.0519999999999999976
60202	R2	12.5	0.0200000000000000004
60202	2Q1	201.300000000000011	0.00700000000000000015
60202	P1	199.099999999999994	0.157000000000000001
60202	2SM2	119.799999999999997	0.0100000000000000002
60202	M3	142.099999999999994	0.0100000000000000002
60202	L2	156.199999999999989	0.223000000000000004
60202	2MK3	212	0.0200000000000000004
60202	K2	145.699999999999989	0.187
60202	M8	229.800000000000011	0.00300000000000000006
60202	MS4	50.7999999999999972	0.0129999999999999994
60203	M2	110.599999999999994	4.46199999999999974
60203	S2	147.099999999999994	0.679000000000000048
60203	N2	77.2000000000000028	1.02699999999999991
60203	K1	205.800000000000011	0.456000000000000016
60203	M4	35.6000000000000014	0.0519999999999999976
60203	O1	187.599999999999994	0.381000000000000005
60203	M6	285.899999999999977	0.107999999999999999
60203	MK3	234.300000000000011	0.0160000000000000003
60203	S4	170.800000000000011	0.00300000000000000006
60203	MN4	26	0.0299999999999999989
60203	NU2	89.9000000000000057	0.223000000000000004
60203	S6	263.5	0.00700000000000000015
60203	MU2	65.2999999999999972	0.0299999999999999989
60203	2N2	66.7999999999999972	0.147999999999999993
60203	OO1	251	0.0229999999999999996
60203	LDA2	137.199999999999989	0.0719999999999999946
60203	S1	173.400000000000006	0.0129999999999999994
60203	M1	188.599999999999994	0.0229999999999999996
60203	J1	210.5	0.0299999999999999989
60203	SSA	89.7999999999999972	0.0589999999999999969
60203	SA	126.299999999999997	0.104999999999999996
60203	RHO1	140.699999999999989	0.0129999999999999994
60203	Q1	174.800000000000011	0.0589999999999999969
60203	T2	128.099999999999994	0.0619999999999999996
60203	R2	12.6999999999999993	0.0160000000000000003
60203	2Q1	210.599999999999994	0.0259999999999999988
60203	P1	203.699999999999989	0.150999999999999995
60203	2SM2	126.900000000000006	0.0129999999999999994
60203	M3	155.099999999999994	0.0129999999999999994
60203	L2	161.699999999999989	0.20699999999999999
60203	2MK3	207.199999999999989	0.0259999999999999988
60203	K2	148.599999999999994	0.197000000000000008
60203	M8	239.5	0.0200000000000000004
60203	MS4	85.5	0.0229999999999999996
60204	M2	113.200000000000003	4.54399999999999959
60204	S2	153.900000000000006	0.65900000000000003
60204	N2	87	1.03000000000000003
60204	K1	207.599999999999994	0.481999999999999984
60204	M4	49	0.0820000000000000034
60204	O1	188	0.394000000000000017
60204	M6	296.300000000000011	0.140999999999999986
60204	S4	159.300000000000011	0.00300000000000000006
60204	NU2	90.5	0.200000000000000011
60204	MU2	290.399999999999977	0.107999999999999999
60204	2N2	60.8999999999999986	0.138000000000000012
60204	OO1	227	0.0160000000000000003
60204	LDA2	132.099999999999994	0.0330000000000000016
60204	M1	197.900000000000006	0.0259999999999999988
60204	J1	217.199999999999989	0.0299999999999999989
60204	SSA	89.7999999999999972	0.0589999999999999969
60204	SA	126.299999999999997	0.104999999999999996
60204	RHO1	179.699999999999989	0.0160000000000000003
60204	Q1	178.400000000000006	0.0749999999999999972
60204	T2	152.300000000000011	0.0389999999999999999
60204	R2	155.599999999999994	0.00700000000000000015
60204	2Q1	168.699999999999989	0.0100000000000000002
60204	P1	206.099999999999994	0.161000000000000004
60204	L2	139.300000000000011	0.128000000000000003
60204	K2	157.199999999999989	0.179999999999999993
60204	M8	238.300000000000011	0.0330000000000000016
60205	M2	110.299999999999997	4.25199999999999978
60205	S2	147.800000000000011	0.622999999999999998
60205	N2	76.2000000000000028	0.964999999999999969
60205	K1	205.699999999999989	0.456000000000000016
60205	M4	359.899999999999977	0.0619999999999999996
60205	O1	188.400000000000006	0.381000000000000005
60205	M6	288.699999999999989	0.0719999999999999946
60205	S4	45.2000000000000028	0.00300000000000000006
60205	NU2	80.7999999999999972	0.187
60205	S6	50.1000000000000014	0.00300000000000000006
60205	MU2	291.300000000000011	0.101999999999999993
60205	2N2	42.1000000000000014	0.128000000000000003
60205	OO1	223	0.0160000000000000003
60205	LDA2	127.799999999999997	0.0299999999999999989
60205	M1	197.099999999999994	0.0259999999999999988
60205	J1	214.199999999999989	0.0299999999999999989
60205	RHO1	180.900000000000006	0.0129999999999999994
60205	Q1	179.800000000000011	0.0749999999999999972
60205	T2	146.300000000000011	0.0359999999999999973
60205	R2	149.300000000000011	0.00700000000000000015
60205	2Q1	171.199999999999989	0.0100000000000000002
60205	P1	204.400000000000006	0.150999999999999995
60205	L2	144.599999999999994	0.117999999999999994
60205	K2	150.800000000000011	0.171000000000000013
60205	M8	275.100000000000023	0.00700000000000000015
60206	M2	112.799999999999997	4.27500000000000036
60206	S2	150.099999999999994	0.630000000000000004
60206	N2	77.0999999999999943	1.0069999999999999
60206	K1	207.599999999999994	0.453000000000000014
60206	M4	8.09999999999999964	0.0619999999999999996
60206	O1	189.400000000000006	0.390000000000000013
60206	M6	299.899999999999977	0.0950000000000000011
60206	NU2	81.9000000000000057	0.197000000000000008
60206	S6	80.7000000000000028	0.00300000000000000006
60206	MU2	293.699999999999989	0.101999999999999993
60206	2N2	41.5	0.135000000000000009
60206	OO1	225.900000000000006	0.0160000000000000003
60206	LDA2	130.300000000000011	0.0299999999999999989
60206	M1	198.599999999999994	0.0259999999999999988
60206	J1	216.699999999999989	0.0299999999999999989
60206	SSA	89.7999999999999972	0.0589999999999999969
60206	SA	126.299999999999997	0.104999999999999996
60206	RHO1	181.5	0.0160000000000000003
60206	Q1	180.300000000000011	0.0749999999999999972
60206	T2	148.599999999999994	0.0359999999999999973
60206	R2	151.599999999999994	0.00700000000000000015
60206	2Q1	171.300000000000011	0.0100000000000000002
60206	P1	206.300000000000011	0.150999999999999995
60206	L2	148.400000000000006	0.117999999999999994
60206	K2	153.099999999999994	0.171000000000000013
60206	M8	257.5	0.00300000000000000006
60207	M2	112	4.48500000000000032
60207	S2	151.300000000000011	0.573999999999999955
60207	N2	78.7999999999999972	1.06000000000000005
60207	K1	206.099999999999994	0.446000000000000008
60207	M4	9.69999999999999929	0.0719999999999999946
60207	O1	187.900000000000006	0.390000000000000013
60207	M6	294.600000000000023	0.131000000000000005
60207	MK3	245.800000000000011	0.0160000000000000003
60207	S4	102.700000000000003	0.00300000000000000006
60207	MN4	351.100000000000023	0.0330000000000000016
60207	NU2	91.9000000000000057	0.235999999999999988
60207	S6	157.599999999999994	0.00300000000000000006
60207	MU2	56.5	0.0129999999999999994
60207	2N2	74.7000000000000028	0.104999999999999996
60207	OO1	235.5	0.0160000000000000003
60207	LDA2	141.900000000000006	0.0660000000000000031
60207	S1	221.199999999999989	0.0160000000000000003
60207	M1	201.699999999999989	0.0229999999999999996
60207	J1	211.900000000000006	0.0299999999999999989
60207	SSA	89.7999999999999972	0.0589999999999999969
60207	SA	126.299999999999997	0.104999999999999996
60207	RHO1	194.400000000000006	0.0100000000000000002
60207	Q1	172	0.0589999999999999969
60207	T2	96.9000000000000057	0.0359999999999999973
60207	2Q1	198.300000000000011	0.00700000000000000015
60207	P1	201.699999999999989	0.140999999999999986
60207	2SM2	102.200000000000003	0.00700000000000000015
60207	M3	152.199999999999989	0.0129999999999999994
60207	L2	170.300000000000011	0.266000000000000014
60207	2MK3	216.599999999999994	0.0229999999999999996
60207	K2	138.800000000000011	0.23000000000000001
60207	M8	48.6000000000000014	0.00300000000000000006
60207	MS4	55.6000000000000014	0.0229999999999999996
60208	M2	120.400000000000006	4.46799999999999997
60208	S2	161.400000000000006	0.630000000000000004
60208	N2	89.5	1.004
60208	K1	213.199999999999989	0.466000000000000025
60208	M4	127.900000000000006	0.235999999999999988
60208	O1	193.599999999999994	0.400000000000000022
60208	M6	340	0.187
60208	NU2	93.5999999999999943	0.194000000000000006
60208	S6	109.700000000000003	0.0100000000000000002
60208	MU2	298.199999999999989	0.107999999999999999
60208	2N2	58.3999999999999986	0.135000000000000009
60208	OO1	232.800000000000011	0.0160000000000000003
60208	LDA2	139.400000000000006	0.0330000000000000016
60208	M1	203.5	0.0299999999999999989
60208	J1	222.900000000000006	0.0330000000000000016
60208	SSA	89.7999999999999972	0.0589999999999999969
60208	SA	126.299999999999997	0.104999999999999996
60208	RHO1	185.199999999999989	0.0160000000000000003
60208	Q1	183.900000000000006	0.0790000000000000008
60208	T2	159.699999999999989	0.0359999999999999973
60208	R2	163	0.00700000000000000015
60208	2Q1	174.199999999999989	0.0100000000000000002
60208	P1	211.699999999999989	0.153999999999999998
60208	L2	151.599999999999994	0.125
60208	K2	164.699999999999989	0.171000000000000013
60208	M8	340.399999999999977	0.0619999999999999996
60209	M2	117.400000000000006	4.44500000000000028
60209	S2	156.300000000000011	0.682000000000000051
60209	N2	83.5	1.004
60209	K1	210.900000000000006	0.459000000000000019
60209	M4	112.700000000000003	0.150999999999999995
60209	O1	193.400000000000006	0.384000000000000008
60209	M6	325.199999999999989	0.194000000000000006
60209	S4	284.5	0.00300000000000000006
60209	NU2	88.0999999999999943	0.194000000000000006
60209	S6	90.7999999999999972	0.0100000000000000002
60209	MU2	297.199999999999989	0.107999999999999999
60209	2N2	49.7000000000000028	0.135000000000000009
60209	OO1	228.400000000000006	0.0160000000000000003
60209	LDA2	135.400000000000006	0.0330000000000000016
60209	M1	202.199999999999989	0.0259999999999999988
60209	J1	219.5	0.0299999999999999989
60209	SSA	89.7999999999999972	0.0589999999999999969
60209	SA	126.299999999999997	0.104999999999999996
60209	RHO1	185.900000000000006	0.0129999999999999994
60209	Q1	184.800000000000011	0.0749999999999999972
60209	T2	154.699999999999989	0.0389999999999999999
60209	R2	157.800000000000011	0.00700000000000000015
60209	2Q1	176.099999999999994	0.0100000000000000002
60209	P1	209.599999999999994	0.150999999999999995
60209	L2	151.300000000000011	0.125
60209	K2	159.400000000000006	0.183999999999999997
60209	M8	300.5	0.0429999999999999966
60210	M2	107.299999999999997	3.65799999999999992
60210	S2	142	0.541000000000000036
60210	N2	75.4000000000000057	0.876000000000000001
60210	K1	202.199999999999989	0.429999999999999993
60210	M4	64.0999999999999943	0.143999999999999989
60210	O1	188	0.343999999999999972
60210	M6	297.300000000000011	0.128000000000000003
60210	S4	35.8999999999999986	0.00700000000000000015
60210	NU2	79.7000000000000028	0.171000000000000013
60210	S6	130.699999999999989	0.00300000000000000006
60210	MU2	291.600000000000023	0.0889999999999999958
60210	2N2	43.5	0.117999999999999994
60210	OO1	216.300000000000011	0.0160000000000000003
60210	LDA2	123.5	0.0259999999999999988
60210	M1	195.199999999999989	0.0229999999999999996
60210	J1	209.199999999999989	0.0259999999999999988
60210	RHO1	182	0.0129999999999999994
60210	Q1	181	0.0660000000000000031
60210	T2	140.599999999999994	0.0330000000000000016
60210	R2	143.400000000000006	0.00300000000000000006
60210	2Q1	174	0.0100000000000000002
60210	P1	201.099999999999994	0.140999999999999986
60210	L2	139.300000000000011	0.101999999999999993
60210	K2	144.800000000000011	0.147999999999999993
60210	M8	223.699999999999989	0.0160000000000000003
60211	M2	109.200000000000003	4.10400000000000009
60211	S2	146.599999999999994	0.603999999999999981
60211	N2	77.5999999999999943	0.964999999999999969
60211	K1	203.300000000000011	0.446000000000000008
60211	M4	35.2000000000000028	0.0950000000000000011
60211	O1	187.900000000000006	0.36399999999999999
60211	M6	294.600000000000023	0.131000000000000005
60211	S4	229.400000000000006	0.00300000000000000006
60211	NU2	81.9000000000000057	0.187
60211	S6	127.900000000000006	0.00300000000000000006
60211	MU2	71.7999999999999972	0.0980000000000000038
60211	2N2	46	0.128000000000000003
60211	OO1	218.699999999999989	0.0160000000000000003
60211	LDA2	126.599999999999994	0.0299999999999999989
60211	M1	195.699999999999989	0.0259999999999999988
60211	J1	211	0.0299999999999999989
60211	RHO1	181.300000000000011	0.0129999999999999994
60211	Q1	180.300000000000011	0.0690000000000000058
60211	T2	145.199999999999989	0.0359999999999999973
60211	R2	147.699999999999989	0.00300000000000000006
60211	2Q1	172.599999999999994	0.0100000000000000002
60211	P1	202.099999999999994	0.147999999999999993
60211	L2	140.900000000000006	0.115000000000000005
60211	K2	149.699999999999989	0.164000000000000007
60211	M8	230.699999999999989	0.00300000000000000006
60212	M2	99.0999999999999943	2.82500000000000018
60212	S2	130.5	0.406999999999999973
60212	N2	66.5999999999999943	0.711999999999999966
60212	K1	198.5	0.341000000000000025
60212	M4	58.2999999999999972	0.143999999999999989
60212	O1	194.800000000000011	0.301999999999999991
60212	M6	295.399999999999977	0.112000000000000002
60212	S4	52.3999999999999986	0.0129999999999999994
60212	NU2	70.9000000000000057	0.138000000000000012
60212	S6	93.2000000000000028	0.0100000000000000002
60212	MU2	286.5	0.0690000000000000058
60212	2N2	34	0.0950000000000000011
60212	OO1	202.800000000000011	0.0129999999999999994
60212	LDA2	113.799999999999997	0.0200000000000000004
60212	M1	196.699999999999989	0.0229999999999999996
60212	J1	200.699999999999989	0.0229999999999999996
60212	RHO1	192.300000000000011	0.0129999999999999994
60212	Q1	192.800000000000011	0.0589999999999999969
60212	T2	129.400000000000006	0.0229999999999999996
60212	R2	131.900000000000006	0.00300000000000000006
60212	2Q1	190.599999999999994	0.00700000000000000015
60212	P1	198.199999999999989	0.115000000000000005
60212	L2	131.800000000000011	0.0790000000000000008
60212	K2	133.099999999999994	0.112000000000000002
60212	M8	221.300000000000011	0.0160000000000000003
60213	M2	111.799999999999997	4.68799999999999972
60213	S2	148.5	0.701999999999999957
60213	N2	79	1.07600000000000007
60213	K1	205	0.456000000000000016
60213	M4	21.6999999999999993	0.0950000000000000011
60213	O1	189	0.370999999999999996
60213	M6	298.800000000000011	0.216999999999999998
60213	S4	57.7999999999999972	0.00300000000000000006
60213	NU2	83.4000000000000057	0.209999999999999992
60213	S6	124	0.00300000000000000006
60213	MU2	294.800000000000011	0.112000000000000002
60213	2N2	46.2000000000000028	0.140999999999999986
60213	OO1	220.800000000000011	0.0160000000000000003
60213	LDA2	128.900000000000006	0.0330000000000000016
60213	M1	197	0.0259999999999999988
60213	J1	212.699999999999989	0.0299999999999999989
60213	SSA	89.7999999999999972	0.0589999999999999969
60213	SA	126.299999999999997	0.104999999999999996
60213	RHO1	182.199999999999989	0.0129999999999999994
60213	Q1	181.099999999999994	0.0719999999999999946
60213	T2	147.099999999999994	0.0429999999999999966
60213	R2	150	0.00700000000000000015
60213	2Q1	173.199999999999989	0.0100000000000000002
60213	P1	203.800000000000011	0.150999999999999995
60213	L2	144.599999999999994	0.131000000000000005
60213	K2	151.599999999999994	0.190000000000000002
60213	M8	21.3000000000000007	0.0100000000000000002
60214	M2	79.0999999999999943	1.95199999999999996
60214	S2	104.799999999999997	0.294999999999999984
60214	N2	49.1000000000000014	0.551000000000000045
60214	K1	187.900000000000006	0.298999999999999988
60214	M4	64.7999999999999972	0.223000000000000004
60214	O1	196.699999999999989	0.279000000000000026
60214	M6	300	0.107999999999999999
60214	S4	50.7999999999999972	0.0229999999999999996
60214	NU2	53.1000000000000014	0.107999999999999999
60214	S6	88.7999999999999972	0.0100000000000000002
60214	MU2	272.300000000000011	0.0459999999999999992
60214	2N2	19	0.0719999999999999946
60214	OO1	179.099999999999994	0.0129999999999999994
60214	LDA2	91.0999999999999943	0.0129999999999999994
60214	M1	192.199999999999989	0.0200000000000000004
60214	J1	183.5	0.0229999999999999996
60214	RHO1	200.400000000000006	0.0100000000000000002
60214	Q1	201	0.0519999999999999976
60214	T2	103.799999999999997	0.0160000000000000003
60214	R2	105.900000000000006	0.00300000000000000006
60214	2Q1	205.400000000000006	0.00700000000000000015
60214	P1	188.5	0.0980000000000000038
60214	L2	109.200000000000003	0.0560000000000000012
60214	K2	106.900000000000006	0.0820000000000000034
60214	M8	231.099999999999994	0.0229999999999999996
60215	M2	50	1.69599999999999995
60215	S2	65.2000000000000028	0.315000000000000002
60215	N2	28.1999999999999993	0.475999999999999979
60215	K1	184.900000000000006	0.266000000000000014
60215	M4	65.4000000000000057	0.298999999999999988
60215	O1	194.900000000000006	0.23000000000000001
60215	M6	292.399999999999977	0.0690000000000000058
60215	MK3	12.6999999999999993	0.0259999999999999988
60215	S4	20.5	0.0299999999999999989
60215	MN4	14.8000000000000007	0.120999999999999996
60215	NU2	35.6000000000000014	0.0889999999999999958
60215	S6	320.100000000000023	0.0160000000000000003
60215	MU2	4	0.0790000000000000008
60215	2N2	15.6999999999999993	0.0749999999999999972
60215	OO1	194.800000000000011	0.0160000000000000003
60215	LDA2	126	0.0100000000000000002
60215	S1	117.400000000000006	0.0330000000000000016
60215	M1	191.5	0.0229999999999999996
60215	J1	179.900000000000006	0.0200000000000000004
60215	RHO1	185.099999999999994	0.0129999999999999994
60215	Q1	185.099999999999994	0.0490000000000000019
60215	T2	61.7999999999999972	0.0389999999999999999
60215	R2	65.7999999999999972	0.00300000000000000006
60215	2Q1	204.699999999999989	0.00700000000000000015
60215	P1	185.400000000000006	0.101999999999999993
60215	M3	43	0.0229999999999999996
60215	L2	90.2999999999999972	0.0100000000000000002
60215	2MK3	354.800000000000011	0.0359999999999999973
60215	K2	63.7999999999999972	0.0790000000000000008
60215	M8	229.099999999999994	0.0200000000000000004
60215	MS4	143.400000000000006	0.0820000000000000034
60216	M2	28.6999999999999993	1.7390000000000001
60216	S2	47.6000000000000014	0.322000000000000008
60216	N2	10.1999999999999993	0.466000000000000025
60216	K1	173.400000000000006	0.281999999999999973
60216	M4	54.6000000000000014	0.288999999999999979
60216	O1	199.900000000000006	0.173999999999999988
60216	M6	292.699999999999989	0.0749999999999999972
60216	S4	0.200000000000000011	0.0330000000000000016
60216	NU2	12.5999999999999996	0.0919999999999999984
60216	S6	273.399999999999977	0.0200000000000000004
60216	MU2	228.5	0.0429999999999999966
60216	2N2	351.600000000000023	0.0619999999999999996
60216	OO1	148.300000000000011	0.00700000000000000015
60216	LDA2	37.5	0.0129999999999999994
60216	M1	186.599999999999994	0.0129999999999999994
60216	J1	160.800000000000011	0.0129999999999999994
60216	RHO1	211.400000000000006	0.00700000000000000015
60216	Q1	213.099999999999994	0.0330000000000000016
60216	T2	46.8999999999999986	0.0200000000000000004
60216	R2	48.3999999999999986	0.00300000000000000006
60216	2Q1	224.699999999999989	0.00300000000000000006
60216	P1	175.400000000000006	0.0919999999999999984
60216	L2	47.2000000000000028	0.0490000000000000019
60216	K2	49.1000000000000014	0.0889999999999999958
60216	M8	193.5	0.00700000000000000015
60217	M2	10.6999999999999993	1.83400000000000007
60217	S2	33.7999999999999972	0.406999999999999973
60217	N2	350.300000000000011	0.509000000000000008
60217	K1	165.5	0.233000000000000013
60217	M4	45.1000000000000014	0.331000000000000016
60217	O1	198.400000000000006	0.190000000000000002
60217	M6	315.800000000000011	0.0389999999999999999
60217	S4	67.2000000000000028	0.0359999999999999973
60217	NU2	353	0.0980000000000000038
60217	S6	284.399999999999977	0.0100000000000000002
60217	MU2	206.099999999999994	0.0429999999999999966
60217	2N2	329.800000000000011	0.0690000000000000058
60217	OO1	132.699999999999989	0.0100000000000000002
60217	LDA2	21.3999999999999986	0.0129999999999999994
60217	M1	181.800000000000011	0.0129999999999999994
60217	J1	149.199999999999989	0.0160000000000000003
60217	RHO1	212.5	0.00700000000000000015
60217	Q1	214.699999999999989	0.0359999999999999973
60217	T2	32.8999999999999986	0.0229999999999999996
60217	R2	34.7000000000000028	0.00300000000000000006
60217	2Q1	231	0.00700000000000000015
60217	P1	168	0.0790000000000000008
60217	L2	31.1000000000000014	0.0519999999999999976
60217	K2	35.7000000000000028	0.112000000000000002
60217	M8	236.5	0.0100000000000000002
60218	M2	8.69999999999999929	2.01399999999999979
60218	S2	31.1000000000000014	0.429999999999999993
60218	N2	353.5	0.494999999999999996
60218	K1	168.900000000000006	0.23000000000000001
60218	M4	64.7999999999999972	0.331000000000000016
60218	O1	200.300000000000011	0.171000000000000013
60218	M6	335.399999999999977	0.0719999999999999946
60218	MK3	29.8000000000000007	0.0429999999999999966
60218	S4	29.3000000000000007	0.0359999999999999973
60218	MN4	15	0.147999999999999993
60218	NU2	348.5	0.0820000000000000034
60218	S6	338.600000000000023	0.0100000000000000002
60218	MU2	0.200000000000000011	0.0980000000000000038
60218	2N2	341.100000000000023	0.0690000000000000058
60218	OO1	172.599999999999994	0.0129999999999999994
60218	LDA2	341.600000000000023	0.0129999999999999994
60218	S1	124.700000000000003	0.0560000000000000012
60218	M1	183.300000000000011	0.0129999999999999994
60218	J1	205.300000000000011	0.0229999999999999996
60218	SA	131.800000000000011	0.197000000000000008
60218	RHO1	213.800000000000011	0.00700000000000000015
60218	Q1	182.199999999999989	0.0429999999999999966
60218	T2	17.1000000000000014	0.0359999999999999973
60218	R2	32.1000000000000014	0.00300000000000000006
60218	2Q1	231.5	0.00300000000000000006
60218	P1	185.099999999999994	0.0850000000000000061
60218	M3	35.8999999999999986	0.0330000000000000016
60218	L2	344.399999999999977	0.0660000000000000031
60218	2MK3	9.90000000000000036	0.0589999999999999969
60218	K2	30.1999999999999993	0.117999999999999994
60218	MS4	149.599999999999994	0.0889999999999999958
60219	M2	9.5	1.84400000000000008
60219	S2	31.6999999999999993	0.384000000000000008
60219	N2	353.5	0.471999999999999975
60219	K1	166.300000000000011	0.242999999999999994
60219	M4	41.2999999999999972	0.298999999999999988
60219	O1	201	0.161000000000000004
60219	M6	286.699999999999989	0.0359999999999999973
60219	S4	347.600000000000023	0.0359999999999999973
60219	NU2	355.699999999999989	0.0919999999999999984
60219	S6	262.300000000000011	0.0200000000000000004
60219	MU2	205.800000000000011	0.0429999999999999966
60219	2N2	337.600000000000023	0.0619999999999999996
60219	OO1	131.900000000000006	0.00700000000000000015
60219	LDA2	19.8000000000000007	0.0129999999999999994
60219	M1	183.599999999999994	0.0100000000000000002
60219	J1	149.300000000000011	0.0129999999999999994
60219	SSA	61.7999999999999972	0.0660000000000000031
60219	SA	140.5	0.200000000000000011
60219	RHO1	215.900000000000006	0.00700000000000000015
60219	Q1	218.199999999999989	0.0330000000000000016
60219	T2	30.8000000000000007	0.0229999999999999996
60219	R2	32.5	0.00300000000000000006
60219	2Q1	235.300000000000011	0.00300000000000000006
60219	P1	168.900000000000006	0.0820000000000000034
60219	L2	25.5	0.0519999999999999976
60219	K2	33.5	0.104999999999999996
60219	M8	154.699999999999989	0.00700000000000000015
60220	M2	140	2.33899999999999997
60220	S2	182.099999999999994	0.291999999999999982
60220	N2	108.5	0.456000000000000016
60220	K1	237.599999999999994	0.338000000000000023
60220	M4	172.699999999999989	0.138000000000000012
60220	O1	223.400000000000006	0.288999999999999979
60220	M6	140.599999999999994	0.0619999999999999996
60220	MK3	254	0.0560000000000000012
60220	S4	306.699999999999989	0.00700000000000000015
60220	MN4	154.599999999999994	0.0619999999999999996
60220	NU2	120.400000000000006	0.120999999999999996
60220	S6	64	0.00300000000000000006
60220	MU2	269.100000000000023	0.0389999999999999999
60220	2N2	65.7999999999999972	0.0459999999999999992
60220	OO1	235.800000000000011	0.0229999999999999996
60220	LDA2	156.400000000000006	0.0619999999999999996
60220	S1	285.800000000000011	0.0200000000000000004
60220	M1	289.699999999999989	0.0200000000000000004
60220	J1	292.5	0.0160000000000000003
60220	SA	165.699999999999989	0.120999999999999996
60220	RHO1	235.599999999999994	0.00300000000000000006
60220	Q1	217.699999999999989	0.0490000000000000019
60220	T2	160	0.0299999999999999989
60220	R2	12.9000000000000004	0.0100000000000000002
60220	2Q1	269.300000000000011	0.00700000000000000015
60220	P1	232.5	0.112000000000000002
60220	M3	316.199999999999989	0.0160000000000000003
60220	L2	170.300000000000011	0.176999999999999991
60220	2MK3	235	0.0490000000000000019
60220	K2	185.099999999999994	0.0850000000000000061
60220	M8	120.200000000000003	0.0200000000000000004
60220	MS4	228.300000000000011	0.0459999999999999992
60221	M2	130.300000000000011	1.80099999999999993
60221	S2	163.5	0.216999999999999998
60221	N2	93.7999999999999972	0.466000000000000025
60221	K1	219	0.343999999999999972
60221	M4	8	0.128000000000000003
60221	O1	203.300000000000011	0.294999999999999984
60221	M6	298.399999999999977	0.0719999999999999946
60221	S4	353.899999999999977	0.0100000000000000002
60221	NU2	98.7000000000000028	0.0919999999999999984
60221	MU2	317.100000000000023	0.0429999999999999966
60221	2N2	57.2000000000000028	0.0619999999999999996
60221	OO1	234.900000000000006	0.0129999999999999994
60221	LDA2	145.699999999999989	0.0129999999999999994
60221	M1	211.300000000000011	0.0200000000000000004
60221	J1	227	0.0229999999999999996
60221	SA	165.699999999999989	0.120999999999999996
60221	RHO1	196.5	0.0100000000000000002
60221	Q1	195.400000000000006	0.0560000000000000012
60221	T2	162.199999999999989	0.0129999999999999994
60221	R2	164.900000000000006	0.00300000000000000006
60221	2Q1	187.5	0.00700000000000000015
60221	P1	217.800000000000011	0.115000000000000005
60221	L2	166.900000000000006	0.0490000000000000019
60221	K2	166.199999999999989	0.0589999999999999969
60221	M8	329	0.00300000000000000006
60222	M2	132.599999999999994	1.83099999999999996
60222	S2	175.599999999999994	0.209999999999999992
60222	N2	101.400000000000006	0.471999999999999975
60222	K1	220.800000000000011	0.325000000000000011
60222	M4	13.6999999999999993	0.107999999999999999
60222	O1	211	0.304999999999999993
60222	M6	312.800000000000011	0.0690000000000000058
60222	S4	40.6000000000000014	0.0100000000000000002
60222	NU2	105.599999999999994	0.0919999999999999984
60222	S6	329	0.00300000000000000006
60222	MU2	309.800000000000011	0.0429999999999999966
60222	2N2	70.2000000000000028	0.0619999999999999996
60222	OO1	230	0.0129999999999999994
60222	LDA2	152.5	0.0129999999999999994
60222	M1	215.800000000000011	0.0229999999999999996
60222	J1	225.199999999999989	0.0229999999999999996
60222	SA	165.699999999999989	0.120999999999999996
60222	RHO1	206.900000000000006	0.0129999999999999994
60222	Q1	206.199999999999989	0.0589999999999999969
60222	T2	173.900000000000006	0.0129999999999999994
60222	2Q1	201.599999999999994	0.00700000000000000015
60222	P1	220	0.107999999999999999
60222	L2	163.900000000000006	0.0519999999999999976
60222	K2	179.099999999999994	0.0560000000000000012
60222	M8	309.699999999999989	0.0160000000000000003
60223	M2	134.300000000000011	1.48599999999999999
60223	S2	167	0.150999999999999995
60223	N2	98.7000000000000028	0.39700000000000002
60223	K1	219.5	0.325000000000000011
60223	M4	10.0999999999999996	0.153999999999999998
60223	O1	209.199999999999989	0.288999999999999979
60223	M6	333.699999999999989	0.0660000000000000031
60223	S4	358.399999999999977	0.00700000000000000015
60223	NU2	103.5	0.0790000000000000008
60223	S6	285.600000000000023	0.00300000000000000006
60223	MU2	101.799999999999997	0.0359999999999999973
60223	2N2	63.2000000000000028	0.0519999999999999976
60223	OO1	229.800000000000011	0.0129999999999999994
60223	LDA2	149.400000000000006	0.0100000000000000002
60223	M1	214.300000000000011	0.0200000000000000004
60223	J1	224.5	0.0229999999999999996
60223	SA	145.900000000000006	0.16700000000000001
60223	RHO1	204.800000000000011	0.0100000000000000002
60223	Q1	204.099999999999994	0.0560000000000000012
60223	T2	165.599999999999994	0.0100000000000000002
60223	2Q1	199.099999999999994	0.00700000000000000015
60223	P1	218.699999999999989	0.107999999999999999
60223	L2	169.900000000000006	0.0429999999999999966
60223	K2	169.699999999999989	0.0429999999999999966
60223	M8	149.900000000000006	0.0100000000000000002
60224	M2	7.20000000000000018	1.80400000000000005
60224	S2	28.8000000000000007	0.373999999999999999
60224	N2	351.600000000000023	0.459000000000000019
60224	K1	167.400000000000006	0.233000000000000013
60224	M4	37.5	0.281999999999999973
60224	O1	201.400000000000006	0.157000000000000001
60224	M6	299.100000000000023	0.0229999999999999996
60224	S4	344	0.0330000000000000016
60224	NU2	353.699999999999989	0.0889999999999999958
60224	S6	245.400000000000006	0.0129999999999999994
60224	MU2	345.800000000000011	0.0429999999999999966
60224	2N2	336	0.0589999999999999969
60224	OO1	133.300000000000011	0.00700000000000000015
60224	LDA2	17.3000000000000007	0.0129999999999999994
60224	M1	184.300000000000011	0.0100000000000000002
60224	J1	150.5	0.0129999999999999994
60224	SA	145.900000000000006	0.16700000000000001
60224	RHO1	216.099999999999994	0.00700000000000000015
60224	Q1	218.099999999999994	0.0299999999999999989
60224	T2	27.8999999999999986	0.0229999999999999996
60224	R2	29.6999999999999993	0.00300000000000000006
60224	2Q1	235.199999999999989	0.00300000000000000006
60224	P1	170	0.0749999999999999972
60224	L2	23	0.0490000000000000019
60224	K2	30.3999999999999986	0.101999999999999993
60224	M8	156.300000000000011	0.00300000000000000006
60225	M2	7.79999999999999982	1.68599999999999994
60225	S2	29.3999999999999986	0.381000000000000005
60225	N2	354.600000000000023	0.416999999999999982
60225	K1	168.300000000000011	0.190000000000000002
60225	M4	43.2999999999999972	0.235999999999999988
60225	O1	199.900000000000006	0.171000000000000013
60225	M6	24.8000000000000007	0.00700000000000000015
60225	S4	315.5	0.0129999999999999994
60225	NU2	356.399999999999977	0.0820000000000000034
60225	S6	83.5999999999999943	0.0100000000000000002
60225	MU2	204.099999999999994	0.0389999999999999999
60225	2N2	341.300000000000011	0.0560000000000000012
60225	OO1	137.199999999999989	0.00700000000000000015
60225	LDA2	18	0.0129999999999999994
60225	M1	184.099999999999994	0.0129999999999999994
60225	J1	153	0.0129999999999999994
60225	SSA	61.7999999999999972	0.0660000000000000031
60225	SA	140.5	0.200000000000000011
60225	RHO1	213.300000000000011	0.00700000000000000015
60225	Q1	215.400000000000006	0.0330000000000000016
60225	T2	28.5	0.0229999999999999996
60225	R2	30.1999999999999993	0.00300000000000000006
60225	2Q1	230.900000000000006	0.00300000000000000006
60225	P1	170.599999999999994	0.0619999999999999996
60225	L2	21.1999999999999993	0.0459999999999999992
60225	K2	31.1999999999999993	0.104999999999999996
60225	M8	142.199999999999989	0.00700000000000000015
60226	M2	7.90000000000000036	1.65399999999999991
60226	S2	359.899999999999977	0.580999999999999961
60226	N2	353.699999999999989	0.426999999999999991
60226	K1	163.300000000000011	0.171000000000000013
60226	M4	41.3999999999999986	0.20699999999999999
60226	O1	208.900000000000006	0.187
60226	M6	101.799999999999997	0.0100000000000000002
60226	MK3	23.1999999999999993	0.0490000000000000019
60226	S4	3.79999999999999982	0.00300000000000000006
60226	MN4	350.399999999999977	0.0850000000000000061
60226	NU2	355.399999999999977	0.104999999999999996
60226	S6	357.300000000000011	0.00300000000000000006
60226	MU2	350.800000000000011	0.0820000000000000034
60226	2N2	338.399999999999977	0.0660000000000000031
60226	OO1	154.5	0.00700000000000000015
60226	LDA2	4.29999999999999982	0.0330000000000000016
60226	S1	191.099999999999994	0.0519999999999999976
60226	M1	190.400000000000006	0.0229999999999999996
60226	J1	160.199999999999989	0.0229999999999999996
60226	SSA	61.7999999999999972	0.0660000000000000031
60226	SA	140.5	0.200000000000000011
60226	RHO1	100.599999999999994	0.0359999999999999973
60226	Q1	152.400000000000006	0.0749999999999999972
60226	T2	332.699999999999989	0.157000000000000001
60226	R2	146.900000000000006	0.325000000000000011
60226	2Q1	64.4000000000000057	0.0129999999999999994
60226	P1	156	0.0490000000000000019
60226	2SM2	105.400000000000006	0.0100000000000000002
60226	M3	44.7000000000000028	0.0200000000000000004
60226	L2	328	0.0429999999999999966
60226	2MK3	339.5	0.0429999999999999966
60226	K2	164.300000000000011	0.101999999999999993
60226	MS4	117.599999999999994	0.0429999999999999966
60227	M2	34.6000000000000014	0.797000000000000042
60227	S2	35.6000000000000014	0.200000000000000011
60227	N2	19.3999999999999986	0.262000000000000011
60227	K1	189	0.233000000000000013
60227	M4	355.100000000000023	0.176999999999999991
60227	O1	203.699999999999989	0.216999999999999998
60227	M6	45.5	0.0660000000000000031
60227	MK3	13.5999999999999996	0.0359999999999999973
60227	S4	347.199999999999989	0.0129999999999999994
60227	MN4	315.399999999999977	0.0790000000000000008
60227	NU2	25.8999999999999986	0.0330000000000000016
60227	MU2	352.199999999999989	0.0749999999999999972
60227	2N2	2.39999999999999991	0.0459999999999999992
60227	OO1	174.199999999999989	0.0100000000000000002
60227	LDA2	35.1000000000000014	0.00700000000000000015
60227	S1	117.200000000000003	0.0229999999999999996
60227	M1	182.900000000000006	0.0129999999999999994
60227	J1	212.400000000000006	0.0200000000000000004
60227	SA	145.900000000000006	0.16700000000000001
60227	RHO1	184.900000000000006	0.0100000000000000002
60227	Q1	185.099999999999994	0.0490000000000000019
60227	T2	25	0.0160000000000000003
60227	R2	35.7000000000000028	0.00300000000000000006
60227	2Q1	218.199999999999989	0.00700000000000000015
60227	P1	199.900000000000006	0.0889999999999999958
60227	M3	24.8999999999999986	0.0160000000000000003
60227	L2	252	0.0299999999999999989
60227	2MK3	344.699999999999989	0.0359999999999999973
60227	K2	29.6999999999999993	0.0519999999999999976
60227	M8	165.800000000000011	0.0129999999999999994
60227	MS4	56.3999999999999986	0.0359999999999999973
60228	M2	86.9000000000000057	0.676000000000000045
60228	S2	59.1000000000000014	0.0950000000000000011
60228	N2	56.6000000000000014	0.23899999999999999
60228	K1	202	0.242999999999999994
60228	M4	339.899999999999977	0.171000000000000013
60228	O1	206.099999999999994	0.220000000000000001
60228	M6	12.9000000000000004	0.0690000000000000058
60228	S4	341.699999999999989	0.0129999999999999994
60228	NU2	60.7000000000000028	0.0459999999999999992
60228	S6	45.7999999999999972	0.00700000000000000015
60228	MU2	114.799999999999997	0.0160000000000000003
60228	2N2	26.1999999999999993	0.0299999999999999989
60228	OO1	198	0.0100000000000000002
60228	LDA2	74	0.00300000000000000006
60228	M1	204	0.0129999999999999994
60228	J1	199.900000000000006	0.0160000000000000003
60228	SA	145.900000000000006	0.16700000000000001
60228	RHO1	208.300000000000011	0.00700000000000000015
60228	Q1	208.199999999999989	0.0429999999999999966
60228	T2	60.2000000000000028	0.00700000000000000015
60228	2Q1	209.900000000000006	0.00700000000000000015
60228	P1	202.300000000000011	0.0790000000000000008
60228	L2	117.299999999999997	0.0200000000000000004
60228	K2	56.7999999999999972	0.0259999999999999988
60228	M8	185.5	0.0160000000000000003
60229	M2	2.5	1.61099999999999999
60229	S2	23	0.357999999999999985
60229	N2	348	0.404000000000000026
60229	K1	166	0.179999999999999993
60229	M4	29.6999999999999993	0.190000000000000002
60229	O1	199.699999999999989	0.164000000000000007
60229	M6	85.2999999999999972	0.0100000000000000002
60229	MK3	8.40000000000000036	0.0389999999999999999
60229	S4	350.300000000000011	0.0129999999999999994
60229	MN4	343.800000000000011	0.0850000000000000061
60229	NU2	346	0.0690000000000000058
60229	MU2	346.899999999999977	0.0749999999999999972
60229	2N2	333.899999999999977	0.0560000000000000012
60229	OO1	214.300000000000011	0.0129999999999999994
60229	LDA2	346.100000000000023	0.00700000000000000015
60229	S1	141	0.0459999999999999992
60229	M1	175	0.0100000000000000002
60229	J1	196	0.0259999999999999988
60229	SSA	61.7999999999999972	0.0660000000000000031
60229	SA	140.5	0.200000000000000011
60229	RHO1	235.400000000000006	0.00700000000000000015
60229	Q1	169.099999999999994	0.0389999999999999999
60229	T2	2.89999999999999991	0.0359999999999999973
60229	R2	205.099999999999994	0.00700000000000000015
60229	2Q1	214.5	0.0129999999999999994
60229	P1	185.699999999999989	0.0560000000000000012
60229	2SM2	5.20000000000000018	0.00300000000000000006
60229	M3	30.5	0.0200000000000000004
60229	L2	314.899999999999977	0.0429999999999999966
60229	2MK3	345.600000000000023	0.0359999999999999973
60229	K2	20.5	0.0919999999999999984
60229	MS4	102.200000000000003	0.0490000000000000019
60230	M2	111.799999999999997	0.868999999999999995
60230	S2	108.700000000000003	0.0749999999999999972
60230	N2	75.4000000000000057	0.288999999999999979
60230	K1	210.599999999999994	0.262000000000000011
60230	M4	22.8999999999999986	0.220000000000000001
60230	O1	212.599999999999994	0.235999999999999988
60230	M6	23.3000000000000007	0.0980000000000000038
60230	S4	98.2999999999999972	0.0200000000000000004
60230	NU2	80.2999999999999972	0.0560000000000000012
60230	S6	163.300000000000011	0.00700000000000000015
60230	MU2	333.899999999999977	0.0200000000000000004
60230	2N2	39	0.0389999999999999999
60230	OO1	208.599999999999994	0.0100000000000000002
60230	LDA2	110.400000000000006	0.00700000000000000015
60230	M1	211.599999999999994	0.0160000000000000003
60230	J1	209.599999999999994	0.0200000000000000004
60230	RHO1	213.400000000000006	0.0100000000000000002
60230	Q1	213.599999999999994	0.0459999999999999992
60230	T2	108.900000000000006	0.00300000000000000006
60230	2Q1	214.599999999999994	0.00700000000000000015
60230	P1	210.800000000000011	0.0889999999999999958
60230	L2	148.199999999999989	0.0229999999999999996
60230	K2	108.5	0.0200000000000000004
60230	M8	197.300000000000011	0.0160000000000000003
60231	M2	13.3000000000000007	1.26600000000000001
60231	S2	33.1000000000000014	0.27200000000000002
60231	N2	358.600000000000023	0.328000000000000014
60231	K1	173.800000000000011	0.200000000000000011
60231	M4	24.1999999999999993	0.143999999999999989
60231	O1	200.5	0.164000000000000007
60231	M6	76.2999999999999972	0.0519999999999999976
60231	MK3	342.699999999999989	0.0259999999999999988
60231	S4	345.800000000000011	0.00700000000000000015
60231	MN4	346.300000000000011	0.0459999999999999992
60231	NU2	351.100000000000023	0.0490000000000000019
60231	S6	188.800000000000011	0.00300000000000000006
60231	MU2	350.699999999999989	0.0619999999999999996
60231	2N2	339.899999999999977	0.0519999999999999976
60231	OO1	179.400000000000006	0.0100000000000000002
60231	LDA2	11.8000000000000007	0.00700000000000000015
60231	S1	147.800000000000011	0.0160000000000000003
60231	M1	240.599999999999994	0.0160000000000000003
60231	J1	173.300000000000011	0.0129999999999999994
60231	SA	166.300000000000011	0.242999999999999994
60231	RHO1	179.400000000000006	0.0129999999999999994
60231	Q1	191.900000000000006	0.0299999999999999989
60231	T2	18.3000000000000007	0.0229999999999999996
60231	R2	276.699999999999989	0.00700000000000000015
60231	2Q1	96	0.00300000000000000006
60231	P1	187.300000000000011	0.0589999999999999969
60231	2SM2	22.1000000000000014	0.00700000000000000015
60231	M3	4.5	0.0100000000000000002
60231	L2	14.5999999999999996	0.0330000000000000016
60231	2MK3	335.399999999999977	0.0330000000000000016
60231	K2	33.2999999999999972	0.0690000000000000058
60231	M8	130.800000000000011	0.00700000000000000015
60231	MS4	92.5999999999999943	0.0459999999999999992
60232	M2	354.899999999999977	1.31899999999999995
60232	S2	17.6999999999999993	0.262000000000000011
60232	N2	338.5	0.331000000000000016
60232	K1	167.800000000000011	0.176999999999999991
60232	M4	318.800000000000011	0.101999999999999993
60232	O1	203.900000000000006	0.138000000000000012
60232	M6	332.899999999999977	0.0389999999999999999
60232	S4	142.099999999999994	0.0259999999999999988
60232	NU2	340.699999999999989	0.0660000000000000031
60232	S6	100.900000000000006	0.0100000000000000002
60232	MU2	332.100000000000023	0.0330000000000000016
60232	2N2	322.100000000000023	0.0429999999999999966
60232	OO1	131.699999999999989	0.00700000000000000015
60232	LDA2	5.5	0.0100000000000000002
60232	M1	185.699999999999989	0.0100000000000000002
60232	J1	149.900000000000006	0.0100000000000000002
60232	SA	165.699999999999989	0.120999999999999996
60232	RHO1	219.400000000000006	0.00700000000000000015
60232	Q1	221.800000000000011	0.0259999999999999988
60232	T2	16.8000000000000007	0.0160000000000000003
60232	R2	18.6000000000000014	0.00300000000000000006
60232	2Q1	239.699999999999989	0.00300000000000000006
60232	P1	170.5	0.0589999999999999969
60232	L2	11.3000000000000007	0.0359999999999999973
60232	K2	19.6000000000000014	0.0719999999999999946
60232	M8	69.0999999999999943	0.00700000000000000015
60233	M2	134.699999999999989	1.43999999999999995
60233	S2	166.699999999999989	0.153999999999999998
60233	N2	102.5	0.370999999999999996
60233	K1	221.599999999999994	0.301999999999999991
60233	M4	25.5	0.0919999999999999984
60233	O1	215.900000000000006	0.276000000000000023
60233	M6	7.29999999999999982	0.0330000000000000016
60233	MN4	355.399999999999977	0.0359999999999999973
60233	NU2	114.700000000000003	0.0749999999999999972
60233	MU2	23.1999999999999993	0.0259999999999999988
60233	2N2	77.9000000000000057	0.0519999999999999976
60233	OO1	238.900000000000006	0.0100000000000000002
60233	LDA2	183.900000000000006	0.0200000000000000004
60233	M1	238.099999999999994	0.0129999999999999994
60233	J1	247.300000000000011	0.0200000000000000004
60233	SA	165.699999999999989	0.120999999999999996
60233	RHO1	213.400000000000006	0.0100000000000000002
60233	Q1	204.400000000000006	0.0519999999999999976
60233	T2	147	0.0160000000000000003
60233	2Q1	210.099999999999994	0.00700000000000000015
60233	P1	225.800000000000011	0.101999999999999993
60233	L2	183.400000000000006	0.0619999999999999996
60233	K2	166.300000000000011	0.0389999999999999999
60233	MS4	73.2999999999999972	0.0229999999999999996
60234	M2	359.5	1.54499999999999993
60234	S2	13.4000000000000004	0.341000000000000025
60234	N2	343	0.390000000000000013
60234	K1	169.300000000000011	0.171000000000000013
60234	M4	16.8000000000000007	0.131000000000000005
60234	O1	198.900000000000006	0.161000000000000004
60234	M6	171.300000000000011	0.0299999999999999989
60234	MK3	17.6000000000000014	0.0229999999999999996
60234	S4	305.5	0.0100000000000000002
60234	MN4	324.5	0.0589999999999999969
60234	NU2	344.100000000000023	0.0619999999999999996
60234	S6	272.5	0.00300000000000000006
60234	MU2	346.100000000000023	0.0719999999999999946
60234	2N2	332.399999999999977	0.0619999999999999996
60234	OO1	215.300000000000011	0.0160000000000000003
60234	LDA2	20.3000000000000007	0.0100000000000000002
60234	S1	73.9000000000000057	0.0459999999999999992
60234	M1	184.599999999999994	0.0129999999999999994
60234	J1	215.199999999999989	0.0100000000000000002
60234	MM	73.9000000000000057	0.0560000000000000012
60234	SSA	75.0999999999999943	0.0519999999999999976
60234	SA	145.300000000000011	0.200000000000000011
60234	RHO1	190.699999999999989	0.0129999999999999994
60234	Q1	191.599999999999994	0.0389999999999999999
60234	T2	313.699999999999989	0.0299999999999999989
60234	R2	176.099999999999994	0.0459999999999999992
60234	2Q1	111.200000000000003	0.0100000000000000002
60234	P1	163.599999999999994	0.0850000000000000061
60234	2SM2	26	0.0100000000000000002
60234	M3	345.5	0.0129999999999999994
60234	L2	345.300000000000011	0.0459999999999999992
60234	2MK3	338.600000000000023	0.0330000000000000016
60234	K2	5.29999999999999982	0.0850000000000000061
60234	M8	298.199999999999989	0.00700000000000000015
60234	MS4	71.5999999999999943	0.0330000000000000016
60235	M2	8.59999999999999964	1.90300000000000002
60235	S2	30	0.432999999999999996
60235	N2	359.600000000000023	0.440000000000000002
60235	K1	184.099999999999994	0.281999999999999973
60235	M4	63.5	0.281999999999999973
60235	O1	172.199999999999989	0.153999999999999998
60235	M6	308.899999999999977	0.0359999999999999973
60235	S4	1.5	0.0690000000000000058
60235	NU2	0.800000000000000044	0.0850000000000000061
60235	S6	294.800000000000011	0.0129999999999999994
60235	MU2	204.699999999999989	0.0459999999999999992
60235	2N2	350.600000000000023	0.0589999999999999969
60235	OO1	196	0.00700000000000000015
60235	LDA2	18.5	0.0129999999999999994
60235	M1	178.199999999999989	0.0100000000000000002
60235	J1	190	0.0129999999999999994
60235	SSA	61.7999999999999972	0.0660000000000000031
60235	SA	140.5	0.200000000000000011
60235	RHO1	167.199999999999989	0.00700000000000000015
60235	Q1	166.400000000000006	0.0299999999999999989
60235	T2	29.1000000000000014	0.0259999999999999988
60235	R2	30.8000000000000007	0.00300000000000000006
60235	2Q1	160.5	0.00300000000000000006
60235	P1	183.199999999999989	0.0950000000000000011
60235	L2	17.6000000000000014	0.0519999999999999976
60235	K2	31.6999999999999993	0.117999999999999994
60235	M8	102.400000000000006	0.00300000000000000006
60236	M2	6.59999999999999964	1.89599999999999991
60236	S2	32.5	0.422999999999999987
60236	N2	352.300000000000011	0.435999999999999999
60236	K1	157.800000000000011	0.203000000000000014
60236	M4	56.3999999999999986	0.281999999999999973
60236	O1	203.599999999999994	0.157000000000000001
60236	M6	296.100000000000023	0.0589999999999999969
60236	MK3	33.7999999999999972	0.0459999999999999992
60236	S4	42.2000000000000028	0.0229999999999999996
60236	MN4	10.0999999999999996	0.115000000000000005
60236	NU2	351	0.0790000000000000008
60236	MU2	355	0.0820000000000000034
60236	2N2	330.600000000000023	0.0589999999999999969
60236	OO1	215.599999999999994	0.00700000000000000015
60236	LDA2	337.399999999999977	0.0100000000000000002
60236	S1	182.900000000000006	0.0560000000000000012
60236	M1	163.699999999999989	0.00700000000000000015
60236	J1	197.400000000000006	0.0330000000000000016
60236	SA	131.800000000000011	0.197000000000000008
60236	RHO1	226.699999999999989	0.0160000000000000003
60236	Q1	172.400000000000006	0.0660000000000000031
60236	T2	38.5	0.0459999999999999992
60236	R2	246.900000000000006	0.0330000000000000016
60236	2Q1	268.300000000000011	0.0259999999999999988
60236	P1	158.800000000000011	0.0589999999999999969
60236	2SM2	52.2000000000000028	0.00700000000000000015
60236	M3	73.2999999999999972	0.0429999999999999966
60236	L2	318.800000000000011	0.0299999999999999989
60236	2MK3	16.3000000000000007	0.0359999999999999973
60236	K2	19.5	0.104999999999999996
60236	M8	100.200000000000003	0.00700000000000000015
60236	MS4	137.800000000000011	0.0619999999999999996
60237	M2	2.29999999999999982	1.65700000000000003
60237	S2	25	0.353999999999999981
60237	N2	345.800000000000011	0.406999999999999973
60237	K1	166.099999999999994	0.203000000000000014
60237	M4	35.7999999999999972	0.187
60237	O1	202	0.153999999999999998
60237	M6	220.099999999999994	0.0160000000000000003
60237	MK3	19.5	0.0259999999999999988
60237	S4	5.09999999999999964	0.0229999999999999996
60237	MN4	347.899999999999977	0.0850000000000000061
60237	NU2	341	0.0690000000000000058
60237	S6	222.900000000000006	0.00300000000000000006
60237	MU2	344.5	0.0820000000000000034
60237	2N2	333	0.0589999999999999969
60237	OO1	195.699999999999989	0.0129999999999999994
60237	LDA2	345.5	0.00700000000000000015
60237	S1	121.900000000000006	0.0229999999999999996
60237	M1	204	0.0129999999999999994
60237	J1	181.099999999999994	0.0160000000000000003
60237	MM	73.9000000000000057	0.0560000000000000012
60237	SSA	75.0999999999999943	0.0519999999999999976
60237	SA	145.300000000000011	0.200000000000000011
60237	RHO1	230.900000000000006	0.0100000000000000002
60237	Q1	185.300000000000011	0.0429999999999999966
60237	T2	9	0.0299999999999999989
60237	R2	252.199999999999989	0.00300000000000000006
60237	2Q1	172.900000000000006	0.00700000000000000015
60237	P1	176.599999999999994	0.0719999999999999946
60237	2SM2	48.7999999999999972	0.00700000000000000015
60237	M3	34.1000000000000014	0.0200000000000000004
60237	L2	349.899999999999977	0.0359999999999999973
60237	2MK3	357.100000000000023	0.0330000000000000016
60237	K2	21.6999999999999993	0.0980000000000000038
60237	M8	330.399999999999977	0.00300000000000000006
60237	MS4	106.400000000000006	0.0459999999999999992
60238	M2	7.20000000000000018	1.94599999999999995
60238	S2	30	0.426999999999999991
60238	N2	351.899999999999977	0.481999999999999984
60238	K1	165.699999999999989	0.223000000000000004
60238	M4	58.2999999999999972	0.301999999999999991
60238	O1	198.599999999999994	0.16700000000000001
60238	M6	304.399999999999977	0.0589999999999999969
60238	MK3	28.8000000000000007	0.0389999999999999999
60238	S4	23.5	0.0330000000000000016
60238	MN4	9.90000000000000036	0.135000000000000009
60238	NU2	344.600000000000023	0.0749999999999999972
60238	MU2	354.399999999999977	0.0889999999999999958
60238	2N2	340.899999999999977	0.0749999999999999972
60238	OO1	169.099999999999994	0.0160000000000000003
60238	LDA2	18.1000000000000014	0.0100000000000000002
60238	S1	120.5	0.0459999999999999992
60238	M1	178.099999999999994	0.0129999999999999994
60238	J1	201.599999999999994	0.0160000000000000003
60238	SA	131.800000000000011	0.197000000000000008
60238	RHO1	212.699999999999989	0.00700000000000000015
60238	Q1	183.699999999999989	0.0429999999999999966
60238	T2	10.1999999999999993	0.0389999999999999999
60238	R2	30.8999999999999986	0.00300000000000000006
60238	2Q1	231.199999999999989	0.00300000000000000006
60238	P1	183.199999999999989	0.0820000000000000034
60238	2SM2	43	0.0100000000000000002
60238	M3	30.1000000000000014	0.0299999999999999989
60238	L2	338.300000000000011	0.0719999999999999946
60238	2MK3	3.10000000000000009	0.0519999999999999976
60238	K2	28.6000000000000014	0.117999999999999994
60238	MS4	142.400000000000006	0.0790000000000000008
60239	M2	2.79999999999999982	1.68599999999999994
60239	S2	24.8000000000000007	0.347999999999999976
60239	N2	349.300000000000011	0.406999999999999973
60239	K1	172.900000000000006	0.284999999999999976
60239	M4	45.5	0.179999999999999993
60239	O1	200.599999999999994	0.171000000000000013
60239	M6	232.699999999999989	0.0160000000000000003
60239	S4	12.1999999999999993	0.0299999999999999989
60239	NU2	351.100000000000023	0.0790000000000000008
60239	S6	345.100000000000023	0.00700000000000000015
60239	MU2	198.099999999999994	0.0389999999999999999
60239	2N2	335.800000000000011	0.0519999999999999976
60239	OO1	145.099999999999994	0.00700000000000000015
60239	LDA2	13	0.0129999999999999994
60239	M1	186.599999999999994	0.0129999999999999994
60239	J1	159.099999999999994	0.0129999999999999994
60239	RHO1	212.5	0.00700000000000000015
60239	Q1	214.400000000000006	0.0330000000000000016
60239	T2	23.8999999999999986	0.0200000000000000004
60239	R2	25.6999999999999993	0.00300000000000000006
60239	2Q1	228.099999999999994	0.00300000000000000006
60239	P1	174.900000000000006	0.0950000000000000011
60239	L2	16.3000000000000007	0.0459999999999999992
60239	K2	26.6000000000000014	0.0950000000000000011
60239	M8	19.1999999999999993	0.00700000000000000015
60240	M2	9.5	2.10999999999999988
60240	S2	33.6000000000000014	0.453000000000000014
60240	N2	354.600000000000023	0.498999999999999999
60240	K1	169.400000000000006	0.23899999999999999
60240	M4	62.1000000000000014	0.338000000000000023
60240	O1	202.199999999999989	0.183999999999999997
60240	M6	312.699999999999989	0.0889999999999999958
60240	MK3	39.2999999999999972	0.0519999999999999976
60240	S4	23.8000000000000007	0.0459999999999999992
60240	MN4	12.6999999999999993	0.143999999999999989
60240	NU2	353	0.0889999999999999958
60240	MU2	358.600000000000023	0.101999999999999993
60240	2N2	343.199999999999989	0.0719999999999999946
60240	OO1	136.5	0.00700000000000000015
60240	LDA2	346.100000000000023	0.0160000000000000003
60240	S1	125	0.0519999999999999976
60240	M1	247.599999999999994	0.0160000000000000003
60240	J1	197.099999999999994	0.0200000000000000004
60240	SA	131.800000000000011	0.197000000000000008
60240	RHO1	216.199999999999989	0.00700000000000000015
60240	Q1	179.900000000000006	0.0519999999999999976
60240	T2	14.0999999999999996	0.0429999999999999966
60240	R2	216.5	0.0129999999999999994
60240	2Q1	234.599999999999994	0.00300000000000000006
60240	P1	182.300000000000011	0.0820000000000000034
60240	M3	68.2999999999999972	0.0389999999999999999
60240	L2	321.399999999999977	0.0389999999999999999
60240	2MK3	11.5	0.0389999999999999999
60240	K2	29.6999999999999993	0.125
60240	M8	130.699999999999989	0.0160000000000000003
60240	MS4	147.400000000000006	0.0850000000000000061
60241	M2	5	1.7649999999999999
60241	S2	27.1000000000000014	0.381000000000000005
60241	N2	349.399999999999977	0.435999999999999999
60241	K1	165.099999999999994	0.209999999999999992
60241	M4	48.8999999999999986	0.216999999999999998
60241	O1	198.199999999999989	0.157000000000000001
60241	M6	270.899999999999977	0.0259999999999999988
60241	MK3	21.3999999999999986	0.0330000000000000016
60241	S4	10.3000000000000007	0.0259999999999999988
60241	MN4	0.599999999999999978	0.0980000000000000038
60241	NU2	344.699999999999989	0.0749999999999999972
60241	MU2	351.199999999999989	0.0850000000000000061
60241	2N2	339	0.0660000000000000031
60241	OO1	166.099999999999994	0.0129999999999999994
60241	LDA2	15.1999999999999993	0.0129999999999999994
60241	S1	128.5	0.0389999999999999999
60241	M1	175.199999999999989	0.0100000000000000002
60241	J1	200.599999999999994	0.0160000000000000003
60241	SA	131.800000000000011	0.197000000000000008
60241	RHO1	212.400000000000006	0.00700000000000000015
60241	Q1	183	0.0389999999999999999
60241	T2	6.79999999999999982	0.0330000000000000016
60241	R2	28	0.00300000000000000006
60241	2Q1	230.900000000000006	0.00300000000000000006
60241	P1	185.699999999999989	0.0749999999999999972
60241	2SM2	29.1999999999999993	0.0100000000000000002
60241	M3	25.3999999999999986	0.0229999999999999996
60241	L2	336.699999999999989	0.0589999999999999969
60241	2MK3	356.5	0.0429999999999999966
60241	K2	25.8000000000000007	0.101999999999999993
60241	MS4	129.199999999999989	0.0560000000000000012
60242	M2	6.79999999999999982	1.74900000000000011
60242	S2	29.6000000000000014	0.36399999999999999
60242	N2	353.699999999999989	0.416999999999999982
60242	K1	165.400000000000006	0.23000000000000001
60242	M4	56	0.209999999999999992
60242	O1	201.800000000000011	0.164000000000000007
60242	M6	268.199999999999989	0.0259999999999999988
60242	S4	348.399999999999977	0.0160000000000000003
60242	NU2	355.5	0.0820000000000000034
60242	MU2	201.099999999999994	0.0429999999999999966
60242	2N2	340.600000000000023	0.0560000000000000012
60242	OO1	128.699999999999989	0.00700000000000000015
60242	LDA2	17.3999999999999986	0.0129999999999999994
60242	M1	183.300000000000011	0.0129999999999999994
60242	J1	147.099999999999994	0.0129999999999999994
60242	SSA	61.7999999999999972	0.0660000000000000031
60242	SA	140.5	0.200000000000000011
60242	RHO1	217.400000000000006	0.00700000000000000015
60242	Q1	219.900000000000006	0.0330000000000000016
60242	T2	28.6999999999999993	0.0229999999999999996
60242	R2	30.5	0.00300000000000000006
60242	2Q1	237.900000000000006	0.00300000000000000006
60242	P1	168.099999999999994	0.0749999999999999972
60242	L2	19.8999999999999986	0.0490000000000000019
60242	K2	31.5	0.0980000000000000038
60242	M8	19.6999999999999993	0.00300000000000000006
60243	M2	6.59999999999999964	1.86699999999999999
60243	S2	32.5	0.412999999999999978
60243	N2	352.199999999999989	0.432999999999999996
60243	K1	157	0.203000000000000014
60243	M4	55.2000000000000028	0.266000000000000014
60243	O1	204	0.153999999999999998
60243	M6	287.199999999999989	0.0560000000000000012
60243	MK3	35.7000000000000028	0.0429999999999999966
60243	S4	40.2999999999999972	0.0229999999999999996
60243	MN4	8	0.107999999999999999
60243	NU2	349	0.0790000000000000008
60243	MU2	354	0.0850000000000000061
60243	2N2	331.100000000000023	0.0589999999999999969
60243	OO1	216.5	0.0100000000000000002
60243	LDA2	330.199999999999989	0.00700000000000000015
60243	S1	188.300000000000011	0.0589999999999999969
60243	M1	155.599999999999994	0.00700000000000000015
60243	J1	197	0.0299999999999999989
60243	SA	131.800000000000011	0.197000000000000008
60243	RHO1	219.900000000000006	0.0200000000000000004
60243	Q1	171.5	0.0690000000000000058
60243	T2	36.6000000000000014	0.0429999999999999966
60243	R2	246.5	0.0330000000000000016
60243	2Q1	266.899999999999977	0.0259999999999999988
60243	P1	155	0.0560000000000000012
60243	2SM2	52.6000000000000014	0.00700000000000000015
60243	M3	74	0.0429999999999999966
60243	L2	317.899999999999977	0.0259999999999999988
60243	2MK3	15.3000000000000007	0.0330000000000000016
60243	K2	18.1000000000000014	0.104999999999999996
60243	M8	72.5999999999999943	0.00300000000000000006
60243	MS4	136.199999999999989	0.0589999999999999969
60244	M2	8.19999999999999929	1.496
60244	S2	28.1999999999999993	0.325000000000000011
60244	N2	349.199999999999989	0.360999999999999988
60244	K1	162.900000000000006	0.209999999999999992
60244	M4	23.8999999999999986	0.0790000000000000008
60244	O1	198.099999999999994	0.161000000000000004
60244	M6	196.900000000000006	0.0359999999999999973
60244	MK3	36.8999999999999986	0.0200000000000000004
60244	S4	27.6000000000000014	0.00700000000000000015
60244	MN4	331.399999999999977	0.0429999999999999966
60244	NU2	320.5	0.0790000000000000008
60244	S6	252.599999999999994	0.00300000000000000006
60244	MU2	347.100000000000023	0.0820000000000000034
60244	2N2	331.600000000000023	0.0690000000000000058
60244	OO1	304.100000000000023	0.00700000000000000015
60244	LDA2	145.300000000000011	0.0229999999999999996
60244	S1	150.099999999999994	0.0490000000000000019
60244	M1	215.699999999999989	0.0200000000000000004
60244	J1	217.900000000000006	0.0160000000000000003
60244	SSA	61.7999999999999972	0.0660000000000000031
60244	SA	140.5	0.200000000000000011
60244	RHO1	82	0.0160000000000000003
60244	Q1	208.199999999999989	0.0490000000000000019
60244	T2	1.60000000000000009	0.0259999999999999988
60244	R2	192.900000000000006	0.0330000000000000016
60244	2Q1	223.599999999999994	0.00700000000000000015
60244	P1	193.599999999999994	0.0519999999999999976
60244	2SM2	61.6000000000000014	0.0229999999999999996
60244	M3	353.800000000000011	0.0229999999999999996
60244	L2	21.1000000000000014	0.0429999999999999966
60244	2MK3	18.1000000000000014	0.0259999999999999988
60244	K2	32.1000000000000014	0.0690000000000000058
60244	M8	341.300000000000011	0.00700000000000000015
60244	MS4	115.400000000000006	0.0160000000000000003
60245	M2	13.5999999999999996	1.91900000000000004
60245	S2	41	0.377000000000000002
60245	N2	359.300000000000011	0.446000000000000008
60245	K1	167.400000000000006	0.248999999999999999
60245	M4	70	0.284999999999999976
60245	O1	200.699999999999989	0.16700000000000001
60245	M6	342.300000000000011	0.0980000000000000038
60245	S4	66.7999999999999972	0.0160000000000000003
60245	NU2	1.19999999999999996	0.0850000000000000061
60245	S6	113.900000000000006	0.00300000000000000006
60245	MU2	346.199999999999989	0.0459999999999999992
60245	2N2	345	0.0589999999999999969
60245	OO1	133.400000000000006	0.00700000000000000015
60245	LDA2	26.3000000000000007	0.0129999999999999994
60245	M1	184	0.0100000000000000002
60245	J1	150.800000000000011	0.0129999999999999994
60245	SA	131.800000000000011	0.197000000000000008
60245	RHO1	214.300000000000011	0.00700000000000000015
60245	Q1	217.400000000000006	0.0330000000000000016
60245	T2	40	0.0229999999999999996
60245	R2	42.2000000000000028	0.00300000000000000006
60245	2Q1	236.099999999999994	0.00300000000000000006
60245	P1	169.900000000000006	0.0820000000000000034
60245	L2	27.8000000000000007	0.0519999999999999976
60245	K2	43.2000000000000028	0.101999999999999993
60245	M8	101	0.00700000000000000015
60246	M2	44.2000000000000028	1.19700000000000006
60246	S2	65	0.220000000000000001
60246	N2	25	0.281999999999999973
60246	K1	172.5	0.253000000000000003
60246	M4	8.80000000000000071	0.135000000000000009
60246	O1	207.5	0.161000000000000004
60246	M6	217.300000000000011	0.0889999999999999958
60246	S4	26.6000000000000014	0.00300000000000000006
60246	NU2	27.6999999999999993	0.0560000000000000012
60246	S6	344.800000000000011	0.00300000000000000006
60246	MU2	23.5	0.0299999999999999989
60246	2N2	5.90000000000000036	0.0359999999999999973
60246	OO1	137.800000000000011	0.00700000000000000015
60246	LDA2	53.8999999999999986	0.0100000000000000002
60246	M1	190	0.0100000000000000002
60246	J1	155.300000000000011	0.0129999999999999994
60246	SSA	69.4000000000000057	0.0589999999999999969
60246	SA	135.300000000000011	0.179999999999999993
60246	RHO1	222.199999999999989	0.00700000000000000015
60246	Q1	224.900000000000006	0.0299999999999999989
60246	T2	64.2000000000000028	0.0129999999999999994
60246	R2	65.7999999999999972	0.00300000000000000006
60246	2Q1	241.699999999999989	0.00300000000000000006
60246	P1	175.199999999999989	0.0850000000000000061
60246	L2	63.3999999999999986	0.0330000000000000016
60246	K2	66.7000000000000028	0.0589999999999999969
60246	M8	198.699999999999989	0.00700000000000000015
60247	M2	19.3000000000000007	1.23999999999999999
60247	S2	31.1999999999999993	0.23899999999999999
60247	N2	3.60000000000000009	0.318000000000000005
60247	K1	184.199999999999989	0.235999999999999988
60247	M4	30.1999999999999993	0.0429999999999999966
60247	O1	206.699999999999989	0.138000000000000012
60247	M6	174.099999999999994	0.0519999999999999976
60247	NU2	5.70000000000000018	0.0619999999999999996
60247	S6	17.1000000000000014	0.0100000000000000002
60247	MU2	223.900000000000006	0.0299999999999999989
60247	2N2	347.899999999999977	0.0429999999999999966
60247	OO1	161.699999999999989	0.00700000000000000015
60247	LDA2	24.8000000000000007	0.0100000000000000002
60247	M1	195.400000000000006	0.0100000000000000002
60247	J1	173	0.0100000000000000002
60247	RHO1	216.400000000000006	0.00700000000000000015
60247	Q1	217.900000000000006	0.0259999999999999988
60247	T2	30.6999999999999993	0.0129999999999999994
60247	R2	31.6000000000000014	0.00300000000000000006
60247	2Q1	229.099999999999994	0.00300000000000000006
60247	P1	185.900000000000006	0.0790000000000000008
60247	L2	34.8999999999999986	0.0359999999999999973
60247	K2	32.1000000000000014	0.0660000000000000031
60247	M8	299.800000000000011	0.00700000000000000015
60248	M2	359.800000000000011	1.42100000000000004
60248	S2	22.1000000000000014	0.318000000000000005
60248	N2	343.100000000000023	0.328000000000000014
60248	K1	168.5	0.200000000000000011
60248	M4	11.5	0.0820000000000000034
60248	O1	198.699999999999989	0.147999999999999993
60248	M6	178	0.0429999999999999966
60248	MK3	16.6000000000000014	0.0200000000000000004
60248	S4	312.699999999999989	0.00700000000000000015
60248	MN4	329.800000000000011	0.0389999999999999999
60248	NU2	343.600000000000023	0.0519999999999999976
60248	S6	185.099999999999994	0.00300000000000000006
60248	MU2	340.899999999999977	0.0719999999999999946
60248	2N2	326.899999999999977	0.0490000000000000019
60248	OO1	189.199999999999989	0.0129999999999999994
60248	LDA2	201.699999999999989	0.00300000000000000006
60248	S1	143.099999999999994	0.0129999999999999994
60248	M1	197.800000000000011	0.0100000000000000002
60248	J1	170.599999999999994	0.0160000000000000003
60248	SSA	69.4000000000000057	0.0589999999999999969
60248	SA	135.300000000000011	0.179999999999999993
60248	RHO1	144.800000000000011	0.0160000000000000003
60248	Q1	189.900000000000006	0.0429999999999999966
60248	T2	1.19999999999999996	0.0330000000000000016
60248	R2	181.599999999999994	0.00300000000000000006
60248	2Q1	117.900000000000006	0.00700000000000000015
60248	P1	175.400000000000006	0.0619999999999999996
60248	2SM2	17.5	0.0100000000000000002
60248	M3	49.2000000000000028	0.0200000000000000004
60248	L2	243.199999999999989	0.0160000000000000003
60248	2MK3	352.399999999999977	0.0160000000000000003
60248	K2	19.1000000000000014	0.0850000000000000061
60248	M8	288.699999999999989	0.00700000000000000015
60248	MS4	81	0.0200000000000000004
60249	M2	8.09999999999999964	1.29899999999999993
60249	S2	28.8999999999999986	0.281999999999999973
60249	N2	350.300000000000011	0.304999999999999993
60249	K1	165.199999999999989	0.226000000000000006
60249	M4	16.1000000000000014	0.0820000000000000034
60249	O1	200.800000000000011	0.153999999999999998
60249	M6	182.900000000000006	0.0519999999999999976
60249	MK3	22.6000000000000014	0.0160000000000000003
60249	S4	315.399999999999977	0.00300000000000000006
60249	MN4	327	0.0359999999999999973
60249	NU2	350.399999999999977	0.0619999999999999996
60249	S6	168.5	0.00300000000000000006
60249	MU2	343.100000000000023	0.0660000000000000031
60249	2N2	329	0.0459999999999999992
60249	OO1	180.099999999999994	0.0129999999999999994
60249	LDA2	84.5	0.00700000000000000015
60249	S1	227.300000000000011	0.0229999999999999996
60249	M1	196.099999999999994	0.0100000000000000002
60249	J1	171.599999999999994	0.0200000000000000004
60249	SSA	61.7999999999999972	0.0660000000000000031
60249	SA	140.5	0.200000000000000011
60249	RHO1	125	0.00700000000000000015
60249	Q1	183.800000000000011	0.0429999999999999966
60249	T2	21.1999999999999993	0.0229999999999999996
60249	R2	110.900000000000006	0.00300000000000000006
60249	2Q1	145.599999999999994	0.00300000000000000006
60249	P1	162.400000000000006	0.0560000000000000012
60249	2SM2	37.7999999999999972	0.00700000000000000015
60249	M3	59.1000000000000014	0.0160000000000000003
60249	L2	251.300000000000011	0.0229999999999999996
60249	2MK3	0.299999999999999989	0.0129999999999999994
60249	K2	29	0.0790000000000000008
60249	M8	276.5	0.00700000000000000015
60249	MS4	90.7000000000000028	0.0200000000000000004
60250	M2	5.79999999999999982	1.30600000000000005
60250	S2	25	0.276000000000000023
60250	N2	346.899999999999977	0.312
60250	K1	169.400000000000006	0.212999999999999995
60250	M4	12.6999999999999993	0.0619999999999999996
60250	O1	203.800000000000011	0.150999999999999995
60250	M6	175.900000000000006	0.0459999999999999992
60250	MK3	8.19999999999999929	0.0129999999999999994
60250	MN4	322.100000000000023	0.0299999999999999989
60250	NU2	347.899999999999977	0.0560000000000000012
60250	MU2	344.600000000000023	0.0619999999999999996
60250	2N2	329.800000000000011	0.0459999999999999992
60250	OO1	134.900000000000006	0.00700000000000000015
60250	LDA2	14.5999999999999996	0.0100000000000000002
60250	S1	103.599999999999994	0.0229999999999999996
60250	M1	181.199999999999989	0.0100000000000000002
60250	J1	174.599999999999994	0.0129999999999999994
60250	SA	131.800000000000011	0.197000000000000008
60250	RHO1	254.400000000000006	0.0160000000000000003
60250	Q1	185.699999999999989	0.0389999999999999999
60250	T2	8.5	0.0299999999999999989
60250	R2	25.6999999999999993	0.00300000000000000006
60250	2Q1	201.099999999999994	0.0160000000000000003
60250	P1	185.099999999999994	0.0660000000000000031
60250	M3	43.5	0.0160000000000000003
60250	L2	81.2000000000000028	0.0200000000000000004
60250	2MK3	3.60000000000000009	0.0160000000000000003
60250	K2	25.5	0.0749999999999999972
60250	MS4	85.2000000000000028	0.0160000000000000003
60251	M2	47.6000000000000014	1.13500000000000001
60251	S2	56.8999999999999986	0.23000000000000001
60251	N2	26.3999999999999986	0.266000000000000014
60251	K1	168.599999999999994	0.212999999999999995
60251	M4	347.600000000000023	0.0820000000000000034
60251	O1	211.599999999999994	0.150999999999999995
60251	M6	192	0.0690000000000000058
60251	MK3	39.8999999999999986	0.0200000000000000004
60251	S4	340.100000000000023	0.00700000000000000015
60251	MN4	319.699999999999989	0.0429999999999999966
60251	NU2	26.3000000000000007	0.0560000000000000012
60251	MU2	348.800000000000011	0.0389999999999999999
60251	2N2	355.199999999999989	0.0299999999999999989
60251	OO1	218.400000000000006	0.0100000000000000002
60251	LDA2	104.400000000000006	0.00300000000000000006
60251	S1	197.699999999999989	0.0589999999999999969
60251	M1	182	0.00700000000000000015
60251	J1	211.800000000000011	0.0259999999999999988
60251	SSA	69.4000000000000057	0.0589999999999999969
60251	SA	135.300000000000011	0.179999999999999993
60251	RHO1	236.800000000000011	0.0200000000000000004
60251	Q1	186	0.0619999999999999996
60251	T2	34.2000000000000028	0.0299999999999999989
60251	R2	190.400000000000006	0.0299999999999999989
60251	2Q1	269.300000000000011	0.0200000000000000004
60251	P1	172.5	0.0490000000000000019
60251	2SM2	35.1000000000000014	0.00700000000000000015
60251	M3	71.2999999999999972	0.0160000000000000003
60251	L2	115.5	0.0229999999999999996
60251	2MK3	30.8999999999999986	0.0160000000000000003
60251	K2	74.0999999999999943	0.0389999999999999999
60251	M8	242.800000000000011	0.00300000000000000006
60251	MS4	28.6000000000000014	0.0129999999999999994
60252	M2	58.2999999999999972	1.21999999999999997
60252	S2	69.9000000000000057	0.223000000000000004
60252	N2	34.6000000000000014	0.284999999999999976
60252	K1	178.5	0.242999999999999994
60252	M4	343.699999999999989	0.0850000000000000061
60252	O1	209	0.173999999999999988
60252	M6	206.099999999999994	0.0389999999999999999
60252	MK3	28.8999999999999986	0.0160000000000000003
60252	S4	344.100000000000023	0.0129999999999999994
60252	MN4	313.300000000000011	0.0459999999999999992
60252	NU2	44.7999999999999972	0.0560000000000000012
60252	MU2	347.699999999999989	0.0459999999999999992
60252	2N2	13.4000000000000004	0.0389999999999999999
60252	OO1	209.800000000000011	0.0100000000000000002
60252	LDA2	113.200000000000003	0.0200000000000000004
60252	S1	145.5	0.0229999999999999996
60252	M1	253.900000000000006	0.0160000000000000003
60252	J1	215.599999999999994	0.0200000000000000004
60252	SSA	69.4000000000000057	0.0589999999999999969
60252	SA	135.300000000000011	0.179999999999999993
60252	RHO1	222	0.00700000000000000015
60252	Q1	193.400000000000006	0.0490000000000000019
60252	T2	52.3999999999999986	0.0229999999999999996
60252	R2	70.4000000000000057	0.00300000000000000006
60252	2Q1	233.800000000000011	0.0100000000000000002
60252	P1	189.800000000000011	0.0749999999999999972
60252	M3	66.4000000000000057	0.0129999999999999994
60252	L2	127.099999999999994	0.0359999999999999973
60252	2MK3	15.1999999999999993	0.0129999999999999994
60252	K2	70.7999999999999972	0.0589999999999999969
60252	MS4	5.70000000000000018	0.0129999999999999994
60253	M2	104.599999999999994	2.23399999999999999
60253	S2	128.099999999999994	0.328000000000000014
60253	N2	85.7999999999999972	0.485999999999999988
60253	K1	183.199999999999989	0.291999999999999982
60253	M4	187.400000000000006	0.0519999999999999976
60253	O1	215.099999999999994	0.197000000000000008
60253	M6	352.100000000000023	0.0589999999999999969
60253	NU2	88.2999999999999972	0.0950000000000000011
60253	S6	238.300000000000011	0.00300000000000000006
60253	MU2	296.100000000000023	0.0519999999999999976
60253	2N2	67.0999999999999943	0.0660000000000000031
60253	OO1	151.099999999999994	0.0100000000000000002
60253	LDA2	115.5	0.0160000000000000003
60253	M1	199	0.0129999999999999994
60253	J1	167.300000000000011	0.0160000000000000003
60253	SSA	69.4000000000000057	0.0589999999999999969
60253	SA	135.300000000000011	0.179999999999999993
60253	RHO1	228.800000000000011	0.00700000000000000015
60253	Q1	230.900000000000006	0.0389999999999999999
60253	T2	127.099999999999994	0.0200000000000000004
60253	R2	129	0.00300000000000000006
60253	2Q1	246.800000000000011	0.00700000000000000015
60253	P1	185.5	0.0980000000000000038
60253	L2	123.5	0.0619999999999999996
60253	K2	130	0.0889999999999999958
60253	M8	157.199999999999989	0.0160000000000000003
60254	M2	106.400000000000006	2.93000000000000016
60254	S2	130.699999999999989	0.468999999999999972
60254	N2	81.7000000000000028	0.619999999999999996
60254	K1	190	0.304999999999999993
60254	M4	101.799999999999997	0.0129999999999999994
60254	O1	218.400000000000006	0.209999999999999992
60254	M6	350	0.0889999999999999958
60254	MK3	186.5	0.0129999999999999994
60254	MN4	67.4000000000000057	0.0129999999999999994
60254	NU2	86.2999999999999972	0.140999999999999986
60254	MU2	321.5	0.0129999999999999994
60254	2N2	72	0.0850000000000000061
60254	OO1	229.599999999999994	0.0160000000000000003
60254	LDA2	133.599999999999994	0.0619999999999999996
60254	S1	113.200000000000003	0.0519999999999999976
60254	M1	228.699999999999989	0.0100000000000000002
60254	J1	248.900000000000006	0.0259999999999999988
60254	SSA	61.2000000000000028	0.0719999999999999946
60254	SA	132	0.20699999999999999
60254	RHO1	173.099999999999994	0.0129999999999999994
60254	Q1	210.699999999999989	0.0459999999999999992
60254	T2	99.5999999999999943	0.0429999999999999966
60254	R2	131.800000000000011	0.00300000000000000006
60254	2Q1	246.5	0.00700000000000000015
60254	P1	203.699999999999989	0.0980000000000000038
60254	M3	162.400000000000006	0.0129999999999999994
60254	L2	143.800000000000011	0.171000000000000013
60254	2MK3	186.099999999999994	0.0129999999999999994
60254	K2	131.099999999999994	0.131000000000000005
60255	M2	109.599999999999994	3.25099999999999989
60255	S2	135.900000000000006	0.515000000000000013
60255	N2	87.5999999999999943	0.656000000000000028
60255	K1	191.599999999999994	0.318000000000000005
60255	M4	127.400000000000006	0.0389999999999999999
60255	O1	219.5	0.209999999999999992
60255	M6	353.899999999999977	0.0429999999999999966
60255	MK3	198.800000000000011	0.0229999999999999996
60255	MN4	97.2000000000000028	0.0229999999999999996
60255	NU2	89.7999999999999972	0.147999999999999993
60255	2N2	65.5999999999999943	0.0749999999999999972
60255	OO1	228.699999999999989	0.0160000000000000003
60255	LDA2	131.099999999999994	0.0690000000000000058
60255	S1	175.5	0.0299999999999999989
60255	M1	264.399999999999977	0.0229999999999999996
60255	J1	237	0.0200000000000000004
60255	SSA	61.2000000000000028	0.0719999999999999946
60255	SA	132	0.20699999999999999
60255	RHO1	258.100000000000023	0.0160000000000000003
60255	Q1	205.699999999999989	0.0589999999999999969
60255	T2	106.400000000000006	0.0519999999999999976
60255	R2	136.900000000000006	0.00300000000000000006
60255	2Q1	238.800000000000011	0.0129999999999999994
60255	P1	204.099999999999994	0.0980000000000000038
60255	M3	200.099999999999994	0.0129999999999999994
60255	L2	134.099999999999994	0.161000000000000004
60255	2MK3	203.699999999999989	0.0160000000000000003
60255	K2	134.699999999999989	0.150999999999999995
60256	M2	110.200000000000003	3.31000000000000005
60256	S2	138.400000000000006	0.48899999999999999
60256	N2	92.5999999999999943	0.717999999999999972
60256	K1	182.800000000000011	0.331000000000000016
60256	M4	134.900000000000006	0.0389999999999999999
60256	O1	214.5	0.197000000000000008
60256	M6	354.300000000000011	0.0459999999999999992
60256	S4	135	0.00700000000000000015
60256	NU2	94.9000000000000057	0.140999999999999986
60256	MU2	295.399999999999977	0.0790000000000000008
60256	2N2	75	0.0950000000000000011
60256	OO1	151.400000000000006	0.0100000000000000002
60256	LDA2	123.400000000000006	0.0229999999999999996
60256	M1	198.599999999999994	0.0129999999999999994
60256	J1	167.300000000000011	0.0160000000000000003
60256	SSA	61.2000000000000028	0.0719999999999999946
60256	SA	132	0.20699999999999999
60256	RHO1	228.099999999999994	0.00700000000000000015
60256	Q1	230.099999999999994	0.0359999999999999973
60256	T2	137.300000000000011	0.0299999999999999989
60256	R2	139.599999999999994	0.00300000000000000006
60256	2Q1	245.900000000000006	0.00700000000000000015
60256	P1	185.199999999999989	0.107999999999999999
60256	L2	127.799999999999997	0.0919999999999999984
60256	K2	140.699999999999989	0.135000000000000009
60256	M8	310.399999999999977	0.00700000000000000015
60257	M2	110.700000000000003	3.40899999999999981
60257	S2	145.699999999999989	0.471999999999999975
60257	N2	91.2000000000000028	0.673000000000000043
60257	K1	181.199999999999989	0.315000000000000002
60257	M4	130.099999999999994	0.0429999999999999966
60257	O1	220	0.190000000000000002
60257	M6	4.90000000000000036	0.0330000000000000016
60257	NU2	93.7999999999999972	0.131000000000000005
60257	S6	213.199999999999989	0.00700000000000000015
60257	MU2	75.7000000000000028	0.0820000000000000034
60257	2N2	71.7000000000000028	0.0889999999999999958
60257	OO1	142.5	0.0100000000000000002
60257	LDA2	127	0.0229999999999999996
60257	M1	200.5	0.0129999999999999994
60257	J1	162	0.0160000000000000003
60257	SSA	61.2000000000000028	0.0719999999999999946
60257	SA	132	0.20699999999999999
60257	RHO1	236.599999999999994	0.00700000000000000015
60257	Q1	239.199999999999989	0.0359999999999999973
60257	T2	144.300000000000011	0.0299999999999999989
60257	R2	147.099999999999994	0.00300000000000000006
60257	2Q1	258.399999999999977	0.00700000000000000015
60257	P1	184.199999999999989	0.104999999999999996
60257	L2	130.199999999999989	0.0950000000000000011
60257	K2	148.599999999999994	0.128000000000000003
60257	M8	342.399999999999977	0.0100000000000000002
60258	M2	111.900000000000006	3.41199999999999992
60258	S2	146	0.551000000000000045
60258	N2	90.2999999999999972	0.673000000000000043
60258	K1	185.300000000000011	0.298999999999999988
60258	M4	136.699999999999989	0.0820000000000000034
60258	O1	224.5	0.203000000000000014
60258	M6	31.1999999999999993	0.0200000000000000004
60258	MK3	203.599999999999994	0.0259999999999999988
60258	S4	155.5	0.00700000000000000015
60258	MN4	112.700000000000003	0.0429999999999999966
60258	NU2	89.0999999999999943	0.153999999999999998
60258	MU2	199.900000000000006	0.0129999999999999994
60258	2N2	72.7000000000000028	0.0459999999999999992
60258	OO1	275.300000000000011	0.00700000000000000015
60258	LDA2	138.400000000000006	0.0560000000000000012
60258	S1	201.599999999999994	0.0330000000000000016
60258	M1	209.5	0.0100000000000000002
60258	J1	237.400000000000006	0.0259999999999999988
60258	SSA	61.2000000000000028	0.0719999999999999946
60258	SA	132	0.20699999999999999
60258	RHO1	242	0.0200000000000000004
60258	Q1	196.400000000000006	0.0719999999999999946
60258	T2	174.699999999999989	0.0490000000000000019
60258	R2	34.1000000000000014	0.0790000000000000008
60258	2Q1	284.300000000000011	0.0330000000000000016
60258	P1	196.699999999999989	0.0690000000000000058
60258	2SM2	54.2000000000000028	0.0100000000000000002
60258	M3	219	0.0200000000000000004
60258	L2	142.199999999999989	0.187
60258	2MK3	214.699999999999989	0.0200000000000000004
60258	K2	124.099999999999994	0.173999999999999988
60258	M8	320.699999999999989	0.0129999999999999994
60258	MS4	149.400000000000006	0.0160000000000000003
60259	M2	113.900000000000006	3.51399999999999979
60259	S2	137	0.548000000000000043
60259	N2	92.7000000000000028	0.791000000000000036
60259	K1	185.199999999999989	0.331000000000000016
60259	M4	131.900000000000006	0.0690000000000000058
60259	O1	219.400000000000006	0.223000000000000004
60259	M6	143	0.0160000000000000003
60259	S4	123.700000000000003	0.00700000000000000015
60259	NU2	95.5	0.153999999999999998
60259	MU2	303.899999999999977	0.0850000000000000061
60259	2N2	71.5	0.104999999999999996
60259	OO1	150.900000000000006	0.0100000000000000002
60259	LDA2	124.599999999999994	0.0229999999999999996
60259	M1	202.099999999999994	0.0160000000000000003
60259	J1	168.199999999999989	0.0160000000000000003
60259	SSA	61.2000000000000028	0.0719999999999999946
60259	SA	132	0.20699999999999999
60259	RHO1	234.099999999999994	0.0100000000000000002
60259	Q1	236.400000000000006	0.0429999999999999966
60259	T2	136	0.0330000000000000016
60259	R2	137.900000000000006	0.00300000000000000006
60259	2Q1	253.400000000000006	0.00700000000000000015
60259	P1	187.699999999999989	0.107999999999999999
60259	L2	134.900000000000006	0.0980000000000000038
60259	K2	138.800000000000011	0.150999999999999995
60259	M8	311.199999999999989	0.0100000000000000002
60260	M2	111.700000000000003	3.4780000000000002
60260	S2	141	0.531000000000000028
60260	N2	88	0.744999999999999996
60260	K1	185.800000000000011	0.357999999999999985
60260	M4	137	0.0790000000000000008
60260	O1	229	0.164000000000000007
60260	M6	154.300000000000011	0.0560000000000000012
60260	S4	169.099999999999994	0.0160000000000000003
60260	NU2	91.2000000000000028	0.143999999999999989
60260	S6	22	0.00300000000000000006
60260	MU2	82.4000000000000057	0.0820000000000000034
60260	2N2	64.4000000000000057	0.0980000000000000038
60260	OO1	142.599999999999994	0.00700000000000000015
60260	LDA2	125.299999999999997	0.0229999999999999996
60260	M1	207.199999999999989	0.0129999999999999994
60260	J1	164.400000000000006	0.0129999999999999994
60260	SSA	61.2000000000000028	0.0719999999999999946
60260	SA	132	0.20699999999999999
60260	RHO1	247.5	0.00700000000000000015
60260	Q1	250.400000000000006	0.0330000000000000016
60260	T2	139.800000000000011	0.0330000000000000016
60260	R2	142.199999999999989	0.00300000000000000006
60260	2Q1	271.800000000000011	0.00300000000000000006
60260	P1	189	0.117999999999999994
60260	L2	135.400000000000006	0.0980000000000000038
60260	K2	143.400000000000006	0.143999999999999989
60260	M8	303.100000000000023	0.00300000000000000006
60261	M2	113.5	3.68100000000000005
60261	S2	139.300000000000011	0.593999999999999972
60261	N2	91.7999999999999972	0.721999999999999975
60261	K1	192.400000000000006	0.315000000000000002
60261	M4	133.099999999999994	0.101999999999999993
60261	O1	217.900000000000006	0.20699999999999999
60261	M6	158.400000000000006	0.117999999999999994
60261	MK3	198.099999999999994	0.0299999999999999989
60261	S4	168.5	0.0129999999999999994
60261	MN4	110.900000000000006	0.0560000000000000012
60261	NU2	93.5	0.176999999999999991
60261	S6	243.199999999999989	0.00300000000000000006
60261	MU2	174.199999999999989	0.0129999999999999994
60261	2N2	74.7000000000000028	0.0459999999999999992
60261	OO1	245.400000000000006	0.00700000000000000015
60261	LDA2	119	0.0660000000000000031
60261	S1	163.199999999999989	0.0389999999999999999
60261	M1	179.099999999999994	0.0129999999999999994
60261	J1	256.899999999999977	0.0229999999999999996
60261	SSA	61.2000000000000028	0.0719999999999999946
60261	SA	132	0.20699999999999999
60261	RHO1	288.600000000000023	0.0129999999999999994
60261	Q1	204	0.0619999999999999996
60261	T2	121	0.0589999999999999969
60261	R2	339.800000000000011	0.0229999999999999996
60261	2Q1	283.399999999999977	0.0129999999999999994
60261	P1	206.699999999999989	0.0919999999999999984
60261	2SM2	40.5	0.0129999999999999994
60261	M3	220.199999999999989	0.0229999999999999996
60261	L2	141.099999999999994	0.197000000000000008
60261	2MK3	218.099999999999994	0.0259999999999999988
60261	K2	132.400000000000006	0.171000000000000013
60261	M8	216.699999999999989	0.00700000000000000015
60261	MS4	154.199999999999989	0.0160000000000000003
60262	M2	113.599999999999994	3.66100000000000003
60262	S2	143.199999999999989	0.548000000000000043
60262	N2	91.5999999999999943	0.731999999999999984
60262	K1	187	0.322000000000000008
60262	M4	137.099999999999994	0.0820000000000000034
60262	O1	224.699999999999989	0.212999999999999995
60262	M6	160.400000000000006	0.0919999999999999984
60262	S4	190.900000000000006	0.00700000000000000015
60262	NU2	94.5999999999999943	0.140999999999999986
60262	S6	203.900000000000006	0.00300000000000000006
60262	MU2	83.9000000000000057	0.0889999999999999958
60262	2N2	69.5999999999999943	0.0950000000000000011
60262	OO1	149.099999999999994	0.0100000000000000002
60262	LDA2	127.299999999999997	0.0259999999999999988
60262	M1	205.699999999999989	0.0129999999999999994
60262	J1	168.300000000000011	0.0160000000000000003
60262	SSA	61.2000000000000028	0.0719999999999999946
60262	SA	132	0.20699999999999999
60262	RHO1	240.599999999999994	0.00700000000000000015
60262	Q1	243.400000000000006	0.0389999999999999999
60262	T2	142	0.0330000000000000016
60262	R2	144.400000000000006	0.00300000000000000006
60262	2Q1	262.5	0.00700000000000000015
60262	P1	189.900000000000006	0.104999999999999996
60262	L2	135.599999999999994	0.101999999999999993
60262	K2	145.599999999999994	0.147999999999999993
60262	M8	280.800000000000011	0.00700000000000000015
60263	M2	0.699999999999999956	1.2370000000000001
60263	S2	26.1999999999999993	0.279000000000000026
60263	N2	345	0.291999999999999982
60263	K1	161.099999999999994	0.223000000000000004
60263	M4	123.700000000000003	0.0490000000000000019
60263	O1	194.300000000000011	0.135000000000000009
60263	M6	199.5	0.0490000000000000019
60263	MK3	347.899999999999977	0.0129999999999999994
60263	NU2	339.399999999999977	0.0560000000000000012
60263	MU2	341.699999999999989	0.0660000000000000031
60263	2N2	331	0.0429999999999999966
60263	OO1	127.700000000000003	0.00700000000000000015
60263	LDA2	12.5	0.00700000000000000015
60263	S1	194	0.0229999999999999996
60263	M1	177.699999999999989	0.0100000000000000002
60263	J1	144.400000000000006	0.0100000000000000002
60263	SSA	64.4000000000000057	0.0560000000000000012
60263	SA	145.699999999999989	0.173999999999999988
60263	RHO1	208.699999999999989	0.00700000000000000015
60263	Q1	170	0.0389999999999999999
60263	T2	26.1000000000000014	0.0160000000000000003
60263	R2	26.1999999999999993	0.00300000000000000006
60263	2Q1	227.699999999999989	0.00300000000000000006
60263	P1	158.400000000000006	0.0519999999999999976
60263	M3	55.7000000000000028	0.0160000000000000003
60263	L2	269.199999999999989	0.0359999999999999973
60263	2MK3	328.899999999999977	0.0200000000000000004
60263	K2	18.8000000000000007	0.0749999999999999972
60263	MS4	148.800000000000011	0.0330000000000000016
60264	M2	48.5	0.919000000000000039
60264	S2	60.7000000000000028	0.183999999999999997
60264	N2	25.6000000000000014	0.253000000000000003
60264	K1	174.800000000000011	0.223000000000000004
60264	M4	16.6999999999999993	0.0660000000000000031
60264	O1	215.800000000000011	0.138000000000000012
60264	M6	158.300000000000011	0.0429999999999999966
60264	S4	241.300000000000011	0.00300000000000000006
60264	NU2	28.6999999999999993	0.0490000000000000019
60264	MU2	252.400000000000006	0.0229999999999999996
60264	2N2	2.70000000000000018	0.0330000000000000016
60264	OO1	133.800000000000011	0.00700000000000000015
60264	LDA2	54.1000000000000014	0.00700000000000000015
60264	M1	195.199999999999989	0.0100000000000000002
60264	J1	154.5	0.0100000000000000002
60264	RHO1	233.400000000000006	0.00700000000000000015
60264	Q1	236.199999999999989	0.0259999999999999988
60264	T2	60.2000000000000028	0.0100000000000000002
60264	2Q1	256.5	0.00300000000000000006
60264	P1	177.900000000000006	0.0719999999999999946
60264	L2	71.4000000000000057	0.0259999999999999988
60264	K2	61.6000000000000014	0.0490000000000000019
60264	M8	250.099999999999994	0.00700000000000000015
60265	M2	46.7999999999999972	0.990999999999999992
60265	S2	56.6000000000000014	0.212999999999999995
60265	N2	22.1999999999999993	0.259000000000000008
60265	K1	178.699999999999989	0.242999999999999994
60265	M4	342.699999999999989	0.0749999999999999972
60265	O1	209.800000000000011	0.176999999999999991
60265	M6	160.300000000000011	0.0389999999999999999
60265	MK3	16.8999999999999986	0.0200000000000000004
60265	S4	327.699999999999989	0.0100000000000000002
60265	MN4	307.399999999999977	0.0429999999999999966
60265	NU2	33.6000000000000014	0.0459999999999999992
60265	MU2	354.5	0.0660000000000000031
60265	2N2	354.600000000000023	0.0389999999999999999
60265	OO1	184.599999999999994	0.0129999999999999994
60265	LDA2	147.099999999999994	0.0129999999999999994
60265	S1	143.599999999999994	0.0229999999999999996
60265	M1	223.400000000000006	0.0100000000000000002
60265	J1	202.699999999999989	0.0200000000000000004
60265	SSA	50.8999999999999986	0.112000000000000002
60265	SA	135.099999999999994	0.226000000000000006
60265	RHO1	228.099999999999994	0.0129999999999999994
60265	Q1	192.599999999999994	0.0490000000000000019
60265	T2	41.7000000000000028	0.0160000000000000003
60265	R2	57	0.00300000000000000006
60265	2Q1	199.400000000000006	0.0129999999999999994
60265	P1	193.699999999999989	0.0749999999999999972
60265	M3	52.1000000000000014	0.0129999999999999994
60265	L2	168.300000000000011	0.0299999999999999989
60265	2MK3	6.20000000000000018	0.0160000000000000003
60265	K2	61.6000000000000014	0.0619999999999999996
60266	M2	60.1000000000000014	1.06000000000000005
60266	S2	73.7999999999999972	0.200000000000000011
60266	N2	37.6000000000000014	0.256000000000000005
60266	K1	178.900000000000006	0.242999999999999994
60266	M4	344	0.0719999999999999946
60266	O1	208.099999999999994	0.153999999999999998
60266	M6	194.199999999999989	0.0459999999999999992
60266	MK3	22.1999999999999993	0.0200000000000000004
60266	S4	327.899999999999977	0.0100000000000000002
60266	MN4	309.300000000000011	0.0429999999999999966
60266	NU2	47	0.0519999999999999976
60266	S6	216.599999999999994	0.00700000000000000015
60266	MU2	344.300000000000011	0.0429999999999999966
60266	2N2	33.8999999999999986	0.0429999999999999966
60266	OO1	186	0.0100000000000000002
60266	LDA2	130.900000000000006	0.0200000000000000004
60266	S1	91.5999999999999943	0.0359999999999999973
60266	M1	205.5	0.0229999999999999996
60266	J1	242.900000000000006	0.0259999999999999988
60266	SSA	69.4000000000000057	0.0589999999999999969
60266	SA	135.300000000000011	0.179999999999999993
60266	RHO1	223.5	0.0200000000000000004
60266	Q1	192.699999999999989	0.0429999999999999966
60266	T2	65.5999999999999943	0.0200000000000000004
60266	R2	247.900000000000006	0.00300000000000000006
60266	2Q1	130.199999999999989	0.0100000000000000002
60266	P1	199.599999999999994	0.0820000000000000034
60266	2SM2	35.3999999999999986	0.0100000000000000002
60266	M3	45.7999999999999972	0.00700000000000000015
60266	L2	86.4000000000000057	0.0229999999999999996
60266	2MK3	355	0.0160000000000000003
60266	K2	68.9000000000000057	0.0519999999999999976
60266	M8	218.400000000000006	0.00300000000000000006
60266	MS4	11.4000000000000004	0.0129999999999999994
60267	M2	78	1.16500000000000004
60267	S2	89.0999999999999943	0.209999999999999992
60267	N2	50	0.269000000000000017
60267	K1	186.400000000000006	0.233000000000000013
60267	M4	284.100000000000023	0.0259999999999999988
60267	O1	214.900000000000006	0.150999999999999995
60267	M6	166.699999999999989	0.0160000000000000003
60267	MK3	0	0.0160000000000000003
60267	S4	330.399999999999977	0.00700000000000000015
60267	MN4	291.5	0.0200000000000000004
60267	NU2	59.1000000000000014	0.0459999999999999992
60267	S6	284.199999999999989	0.00300000000000000006
60267	MU2	358.300000000000011	0.0490000000000000019
60267	2N2	9	0.0459999999999999992
60267	OO1	226.199999999999989	0.0129999999999999994
60267	LDA2	142	0.0229999999999999996
60267	S1	135.099999999999994	0.0160000000000000003
60267	M1	209.900000000000006	0.0200000000000000004
60267	J1	255	0.00300000000000000006
60267	SSA	50.8999999999999986	0.112000000000000002
60267	SA	135.099999999999994	0.226000000000000006
60267	RHO1	193.800000000000011	0.0200000000000000004
60267	Q1	211.699999999999989	0.0519999999999999976
60267	T2	54.6000000000000014	0.0229999999999999996
60267	R2	236.199999999999989	0.0100000000000000002
60267	2Q1	137	0.0129999999999999994
60267	P1	191.699999999999989	0.0619999999999999996
60267	2SM2	47.7999999999999972	0.0100000000000000002
60267	M3	74.4000000000000057	0.0129999999999999994
60267	L2	148.099999999999994	0.0889999999999999958
60267	2MK3	14.0999999999999996	0.0160000000000000003
60267	K2	85.2000000000000028	0.0560000000000000012
60267	M8	247	0.00700000000000000015
60267	MS4	232.900000000000006	0.0129999999999999994
60268	M2	73.5999999999999943	1.21700000000000008
60268	S2	84.7000000000000028	0.223000000000000004
60268	N2	44.6000000000000014	0.284999999999999976
60268	K1	180.5	0.248999999999999999
60268	M4	12.0999999999999996	0.0359999999999999973
60268	O1	212.699999999999989	0.16700000000000001
60268	M6	237.099999999999994	0.0229999999999999996
60268	MN4	319.5	0.0299999999999999989
60268	NU2	55.6000000000000014	0.0519999999999999976
60268	MU2	350.399999999999977	0.0560000000000000012
60268	2N2	16.1000000000000014	0.0429999999999999966
60268	OO1	225.5	0.0160000000000000003
60268	LDA2	134.099999999999994	0.0259999999999999988
60268	S1	148.900000000000006	0.0200000000000000004
60268	M1	201.099999999999994	0.0200000000000000004
60268	J1	230.099999999999994	0.0160000000000000003
60268	SSA	50.8999999999999986	0.112000000000000002
60268	SA	135.099999999999994	0.226000000000000006
60268	Q1	202.699999999999989	0.0519999999999999976
60268	T2	56.2000000000000028	0.0229999999999999996
60268	2Q1	169.599999999999994	0.0200000000000000004
60268	P1	188.699999999999989	0.0749999999999999972
60268	M3	65.4000000000000057	0.0100000000000000002
60268	L2	139.199999999999989	0.0660000000000000031
60268	2MK3	15.8000000000000007	0.0129999999999999994
60268	K2	80.0999999999999943	0.0589999999999999969
60269	M2	91.2999999999999972	1.13500000000000001
60269	S2	101.299999999999997	0.187
60269	N2	63.8999999999999986	0.248999999999999999
60269	K1	188.199999999999989	0.23899999999999999
60269	M4	3.70000000000000018	0.0560000000000000012
60269	O1	230.5	0.183999999999999997
60269	M6	219.199999999999989	0.0100000000000000002
60269	S4	35.2000000000000028	0.00300000000000000006
60269	NU2	67.5	0.0490000000000000019
60269	MU2	81.2999999999999972	0.0259999999999999988
60269	2N2	36.5	0.0330000000000000016
60269	OO1	145.599999999999994	0.00700000000000000015
60269	LDA2	95.9000000000000057	0.00700000000000000015
60269	M1	209.099999999999994	0.0129999999999999994
60269	J1	167.199999999999989	0.0129999999999999994
60269	SSA	50.8999999999999986	0.112000000000000002
60269	SA	135.099999999999994	0.226000000000000006
60269	RHO1	248.800000000000011	0.00700000000000000015
60269	Q1	251.599999999999994	0.0359999999999999973
60269	T2	100.900000000000006	0.0100000000000000002
60269	2Q1	272.699999999999989	0.00300000000000000006
60269	P1	191.300000000000011	0.0790000000000000008
60269	L2	118.599999999999994	0.0330000000000000016
60269	K2	102.099999999999994	0.0490000000000000019
60269	M8	212.900000000000006	0.0100000000000000002
60270	M2	83.2999999999999972	1.20100000000000007
60270	S2	93.0999999999999943	0.194000000000000006
60270	N2	58.3999999999999986	0.262000000000000011
60270	K1	195.900000000000006	0.220000000000000001
60270	M4	350.899999999999977	0.0589999999999999969
60270	O1	233	0.173999999999999988
60270	M6	135.300000000000011	0.00700000000000000015
60270	S4	325.600000000000023	0.00700000000000000015
60270	NU2	61.7000000000000028	0.0490000000000000019
60270	S6	201	0.00700000000000000015
60270	MU2	73.5	0.0299999999999999989
60270	2N2	33.5	0.0330000000000000016
60270	OO1	160	0.00700000000000000015
60270	LDA2	87.9000000000000057	0.0100000000000000002
60270	M1	214.599999999999994	0.0129999999999999994
60270	J1	178.400000000000006	0.0129999999999999994
60270	SSA	69.4000000000000057	0.0589999999999999969
60270	SA	135.300000000000011	0.179999999999999993
60270	RHO1	248.699999999999989	0.00700000000000000015
60270	Q1	251.300000000000011	0.0330000000000000016
60270	T2	92.5999999999999943	0.0100000000000000002
60270	2Q1	269.300000000000011	0.00300000000000000006
60270	P1	198.699999999999989	0.0719999999999999946
60270	L2	108	0.0330000000000000016
60270	K2	93.9000000000000057	0.0519999999999999976
60270	M8	223.699999999999989	0.0100000000000000002
60271	M2	92.2000000000000028	1.15199999999999991
60271	S2	104.099999999999994	0.183999999999999997
60271	N2	64.7000000000000028	0.253000000000000003
60271	K1	187.5	0.242999999999999994
60271	M4	330	0.0589999999999999969
60271	O1	228	0.179999999999999993
60271	M6	224.300000000000011	0.0100000000000000002
60271	S4	353	0.00300000000000000006
60271	NU2	68.4000000000000057	0.0490000000000000019
60271	S6	150.400000000000006	0.00300000000000000006
60271	MU2	80.2000000000000028	0.0259999999999999988
60271	2N2	37.2000000000000028	0.0330000000000000016
60271	OO1	147	0.00700000000000000015
60271	LDA2	97.7000000000000028	0.00700000000000000015
60271	M1	207.5	0.0129999999999999994
60271	J1	167.900000000000006	0.0129999999999999994
60271	SSA	50.8999999999999986	0.112000000000000002
60271	SA	135.099999999999994	0.226000000000000006
60271	RHO1	245.300000000000011	0.00700000000000000015
60271	Q1	248	0.0359999999999999973
60271	T2	103.599999999999994	0.0100000000000000002
60271	2Q1	268.100000000000023	0.00300000000000000006
60271	P1	190.599999999999994	0.0820000000000000034
60271	L2	119.599999999999994	0.0330000000000000016
60271	K2	105.099999999999994	0.0490000000000000019
60271	M8	233.599999999999994	0.0100000000000000002
60272	M2	353.600000000000023	1.44399999999999995
60272	S2	22.6999999999999993	0.294999999999999984
60272	N2	338.899999999999977	0.325000000000000011
60272	K1	172	0.212999999999999995
60272	M4	46	0.138000000000000012
60272	O1	174.699999999999989	0.128000000000000003
60272	M6	260	0.0200000000000000004
60272	S4	238.300000000000011	0.00700000000000000015
60272	NU2	340.899999999999977	0.0619999999999999996
60272	S6	14.1999999999999993	0.00300000000000000006
60272	MU2	325	0.0359999999999999973
60272	2N2	324.199999999999989	0.0429999999999999966
60272	OO1	167.900000000000006	0.00300000000000000006
60272	LDA2	7	0.0100000000000000002
60272	M1	173.5	0.0100000000000000002
60272	J1	171.300000000000011	0.0100000000000000002
60272	SSA	42.8999999999999986	0.0919999999999999984
60272	SA	129.099999999999994	0.220000000000000001
60272	RHO1	177.400000000000006	0.00300000000000000006
60272	Q1	175.599999999999994	0.0229999999999999996
60272	T2	21.6000000000000014	0.0160000000000000003
60272	R2	23.6000000000000014	0.00300000000000000006
60272	2Q1	178.599999999999994	0.00300000000000000006
60272	P1	172.199999999999989	0.0690000000000000058
60272	L2	8.30000000000000071	0.0389999999999999999
60272	K2	25	0.0820000000000000034
60272	M8	353.100000000000023	0.00700000000000000015
60273	M2	7.79999999999999982	1.35200000000000009
60273	S2	38.3999999999999986	0.266000000000000014
60273	N2	355.899999999999977	0.294999999999999984
60273	K1	181.699999999999989	0.220000000000000001
60273	M4	329.100000000000023	0.0389999999999999999
60273	O1	185.900000000000006	0.161000000000000004
60273	M6	333	0.0160000000000000003
60273	S4	311.699999999999989	0.0100000000000000002
60273	NU2	357.5	0.0589999999999999969
60273	MU2	337.300000000000011	0.0330000000000000016
60273	2N2	343.899999999999977	0.0389999999999999999
60273	OO1	179	0.00700000000000000015
60273	LDA2	22	0.0100000000000000002
60273	M1	184.199999999999989	0.0100000000000000002
60273	J1	180	0.0129999999999999994
60273	SSA	42.8999999999999986	0.0919999999999999984
60273	SA	129.099999999999994	0.220000000000000001
60273	RHO1	186	0.00700000000000000015
60273	Q1	187.300000000000011	0.0299999999999999989
60273	T2	37.1000000000000014	0.0160000000000000003
60273	R2	39.5	0.00300000000000000006
60273	2Q1	186.5	0.00300000000000000006
60273	P1	182.099999999999994	0.0719999999999999946
60273	L2	19.6999999999999993	0.0359999999999999973
60273	K2	40.8999999999999986	0.0719999999999999946
60273	M8	327.899999999999977	0.00300000000000000006
60274	M2	114.200000000000003	2.46399999999999997
60274	S2	141.699999999999989	0.381000000000000005
60274	N2	94.0999999999999943	0.528000000000000025
60274	K1	185.599999999999994	0.304999999999999993
60274	M4	218.699999999999989	0.0200000000000000004
60274	O1	223.199999999999989	0.200000000000000011
60274	M6	356	0.0790000000000000008
60274	S4	77.7000000000000028	0.00300000000000000006
60274	NU2	96.7999999999999972	0.101999999999999993
60274	S6	128.900000000000006	0.00300000000000000006
60274	MU2	301.5	0.0589999999999999969
60274	2N2	73.9000000000000057	0.0690000000000000058
60274	OO1	148	0.0100000000000000002
60274	LDA2	127	0.0160000000000000003
60274	M1	204.199999999999989	0.0129999999999999994
60274	J1	166.900000000000006	0.0160000000000000003
60274	RHO1	239.300000000000011	0.00700000000000000015
60274	Q1	241.800000000000011	0.0389999999999999999
60274	T2	140.599999999999994	0.0229999999999999996
60274	R2	142.800000000000011	0.00300000000000000006
60274	2Q1	260.5	0.00700000000000000015
60274	P1	188.400000000000006	0.101999999999999993
60274	L2	134.300000000000011	0.0690000000000000058
60274	K2	143.900000000000006	0.104999999999999996
60274	M8	139.900000000000006	0.0129999999999999994
60275	M2	135.300000000000011	1.31600000000000006
60275	S2	161.199999999999989	0.187
60275	N2	116.700000000000003	0.242999999999999994
60275	K1	206.699999999999989	0.259000000000000008
60275	M4	161.699999999999989	0.0519999999999999976
60275	O1	248.699999999999989	0.179999999999999993
60275	M6	79.5999999999999943	0.0429999999999999966
60275	S4	219.599999999999994	0.00700000000000000015
60275	NU2	119.200000000000003	0.0459999999999999992
60275	MU2	324.300000000000011	0.0330000000000000016
60275	2N2	98.0999999999999943	0.0330000000000000016
60275	OO1	164.699999999999989	0.00700000000000000015
60275	LDA2	147.300000000000011	0.0100000000000000002
60275	M1	227.5	0.0129999999999999994
60275	J1	185.900000000000006	0.0129999999999999994
60275	RHO1	266.699999999999989	0.00700000000000000015
60275	Q1	269.5	0.0359999999999999973
60275	T2	160.199999999999989	0.0100000000000000002
60275	R2	162.199999999999989	0.00300000000000000006
60275	2Q1	290.300000000000011	0.00300000000000000006
60275	P1	209.900000000000006	0.0850000000000000061
60275	L2	153.900000000000006	0.0359999999999999973
60275	K2	163.300000000000011	0.0519999999999999976
60275	M8	72.2999999999999972	0.0129999999999999994
60276	M2	48.8999999999999986	1.10600000000000009
60276	S2	66.2999999999999972	0.197000000000000008
60276	N2	37.6000000000000014	0.226000000000000006
60276	K1	202.800000000000011	0.226000000000000006
60276	M4	38.1000000000000014	0.131000000000000005
60276	O1	211.400000000000006	0.117999999999999994
60276	M6	110.700000000000003	0.0330000000000000016
60276	MK3	172.900000000000006	0.0299999999999999989
60276	S4	81.0999999999999943	0.00700000000000000015
60276	MN4	27.3999999999999986	0.0560000000000000012
60276	NU2	26	0.0589999999999999969
60276	S6	120.900000000000006	0.00300000000000000006
60276	MU2	112.900000000000006	0.0589999999999999969
60276	2N2	317.5	0.0100000000000000002
60276	OO1	243.699999999999989	0.00700000000000000015
60276	LDA2	44.3999999999999986	0.0330000000000000016
60276	S1	184	0.0229999999999999996
60276	M1	236	0.0100000000000000002
60276	J1	288.100000000000023	0.0100000000000000002
60276	SSA	50.8999999999999986	0.112000000000000002
60276	SA	135.099999999999994	0.226000000000000006
60276	RHO1	238.800000000000011	0.0100000000000000002
60276	Q1	222.599999999999994	0.0389999999999999999
60276	T2	80.0999999999999943	0.0359999999999999973
60276	R2	83.5	0.0560000000000000012
60276	2Q1	230.599999999999994	0.0100000000000000002
60276	P1	211.699999999999989	0.0619999999999999996
60276	2SM2	257.199999999999989	0.0100000000000000002
60276	M3	189.800000000000011	0.0129999999999999994
60276	L2	10.0999999999999996	0.0660000000000000031
60276	2MK3	94.5	0.0200000000000000004
60276	K2	65.5999999999999943	0.0619999999999999996
60276	M8	111.599999999999994	0.0129999999999999994
60276	MS4	74.2999999999999972	0.0490000000000000019
60277	M2	111.900000000000006	2.54599999999999982
60277	S2	135.599999999999994	0.406999999999999973
60277	N2	87.4000000000000057	0.515000000000000013
60277	K1	191.300000000000011	0.288999999999999979
60277	M4	242.300000000000011	0.0100000000000000002
60277	O1	221.5	0.194000000000000006
60277	M6	345.100000000000023	0.0749999999999999972
60277	MK3	224.099999999999994	0.0100000000000000002
60277	S4	162.300000000000011	0.00300000000000000006
60277	MN4	242.699999999999989	0.00300000000000000006
60277	NU2	91.9000000000000057	0.120999999999999996
60277	S6	341	0.00300000000000000006
60277	MU2	305.899999999999977	0.0100000000000000002
60277	2N2	66.0999999999999943	0.0519999999999999976
60277	OO1	203.800000000000011	0.0129999999999999994
60277	LDA2	143.199999999999989	0.0589999999999999969
60277	S1	125.400000000000006	0.0229999999999999996
60277	M1	222.5	0.0129999999999999994
60277	J1	223.699999999999989	0.0200000000000000004
60277	SSA	61.2000000000000028	0.0719999999999999946
60277	SA	132	0.20699999999999999
60277	RHO1	194.400000000000006	0.0200000000000000004
60277	Q1	213.400000000000006	0.0429999999999999966
60277	T2	108.299999999999997	0.0359999999999999973
60277	R2	288	0.00300000000000000006
60277	2Q1	274.5	0.00700000000000000015
60277	P1	205.5	0.0850000000000000061
60277	2SM2	107.200000000000003	0.00700000000000000015
60277	M3	203.699999999999989	0.00700000000000000015
60277	L2	156.699999999999989	0.143999999999999989
60277	2MK3	211.400000000000006	0.00700000000000000015
60277	K2	136.400000000000006	0.112000000000000002
60277	M8	97.5	0.00700000000000000015
60277	MS4	293.600000000000023	0.00300000000000000006
60278	M2	36.3999999999999986	0.845999999999999974
60278	S2	69.7000000000000028	0.140999999999999986
60278	N2	27.3000000000000007	0.176999999999999991
60278	K1	210.800000000000011	0.164000000000000007
60278	M4	24.6999999999999993	0.0389999999999999999
60278	O1	212.699999999999989	0.128000000000000003
60278	M6	146.400000000000006	0.0200000000000000004
60278	S4	9.5	0.00700000000000000015
60278	NU2	28.5	0.0330000000000000016
60278	S6	62.7000000000000028	0.00300000000000000006
60278	MU2	3	0.0200000000000000004
60278	2N2	18.1999999999999993	0.0229999999999999996
60278	OO1	205.800000000000011	0.00700000000000000015
60278	LDA2	51.8999999999999986	0.00700000000000000015
60278	M1	212.199999999999989	0.0100000000000000002
60278	J1	209.900000000000006	0.0100000000000000002
60278	SSA	50.8999999999999986	0.112000000000000002
60278	SA	135.099999999999994	0.226000000000000006
60278	RHO1	211.400000000000006	0.00300000000000000006
60278	Q1	213	0.0259999999999999988
60278	T2	68.0999999999999943	0.0100000000000000002
60278	2Q1	217	0.00300000000000000006
60278	P1	211.099999999999994	0.0560000000000000012
60278	L2	45.3999999999999986	0.0229999999999999996
60278	K2	72.4000000000000057	0.0389999999999999999
60278	M8	141.599999999999994	0.00300000000000000006
60279	M2	351.100000000000023	1.3580000000000001
60279	S2	18.3999999999999986	0.266000000000000014
60279	N2	332.600000000000023	0.301999999999999991
60279	K1	168.800000000000011	0.197000000000000008
60279	M4	87.2999999999999972	0.117999999999999994
60279	O1	168.400000000000006	0.125
60279	M6	190.800000000000011	0.0229999999999999996
60279	S4	264.199999999999989	0.0100000000000000002
60279	NU2	335.100000000000023	0.0589999999999999969
60279	S6	41.1000000000000014	0.00300000000000000006
60279	MU2	323.800000000000011	0.0330000000000000016
60279	2N2	314.100000000000023	0.0389999999999999999
60279	OO1	172.199999999999989	0.00300000000000000006
60279	LDA2	3.70000000000000018	0.0100000000000000002
60279	M1	169.099999999999994	0.0100000000000000002
60279	J1	170.900000000000006	0.0100000000000000002
60279	SSA	50.8999999999999986	0.112000000000000002
60279	SA	135.099999999999994	0.226000000000000006
60279	RHO1	167	0.00300000000000000006
60279	Q1	167.699999999999989	0.0229999999999999996
60279	T2	17.1999999999999993	0.0160000000000000003
60279	R2	19.5	0.00300000000000000006
60279	2Q1	169.900000000000006	0.00300000000000000006
60279	P1	168.900000000000006	0.0660000000000000031
60279	L2	9.59999999999999964	0.0389999999999999999
60279	K2	20.6000000000000014	0.0719999999999999946
60279	M8	161.199999999999989	0.00700000000000000015
60280	M2	77.7999999999999972	0.525000000000000022
60280	S2	114.599999999999994	0.0820000000000000034
60280	N2	56.6000000000000014	0.107999999999999999
60280	K1	235.400000000000006	0.135000000000000009
60280	M4	43.8999999999999986	0.0330000000000000016
60280	O1	232	0.0919999999999999984
60280	M6	142.099999999999994	0.00700000000000000015
60280	MK3	183	0.0160000000000000003
60280	MN4	34.5	0.0160000000000000003
60280	NU2	71.2999999999999972	0.0299999999999999989
60280	MU2	183.900000000000006	0.00700000000000000015
60280	2N2	11.9000000000000004	0.0200000000000000004
60280	OO1	297.800000000000011	0.00700000000000000015
60280	LDA2	105.700000000000003	0.0129999999999999994
60280	S1	184.800000000000011	0.0200000000000000004
60280	M1	2.10000000000000009	0.0100000000000000002
60280	J1	273.5	0.00700000000000000015
60280	SSA	50.8999999999999986	0.112000000000000002
60280	SA	135.099999999999994	0.226000000000000006
60280	RHO1	174.800000000000011	0.0129999999999999994
60280	Q1	228.900000000000006	0.0160000000000000003
60280	T2	102.700000000000003	0.00300000000000000006
60280	R2	306.199999999999989	0.00700000000000000015
60280	2Q1	255.699999999999989	0.00300000000000000006
60280	P1	242.599999999999994	0.0490000000000000019
60280	2SM2	349.199999999999989	0.00700000000000000015
60280	M3	216.5	0.00300000000000000006
60280	L2	87.7999999999999972	0.0259999999999999988
60280	2MK3	139.300000000000011	0.0100000000000000002
60280	K2	107.299999999999997	0.0160000000000000003
60280	M8	185.900000000000006	0.0100000000000000002
60280	MS4	84	0.0100000000000000002
60281	M2	104	0.485999999999999988
60281	S2	135.699999999999989	0.0690000000000000058
60281	N2	82.2000000000000028	0.0919999999999999984
60281	K1	251.199999999999989	0.125
60281	M4	143.199999999999989	0.0259999999999999988
60281	O1	248.400000000000006	0.0790000000000000008
60281	M6	323.300000000000011	0.0160000000000000003
60281	MK3	211.699999999999989	0.00700000000000000015
60281	S4	146	0.00300000000000000006
60281	MN4	109.5	0.0100000000000000002
60281	NU2	99.4000000000000057	0.0229999999999999996
60281	MU2	212.199999999999989	0.0129999999999999994
60281	2N2	25.5	0.0129999999999999994
60281	OO1	312.600000000000023	0.00300000000000000006
60281	LDA2	132	0.0160000000000000003
60281	S1	182.300000000000011	0.0229999999999999996
60281	M1	352.5	0.00700000000000000015
60281	J1	303.100000000000023	0.00700000000000000015
60281	RHO1	269	0.00700000000000000015
60281	Q1	264.800000000000011	0.0160000000000000003
60281	T2	84.5	0.00700000000000000015
60281	R2	198.400000000000006	0.00300000000000000006
60281	2Q1	203.900000000000006	0.00300000000000000006
60281	P1	255.300000000000011	0.0330000000000000016
60281	2SM2	20	0.00300000000000000006
60281	M3	271.699999999999989	0.00300000000000000006
60281	L2	100.5	0.0299999999999999989
60281	2MK3	147.099999999999994	0.0129999999999999994
60281	K2	139.300000000000011	0.0160000000000000003
60281	M8	355.600000000000023	0.00300000000000000006
60281	MS4	175.800000000000011	0.0100000000000000002
60282	M2	113	3.05799999999999983
60282	S2	144.599999999999994	0.498999999999999999
60282	N2	90.4000000000000057	0.603999999999999981
60282	K1	192.800000000000011	0.294999999999999984
60282	M4	176.300000000000011	0.0299999999999999989
60282	O1	219.300000000000011	0.203000000000000014
60282	M6	348.899999999999977	0.0660000000000000031
60282	MK3	220.800000000000011	0.0229999999999999996
60282	S4	126.5	0.00300000000000000006
60282	MN4	140	0.0160000000000000003
60282	NU2	93.5999999999999943	0.115000000000000005
60282	S6	36.3999999999999986	0.00300000000000000006
60282	MU2	339.100000000000023	0.0200000000000000004
60282	2N2	60.2999999999999972	0.0259999999999999988
60282	OO1	238.099999999999994	0.0200000000000000004
60282	LDA2	145.5	0.0589999999999999969
60282	S1	222.5	0.0259999999999999988
60282	M1	217	0.0200000000000000004
60282	J1	212.599999999999994	0.0200000000000000004
60282	SSA	61.2000000000000028	0.0719999999999999946
60282	SA	132	0.20699999999999999
60282	RHO1	164.300000000000011	0.0299999999999999989
60282	Q1	210.400000000000006	0.0660000000000000031
60282	T2	23.8999999999999986	0.0820000000000000034
60282	2Q1	95.2999999999999972	0.0160000000000000003
60282	P1	195.800000000000011	0.0619999999999999996
60282	2SM2	95.7999999999999972	0.0160000000000000003
60282	M3	231.199999999999989	0.0129999999999999994
60282	L2	152.300000000000011	0.197000000000000008
60282	2MK3	218.5	0.0129999999999999994
60282	K2	130.099999999999994	0.120999999999999996
60282	M8	354.899999999999977	0.00700000000000000015
60282	MS4	242.300000000000011	0.00300000000000000006
60283	M2	82.5	0.541000000000000036
60283	S2	106.200000000000003	0.0690000000000000058
60283	N2	60.3999999999999986	0.101999999999999993
60283	K1	236.199999999999989	0.140999999999999986
60283	M4	110.200000000000003	0.0200000000000000004
60283	O1	244.099999999999994	0.107999999999999999
60283	M6	219	0.0129999999999999994
60283	S4	143.5	0.00300000000000000006
60283	NU2	63.2999999999999972	0.0200000000000000004
60283	MU2	58.7999999999999972	0.0129999999999999994
60283	2N2	38.2000000000000028	0.0129999999999999994
60283	OO1	228.300000000000011	0.00300000000000000006
60283	LDA2	93.5	0.00300000000000000006
60283	M1	240.099999999999994	0.00700000000000000015
60283	J1	232.300000000000011	0.0100000000000000002
60283	SSA	42.8999999999999986	0.0919999999999999984
60283	SA	129.099999999999994	0.220000000000000001
60283	RHO1	247.5	0.00300000000000000006
60283	Q1	248	0.0200000000000000004
60283	T2	105.200000000000003	0.00300000000000000006
60283	2Q1	252	0.00300000000000000006
60283	P1	236.800000000000011	0.0459999999999999992
60283	L2	104.700000000000003	0.0160000000000000003
60283	K2	108.099999999999994	0.0200000000000000004
60283	M8	213.400000000000006	0.00300000000000000006
60284	M2	9	0.906000000000000028
60284	S2	30.8999999999999986	0.147999999999999993
60284	N2	351.699999999999989	0.179999999999999993
60284	K1	199	0.161000000000000004
60284	M4	249.599999999999994	0.0229999999999999996
60284	O1	195.599999999999994	0.125
60284	M6	154.400000000000006	0.00300000000000000006
60284	S4	303.699999999999989	0.0100000000000000002
60284	NU2	354	0.0359999999999999973
60284	S6	138.300000000000011	0.00700000000000000015
60284	MU2	347	0.0229999999999999996
60284	2N2	334.399999999999977	0.0229999999999999996
60284	OO1	200.300000000000011	0.00700000000000000015
60284	LDA2	19.1999999999999993	0.00700000000000000015
60284	M1	197.300000000000011	0.00700000000000000015
60284	J1	200	0.0100000000000000002
60284	SSA	42.8999999999999986	0.0919999999999999984
60284	SA	129.099999999999994	0.220000000000000001
60284	RHO1	193.400000000000006	0.00300000000000000006
60284	Q1	194.099999999999994	0.0229999999999999996
60284	T2	30	0.0100000000000000002
60284	2Q1	193.5	0.00300000000000000006
60284	P1	198.900000000000006	0.0519999999999999976
60284	L2	25.8000000000000007	0.0259999999999999988
60284	K2	32.7000000000000028	0.0389999999999999999
60285	M2	116	3.64500000000000002
60285	S2	144.900000000000006	0.593999999999999972
60285	N2	89.5	0.737999999999999989
60285	K1	188.099999999999994	0.328000000000000014
60285	M4	144.800000000000011	0.0660000000000000031
60285	O1	221.5	0.209999999999999992
60285	M6	182.599999999999994	0.0560000000000000012
60285	S4	165.900000000000006	0.00700000000000000015
60285	NU2	93.0999999999999943	0.143999999999999989
60285	MU2	300.5	0.0889999999999999958
60285	2N2	63	0.0980000000000000038
60285	OO1	154.699999999999989	0.0100000000000000002
60285	LDA2	129.400000000000006	0.0259999999999999988
60285	M1	204.699999999999989	0.0160000000000000003
60285	J1	171.599999999999994	0.0160000000000000003
60285	SSA	61.2000000000000028	0.0719999999999999946
60285	SA	132	0.20699999999999999
60285	RHO1	235.800000000000011	0.00700000000000000015
60285	Q1	238	0.0389999999999999999
60285	T2	143.699999999999989	0.0359999999999999973
60285	R2	146	0.00300000000000000006
60285	2Q1	254.199999999999989	0.00700000000000000015
60285	P1	190.599999999999994	0.107999999999999999
60285	L2	142.699999999999989	0.101999999999999993
60285	K2	147.199999999999989	0.161000000000000004
60285	M8	302.399999999999977	0.0129999999999999994
60286	M2	114.099999999999994	3.57900000000000018
60286	S2	137.5	0.551000000000000045
60286	N2	94.9000000000000057	0.771000000000000019
60286	K1	184.900000000000006	0.325000000000000011
60286	M4	151.599999999999994	0.0690000000000000058
60286	O1	222.199999999999989	0.197000000000000008
60286	M6	178.300000000000011	0.0459999999999999992
60286	MK3	190.5	0.0330000000000000016
60286	S4	173.900000000000006	0.0100000000000000002
60286	MN4	119.900000000000006	0.0459999999999999992
60286	NU2	83.5999999999999943	0.161000000000000004
60286	S6	204.199999999999989	0.00300000000000000006
60286	MU2	119	0.0160000000000000003
60286	2N2	52.7999999999999972	0.0850000000000000061
60286	OO1	204.900000000000006	0.0200000000000000004
60286	LDA2	140.300000000000011	0.0950000000000000011
60286	S1	188.800000000000011	0.0359999999999999973
60286	M1	219	0.0299999999999999989
60286	J1	231.199999999999989	0.0200000000000000004
60286	SSA	61.2000000000000028	0.0719999999999999946
60286	SA	132	0.20699999999999999
60286	RHO1	214.599999999999994	0.0129999999999999994
60286	Q1	201.400000000000006	0.0660000000000000031
60286	T2	95.5	0.0589999999999999969
60286	R2	200.699999999999989	0.0429999999999999966
60286	2Q1	236.099999999999994	0.0100000000000000002
60286	P1	197.900000000000006	0.0850000000000000061
60286	2SM2	90.2000000000000028	0.0100000000000000002
60286	M3	166.099999999999994	0.0160000000000000003
60286	L2	107.5	0.223000000000000004
60286	2MK3	190	0.0229999999999999996
60286	K2	145.900000000000006	0.183999999999999997
60286	M8	302.199999999999989	0.0100000000000000002
60286	MS4	187.099999999999994	0.0129999999999999994
60287	M2	114.700000000000003	3.51399999999999979
60287	S2	148.800000000000011	0.551000000000000045
60287	N2	87.4000000000000057	0.688999999999999946
60287	K1	186.699999999999989	0.315000000000000002
60287	M4	147.900000000000006	0.0660000000000000031
60287	O1	220.900000000000006	0.209999999999999992
60287	M6	168.400000000000006	0.0490000000000000019
60287	S4	139.900000000000006	0.00700000000000000015
60287	NU2	91	0.135000000000000009
60287	S6	245.099999999999994	0.00300000000000000006
60287	MU2	293.800000000000011	0.0850000000000000061
60287	2N2	60	0.0889999999999999958
60287	OO1	152.599999999999994	0.0100000000000000002
60287	LDA2	130.5	0.0229999999999999996
60287	M1	203.699999999999989	0.0160000000000000003
60287	J1	169.800000000000011	0.0160000000000000003
60287	SSA	61.2000000000000028	0.0719999999999999946
60287	SA	132	0.20699999999999999
60287	RHO1	235.400000000000006	0.00700000000000000015
60287	Q1	237.800000000000011	0.0389999999999999999
60287	T2	147.400000000000006	0.0330000000000000016
60287	R2	150.199999999999989	0.00300000000000000006
60287	2Q1	254.699999999999989	0.00700000000000000015
60287	P1	189.300000000000011	0.104999999999999996
60287	L2	141.900000000000006	0.0980000000000000038
60287	K2	151.5	0.150999999999999995
60287	M8	303	0.0129999999999999994
60288	M2	115.799999999999997	3.7370000000000001
60288	S2	144.5	0.619999999999999996
60288	N2	90.2999999999999972	0.76100000000000001
60288	K1	188	0.331000000000000016
60288	M4	146.900000000000006	0.0749999999999999972
60288	O1	221.099999999999994	0.212999999999999995
60288	M6	173.199999999999989	0.112000000000000002
60288	S4	148.800000000000011	0.00700000000000000015
60288	NU2	93.7000000000000028	0.147999999999999993
60288	S6	291	0.00300000000000000006
60288	MU2	300.100000000000023	0.0889999999999999958
60288	2N2	64.7000000000000028	0.101999999999999993
60288	OO1	155	0.0100000000000000002
60288	LDA2	129.099999999999994	0.0259999999999999988
60288	M1	204.400000000000006	0.0160000000000000003
60288	J1	171.599999999999994	0.0160000000000000003
60288	SSA	60.1000000000000014	0.0790000000000000008
60288	SA	135.5	0.212999999999999995
60288	RHO1	235.300000000000011	0.00700000000000000015
60288	Q1	237.599999999999994	0.0429999999999999966
60288	T2	143.400000000000006	0.0359999999999999973
60288	R2	145.699999999999989	0.00300000000000000006
60288	2Q1	254	0.00700000000000000015
60288	P1	190.5	0.107999999999999999
60288	L2	141.400000000000006	0.104999999999999996
60288	K2	146.900000000000006	0.16700000000000001
60288	M8	279.699999999999989	0.0129999999999999994
60289	M2	20.8000000000000007	1.41100000000000003
60289	S2	56.1000000000000014	0.245999999999999996
60289	N2	6.90000000000000036	0.27200000000000002
60289	K1	198.5	0.212999999999999995
60289	M4	246.5	0.0229999999999999996
60289	O1	187.400000000000006	0.164000000000000007
60289	M6	97.2000000000000028	0.0519999999999999976
60289	S4	2.89999999999999991	0.0200000000000000004
60289	NU2	8.80000000000000071	0.0519999999999999976
60289	S6	240.599999999999994	0.00700000000000000015
60289	MU2	345.300000000000011	0.0330000000000000016
60289	2N2	353.199999999999989	0.0359999999999999973
60289	OO1	209.699999999999989	0.00700000000000000015
60289	LDA2	37.3999999999999986	0.0100000000000000002
60289	M1	193.099999999999994	0.0100000000000000002
60289	J1	204.099999999999994	0.0129999999999999994
60289	SSA	42.8999999999999986	0.0919999999999999984
60289	SA	129.099999999999994	0.220000000000000001
60289	RHO1	182.800000000000011	0.00700000000000000015
60289	Q1	181.900000000000006	0.0299999999999999989
60289	T2	54.7000000000000028	0.0129999999999999994
60289	R2	57.8999999999999986	0.00300000000000000006
60289	2Q1	176.5	0.00300000000000000006
60289	P1	197.699999999999989	0.0690000000000000058
60289	L2	34.7999999999999972	0.0389999999999999999
60289	K2	59	0.0690000000000000058
60289	M8	339.899999999999977	0.00300000000000000006
60290	M2	116.900000000000006	3.78600000000000003
60290	S2	147.300000000000011	0.622999999999999998
60290	N2	91	0.781000000000000028
60290	K1	188.800000000000011	0.33500000000000002
60290	M4	167.699999999999989	0.0980000000000000038
60290	O1	220.300000000000011	0.216999999999999998
60290	M6	184	0.125
60290	S4	162.599999999999994	0.00700000000000000015
60290	NU2	94.5	0.150999999999999995
60290	S6	245.099999999999994	0.00300000000000000006
60290	MU2	299.5	0.0919999999999999984
60290	2N2	65	0.104999999999999996
60290	OO1	157.199999999999989	0.0100000000000000002
60290	LDA2	131	0.0259999999999999988
60290	M1	204.400000000000006	0.0160000000000000003
60290	J1	173.099999999999994	0.0160000000000000003
60290	SSA	60.1000000000000014	0.0790000000000000008
60290	SA	135.5	0.212999999999999995
60290	RHO1	233.900000000000006	0.0100000000000000002
60290	Q1	236	0.0429999999999999966
60290	T2	146.099999999999994	0.0359999999999999973
60290	R2	148.400000000000006	0.00700000000000000015
60290	2Q1	251.699999999999989	0.00700000000000000015
60290	P1	191.099999999999994	0.112000000000000002
60290	L2	143	0.104999999999999996
60290	K2	149.800000000000011	0.171000000000000013
60290	M8	258.899999999999977	0.0229999999999999996
60291	M2	2.39999999999999991	1.95199999999999996
60291	S2	31.1000000000000014	0.322000000000000008
60291	N2	349.899999999999977	0.416999999999999982
60291	K1	172.300000000000011	0.347999999999999976
60291	M4	50.6000000000000014	0.0100000000000000002
60291	O1	180.199999999999989	0.153999999999999998
60291	M6	29.8000000000000007	0.0519999999999999976
60291	S4	75.9000000000000057	0.00700000000000000015
60291	NU2	351.5	0.0820000000000000034
60291	S6	334.600000000000023	0.00300000000000000006
60291	MU2	333.699999999999989	0.0459999999999999992
60291	2N2	337.300000000000011	0.0560000000000000012
60291	OO1	164	0.00700000000000000015
60291	LDA2	15.8000000000000007	0.0129999999999999994
60291	M1	176.199999999999989	0.0100000000000000002
60291	J1	168.199999999999989	0.0129999999999999994
60291	SSA	42.8999999999999986	0.0919999999999999984
60291	SA	129.099999999999994	0.220000000000000001
60291	RHO1	184.099999999999994	0.00700000000000000015
60291	Q1	184.199999999999989	0.0299999999999999989
60291	T2	30	0.0200000000000000004
60291	R2	32.2999999999999972	0.00300000000000000006
60291	2Q1	188.800000000000011	0.00300000000000000006
60291	P1	172.800000000000011	0.115000000000000005
60291	L2	14.9000000000000004	0.0560000000000000012
60291	K2	33.3999999999999986	0.0889999999999999958
60291	M8	86.4000000000000057	0.00300000000000000006
60292	M2	11.8000000000000007	2.02400000000000002
60292	S2	45.6000000000000014	0.343999999999999972
60292	N2	2.20000000000000018	0.432999999999999996
60292	K1	177.199999999999989	0.347999999999999976
60292	M4	269.800000000000011	0.0919999999999999984
60292	O1	186.699999999999989	0.176999999999999991
60292	M6	79.9000000000000057	0.0749999999999999972
60292	S4	88.0999999999999943	0.0100000000000000002
60292	NU2	3.5	0.0820000000000000034
60292	S6	32.1000000000000014	0.00700000000000000015
60292	MU2	337.899999999999977	0.0490000000000000019
60292	2N2	352.699999999999989	0.0560000000000000012
60292	OO1	167.900000000000006	0.00700000000000000015
60292	LDA2	27.3999999999999986	0.0129999999999999994
60292	M1	181.900000000000006	0.0129999999999999994
60292	J1	172.5	0.0129999999999999994
60292	SSA	42.8999999999999986	0.0919999999999999984
60292	SA	129.099999999999994	0.220000000000000001
60292	RHO1	191.5	0.00700000000000000015
60292	Q1	191.5	0.0330000000000000016
60292	T2	44.2999999999999972	0.0200000000000000004
60292	R2	47	0.00300000000000000006
60292	2Q1	194.300000000000011	0.00300000000000000006
60292	P1	178	0.115000000000000005
60292	L2	21.3000000000000007	0.0560000000000000012
60292	K2	48.2999999999999972	0.0950000000000000011
60292	M8	320.300000000000011	0.0100000000000000002
60293	M2	115.599999999999994	3.83199999999999985
60293	S2	141.300000000000011	0.593999999999999972
60293	N2	95.0999999999999943	0.758000000000000007
60293	K1	186.800000000000011	0.328000000000000014
60293	M4	143.199999999999989	0.101999999999999993
60293	O1	229.099999999999994	0.248999999999999999
60293	M6	168.400000000000006	0.190000000000000002
60293	S4	169.099999999999994	0.0100000000000000002
60293	NU2	97.9000000000000057	0.147999999999999993
60293	S6	246.800000000000011	0.00700000000000000015
60293	MU2	90	0.0919999999999999984
60293	2N2	74.5999999999999943	0.101999999999999993
60293	OO1	144.300000000000011	0.0100000000000000002
60293	LDA2	127.599999999999994	0.0259999999999999988
60293	M1	208	0.0160000000000000003
60293	J1	165.599999999999994	0.0200000000000000004
60293	SSA	60.1000000000000014	0.0790000000000000008
60293	SA	135.5	0.212999999999999995
60293	RHO1	247.300000000000011	0.0100000000000000002
60293	Q1	250.300000000000011	0.0490000000000000019
60293	T2	140.199999999999989	0.0359999999999999973
60293	R2	142.300000000000011	0.00300000000000000006
60293	2Q1	271.199999999999989	0.00700000000000000015
60293	P1	190	0.107999999999999999
60293	L2	136.199999999999989	0.107999999999999999
60293	K2	143.400000000000006	0.161000000000000004
60293	M8	187.5	0.0100000000000000002
60294	M2	116.799999999999997	3.83899999999999997
60294	S2	145.599999999999994	0.640000000000000013
60294	N2	91.0999999999999943	0.78400000000000003
60294	K1	187.900000000000006	0.33500000000000002
60294	M4	145.900000000000006	0.0919999999999999984
60294	O1	220.800000000000011	0.216999999999999998
60294	M6	169	0.197000000000000008
60294	S4	164.599999999999994	0.00700000000000000015
60294	NU2	94.5	0.150999999999999995
60294	S6	219.400000000000006	0.00300000000000000006
60294	MU2	300.600000000000023	0.0919999999999999984
60294	2N2	65.4000000000000057	0.104999999999999996
60294	OO1	155.099999999999994	0.0100000000000000002
60294	LDA2	130.199999999999989	0.0259999999999999988
60294	M1	204.199999999999989	0.0160000000000000003
60294	J1	171.5	0.0160000000000000003
60294	SSA	60.1000000000000014	0.0790000000000000008
60294	SA	135.5	0.212999999999999995
60294	RHO1	235	0.00700000000000000015
60294	Q1	237.099999999999994	0.0429999999999999966
60294	T2	144.5	0.0359999999999999973
60294	R2	146.900000000000006	0.00700000000000000015
60294	2Q1	253.699999999999989	0.00700000000000000015
60294	P1	190.400000000000006	0.112000000000000002
60294	L2	142.5	0.107999999999999999
60294	K2	148	0.173999999999999988
60294	M8	208.5	0.0100000000000000002
60295	M2	15.8000000000000007	2.12599999999999989
60295	S2	51.8999999999999986	0.347999999999999976
60295	N2	8.09999999999999964	0.44900000000000001
60295	K1	180.400000000000006	0.36399999999999999
60295	M4	288.399999999999977	0.0919999999999999984
60295	O1	188.800000000000011	0.179999999999999993
60295	M6	82.7999999999999972	0.0850000000000000061
60295	S4	113.799999999999997	0.0100000000000000002
60295	NU2	9.19999999999999929	0.0850000000000000061
60295	S6	51.7000000000000028	0.00300000000000000006
60295	MU2	339.5	0.0490000000000000019
60295	2N2	0.5	0.0589999999999999969
60295	OO1	172.199999999999989	0.00700000000000000015
60295	LDA2	32.6000000000000014	0.0160000000000000003
60295	M1	184.5	0.0129999999999999994
60295	J1	176.199999999999989	0.0129999999999999994
60295	SSA	42.8999999999999986	0.0919999999999999984
60295	SA	129.099999999999994	0.220000000000000001
60295	RHO1	193.199999999999989	0.00700000000000000015
60295	Q1	192.900000000000006	0.0359999999999999973
60295	T2	50.5	0.0200000000000000004
60295	R2	53.3999999999999986	0.00300000000000000006
60295	2Q1	195.699999999999989	0.00300000000000000006
60295	P1	181.099999999999994	0.120999999999999996
60295	L2	23.3999999999999986	0.0589999999999999969
60295	K2	54.7999999999999972	0.0950000000000000011
60295	M8	265.699999999999989	0.0129999999999999994
60296	M2	10.1999999999999993	2.00499999999999989
60296	S2	45.1000000000000014	0.400000000000000022
60296	N2	357.300000000000011	0.39700000000000002
60296	K1	187.599999999999994	0.269000000000000017
60296	M4	264.600000000000023	0.0519999999999999976
60296	O1	171.199999999999989	0.20699999999999999
60296	M6	55.2000000000000028	0.0619999999999999996
60296	S4	9	0.0330000000000000016
60296	NU2	359	0.0749999999999999972
60296	S6	233.800000000000011	0.0160000000000000003
60296	MU2	335.199999999999989	0.0490000000000000019
60296	2N2	344.5	0.0519999999999999976
60296	OO1	204.699999999999989	0.00700000000000000015
60296	LDA2	26.3999999999999986	0.0129999999999999994
60296	M1	179.599999999999994	0.0129999999999999994
60296	J1	195.900000000000006	0.0160000000000000003
60296	SSA	42.8999999999999986	0.0919999999999999984
60296	SA	129.099999999999994	0.220000000000000001
60296	RHO1	164.099999999999994	0.00700000000000000015
60296	Q1	162.900000000000006	0.0389999999999999999
60296	T2	43.7000000000000028	0.0229999999999999996
60296	R2	46.6000000000000014	0.00300000000000000006
60296	2Q1	154.699999999999989	0.00300000000000000006
60296	P1	186.300000000000011	0.0889999999999999958
60296	L2	23.1000000000000014	0.0560000000000000012
60296	K2	47.8999999999999986	0.107999999999999999
60296	M8	276	0.0100000000000000002
60297	M2	118.299999999999997	3.8879999999999999
60297	S2	149	0.650000000000000022
60297	N2	93.9000000000000057	0.819999999999999951
60297	K1	187.900000000000006	0.341000000000000025
60297	M4	146.800000000000011	0.104999999999999996
60297	O1	221.800000000000011	0.220000000000000001
60297	M6	171.5	0.259000000000000008
60297	S4	198.300000000000011	0.00300000000000000006
60297	NU2	97.0999999999999943	0.161000000000000004
60297	S6	213.099999999999994	0.0100000000000000002
60297	MU2	300.300000000000011	0.0950000000000000011
60297	2N2	69.5	0.107999999999999999
60297	OO1	153.900000000000006	0.0100000000000000002
60297	LDA2	132.599999999999994	0.0259999999999999988
60297	M1	204.699999999999989	0.0160000000000000003
60297	J1	171.199999999999989	0.0160000000000000003
60297	SSA	60.1000000000000014	0.0790000000000000008
60297	SA	135.5	0.212999999999999995
60297	RHO1	236.400000000000006	0.0100000000000000002
60297	Q1	238.699999999999989	0.0429999999999999966
60297	T2	147.900000000000006	0.0389999999999999999
60297	R2	150.300000000000011	0.00700000000000000015
60297	2Q1	255.5	0.00700000000000000015
60297	P1	190.400000000000006	0.115000000000000005
60297	L2	142.800000000000011	0.107999999999999999
60297	K2	151.5	0.176999999999999991
60297	M8	191.099999999999994	0.0160000000000000003
60298	M2	359.899999999999977	2.06000000000000005
60298	S2	28.3999999999999986	0.360999999999999988
60298	N2	346.600000000000023	0.44900000000000001
60298	K1	169.599999999999994	0.353999999999999981
60298	M4	61	0.0129999999999999994
60298	O1	174.599999999999994	0.161000000000000004
60298	M6	21.6000000000000014	0.0519999999999999976
60298	S4	53.6000000000000014	0.00700000000000000015
60298	NU2	348.399999999999977	0.0889999999999999958
60298	S6	307.399999999999977	0.00300000000000000006
60298	MU2	331.300000000000011	0.0490000000000000019
60298	2N2	333.300000000000011	0.0589999999999999969
60298	OO1	164.400000000000006	0.00700000000000000015
60298	LDA2	13.1999999999999993	0.0129999999999999994
60298	M1	172	0.0129999999999999994
60298	J1	167.199999999999989	0.0129999999999999994
60298	SSA	42.8999999999999986	0.0919999999999999984
60298	SA	129.099999999999994	0.220000000000000001
60298	RHO1	177.199999999999989	0.00700000000000000015
60298	Q1	177	0.0299999999999999989
60298	T2	27.1999999999999993	0.0200000000000000004
60298	R2	29.6000000000000014	0.00300000000000000006
60298	2Q1	180.099999999999994	0.00300000000000000006
60298	P1	170	0.117999999999999994
60298	L2	13.1999999999999993	0.0589999999999999969
60298	K2	30.8000000000000007	0.0980000000000000038
60298	M8	119.700000000000003	0.00300000000000000006
60299	M2	18.1999999999999993	2.57200000000000006
60299	S2	48.8999999999999986	0.48899999999999999
60299	N2	7.79999999999999982	0.576999999999999957
60299	K1	187.800000000000011	0.33500000000000002
60299	M4	309.699999999999989	0.104999999999999996
60299	O1	175.5	0.20699999999999999
60299	M6	100.700000000000003	0.0980000000000000038
60299	S4	33.5	0.0660000000000000031
60299	NU2	9.19999999999999929	0.112000000000000002
60299	S6	342.399999999999977	0.00700000000000000015
60299	MU2	347.5	0.0619999999999999996
60299	2N2	357.399999999999977	0.0749999999999999972
60299	OO1	198.300000000000011	0.00700000000000000015
60299	LDA2	32.2999999999999972	0.0160000000000000003
60299	M1	181.599999999999994	0.0160000000000000003
60299	J1	193.5	0.0160000000000000003
60299	SSA	42.8999999999999986	0.0919999999999999984
60299	SA	129.099999999999994	0.0919999999999999984
60299	RHO1	171.599999999999994	0.00700000000000000015
60299	Q1	169.5	0.0389999999999999999
60299	T2	47.7000000000000028	0.0299999999999999989
60299	R2	50	0.00300000000000000006
60299	2Q1	166.699999999999989	0.00300000000000000006
60299	P1	186.800000000000011	0.112000000000000002
60299	L2	28.5	0.0719999999999999946
60299	K2	51.3999999999999986	0.131000000000000005
60299	M8	324.600000000000023	0.00700000000000000015
60300	M2	115.700000000000003	3.74699999999999989
60300	S2	140.699999999999989	0.619999999999999996
60300	N2	92.5999999999999943	0.791000000000000036
60300	K1	192	0.328000000000000014
60300	M4	145.5	0.117999999999999994
60300	O1	220.599999999999994	0.216999999999999998
60300	M6	159.900000000000006	0.262000000000000011
60300	MK3	202.800000000000011	0.0330000000000000016
60300	S4	152.300000000000011	0.0129999999999999994
60300	MN4	117.200000000000003	0.0719999999999999946
60300	NU2	92	0.171000000000000013
60300	2N2	69.7000000000000028	0.0980000000000000038
60300	OO1	224.5	0.0229999999999999996
60300	LDA2	141.699999999999989	0.0820000000000000034
60300	S1	121.900000000000006	0.0299999999999999989
60300	M1	228.400000000000006	0.0160000000000000003
60300	J1	252.099999999999994	0.0259999999999999988
60300	SSA	60.1000000000000014	0.0790000000000000008
60300	SA	135.5	0.212999999999999995
60300	RHO1	204.5	0.0129999999999999994
60300	Q1	212.199999999999989	0.0560000000000000012
60300	T2	112.299999999999997	0.0490000000000000019
60300	R2	141.800000000000011	0.00700000000000000015
60300	2Q1	249.099999999999994	0.00700000000000000015
60300	P1	211.099999999999994	0.104999999999999996
60300	2SM2	75.0999999999999943	0.0100000000000000002
60300	M3	181.400000000000006	0.0229999999999999996
60300	L2	140.400000000000006	0.23000000000000001
60300	2MK3	202.400000000000006	0.0299999999999999989
60300	K2	141.800000000000011	0.173999999999999988
60300	M8	155	0.0229999999999999996
60300	MS4	160.900000000000006	0.0259999999999999988
60301	M2	116.200000000000003	3.61900000000000022
60301	S2	142.199999999999989	0.599999999999999978
60301	N2	94.2999999999999972	0.734999999999999987
60301	K1	193.099999999999994	0.325000000000000011
60301	M4	147.300000000000011	0.117999999999999994
60301	O1	220.699999999999989	0.209999999999999992
60301	M6	160	0.253000000000000003
60301	MK3	207.599999999999994	0.0359999999999999973
60301	S4	146.300000000000011	0.0129999999999999994
60301	MN4	121.900000000000006	0.0690000000000000058
60301	NU2	95	0.164000000000000007
60301	MU2	96.0999999999999943	0.0129999999999999994
60301	2N2	72.9000000000000057	0.0889999999999999958
60301	OO1	232.300000000000011	0.0200000000000000004
60301	LDA2	139.5	0.0749999999999999972
60301	S1	116.200000000000003	0.0259999999999999988
60301	M1	263.100000000000023	0.0229999999999999996
60301	J1	235.800000000000011	0.0200000000000000004
60301	SSA	60.1000000000000014	0.0790000000000000008
60301	SA	135.5	0.212999999999999995
60301	RHO1	254.800000000000011	0.0129999999999999994
60301	Q1	206.199999999999989	0.0589999999999999969
60301	T2	117	0.0589999999999999969
60301	R2	143.300000000000011	0.00700000000000000015
60301	2Q1	224.199999999999989	0.0129999999999999994
60301	P1	206.099999999999994	0.0950000000000000011
60301	M3	216.699999999999989	0.0160000000000000003
60301	L2	140.900000000000006	0.171000000000000013
60301	2MK3	215.599999999999994	0.0259999999999999988
60301	K2	141.300000000000011	0.176999999999999991
60301	M8	150.300000000000011	0.0229999999999999996
60301	MS4	160.699999999999989	0.0259999999999999988
60302	M2	13.1999999999999993	2.53600000000000003
60302	S2	44.2000000000000028	0.502000000000000002
60302	N2	1	0.538000000000000034
60302	K1	180.199999999999989	0.33500000000000002
60302	M4	311.100000000000023	0.0850000000000000061
60302	O1	170.5	0.161000000000000004
60302	M6	84.0999999999999943	0.0790000000000000008
60302	MK3	106.900000000000006	0.0359999999999999973
60302	S4	59.2999999999999972	0.0259999999999999988
60302	MN4	320.199999999999989	0.0359999999999999973
60302	NU2	349.5	0.107999999999999999
60302	MU2	51.2000000000000028	0.0980000000000000038
60302	2N2	4.70000000000000018	0.0660000000000000031
60302	OO1	187	0.0229999999999999996
60302	LDA2	348.5	0.0359999999999999973
60302	S1	152.199999999999989	0.0589999999999999969
60302	M1	248	0.0160000000000000003
60302	J1	192.800000000000011	0.0129999999999999994
60302	SSA	42.8999999999999986	0.0919999999999999984
60302	SA	129.099999999999994	0.220000000000000001
60302	RHO1	172.099999999999994	0.0100000000000000002
60302	Q1	187.599999999999994	0.0490000000000000019
60302	T2	32.7999999999999972	0.0660000000000000031
60302	R2	178.300000000000011	0.0100000000000000002
60302	2Q1	255.699999999999989	0.0160000000000000003
60302	P1	182.800000000000011	0.0919999999999999984
60302	2SM2	131.400000000000006	0.00300000000000000006
60302	M3	99.7000000000000028	0.0359999999999999973
60302	L2	343.199999999999989	0.112000000000000002
60302	2MK3	23	0.0160000000000000003
60302	K2	45	0.140999999999999986
60302	M8	334.800000000000011	0.00300000000000000006
60302	MS4	269.300000000000011	0.0299999999999999989
60303	M2	15.4000000000000004	2.57500000000000018
60303	S2	48.2000000000000028	0.44900000000000001
60303	N2	3.5	0.548000000000000043
60303	K1	180.900000000000006	0.33500000000000002
60303	M4	303.100000000000023	0.0919999999999999984
60303	O1	172.699999999999989	0.161000000000000004
60303	M6	91.7000000000000028	0.0950000000000000011
60303	MK3	104	0.0359999999999999973
60303	S4	64.7000000000000028	0.0299999999999999989
60303	MN4	313.899999999999977	0.0359999999999999973
60303	NU2	354.399999999999977	0.104999999999999996
60303	MU2	53.6000000000000014	0.104999999999999996
60303	2N2	3.39999999999999991	0.0690000000000000058
60303	OO1	164.099999999999994	0.0200000000000000004
60303	LDA2	341.899999999999977	0.0459999999999999992
60303	S1	151.5	0.0790000000000000008
60303	M1	247.800000000000011	0.0160000000000000003
60303	J1	187.099999999999994	0.0100000000000000002
60303	SSA	42.8999999999999986	0.0919999999999999984
60303	SA	129.099999999999994	0.220000000000000001
60303	RHO1	190.400000000000006	0.0129999999999999994
60303	Q1	193	0.0519999999999999976
60303	T2	39.2999999999999972	0.0429999999999999966
60303	R2	44.7999999999999972	0.0429999999999999966
60303	2Q1	255.199999999999989	0.0160000000000000003
60303	P1	182.199999999999989	0.0850000000000000061
60303	2SM2	182.099999999999994	0.0129999999999999994
60303	M3	105.200000000000003	0.0389999999999999999
60303	L2	347	0.128000000000000003
60303	2MK3	21.5	0.0200000000000000004
60303	K2	49.7000000000000028	0.16700000000000001
60303	M8	312.399999999999977	0.00700000000000000015
60303	MS4	277.5	0.0389999999999999999
60304	M2	118.5	3.58599999999999985
60304	S2	144.699999999999989	0.563999999999999946
60304	N2	97.4000000000000057	0.724999999999999978
60304	K1	188.800000000000011	0.33500000000000002
60304	M4	166.400000000000006	0.138000000000000012
60304	O1	227.699999999999989	0.235999999999999988
60304	M6	162.099999999999994	0.341000000000000025
60304	S4	178.199999999999989	0.0100000000000000002
60304	NU2	100.200000000000003	0.140999999999999986
60304	S6	224.599999999999994	0.00700000000000000015
60304	MU2	92.2000000000000028	0.0850000000000000061
60304	2N2	76.2999999999999972	0.0980000000000000038
60304	OO1	149.699999999999989	0.0100000000000000002
60304	LDA2	130.699999999999989	0.0259999999999999988
60304	M1	208	0.0160000000000000003
60304	J1	169	0.0200000000000000004
60304	SSA	60.1000000000000014	0.0790000000000000008
60304	SA	135.5	0.212999999999999995
60304	RHO1	244.400000000000006	0.0100000000000000002
60304	Q1	247.099999999999994	0.0459999999999999992
60304	T2	143.699999999999989	0.0330000000000000016
60304	R2	145.800000000000011	0.00300000000000000006
60304	2Q1	266.300000000000011	0.00700000000000000015
60304	P1	191.699999999999989	0.112000000000000002
60304	L2	139.5	0.101999999999999993
60304	K2	146.900000000000006	0.153999999999999998
60304	M8	142.400000000000006	0.0359999999999999973
60305	M2	117.5	3.57600000000000007
60305	S2	145.599999999999994	0.596999999999999975
60305	N2	91.5999999999999943	0.691999999999999948
60305	K1	189.5	0.325000000000000011
60305	M4	165.300000000000011	0.140999999999999986
60305	O1	239	0.20699999999999999
60305	M6	156.099999999999994	0.347999999999999976
60305	S4	169.300000000000011	0.00300000000000000006
60305	NU2	95.0999999999999943	0.135000000000000009
60305	S6	272.199999999999989	0.0100000000000000002
60305	MU2	89.4000000000000057	0.0850000000000000061
60305	2N2	65.7000000000000028	0.0919999999999999984
60305	OO1	140	0.0100000000000000002
60305	LDA2	130.5	0.0259999999999999988
60305	M1	214	0.0129999999999999994
60305	J1	164.900000000000006	0.0160000000000000003
60305	SSA	60.1000000000000014	0.0790000000000000008
60305	SA	135.5	0.212999999999999995
60305	RHO1	260.199999999999989	0.00700000000000000015
60305	Q1	263.5	0.0389999999999999999
60305	T2	144.5	0.0359999999999999973
60305	R2	146.699999999999989	0.00300000000000000006
60305	2Q1	288.100000000000023	0.00700000000000000015
60305	P1	193.199999999999989	0.107999999999999999
60305	L2	143.400000000000006	0.101999999999999993
60305	K2	147.900000000000006	0.161000000000000004
60305	M8	149	0.0389999999999999999
60306	M2	6.29999999999999982	2.33300000000000018
60306	S2	35.5	0.426999999999999991
60306	N2	351.5	0.498999999999999999
60306	K1	174.400000000000006	0.331000000000000016
60306	M4	317.399999999999977	0.0389999999999999999
60306	O1	167.599999999999994	0.157000000000000001
60306	M6	62.5	0.0490000000000000019
60306	MK3	95.7000000000000028	0.0200000000000000004
60306	S4	38.1000000000000014	0.0200000000000000004
60306	MN4	324.899999999999977	0.0200000000000000004
60306	NU2	345.300000000000011	0.0980000000000000038
60306	MU2	30.1000000000000014	0.0719999999999999946
60306	2N2	344	0.0589999999999999969
60306	OO1	163.900000000000006	0.0229999999999999996
60306	LDA2	345.699999999999989	0.0299999999999999989
60306	S1	158.599999999999994	0.0660000000000000031
60306	M1	232.400000000000006	0.0160000000000000003
60306	J1	182.400000000000006	0.0100000000000000002
60306	SSA	42.8999999999999986	0.0919999999999999984
60306	SA	129.099999999999994	0.220000000000000001
60306	RHO1	188.900000000000006	0.0129999999999999994
60306	Q1	186.699999999999989	0.0519999999999999976
60306	T2	34.5	0.0459999999999999992
60306	R2	21.6999999999999993	0.0200000000000000004
60306	2Q1	228.599999999999994	0.0160000000000000003
60306	P1	170.400000000000006	0.0889999999999999958
60306	2SM2	171	0.00700000000000000015
60306	M3	82.5	0.0330000000000000016
60306	L2	349.5	0.0889999999999999958
60306	2MK3	40.7999999999999972	0.0100000000000000002
60306	K2	36.2000000000000028	0.143999999999999989
60306	M8	146.199999999999989	0.00700000000000000015
60306	MS4	204.199999999999989	0.0160000000000000003
60307	M2	24	2.1419999999999999
60307	S2	42	0.422999999999999987
60307	N2	359.5	0.541000000000000036
60307	K1	191	0.350999999999999979
60307	M4	184.300000000000011	0.0519999999999999976
60307	O1	172.699999999999989	0.20699999999999999
60307	M6	167.199999999999989	0.104999999999999996
60307	S4	349	0.0619999999999999996
60307	NU2	2.70000000000000018	0.104999999999999996
60307	S6	269.300000000000011	0.0129999999999999994
60307	MU2	218	0.0519999999999999976
60307	2N2	334.899999999999977	0.0719999999999999946
60307	OO1	209.300000000000011	0.0100000000000000002
60307	LDA2	32.3999999999999986	0.0160000000000000003
60307	M1	181.900000000000006	0.0160000000000000003
60307	J1	200.099999999999994	0.0160000000000000003
60307	SSA	47.3999999999999986	0.0980000000000000038
60307	SA	129.900000000000006	0.23000000000000001
60307	RHO1	164.900000000000006	0.00700000000000000015
60307	Q1	163.599999999999994	0.0389999999999999999
60307	T2	41.2999999999999972	0.0259999999999999988
60307	R2	42.7999999999999972	0.00300000000000000006
60307	2Q1	154.599999999999994	0.00700000000000000015
60307	P1	189.599999999999994	0.117999999999999994
60307	L2	48.6000000000000014	0.0589999999999999969
60307	K2	43.5	0.115000000000000005
60307	M8	284.800000000000011	0.0229999999999999996
60308	M2	113.900000000000006	3.72699999999999987
60308	S2	140.800000000000011	0.619999999999999996
60308	N2	91.0999999999999943	0.721999999999999975
60308	K1	192.599999999999994	0.322000000000000008
60308	M4	134.5	0.0950000000000000011
60308	O1	217.599999999999994	0.220000000000000001
60308	M6	164.099999999999994	0.157000000000000001
60308	MK3	205.599999999999994	0.0359999999999999973
60308	S4	137.900000000000006	0.0100000000000000002
60308	MN4	115.299999999999997	0.0519999999999999976
60308	NU2	92	0.164000000000000007
60308	S6	180.400000000000006	0.00300000000000000006
60308	MU2	263.699999999999989	0.0160000000000000003
60308	2N2	83.0999999999999943	0.0459999999999999992
60308	OO1	231.599999999999994	0.0160000000000000003
60308	LDA2	144.099999999999994	0.0790000000000000008
60308	S1	144.099999999999994	0.0330000000000000016
60308	M1	221.699999999999989	0.0129999999999999994
60308	J1	205.199999999999989	0.0200000000000000004
60308	MM	313	0.164000000000000007
60308	SSA	64.5999999999999943	0.125
60308	SA	112.299999999999997	0.226000000000000006
60308	MSF	278.5	0.0690000000000000058
60308	MF	257.399999999999977	0.0429999999999999966
60308	RHO1	157.699999999999989	0.0200000000000000004
60308	Q1	220.5	0.0619999999999999996
60308	T2	101.200000000000003	0.0589999999999999969
60308	R2	334.399999999999977	0.00700000000000000015
60308	2Q1	113.799999999999997	0.0100000000000000002
60308	P1	205.400000000000006	0.0820000000000000034
60308	2SM2	95	0.0160000000000000003
60308	M3	237	0.0229999999999999996
60308	L2	162.099999999999994	0.23000000000000001
60308	2MK3	215.699999999999989	0.0330000000000000016
60308	K2	141	0.171000000000000013
60308	M8	216	0.00700000000000000015
60308	MS4	142.800000000000011	0.0160000000000000003
60309	M2	117.200000000000003	3.78299999999999992
60309	S2	143.800000000000011	0.59099999999999997
60309	N2	96.5	0.76100000000000001
60309	K1	189	0.341000000000000025
60309	M4	145.300000000000011	0.128000000000000003
60309	O1	227.199999999999989	0.242999999999999994
60309	M6	162.300000000000011	0.284999999999999976
60309	S4	169.900000000000006	0.0100000000000000002
60309	NU2	99.2999999999999972	0.147999999999999993
60309	S6	208.5	0.0100000000000000002
60309	MU2	90.5999999999999943	0.0919999999999999984
60309	2N2	75.7999999999999972	0.101999999999999993
60309	OO1	150.400000000000006	0.0100000000000000002
60309	LDA2	129.599999999999994	0.0259999999999999988
60309	M1	207.800000000000011	0.0160000000000000003
60309	J1	169.699999999999989	0.0200000000000000004
60309	SSA	60.1000000000000014	0.0790000000000000008
60309	SA	135.5	0.212999999999999995
60309	RHO1	243.599999999999994	0.0100000000000000002
60309	Q1	246.199999999999989	0.0459999999999999992
60309	T2	142.800000000000011	0.0359999999999999973
60309	R2	144.900000000000006	0.00300000000000000006
60309	2Q1	265.300000000000011	0.00700000000000000015
60309	P1	191.800000000000011	0.115000000000000005
60309	L2	137.900000000000006	0.104999999999999996
60309	K2	146	0.161000000000000004
60309	M8	147.699999999999989	0.0200000000000000004
60310	M2	116.5	3.29999999999999982
60310	S2	141.400000000000006	0.538000000000000034
60310	N2	91.5999999999999943	0.70499999999999996
60310	K1	194.400000000000006	0.33500000000000002
60310	M4	171.699999999999989	0.125
60310	O1	218.199999999999989	0.216999999999999998
60310	M6	160	0.307999999999999996
60310	MK3	204.900000000000006	0.0160000000000000003
60310	S4	133.300000000000011	0.0100000000000000002
60310	MN4	139.5	0.0660000000000000031
60310	NU2	93.9000000000000057	0.153999999999999998
60310	S6	203.300000000000011	0.0129999999999999994
60310	MU2	26.1999999999999993	0.0160000000000000003
60310	2N2	79.9000000000000057	0.104999999999999996
60310	OO1	235.300000000000011	0.0229999999999999996
60310	LDA2	137.099999999999994	0.0690000000000000058
60310	S1	127.900000000000006	0.0330000000000000016
60310	M1	207.800000000000011	0.0160000000000000003
60310	J1	260.300000000000011	0.0259999999999999988
60310	SSA	47.3999999999999986	0.0980000000000000038
60310	SA	129.900000000000006	0.23000000000000001
60310	RHO1	109.5	0.0160000000000000003
60310	Q1	211.5	0.0519999999999999976
60310	T2	99	0.0429999999999999966
60310	R2	140.300000000000011	0.00700000000000000015
60310	2Q1	81.7999999999999972	0.0160000000000000003
60310	P1	211.900000000000006	0.101999999999999993
60310	2SM2	83.7999999999999972	0.0129999999999999994
60310	M3	172.099999999999994	0.0259999999999999988
60310	L2	154.599999999999994	0.176999999999999991
60310	2MK3	212.199999999999989	0.0229999999999999996
60310	K2	142.099999999999994	0.147999999999999993
60310	M8	163.400000000000006	0.0299999999999999989
60310	MS4	198.599999999999994	0.0359999999999999973
60311	M2	92.2000000000000028	2.13899999999999979
60311	S2	118.099999999999994	0.33500000000000002
60311	N2	71	0.453000000000000014
60311	K1	185.699999999999989	0.338000000000000023
60311	M4	249.5	0.0889999999999999958
60311	O1	214	0.194000000000000006
60311	M6	175.400000000000006	0.245999999999999996
60311	S4	136.099999999999994	0.0129999999999999994
60311	NU2	73.9000000000000057	0.0889999999999999958
60311	S6	193.5	0.00300000000000000006
60311	MU2	66.4000000000000057	0.0519999999999999976
60311	2N2	49.7999999999999972	0.0589999999999999969
60311	OO1	156.900000000000006	0.0100000000000000002
60311	LDA2	104.200000000000003	0.0160000000000000003
60311	M1	199.699999999999989	0.0129999999999999994
60311	J1	171.599999999999994	0.0160000000000000003
60311	SSA	47.3999999999999986	0.0980000000000000038
60311	SA	129.900000000000006	0.23000000000000001
60311	RHO1	226.199999999999989	0.00700000000000000015
60311	Q1	228.099999999999994	0.0359999999999999973
60311	T2	117	0.0200000000000000004
60311	R2	119.099999999999994	0.00300000000000000006
60311	2Q1	242.900000000000006	0.00700000000000000015
60311	P1	187.800000000000011	0.112000000000000002
60311	L2	113.5	0.0589999999999999969
60311	K2	120.200000000000003	0.0919999999999999984
60311	M8	215.199999999999989	0.0100000000000000002
60312	M2	93.7999999999999972	2.22100000000000009
60312	S2	116.099999999999994	0.377000000000000002
60312	N2	73.5999999999999943	0.48899999999999999
60312	K1	186.900000000000006	0.328000000000000014
60312	M4	237.099999999999994	0.0660000000000000031
60312	O1	201.699999999999989	0.171000000000000013
60312	M6	170.300000000000011	0.245999999999999996
60312	MK3	146.300000000000011	0.0100000000000000002
60312	S4	65.2000000000000028	0.0129999999999999994
60312	MN4	208.699999999999989	0.0229999999999999996
60312	NU2	64.7999999999999972	0.104999999999999996
60312	S6	218.300000000000011	0.0100000000000000002
60312	MU2	46.3999999999999986	0.0359999999999999973
60312	2N2	42.5	0.0690000000000000058
60312	OO1	204.800000000000011	0.0160000000000000003
60312	LDA2	138.199999999999989	0.0459999999999999992
60312	S1	116.799999999999997	0.0299999999999999989
60312	M1	227.5	0.0229999999999999996
60312	J1	240.300000000000011	0.0229999999999999996
60312	MM	49.2999999999999972	0.0889999999999999958
60312	SSA	76.2000000000000028	0.187
60312	SA	127.200000000000003	0.341000000000000025
60312	MSF	13.6999999999999993	0.125
60312	MF	81.5	0.0459999999999999992
60312	RHO1	236	0.0129999999999999994
60312	Q1	209.300000000000011	0.0519999999999999976
60312	T2	89.4000000000000057	0.0429999999999999966
60312	R2	300.300000000000011	0.0100000000000000002
60312	2Q1	197.400000000000006	0.00300000000000000006
60312	P1	204	0.104999999999999996
60312	2SM2	79.7999999999999972	0.0100000000000000002
60312	M3	126.799999999999997	0.00700000000000000015
60312	L2	94.2000000000000028	0.112000000000000002
60312	2MK3	135.699999999999989	0.00700000000000000015
60312	K2	118.900000000000006	0.104999999999999996
60312	M8	223.099999999999994	0.0129999999999999994
60312	MS4	261.199999999999989	0.0330000000000000016
60313	M2	61.3999999999999986	1.88300000000000001
60313	S2	80.5	0.33500000000000002
60313	N2	36.8999999999999986	0.422999999999999987
60313	K1	186.099999999999994	0.343999999999999972
60313	M4	240.5	0.0749999999999999972
60313	O1	192.599999999999994	0.161000000000000004
60313	M6	175.300000000000011	0.190000000000000002
60313	S4	23	0.0359999999999999973
60313	NU2	40.2000000000000028	0.0820000000000000034
60313	S6	261.899999999999977	0.00700000000000000015
60313	MU2	254.400000000000006	0.0459999999999999992
60313	2N2	12.5	0.0560000000000000012
60313	OO1	180.599999999999994	0.00700000000000000015
60313	LDA2	70.2999999999999972	0.0129999999999999994
60313	M1	189.699999999999989	0.0100000000000000002
60313	J1	184.300000000000011	0.0129999999999999994
60313	SSA	47.3999999999999986	0.0980000000000000038
60313	SA	129.900000000000006	0.23000000000000001
60313	RHO1	195.400000000000006	0.00700000000000000015
60313	Q1	195.5	0.0299999999999999989
60313	T2	79.7999999999999972	0.0200000000000000004
60313	R2	81.2999999999999972	0.00300000000000000006
60313	2Q1	196.400000000000006	0.00300000000000000006
60313	P1	186.5	0.115000000000000005
60313	L2	85.9000000000000057	0.0519999999999999976
60313	K2	82	0.0919999999999999984
60313	M8	264.5	0.0160000000000000003
60314	M2	36.7999999999999972	1.89599999999999991
60314	S2	59.6000000000000014	0.318000000000000005
60314	N2	16.8000000000000007	0.422999999999999987
60314	K1	179.400000000000006	0.350999999999999979
60314	M4	249.199999999999989	0.0749999999999999972
60314	O1	184.800000000000011	0.147999999999999993
60314	M6	167.5	0.131000000000000005
60314	S4	3.20000000000000018	0.0229999999999999996
60314	NU2	19.5	0.0820000000000000034
60314	S6	75.2999999999999972	0.00300000000000000006
60314	MU2	226	0.0459999999999999992
60314	2N2	356.899999999999977	0.0560000000000000012
60314	OO1	173.900000000000006	0.00700000000000000015
60314	LDA2	47.3999999999999986	0.0129999999999999994
60314	M1	181.699999999999989	0.0100000000000000002
60314	J1	176.900000000000006	0.0129999999999999994
60314	SSA	47.3999999999999986	0.0980000000000000038
60314	SA	129.900000000000006	0.23000000000000001
60314	RHO1	187	0.00700000000000000015
60314	Q1	187.5	0.0299999999999999989
60314	T2	58.7000000000000028	0.0200000000000000004
60314	R2	60.6000000000000014	0.00300000000000000006
60314	2Q1	190.099999999999994	0.00300000000000000006
60314	P1	179.800000000000011	0.117999999999999994
60314	L2	56.7000000000000028	0.0519999999999999976
60314	K2	61.3999999999999986	0.0850000000000000061
60314	M8	295.5	0.0200000000000000004
60315	M2	19	2.18800000000000017
60315	S2	43.2999999999999972	0.419999999999999984
60315	N2	0	0.509000000000000008
60315	K1	179.599999999999994	0.331000000000000016
60315	M4	258.199999999999989	0.0820000000000000034
60315	O1	176.300000000000011	0.171000000000000013
60315	M6	151.199999999999989	0.0850000000000000061
60315	MK3	71.5999999999999943	0.0259999999999999988
60315	S4	18.8000000000000007	0.0330000000000000016
60315	MN4	262.699999999999989	0.0389999999999999999
60315	NU2	357.800000000000011	0.0850000000000000061
60315	MU2	10	0.0690000000000000058
60315	2N2	347.699999999999989	0.0660000000000000031
60315	OO1	220.099999999999994	0.0160000000000000003
60315	LDA2	25	0.0259999999999999988
60315	S1	128	0.0429999999999999966
60315	M1	229.800000000000011	0.0100000000000000002
60315	J1	211.300000000000011	0.0160000000000000003
60315	SSA	47.3999999999999986	0.0980000000000000038
60315	SA	129.900000000000006	0.23000000000000001
60315	RHO1	174.900000000000006	0.00700000000000000015
60315	Q1	190.699999999999989	0.0359999999999999973
60315	T2	30.5	0.0359999999999999973
60315	R2	44.3999999999999986	0.00300000000000000006
60315	2Q1	172.900000000000006	0.00300000000000000006
60315	P1	183.900000000000006	0.101999999999999993
60315	M3	68	0.0330000000000000016
60315	L2	27.8000000000000007	0.0820000000000000034
60315	2MK3	49.2999999999999972	0.0259999999999999988
60315	K2	43.8999999999999986	0.115000000000000005
60315	M8	326.699999999999989	0.0129999999999999994
60315	MS4	247.199999999999989	0.0490000000000000019
60316	M2	42.7999999999999972	1.88300000000000001
60316	S2	70.7999999999999972	0.301999999999999991
60316	N2	24.3999999999999986	0.404000000000000026
60316	K1	195.400000000000006	0.304999999999999993
60316	M4	272.399999999999977	0.104999999999999996
60316	O1	201.900000000000006	0.120999999999999996
60316	M6	185.900000000000006	0.0719999999999999946
60316	S4	141.199999999999989	0.0100000000000000002
60316	NU2	26.8000000000000007	0.0790000000000000008
60316	S6	108	0.00300000000000000006
60316	MU2	14.6999999999999993	0.0459999999999999992
60316	2N2	5.90000000000000036	0.0519999999999999976
60316	OO1	189.900000000000006	0.00700000000000000015
60316	LDA2	55.7999999999999972	0.0129999999999999994
60316	M1	198.599999999999994	0.0100000000000000002
60316	J1	192.099999999999994	0.0100000000000000002
60316	SSA	47.3999999999999986	0.0980000000000000038
60316	SA	129.900000000000006	0.23000000000000001
60316	RHO1	204.300000000000011	0.00300000000000000006
60316	Q1	205.199999999999989	0.0229999999999999996
60316	T2	69.7000000000000028	0.0160000000000000003
60316	R2	72	0.00300000000000000006
60316	2Q1	208.5	0.00300000000000000006
60316	P1	195.900000000000006	0.101999999999999993
60316	L2	61.2000000000000028	0.0519999999999999976
60316	K2	73.0999999999999943	0.0820000000000000034
60316	M8	80.2000000000000028	0.0200000000000000004
60317	M2	46	1.7649999999999999
60317	S2	71.5	0.341000000000000025
60317	N2	23.6000000000000014	0.377000000000000002
60317	K1	192.300000000000011	0.269000000000000017
60317	M4	263.5	0.0619999999999999996
60317	O1	199.400000000000006	0.131000000000000005
60317	M6	190	0.0790000000000000008
60317	S4	43.2999999999999972	0.0160000000000000003
60317	NU2	26.6000000000000014	0.0719999999999999946
60317	2N2	1.19999999999999996	0.0490000000000000019
60317	OO1	185.099999999999994	0.00700000000000000015
60317	LDA2	57.7999999999999972	0.0129999999999999994
60317	M1	195.800000000000011	0.0100000000000000002
60317	J1	188.699999999999989	0.0100000000000000002
60317	RHO1	202.5	0.00700000000000000015
60317	Q1	202.800000000000011	0.0259999999999999988
60317	T2	71.4000000000000057	0.0200000000000000004
60317	R2	71.4000000000000057	0.00300000000000000006
60317	2Q1	206.5	0.00300000000000000006
60317	P1	192.199999999999989	0.0889999999999999958
60317	L2	68.4000000000000057	0.0490000000000000019
60317	K2	71.4000000000000057	0.0919999999999999984
60317	M8	62.7000000000000028	0.0129999999999999994
60318	M2	47.6000000000000014	1.79499999999999993
60318	S2	74	0.33500000000000002
60318	N2	23.3999999999999986	0.400000000000000022
60318	K1	189.5	0.266000000000000014
60318	M4	279.300000000000011	0.0619999999999999996
60318	O1	190.800000000000011	0.128000000000000003
60318	M6	189.599999999999994	0.0719999999999999946
60318	S4	14.5999999999999996	0.0100000000000000002
60318	NU2	26.6999999999999993	0.0790000000000000008
60318	S6	200.199999999999989	0.00300000000000000006
60318	MU2	21.1999999999999993	0.0429999999999999966
60318	2N2	359.199999999999989	0.0519999999999999976
60318	OO1	188.199999999999989	0.00700000000000000015
60318	LDA2	59.8999999999999986	0.0129999999999999994
60318	M1	190.199999999999989	0.0100000000000000002
60318	J1	188.900000000000006	0.0100000000000000002
60318	SSA	47.3999999999999986	0.0980000000000000038
60318	SA	129.900000000000006	0.23000000000000001
60318	RHO1	191.400000000000006	0.00300000000000000006
60318	Q1	191.5	0.0259999999999999988
60318	T2	73	0.0200000000000000004
60318	R2	75.0999999999999943	0.00300000000000000006
60318	2Q1	192.099999999999994	0.00300000000000000006
60318	P1	189.599999999999994	0.0889999999999999958
60318	L2	71.7999999999999972	0.0490000000000000019
60318	K2	76.0999999999999943	0.0919999999999999984
60318	M8	78.4000000000000057	0.0129999999999999994
60319	M2	94.7999999999999972	1.51899999999999991
60319	S2	118.900000000000006	0.266000000000000014
60319	N2	73.0999999999999943	0.284999999999999976
60319	K1	238.599999999999994	0.269000000000000017
60319	M4	106.200000000000003	0.0850000000000000061
60319	O1	235.800000000000011	0.150999999999999995
60319	M6	26.3000000000000007	0.0519999999999999976
60319	MK3	206.699999999999989	0.0359999999999999973
60319	S4	183.900000000000006	0.0160000000000000003
60319	MN4	96.5	0.0359999999999999973
60319	NU2	66.0999999999999943	0.0790000000000000008
60319	S6	105	0.00300000000000000006
60319	MU2	236.699999999999989	0.0160000000000000003
60319	2N2	64.0999999999999943	0.0490000000000000019
60319	OO1	297.899999999999977	0.0100000000000000002
60319	LDA2	109.900000000000006	0.0429999999999999966
60319	S1	212.300000000000011	0.0560000000000000012
60319	M1	28.6000000000000014	0.0200000000000000004
60319	J1	84.9000000000000057	0.0129999999999999994
60319	MM	186.599999999999994	0.0229999999999999996
60319	SSA	68.5	0.128000000000000003
60319	SA	109.400000000000006	0.183999999999999997
60319	MSF	37.7000000000000028	0.0820000000000000034
60319	MF	204.300000000000011	0.0749999999999999972
60319	RHO1	206.800000000000011	0.00300000000000000006
60319	Q1	258.600000000000023	0.0299999999999999989
60319	T2	109.599999999999994	0.0229999999999999996
60319	R2	6.5	0.0200000000000000004
60319	2Q1	334.5	0.00300000000000000006
60319	P1	233.300000000000011	0.0749999999999999972
60319	2SM2	23.1999999999999993	0.0100000000000000002
60319	M3	167.400000000000006	0.0229999999999999996
60319	L2	129.699999999999989	0.0950000000000000011
60319	2MK3	178.800000000000011	0.0459999999999999992
60319	K2	118.900000000000006	0.0719999999999999946
60319	M8	323.199999999999989	0.00700000000000000015
60319	MS4	96.7999999999999972	0.0229999999999999996
60320	M2	124.700000000000003	1.5089999999999999
60320	S2	148.300000000000011	0.242999999999999994
60320	N2	104.5	0.298999999999999988
60320	K1	244.699999999999989	0.373999999999999999
60320	M4	145.5	0.0719999999999999946
60320	O1	265.699999999999989	0.190000000000000002
60320	M6	111.900000000000006	0.0560000000000000012
60320	S4	318.800000000000011	0.0100000000000000002
60320	NU2	107.200000000000003	0.0589999999999999969
60320	S6	342.199999999999989	0.00300000000000000006
60320	MU2	101	0.0359999999999999973
60320	2N2	84.2999999999999972	0.0389999999999999999
60320	OO1	223.900000000000006	0.00700000000000000015
60320	LDA2	135.699999999999989	0.0100000000000000002
60320	M1	255	0.0129999999999999994
60320	J1	234.5	0.0160000000000000003
60320	RHO1	274.5	0.00700000000000000015
60320	Q1	275.800000000000011	0.0359999999999999973
60320	T2	147.199999999999989	0.0129999999999999994
60320	R2	149.300000000000011	0.00300000000000000006
60320	2Q1	284.800000000000011	0.00300000000000000006
60320	P1	246.300000000000011	0.125
60320	L2	145	0.0429999999999999966
60320	K2	150.199999999999989	0.0660000000000000031
60320	M8	77.2999999999999972	0.00300000000000000006
60321	M2	158.5	1.64999999999999991
60321	S2	182.900000000000006	0.253000000000000003
60321	N2	135.900000000000006	0.325000000000000011
60321	K1	256	0.409999999999999976
60321	M4	227.900000000000006	0.0980000000000000038
60321	O1	277.600000000000023	0.212999999999999995
60321	M6	184.300000000000011	0.0719999999999999946
60321	S4	25.6000000000000014	0.00700000000000000015
60321	NU2	139	0.0619999999999999996
60321	MU2	133.900000000000006	0.0389999999999999999
60321	2N2	113.299999999999997	0.0429999999999999966
60321	OO1	234.5	0.0100000000000000002
60321	LDA2	170.099999999999994	0.0129999999999999994
60321	M1	266.899999999999977	0.0160000000000000003
60321	J1	245.199999999999989	0.0160000000000000003
60321	RHO1	286.800000000000011	0.00700000000000000015
60321	Q1	288.399999999999977	0.0429999999999999966
60321	T2	181.900000000000006	0.0129999999999999994
60321	R2	184.099999999999994	0.00300000000000000006
60321	2Q1	298.600000000000023	0.00700000000000000015
60321	P1	257.600000000000023	0.135000000000000009
60321	L2	181.199999999999989	0.0459999999999999992
60321	K2	184.900000000000006	0.0690000000000000058
60321	M8	163	0.0100000000000000002
60322	M2	181	1.84699999999999998
60322	S2	209.800000000000011	0.284999999999999976
60322	N2	152.699999999999989	0.366999999999999993
60322	K1	265.100000000000023	0.435999999999999999
60322	M4	255.900000000000006	0.153999999999999998
60322	O1	271.699999999999989	0.209999999999999992
60322	M6	241.099999999999994	0.0749999999999999972
60322	S4	330.100000000000023	0.0100000000000000002
60322	NU2	156.5	0.0719999999999999946
60322	S6	203.199999999999989	0.00300000000000000006
60322	MU2	152.099999999999994	0.0459999999999999992
60322	2N2	124.5	0.0490000000000000019
60322	OO1	258.600000000000023	0.0100000000000000002
60322	LDA2	194.300000000000011	0.0129999999999999994
60322	M1	268.399999999999977	0.0160000000000000003
60322	J1	261.899999999999977	0.0160000000000000003
60322	RHO1	274.5	0.00700000000000000015
60322	Q1	274.899999999999977	0.0389999999999999999
60322	T2	208.599999999999994	0.0160000000000000003
60322	R2	211	0.00300000000000000006
60322	2Q1	278.100000000000023	0.00700000000000000015
60322	P1	265.600000000000023	0.143999999999999989
60322	L2	209.199999999999989	0.0519999999999999976
60322	K2	212.099999999999994	0.0790000000000000008
60322	M8	296.199999999999989	0.00700000000000000015
60323	M2	269.100000000000023	2.254
60323	S2	301.5	0.325000000000000011
60323	N2	249.300000000000011	0.419999999999999984
60323	K1	313.600000000000023	0.370999999999999996
60323	M4	85.0999999999999943	0.301999999999999991
60323	O1	307.699999999999989	0.209999999999999992
60323	M6	178	0.147999999999999993
60323	MK3	98.7000000000000028	0.101999999999999993
60323	S4	139.400000000000006	0.0129999999999999994
60323	MN4	67.7000000000000028	0.112000000000000002
60323	NU2	241.699999999999989	0.0790000000000000008
60323	MU2	45.7999999999999972	0.0820000000000000034
60323	2N2	209.699999999999989	0.0359999999999999973
60323	OO1	13.3000000000000007	0.0129999999999999994
60323	LDA2	270.300000000000011	0.117999999999999994
60323	S1	274.800000000000011	0.0889999999999999958
60323	M1	57.1000000000000014	0.0330000000000000016
60323	J1	157.900000000000006	0.0200000000000000004
60323	SSA	78.5	0.304999999999999993
60323	SA	21.6999999999999993	0.394000000000000017
60323	RHO1	255.800000000000011	0.0100000000000000002
60323	Q1	324.600000000000023	0.0359999999999999973
60323	T2	127.799999999999997	0.00700000000000000015
60323	R2	0.100000000000000006	0.00300000000000000006
60323	2Q1	215.300000000000011	0.00700000000000000015
60323	P1	312.300000000000011	0.101999999999999993
60323	2SM2	224.300000000000011	0.0229999999999999996
60323	M3	54.2000000000000028	0.0359999999999999973
60323	L2	277.899999999999977	0.220000000000000001
60323	2MK3	65.0999999999999943	0.104999999999999996
60323	K2	303.199999999999989	0.112000000000000002
60323	M8	9.59999999999999964	0.0389999999999999999
60323	MS4	111.200000000000003	0.0850000000000000061
60324	M2	8.80000000000000071	2.18500000000000005
60324	S2	33.7999999999999972	0.370999999999999996
60324	N2	353.5	0.48899999999999999
60324	K1	170.199999999999989	0.36399999999999999
60324	M4	245.900000000000006	0.0749999999999999972
60324	O1	177.5	0.164000000000000007
60324	M6	117.599999999999994	0.0490000000000000019
60324	S4	92.0999999999999943	0.0200000000000000004
60324	NU2	355.5	0.0950000000000000011
60324	S6	63	0.00300000000000000006
60324	MU2	343.699999999999989	0.0519999999999999976
60324	2N2	338.100000000000023	0.0660000000000000031
60324	OO1	162.800000000000011	0.00700000000000000015
60324	LDA2	20.3999999999999986	0.0160000000000000003
60324	M1	173.599999999999994	0.0129999999999999994
60324	J1	166.5	0.0129999999999999994
60324	SSA	42.8999999999999986	0.0919999999999999984
60324	SA	129.099999999999994	0.220000000000000001
60324	RHO1	181.099999999999994	0.00700000000000000015
60324	Q1	181.099999999999994	0.0330000000000000016
60324	T2	32.7000000000000028	0.0229999999999999996
60324	R2	34.8999999999999986	0.00300000000000000006
60324	2Q1	185.300000000000011	0.00300000000000000006
60324	P1	170.800000000000011	0.120999999999999996
60324	L2	24.1000000000000014	0.0619999999999999996
60324	K2	35.7999999999999972	0.101999999999999993
60324	M8	345.100000000000023	0.00300000000000000006
60325	M2	4.59999999999999964	2.34600000000000009
60325	S2	32.3999999999999986	0.39700000000000002
60325	N2	350.899999999999977	0.512000000000000011
60325	K1	168.199999999999989	0.373999999999999999
60325	M4	250.400000000000006	0.0980000000000000038
60325	O1	175	0.179999999999999993
60325	M6	91.9000000000000057	0.0850000000000000061
60325	S4	81.7000000000000028	0.0200000000000000004
60325	NU2	352.800000000000011	0.0980000000000000038
60325	S6	45.6000000000000014	0.00700000000000000015
60325	MU2	336.699999999999989	0.0560000000000000012
60325	2N2	337.199999999999989	0.0690000000000000058
60325	OO1	161.800000000000011	0.00700000000000000015
60325	LDA2	17.6000000000000014	0.0160000000000000003
60325	M1	171.699999999999989	0.0129999999999999994
60325	J1	164.900000000000006	0.0129999999999999994
60325	SSA	42.8999999999999986	0.0919999999999999984
60325	SA	129.099999999999994	0.220000000000000001
60325	RHO1	178.300000000000011	0.00700000000000000015
60325	Q1	178.300000000000011	0.0359999999999999973
60325	T2	31.3999999999999986	0.0229999999999999996
60325	R2	33.6000000000000014	0.00300000000000000006
60325	2Q1	179.199999999999989	0.00300000000000000006
60325	P1	168.800000000000011	0.120999999999999996
60325	L2	18.3000000000000007	0.0660000000000000031
60325	K2	34.7000000000000028	0.107999999999999999
60325	M8	43	0.00700000000000000015
60326	M2	21.1999999999999993	2.44399999999999995
60326	S2	51.2000000000000028	0.468999999999999972
60326	N2	5.09999999999999964	0.54500000000000004
60326	K1	182.900000000000006	0.347999999999999976
60326	M4	292.399999999999977	0.117999999999999994
60326	O1	179.300000000000011	0.173999999999999988
60326	M6	174.300000000000011	0.0690000000000000058
60326	MK3	72.7999999999999972	0.0330000000000000016
60326	S4	44.5	0.0459999999999999992
60326	MN4	291.5	0.0560000000000000012
60326	NU2	1.60000000000000009	0.112000000000000002
60326	MU2	38.1000000000000014	0.0950000000000000011
60326	2N2	345	0.0690000000000000058
60326	OO1	204.5	0.0100000000000000002
60326	LDA2	2.29999999999999982	0.0429999999999999966
60326	S1	139.599999999999994	0.0429999999999999966
60326	M1	245.900000000000006	0.0229999999999999996
60326	J1	204	0.0160000000000000003
60326	SSA	58.3999999999999986	0.101999999999999993
60326	SA	129.199999999999989	0.242999999999999994
60326	RHO1	181.5	0.0100000000000000002
60326	Q1	191.300000000000011	0.0359999999999999973
60326	T2	30.3999999999999986	0.0429999999999999966
60326	R2	270.199999999999989	0.0160000000000000003
60326	2Q1	175.699999999999989	0.00300000000000000006
60326	P1	181.800000000000011	0.107999999999999999
60326	M3	86.5999999999999943	0.0389999999999999999
60326	L2	10.1999999999999993	0.0850000000000000061
60326	2MK3	46.1000000000000014	0.0299999999999999989
60326	K2	47.8999999999999986	0.131000000000000005
60326	MS4	284.899999999999977	0.0589999999999999969
60327	M2	10.9000000000000004	2.49699999999999989
60327	S2	41.8999999999999986	0.471999999999999975
60327	N2	355	0.558000000000000052
60327	K1	179.099999999999994	0.390000000000000013
60327	M4	275.100000000000023	0.101999999999999993
60327	O1	169.300000000000011	0.171000000000000013
60327	M6	117	0.0980000000000000038
60327	MK3	25.5	0.0129999999999999994
60327	S4	49.7999999999999972	0.0519999999999999976
60327	MN4	278.699999999999989	0.0519999999999999976
60327	NU2	0.5	0.0950000000000000011
60327	S6	132.099999999999994	0.00300000000000000006
60327	MU2	37.8999999999999986	0.0950000000000000011
60327	2N2	341.100000000000023	0.0919999999999999984
60327	OO1	221.300000000000011	0.00700000000000000015
60327	LDA2	352.899999999999977	0.0490000000000000019
60327	S1	106.700000000000003	0.128000000000000003
60327	M1	162.199999999999989	0.00700000000000000015
60327	J1	215.800000000000011	0.0259999999999999988
60327	MM	339.100000000000023	0.0619999999999999996
60327	SSA	42.8999999999999986	0.0919999999999999984
60327	SA	129.099999999999994	0.220000000000000001
60327	MSF	233.5	0.0560000000000000012
60327	MF	219.199999999999989	0.0850000000000000061
60327	RHO1	154.599999999999994	0.00700000000000000015
60327	Q1	193.699999999999989	0.0490000000000000019
60327	T2	11	0.0490000000000000019
60327	R2	283.300000000000011	0.0160000000000000003
60327	2Q1	319	0.0160000000000000003
60327	P1	172.800000000000011	0.0820000000000000034
60327	2SM2	93.5	0.0100000000000000002
60327	M3	60.2999999999999972	0.0359999999999999973
60327	L2	18.5	0.128000000000000003
60327	2MK3	40.7999999999999972	0.0330000000000000016
60327	K2	40.7000000000000028	0.135000000000000009
60327	M8	48.2000000000000028	0.0100000000000000002
60327	MS4	255.800000000000011	0.0619999999999999996
60328	M2	11.6999999999999993	2.41500000000000004
60328	S2	45.2000000000000028	0.485999999999999988
60328	N2	359.800000000000011	0.548000000000000043
60328	K1	172.099999999999994	0.357999999999999985
60328	M4	261	0.0889999999999999958
60328	O1	180.900000000000006	0.187
60328	M6	128.699999999999989	0.0889999999999999958
60328	S4	63	0.0200000000000000004
60328	NU2	1.39999999999999991	0.104999999999999996
60328	S6	43.2000000000000028	0.00300000000000000006
60328	MU2	338.199999999999989	0.0589999999999999969
60328	2N2	348	0.0719999999999999946
60328	OO1	161.599999999999994	0.00700000000000000015
60328	LDA2	27.1999999999999993	0.0160000000000000003
60328	M1	176.199999999999989	0.0129999999999999994
60328	J1	166.800000000000011	0.0160000000000000003
60328	SSA	42.8999999999999986	0.0919999999999999984
60328	SA	129.099999999999994	0.220000000000000001
60328	RHO1	184.199999999999989	0.00700000000000000015
60328	Q1	185.5	0.0359999999999999973
60328	T2	43.8999999999999986	0.0299999999999999989
60328	R2	46.3999999999999986	0.00300000000000000006
60328	2Q1	191.400000000000006	0.00700000000000000015
60328	P1	172.800000000000011	0.117999999999999994
60328	L2	23.5	0.0690000000000000058
60328	K2	47.8999999999999986	0.131000000000000005
60328	M8	68.0999999999999943	0.00300000000000000006
60329	M2	11.3000000000000007	2.46700000000000008
60329	S2	39.1000000000000014	0.509000000000000008
60329	N2	358.399999999999977	0.573999999999999955
60329	K1	176.900000000000006	0.350999999999999979
60329	M4	283.800000000000011	0.112000000000000002
60329	O1	174.400000000000006	0.197000000000000008
60329	M6	126.400000000000006	0.112000000000000002
60329	MK3	67.4000000000000057	0.0490000000000000019
60329	S4	62.7000000000000028	0.0359999999999999973
60329	MN4	288.899999999999977	0.0589999999999999969
60329	NU2	350.699999999999989	0.0950000000000000011
60329	S6	56.7999999999999972	0.00300000000000000006
60329	MU2	31.3000000000000007	0.0889999999999999958
60329	2N2	338.600000000000023	0.0690000000000000058
60329	OO1	265.899999999999977	0.0129999999999999994
60329	LDA2	347.699999999999989	0.0459999999999999992
60329	S1	166	0.0389999999999999999
60329	M1	176.400000000000006	0.0259999999999999988
60329	SSA	42.8999999999999986	0.0919999999999999984
60329	SA	129.099999999999994	0.220000000000000001
60329	RHO1	262.699999999999989	0.0160000000000000003
60329	Q1	190.800000000000011	0.0330000000000000016
60329	T2	27.1999999999999993	0.0619999999999999996
60329	R2	147.300000000000011	0.0229999999999999996
60329	2Q1	235.599999999999994	0.0200000000000000004
60329	P1	168	0.104999999999999996
60329	2SM2	103.799999999999997	0.0200000000000000004
60329	M3	60.3999999999999986	0.0359999999999999973
60329	L2	342.800000000000011	0.150999999999999995
60329	2MK3	9.30000000000000071	0.0389999999999999999
60329	K2	49.7000000000000028	0.150999999999999995
60329	M8	57.1000000000000014	0.0129999999999999994
60329	MS4	258.399999999999977	0.0619999999999999996
60330	M2	25.3000000000000007	2.65700000000000003
60330	S2	57.8999999999999986	0.381000000000000005
60330	N2	15.6999999999999993	0.616999999999999993
60330	K1	188.699999999999989	0.353999999999999981
60330	M4	299.600000000000023	0.104999999999999996
60330	O1	193.300000000000011	0.179999999999999993
60330	M6	179.400000000000006	0.131000000000000005
60330	MK3	53.5	0.0459999999999999992
60330	S4	92.9000000000000057	0.0299999999999999989
60330	MN4	303.399999999999977	0.0490000000000000019
60330	NU2	4.59999999999999964	0.0790000000000000008
60330	S6	132.5	0.00700000000000000015
60330	MU2	67.0999999999999943	0.16700000000000001
60330	2N2	14.5	0.0490000000000000019
60330	OO1	15.1999999999999993	0.0330000000000000016
60330	LDA2	338.399999999999977	0.0889999999999999958
60330	S1	149.400000000000006	0.0619999999999999996
60330	M1	184.900000000000006	0.0429999999999999966
60330	J1	243.5	0.0200000000000000004
60330	SSA	42.8999999999999986	0.0919999999999999984
60330	SA	129.099999999999994	0.220000000000000001
60330	RHO1	275.399999999999977	0.0200000000000000004
60330	Q1	230.400000000000006	0.0459999999999999992
60330	T2	352.100000000000023	0.0490000000000000019
60330	R2	48	0.157000000000000001
60330	2Q1	203.900000000000006	0.0129999999999999994
60330	P1	194.5	0.0719999999999999946
60330	2SM2	153.699999999999989	0.0359999999999999973
60330	M3	99.0999999999999943	0.0359999999999999973
60330	L2	339.699999999999989	0.216999999999999998
60330	2MK3	26.8999999999999986	0.0690000000000000058
60330	K2	61	0.245999999999999996
60330	M8	107.400000000000006	0.0100000000000000002
60330	MS4	280.600000000000023	0.0950000000000000011
60331	M2	14.9000000000000004	2.54599999999999982
60331	S2	47.6000000000000014	0.505000000000000004
60331	N2	3.5	0.583999999999999964
60331	K1	180.199999999999989	0.36399999999999999
60331	M4	292.5	0.138000000000000012
60331	O1	184.400000000000006	0.179999999999999993
60331	M6	137.900000000000006	0.117999999999999994
60331	MK3	68.0999999999999943	0.0459999999999999992
60331	S4	32.3999999999999986	0.0560000000000000012
60331	MN4	290.899999999999977	0.0619999999999999996
60331	NU2	1.30000000000000004	0.135000000000000009
60331	S6	352.100000000000023	0.00700000000000000015
60331	MU2	45.7999999999999972	0.115000000000000005
60331	2N2	349.100000000000023	0.0619999999999999996
60331	OO1	254.900000000000006	0.0229999999999999996
60331	LDA2	354.199999999999989	0.0690000000000000058
60331	S1	156.099999999999994	0.0459999999999999992
60331	M1	188.900000000000006	0.0259999999999999988
60331	J1	322.899999999999977	0.0129999999999999994
60331	SSA	42.8999999999999986	0.0919999999999999984
60331	SA	129.099999999999994	0.220000000000000001
60331	RHO1	336.600000000000023	0.0160000000000000003
60331	Q1	170.5	0.0389999999999999999
60331	T2	44.2000000000000028	0.0660000000000000031
60331	R2	262	0.0299999999999999989
60331	2Q1	156.099999999999994	0.0160000000000000003
60331	P1	176.099999999999994	0.0889999999999999958
60331	2SM2	156.599999999999994	0.0160000000000000003
60331	M3	70.9000000000000057	0.0389999999999999999
60331	L2	345	0.138000000000000012
60331	2MK3	14.6999999999999993	0.0519999999999999976
60331	K2	43.2000000000000028	0.147999999999999993
60331	M8	81.2999999999999972	0.0129999999999999994
60331	MS4	268.199999999999989	0.0749999999999999972
60332	M2	23.8000000000000007	2.6509999999999998
60332	S2	58.3999999999999986	0.563999999999999946
60332	N2	13.6999999999999993	0.609999999999999987
60332	K1	185	0.347999999999999976
60332	M4	305.600000000000023	0.150999999999999995
60332	O1	184.699999999999989	0.200000000000000011
60332	M6	175.5	0.135000000000000009
60332	MK3	82.7000000000000028	0.0560000000000000012
60332	S4	93.7999999999999972	0.0519999999999999976
60332	MN4	310.800000000000011	0.0749999999999999972
60332	NU2	4.90000000000000036	0.0889999999999999958
60332	S6	96.9000000000000057	0.00700000000000000015
60332	MU2	64.5	0.150999999999999995
60332	2N2	2.5	0.0690000000000000058
60332	OO1	333.100000000000023	0.0160000000000000003
60332	LDA2	349.300000000000011	0.0619999999999999996
60332	S1	193.5	0.0429999999999999966
60332	M1	186.099999999999994	0.0389999999999999999
60332	J1	256.199999999999989	0.0100000000000000002
60332	SSA	69	0.0919999999999999984
60332	SA	129.099999999999994	0.220000000000000001
60332	RHO1	279.699999999999989	0.0200000000000000004
60332	Q1	208.400000000000006	0.0389999999999999999
60332	T2	67.4000000000000057	0.0619999999999999996
60332	R2	169	0.0749999999999999972
60332	2Q1	272.199999999999989	0.0129999999999999994
60332	P1	174.800000000000011	0.101999999999999993
60332	2SM2	145.300000000000011	0.0259999999999999988
60332	M3	83.2000000000000028	0.0359999999999999973
60332	L2	344.300000000000011	0.212999999999999995
60332	2MK3	24.6999999999999993	0.0660000000000000031
60332	K2	77.2000000000000028	0.147999999999999993
60332	M8	109.599999999999994	0.0100000000000000002
60332	MS4	289.5	0.0950000000000000011
60333	M2	6	2.25700000000000012
60333	S2	32.6000000000000014	0.440000000000000002
60333	N2	348.600000000000023	0.518000000000000016
60333	K1	175.699999999999989	0.338000000000000023
60333	M4	269.699999999999989	0.0519999999999999976
60333	O1	172.5	0.176999999999999991
60333	M6	83.7999999999999972	0.0560000000000000012
60333	MK3	52.3999999999999986	0.0160000000000000003
60333	S4	11.4000000000000004	0.0330000000000000016
60333	MN4	275.800000000000011	0.0259999999999999988
60333	NU2	345.699999999999989	0.0950000000000000011
60333	MU2	14.5	0.0790000000000000008
60333	2N2	336.800000000000011	0.0690000000000000058
60333	OO1	218.699999999999989	0.0160000000000000003
60333	LDA2	359.699999999999989	0.0259999999999999988
60333	S1	124.900000000000006	0.0330000000000000016
60333	M1	220.800000000000011	0.0129999999999999994
60333	J1	209.199999999999989	0.0160000000000000003
60333	SSA	42.8999999999999986	0.0919999999999999984
60333	SA	129.099999999999994	0.220000000000000001
60333	RHO1	171.099999999999994	0.00700000000000000015
60333	Q1	183.099999999999994	0.0359999999999999973
60333	T2	17.3999999999999986	0.0330000000000000016
60333	R2	33.7999999999999972	0.00300000000000000006
60333	2Q1	169.199999999999989	0.00700000000000000015
60333	P1	180.199999999999989	0.101999999999999993
60333	M3	56.3999999999999986	0.0359999999999999973
60333	L2	359.800000000000011	0.0889999999999999958
60333	2MK3	33.7999999999999972	0.0259999999999999988
60333	K2	31.5	0.125
60333	MS4	224.300000000000011	0.0389999999999999999
60334	M2	39.1000000000000014	1.627
60334	S2	69.9000000000000057	0.262000000000000011
60334	N2	22.5	0.322000000000000008
60334	K1	199.900000000000006	0.269000000000000017
60334	M4	163.400000000000006	0.0129999999999999994
60334	O1	198.599999999999994	0.150999999999999995
60334	M6	143.900000000000006	0.0619999999999999996
60334	MK3	128.099999999999994	0.0100000000000000002
60334	S4	51.6000000000000014	0.0100000000000000002
60334	NU2	15.9000000000000004	0.0790000000000000008
60334	S6	316.899999999999977	0.00300000000000000006
60334	MU2	101.099999999999994	0.0359999999999999973
60334	2N2	8	0.0299999999999999989
60334	OO1	194.599999999999994	0.0100000000000000002
60334	LDA2	30.3000000000000007	0.0359999999999999973
60334	S1	209.800000000000011	0.0299999999999999989
60334	M1	294.300000000000011	0.0100000000000000002
60334	SSA	42.8999999999999986	0.0919999999999999984
60334	SA	129.099999999999994	0.220000000000000001
60334	RHO1	124.900000000000006	0.00700000000000000015
60334	Q1	206.800000000000011	0.0389999999999999999
60334	T2	63.3999999999999986	0.0259999999999999988
60334	R2	90	0.00300000000000000006
60334	2Q1	251.599999999999994	0.0100000000000000002
60334	P1	200.300000000000011	0.0660000000000000031
60334	M3	127.799999999999997	0.0200000000000000004
60334	L2	42.3999999999999986	0.101999999999999993
60334	2MK3	68.7000000000000028	0.0160000000000000003
60334	K2	70.0999999999999943	0.0749999999999999972
60334	M8	312.5	0.00700000000000000015
60334	MS4	237.699999999999989	0.0200000000000000004
60335	M2	122.599999999999994	0.33500000000000002
60335	S2	139.699999999999989	0.0459999999999999992
60335	N2	92.7000000000000028	0.0560000000000000012
60335	K1	294	0.107999999999999999
60335	M4	127.599999999999994	0.0129999999999999994
60335	O1	266.399999999999977	0.0749999999999999972
60335	M6	336.600000000000023	0.0160000000000000003
60335	S4	193	0.00300000000000000006
60335	NU2	96.2000000000000028	0.0100000000000000002
60335	S6	11.1999999999999993	0.00300000000000000006
60335	MU2	106.200000000000003	0.00700000000000000015
60335	2N2	63.2999999999999972	0.00700000000000000015
60335	OO1	321.300000000000011	0.00300000000000000006
60335	LDA2	130.199999999999989	0.00300000000000000006
60335	M1	280.199999999999989	0.00700000000000000015
60335	J1	306.5	0.00700000000000000015
60335	SSA	40	0.0980000000000000038
60335	SA	145.5	0.233000000000000013
60335	RHO1	254.099999999999994	0.00300000000000000006
60335	Q1	252.699999999999989	0.0160000000000000003
60335	T2	138.400000000000006	0.00300000000000000006
60335	2Q1	243.300000000000011	0.00300000000000000006
60335	P1	291.800000000000011	0.0359999999999999973
60335	L2	152.300000000000011	0.0100000000000000002
60335	K2	140.400000000000006	0.0129999999999999994
60335	M8	13	0.00700000000000000015
60336	M2	91.2000000000000028	0.298999999999999988
60336	S2	108.200000000000003	0.0359999999999999973
60336	N2	73.5	0.0560000000000000012
60336	K1	262.699999999999989	0.112000000000000002
60336	M4	54.6000000000000014	0.0129999999999999994
60336	O1	250.900000000000006	0.0749999999999999972
60336	M6	249.5	0.0160000000000000003
60336	MK3	192.199999999999989	0.00300000000000000006
60336	MN4	21.6000000000000014	0.00700000000000000015
60336	NU2	71.7999999999999972	0.0129999999999999994
60336	MU2	233.699999999999989	0.0100000000000000002
60336	OO1	233.5	0.0129999999999999994
60336	LDA2	105.200000000000003	0.00700000000000000015
60336	S1	244.5	0.0160000000000000003
60336	M1	8.90000000000000036	0.00700000000000000015
60336	J1	163.900000000000006	0.00300000000000000006
60336	SSA	40	0.0980000000000000038
60336	SA	145.5	0.233000000000000013
60336	RHO1	172.199999999999989	0.00300000000000000006
60336	Q1	274.800000000000011	0.0100000000000000002
60336	T2	1.5	0.00300000000000000006
60336	R2	145	0.00300000000000000006
60336	2Q1	297.600000000000023	0.00700000000000000015
60336	P1	258.5	0.0359999999999999973
60336	2SM2	1.5	0.00300000000000000006
60336	M3	178.5	0.00300000000000000006
60336	L2	106.900000000000006	0.0259999999999999988
60336	2MK3	100.400000000000006	0.00700000000000000015
60336	K2	134.5	0.0129999999999999994
60336	M8	269	0.00300000000000000006
60336	MS4	71.4000000000000057	0.00300000000000000006
60337	M2	2.89999999999999991	1.12200000000000011
60337	S2	27.1999999999999993	0.212999999999999995
60337	N2	347	0.248999999999999999
60337	K1	183.300000000000011	0.216999999999999998
60337	M4	297.199999999999989	0.0330000000000000016
60337	O1	178.099999999999994	0.128000000000000003
60337	M6	74.2999999999999972	0.0299999999999999989
60337	MK3	102.400000000000006	0.0160000000000000003
60337	S4	321.199999999999989	0.00700000000000000015
60337	MN4	288.899999999999977	0.0160000000000000003
60337	NU2	344.899999999999977	0.0459999999999999992
60337	S6	117.599999999999994	0.00300000000000000006
60337	MU2	2.70000000000000018	0.0299999999999999989
60337	2N2	327	0.0229999999999999996
60337	OO1	215.599999999999994	0.0100000000000000002
60337	LDA2	0.100000000000000006	0.0229999999999999996
60337	S1	123.5	0.0100000000000000002
60337	M1	212.099999999999994	0.0100000000000000002
60337	J1	93.9000000000000057	0.00300000000000000006
60337	SSA	40	0.0980000000000000038
60337	SA	145.5	0.233000000000000013
60337	RHO1	319.5	0.00700000000000000015
60337	Q1	178.5	0.0299999999999999989
60337	T2	357.199999999999989	0.0229999999999999996
60337	R2	249	0.00700000000000000015
60337	2Q1	298.399999999999977	0.00300000000000000006
60337	P1	187.599999999999994	0.0660000000000000031
60337	2SM2	96.9000000000000057	0.00700000000000000015
60337	M3	42.7000000000000028	0.0160000000000000003
60337	L2	8.40000000000000036	0.0690000000000000058
60337	2MK3	84.9000000000000057	0.0100000000000000002
60337	K2	29.1999999999999993	0.0490000000000000019
60337	M8	346.800000000000011	0.00300000000000000006
60337	MS4	326.300000000000011	0.00700000000000000015
60338	M2	20.6000000000000014	1.31200000000000006
60338	S2	47.3999999999999986	0.220000000000000001
60338	N2	3.5	0.266000000000000014
60338	K1	198.300000000000011	0.27200000000000002
60338	M4	81.4000000000000057	0.0160000000000000003
60338	O1	187.300000000000011	0.176999999999999991
60338	M6	109.599999999999994	0.0459999999999999992
60338	MK3	127.299999999999997	0.0129999999999999994
60338	S4	359.300000000000011	0.00300000000000000006
60338	MN4	83.7999999999999972	0.00300000000000000006
60338	NU2	356.300000000000011	0.0589999999999999969
60338	MU2	64	0.0100000000000000002
60338	2N2	342.399999999999977	0.0389999999999999999
60338	OO1	213.099999999999994	0.0160000000000000003
60338	LDA2	14.1999999999999993	0.0259999999999999988
60338	S1	134.5	0.0160000000000000003
60338	M1	311.699999999999989	0.0129999999999999994
60338	J1	164.599999999999994	0.0100000000000000002
60338	SSA	40	0.0980000000000000038
60338	SA	145.5	0.233000000000000013
60338	RHO1	241.699999999999989	0.00700000000000000015
60338	Q1	197.599999999999994	0.0389999999999999999
60338	T2	10.5	0.0200000000000000004
60338	2Q1	108.599999999999994	0.00700000000000000015
60338	P1	190.199999999999989	0.0790000000000000008
60338	2SM2	45	0.00700000000000000015
60338	M3	70.4000000000000057	0.00700000000000000015
60338	L2	27.6999999999999993	0.0619999999999999996
60338	2MK3	54.2999999999999972	0.0129999999999999994
60338	K2	43.6000000000000014	0.0560000000000000012
60338	M8	212.599999999999994	0.00300000000000000006
60338	MS4	130	0.00700000000000000015
60339	M2	72.9000000000000057	1.7589999999999999
60339	S2	120	0.262000000000000011
60339	N2	65.7999999999999972	0.343999999999999972
60339	K1	237.800000000000011	0.343999999999999972
60339	M4	4.09999999999999964	0.164000000000000007
60339	O1	227.099999999999994	0.276000000000000023
60339	M6	267.399999999999977	0.0790000000000000008
60339	MK3	124	0.0950000000000000011
60339	S4	34.7999999999999972	0.0100000000000000002
60339	MN4	352.100000000000023	0.0690000000000000058
60339	NU2	58.8999999999999986	0.0850000000000000061
60339	S6	23.8999999999999986	0.00300000000000000006
60339	MU2	153.300000000000011	0.128000000000000003
60339	2N2	180.599999999999994	0.0129999999999999994
60339	OO1	261.399999999999977	0.0259999999999999988
60339	LDA2	78.5999999999999943	0.0950000000000000011
60339	S1	192.900000000000006	0.0229999999999999996
60339	M1	280.199999999999989	0.0229999999999999996
60339	J1	302.199999999999989	0.0100000000000000002
60339	RHO1	228.699999999999989	0.0129999999999999994
60339	Q1	246.900000000000006	0.0589999999999999969
60339	T2	47.7999999999999972	0.0259999999999999988
60339	R2	111.400000000000006	0.0160000000000000003
60339	2Q1	144.699999999999989	0.00700000000000000015
60339	P1	231.099999999999994	0.0820000000000000034
60339	2SM2	337.800000000000011	0.0200000000000000004
60339	M3	184.099999999999994	0.0459999999999999992
60339	L2	54	0.187
60339	2MK3	91.2999999999999972	0.0950000000000000011
60339	K2	125.5	0.0919999999999999984
60339	M8	184.5	0.0129999999999999994
60339	MS4	44.1000000000000014	0.0490000000000000019
60340	M2	355.399999999999977	1.94900000000000007
60340	S2	17.8000000000000007	0.381000000000000005
60340	N2	335.899999999999977	0.463000000000000023
60340	K1	183.199999999999989	0.360999999999999988
60340	M4	181.699999999999989	0.0330000000000000016
60340	O1	166.099999999999994	0.245999999999999996
60340	M6	84.7999999999999972	0.0200000000000000004
60340	MN4	156.900000000000006	0.0200000000000000004
60340	NU2	336.600000000000023	0.0850000000000000061
60340	MU2	341.100000000000023	0.0660000000000000031
60340	2N2	319.5	0.0660000000000000031
60340	OO1	203.699999999999989	0.0100000000000000002
60340	LDA2	13.5999999999999996	0.0160000000000000003
60340	S1	114.700000000000003	0.0160000000000000003
60340	M1	214.400000000000006	0.0129999999999999994
60340	J1	174.199999999999989	0.0200000000000000004
60340	SSA	40	0.0980000000000000038
60340	SA	145.5	0.233000000000000013
60340	RHO1	158.800000000000011	0.0100000000000000002
60340	Q1	168.699999999999989	0.0389999999999999999
60340	T2	0.200000000000000011	0.0299999999999999989
60340	R2	18.6999999999999993	0.00300000000000000006
60340	2Q1	149	0.00700000000000000015
60340	P1	178.5	0.107999999999999999
60340	M3	37.5	0.0200000000000000004
60340	L2	6.29999999999999982	0.0619999999999999996
60340	2MK3	33.2000000000000028	0.0100000000000000002
60340	K2	18.6999999999999993	0.101999999999999993
60341	M2	355.100000000000023	1.93199999999999994
60341	S2	19.8999999999999986	0.377000000000000002
60341	N2	335.899999999999977	0.440000000000000002
60341	K1	182.300000000000011	0.357999999999999985
60341	M4	186	0.0299999999999999989
60341	O1	167.099999999999994	0.253000000000000003
60341	M6	70.0999999999999943	0.0129999999999999994
60341	MK3	90.5999999999999943	0.00700000000000000015
60341	S4	232.599999999999994	0.00700000000000000015
60341	MN4	160.199999999999989	0.0160000000000000003
60341	NU2	336.899999999999977	0.0850000000000000061
60341	S6	140.300000000000011	0.00300000000000000006
60341	MU2	339.5	0.0690000000000000058
60341	2N2	317.899999999999977	0.0619999999999999996
60341	OO1	193.300000000000011	0.0100000000000000002
60341	LDA2	10.8000000000000007	0.0160000000000000003
60341	S1	110.099999999999994	0.0330000000000000016
60341	M1	173.599999999999994	0.00700000000000000015
60341	J1	170.800000000000011	0.0160000000000000003
60341	SSA	39.7999999999999972	0.0850000000000000061
60341	SA	132.900000000000006	0.248999999999999999
60341	RHO1	181.300000000000011	0.0100000000000000002
60341	Q1	168.5	0.0389999999999999999
60341	T2	358.600000000000023	0.0330000000000000016
60341	R2	257.5	0.0100000000000000002
60341	2Q1	159.5	0.00700000000000000015
60341	P1	180.400000000000006	0.107999999999999999
60341	2SM2	8.80000000000000071	0.0100000000000000002
60341	M3	44.8999999999999986	0.0200000000000000004
60341	L2	8.69999999999999929	0.0429999999999999966
60341	2MK3	77.4000000000000057	0.00700000000000000015
60341	K2	17.3000000000000007	0.104999999999999996
60341	M8	18.8000000000000007	0.00300000000000000006
60341	MS4	163.300000000000011	0.00700000000000000015
60342	M2	8.19999999999999929	1.79499999999999993
60342	S2	37.2999999999999972	0.331000000000000016
60342	N2	356.100000000000023	0.394000000000000017
60342	K1	193.599999999999994	0.33500000000000002
60342	M4	311.100000000000023	0.0259999999999999988
60342	O1	181.099999999999994	0.23000000000000001
60342	M6	76.4000000000000057	0.0229999999999999996
60342	S4	283.100000000000023	0.00700000000000000015
60342	NU2	357.699999999999989	0.0749999999999999972
60342	S6	69.7000000000000028	0.00300000000000000006
60342	MU2	190.099999999999994	0.0429999999999999966
60342	2N2	343.800000000000011	0.0519999999999999976
60342	OO1	205.5	0.0100000000000000002
60342	LDA2	21.6000000000000014	0.0129999999999999994
60342	M1	187.300000000000011	0.0160000000000000003
60342	J1	199.400000000000006	0.0200000000000000004
60342	SSA	40	0.0980000000000000038
60342	SA	145.5	0.233000000000000013
60342	RHO1	175.699999999999989	0.0100000000000000002
60342	Q1	174.900000000000006	0.0429999999999999966
60342	T2	36.1000000000000014	0.0200000000000000004
60342	R2	38.5	0.00300000000000000006
60342	2Q1	168.699999999999989	0.00700000000000000015
60342	P1	192.800000000000011	0.112000000000000002
60342	L2	20.3999999999999986	0.0490000000000000019
60342	K2	39.6000000000000014	0.0889999999999999958
60342	M8	84.7000000000000028	0.00700000000000000015
60343	M2	59.3999999999999986	1.63700000000000001
60343	S2	106	0.200000000000000011
60343	N2	50.7999999999999972	0.245999999999999996
60343	K1	235.099999999999994	0.384000000000000008
60343	M4	338.300000000000011	0.200000000000000011
60343	O1	222.699999999999989	0.284999999999999976
60343	M6	239.099999999999994	0.0660000000000000031
60343	NU2	51.8999999999999986	0.0490000000000000019
60343	MU2	13.4000000000000004	0.0389999999999999999
60343	2N2	42.2999999999999972	0.0330000000000000016
60343	OO1	247.5	0.0129999999999999994
60343	LDA2	80.9000000000000057	0.0129999999999999994
60343	M1	228.900000000000006	0.0200000000000000004
60343	J1	241.300000000000011	0.0229999999999999996
60343	RHO1	217.400000000000006	0.0100000000000000002
60343	Q1	216.5	0.0560000000000000012
60343	T2	105.900000000000006	0.0129999999999999994
60343	R2	106	0.00300000000000000006
60343	2Q1	210.300000000000011	0.00700000000000000015
60343	P1	235.099999999999994	0.128000000000000003
60343	L2	67.9000000000000057	0.0459999999999999992
60343	K2	106	0.0560000000000000012
60344	M2	51.8999999999999986	2.58499999999999996
60344	S2	85.7999999999999972	0.406999999999999973
60344	N2	34.7999999999999972	0.515000000000000013
60344	K1	214.599999999999994	0.347999999999999976
60344	M4	354	0.107999999999999999
60344	O1	197	0.279000000000000026
60344	M6	183.099999999999994	0.0619999999999999996
60344	MK3	144.800000000000011	0.0359999999999999973
60344	S4	49.8999999999999986	0.0100000000000000002
60344	MN4	336.300000000000011	0.0459999999999999992
60344	NU2	23.8999999999999986	0.117999999999999994
60344	S6	333.300000000000011	0.00300000000000000006
60344	MU2	110.400000000000006	0.0619999999999999996
60344	2N2	1.60000000000000009	0.0749999999999999972
60344	OO1	286.5	0.0389999999999999999
60344	LDA2	65.5	0.0490000000000000019
60344	S1	164	0.0560000000000000012
60344	M1	348.899999999999977	0.0100000000000000002
60344	J1	220.199999999999989	0.0229999999999999996
60344	SSA	41.2999999999999972	0.101999999999999993
60344	SA	140.5	0.171000000000000013
60344	RHO1	190.599999999999994	0.0200000000000000004
60344	Q1	203	0.0690000000000000058
60344	T2	80.0999999999999943	0.0389999999999999999
60344	R2	347.699999999999989	0.00700000000000000015
60344	2Q1	52	0.0330000000000000016
60344	P1	205.099999999999994	0.120999999999999996
60344	2SM2	300.199999999999989	0.00700000000000000015
60344	M3	150	0.0229999999999999996
60344	L2	60.7999999999999972	0.140999999999999986
60344	2MK3	118.599999999999994	0.0330000000000000016
60344	K2	89.2000000000000028	0.112000000000000002
60344	M8	54.6000000000000014	0.0200000000000000004
60344	MS4	48.8999999999999986	0.0330000000000000016
60345	M2	8.5	1.87000000000000011
60345	S2	37.1000000000000014	0.331000000000000016
60345	N2	354.100000000000023	0.404000000000000026
60345	K1	194.199999999999989	0.341000000000000025
60345	M4	162.199999999999989	0.0359999999999999973
60345	O1	178.800000000000011	0.269000000000000017
60345	M6	45	0.0129999999999999994
60345	MK3	354.699999999999989	0.0200000000000000004
60345	S4	230.699999999999989	0.0100000000000000002
60345	MN4	154.699999999999989	0.0259999999999999988
60345	NU2	345.899999999999977	0.0919999999999999984
60345	S6	118.900000000000006	0.00300000000000000006
60345	MU2	26.3000000000000007	0.0589999999999999969
60345	2N2	343.399999999999977	0.0619999999999999996
60345	OO1	245.599999999999994	0.00300000000000000006
60345	LDA2	18.8000000000000007	0.0299999999999999989
60345	S1	115.700000000000003	0.0330000000000000016
60345	M1	308.699999999999989	0.00300000000000000006
60345	J1	198.699999999999989	0.0229999999999999996
60345	SSA	40	0.0980000000000000038
60345	SA	145.5	0.233000000000000013
60345	RHO1	213.300000000000011	0.0200000000000000004
60345	Q1	184.400000000000006	0.0389999999999999999
60345	T2	18.6999999999999993	0.0330000000000000016
60345	2Q1	216.099999999999994	0.00300000000000000006
60345	P1	183.699999999999989	0.107999999999999999
60345	2SM2	196.099999999999994	0.00700000000000000015
60345	M3	84.9000000000000057	0.0160000000000000003
60345	L2	5.90000000000000036	0.0690000000000000058
60345	2MK3	329.399999999999977	0.0200000000000000004
60345	K2	29.8000000000000007	0.107999999999999999
60345	M8	188.599999999999994	0.00300000000000000006
60345	MS4	177	0.0160000000000000003
60346	M2	8.90000000000000036	1.89999999999999991
60346	S2	38.1000000000000014	0.377000000000000002
60346	N2	351.800000000000011	0.39700000000000002
60346	K1	197.400000000000006	0.331000000000000016
60346	M4	154.599999999999994	0.0330000000000000016
60346	O1	180.599999999999994	0.256000000000000005
60346	M6	39.6000000000000014	0.0200000000000000004
60346	MK3	345.600000000000023	0.0200000000000000004
60346	S4	272	0.0100000000000000002
60346	MN4	149.900000000000006	0.0229999999999999996
60346	NU2	343.399999999999977	0.0889999999999999958
60346	MU2	27.6999999999999993	0.0519999999999999976
60346	2N2	329.899999999999977	0.0519999999999999976
60346	OO1	154	0.0229999999999999996
60346	LDA2	10.5	0.0299999999999999989
60346	S1	143.400000000000006	0.0560000000000000012
60346	M1	227.699999999999989	0.0200000000000000004
60346	J1	175.400000000000006	0.0160000000000000003
60346	SSA	40	0.0980000000000000038
60346	SA	145.5	0.233000000000000013
60346	RHO1	168.199999999999989	0.00300000000000000006
60346	Q1	199.300000000000011	0.0429999999999999966
60346	T2	43.5	0.0690000000000000058
60346	R2	199.5	0.0389999999999999999
60346	2Q1	148.800000000000011	0.0200000000000000004
60346	P1	196.300000000000011	0.0950000000000000011
60346	2SM2	218.400000000000006	0.00300000000000000006
60346	M3	74.4000000000000057	0.0200000000000000004
60346	L2	8.59999999999999964	0.0749999999999999972
60346	2MK3	344.699999999999989	0.0160000000000000003
60346	K2	33.7000000000000028	0.0790000000000000008
60346	M8	196.800000000000011	0.00300000000000000006
60346	MS4	162.800000000000011	0.0160000000000000003
60347	M2	24	1.91300000000000003
60347	S2	58.7000000000000028	0.331000000000000016
60347	N2	10.5999999999999996	0.412999999999999978
60347	K1	207	0.347999999999999976
60347	M4	245.400000000000006	0.0519999999999999976
60347	O1	189.300000000000011	0.269000000000000017
60347	M6	67	0.0389999999999999999
60347	MK3	27.8999999999999986	0.0330000000000000016
60347	S4	311.100000000000023	0.0100000000000000002
60347	MN4	220.199999999999989	0.0259999999999999988
60347	NU2	4.70000000000000018	0.0820000000000000034
60347	S6	216.400000000000006	0.00300000000000000006
60347	MU2	65	0.0749999999999999972
60347	2N2	350.800000000000011	0.0519999999999999976
60347	OO1	261.899999999999977	0.0229999999999999996
60347	LDA2	11.1999999999999993	0.0519999999999999976
60347	S1	169.400000000000006	0.0200000000000000004
60347	M1	282.5	0.0129999999999999994
60347	J1	212.300000000000011	0.0229999999999999996
60347	SSA	40	0.0980000000000000038
60347	SA	145.5	0.233000000000000013
60347	MF	188.599999999999994	0.125
60347	RHO1	209.400000000000006	0.0160000000000000003
60347	Q1	191.099999999999994	0.0719999999999999946
60347	T2	27.5	0.0389999999999999999
60347	R2	245.599999999999994	0.00700000000000000015
60347	2Q1	45.8999999999999986	0.0160000000000000003
60347	P1	199.400000000000006	0.107999999999999999
60347	2SM2	209	0.00300000000000000006
60347	M3	78	0.0259999999999999988
60347	L2	15.3000000000000007	0.0980000000000000038
60347	2MK3	9.5	0.0330000000000000016
60347	K2	52.3999999999999986	0.0919999999999999984
60347	M8	270.699999999999989	0.00700000000000000015
60347	MS4	261.800000000000011	0.0160000000000000003
60348	M2	1	2.05399999999999983
60348	S2	22.8000000000000007	0.416999999999999982
60348	N2	343.600000000000023	0.485999999999999988
60348	K1	185.599999999999994	0.373999999999999999
60348	M4	166	0.0259999999999999988
60348	O1	172	0.276000000000000023
60348	M6	255.699999999999989	0.0160000000000000003
60348	S4	237.5	0.0129999999999999994
60348	NU2	345.899999999999977	0.0950000000000000011
60348	S6	145.199999999999989	0.00300000000000000006
60348	MU2	338.5	0.0490000000000000019
60348	2N2	326.5	0.0660000000000000031
60348	OO1	199.900000000000006	0.0129999999999999994
60348	LDA2	11	0.0129999999999999994
60348	M1	178.900000000000006	0.0200000000000000004
60348	J1	192.699999999999989	0.0229999999999999996
60348	SSA	40	0.0980000000000000038
60348	SA	145.5	0.233000000000000013
60348	RHO1	166	0.0100000000000000002
60348	Q1	165.099999999999994	0.0519999999999999976
60348	T2	21.8999999999999986	0.0259999999999999988
60348	R2	23.8000000000000007	0.00300000000000000006
60348	2Q1	158.099999999999994	0.00700000000000000015
60348	P1	184.599999999999994	0.125
60348	L2	17.8999999999999986	0.0589999999999999969
60348	K2	24.6000000000000014	0.115000000000000005
60349	M2	28.6000000000000014	2.34200000000000008
60349	S2	55.2999999999999972	0.409999999999999976
60349	N2	9.69999999999999929	0.52200000000000002
60349	K1	200.400000000000006	0.343999999999999972
60349	M4	101	0.0330000000000000016
60349	O1	185.599999999999994	0.276000000000000023
60349	M6	20.8000000000000007	0.0259999999999999988
60349	MN4	115.299999999999997	0.0100000000000000002
60349	NU2	7.40000000000000036	0.104999999999999996
60349	MU2	40.5	0.0389999999999999999
60349	2N2	352.300000000000011	0.0690000000000000058
60349	OO1	215	0.0129999999999999994
60349	LDA2	41.6000000000000014	0.0330000000000000016
60349	S1	134.699999999999989	0.0299999999999999989
60349	M1	243.400000000000006	0.0129999999999999994
60349	J1	197.099999999999994	0.0200000000000000004
60349	SSA	40.2999999999999972	0.104999999999999996
60349	SA	147.699999999999989	0.190000000000000002
60349	RHO1	179.300000000000011	0.0100000000000000002
60349	Q1	184.099999999999994	0.0429999999999999966
60349	T2	33.7000000000000028	0.0389999999999999999
60349	R2	56.5	0.00300000000000000006
60349	2Q1	171	0.00700000000000000015
60349	P1	199.199999999999989	0.117999999999999994
60349	M3	94.0999999999999943	0.0160000000000000003
60349	L2	43.8999999999999986	0.120999999999999996
60349	2MK3	110.5	0.0129999999999999994
60349	K2	54.5	0.107999999999999999
60349	MS4	128.099999999999994	0.0160000000000000003
60350	M2	43.2999999999999972	2.6379999999999999
60350	S2	73.7999999999999972	0.446000000000000008
60350	N2	27.1000000000000014	0.59099999999999997
60350	K1	212	0.36399999999999999
60350	M4	320	0.0919999999999999984
60350	O1	193.900000000000006	0.288999999999999979
60350	M6	147.800000000000011	0.0519999999999999976
60350	S4	14.0999999999999996	0.0200000000000000004
60350	NU2	29.1999999999999993	0.115000000000000005
60350	S6	215.5	0.00300000000000000006
60350	MU2	223.099999999999994	0.0619999999999999996
60350	2N2	10.8000000000000007	0.0790000000000000008
60350	OO1	226.900000000000006	0.0100000000000000002
60350	LDA2	57.5	0.0200000000000000004
60350	M1	202.099999999999994	0.0200000000000000004
60350	J1	218.400000000000006	0.0229999999999999996
60350	SSA	40.2999999999999972	0.104999999999999996
60350	SA	147.699999999999989	0.190000000000000002
60350	RHO1	186.900000000000006	0.0100000000000000002
60350	Q1	185.699999999999989	0.0519999999999999976
60350	T2	72.5999999999999943	0.0259999999999999988
60350	R2	75	0.00300000000000000006
60350	2Q1	177.5	0.00700000000000000015
60350	P1	210.5	0.120999999999999996
60350	L2	59.5	0.0719999999999999946
60350	K2	76.2999999999999972	0.120999999999999996
60350	M8	55.1000000000000014	0.0160000000000000003
60351	M2	56.3999999999999986	2.7200000000000002
60351	S2	89.9000000000000057	0.406999999999999973
60351	N2	41.1000000000000014	0.593999999999999972
60351	K1	216.5	0.377000000000000002
60351	M4	15.1999999999999993	0.120999999999999996
60351	O1	200.199999999999989	0.279000000000000026
60351	M6	212.599999999999994	0.0589999999999999969
60351	S4	348.199999999999989	0.00300000000000000006
60351	NU2	43.1000000000000014	0.115000000000000005
60351	MU2	22.8000000000000007	0.0660000000000000031
60351	2N2	25.8000000000000007	0.0790000000000000008
60351	OO1	232.5	0.0129999999999999994
60351	LDA2	72	0.0160000000000000003
60351	M1	208.400000000000006	0.0200000000000000004
60351	J1	224.400000000000006	0.0229999999999999996
60351	SSA	40.2999999999999972	0.104999999999999996
60351	SA	147.699999999999989	0.190000000000000002
60351	RHO1	193.400000000000006	0.0100000000000000002
60351	Q1	192.400000000000006	0.0519999999999999976
60351	T2	88.5999999999999943	0.0229999999999999996
60351	R2	91.2999999999999972	0.00300000000000000006
60351	2Q1	184.5	0.00700000000000000015
60351	P1	215.300000000000011	0.125
60351	L2	71.7000000000000028	0.0749999999999999972
60351	K2	92.7000000000000028	0.112000000000000002
60351	M8	131.900000000000006	0.00700000000000000015
60352	M2	72.2000000000000028	2.7330000000000001
60352	S2	100.5	0.409999999999999976
60352	N2	61.2999999999999972	0.538000000000000034
60352	K1	221.099999999999994	0.33500000000000002
60352	M4	40	0.117999999999999994
60352	O1	206.900000000000006	0.262000000000000011
60352	M6	274.5	0.0660000000000000031
60352	MK3	162.199999999999989	0.0389999999999999999
60352	S4	55.7000000000000028	0.0100000000000000002
60352	MN4	29.1000000000000014	0.0619999999999999996
60352	NU2	35.1000000000000014	0.16700000000000001
60352	S6	34.5	0.00300000000000000006
60352	MU2	164.599999999999994	0.0589999999999999969
60352	2N2	55.3999999999999986	0.0389999999999999999
60352	OO1	25.5	0.00700000000000000015
60352	LDA2	95.5	0.0459999999999999992
60352	S1	183.400000000000006	0.0490000000000000019
60352	M1	258.199999999999989	0.0330000000000000016
60352	J1	217.099999999999994	0.0200000000000000004
60352	MM	49	0.0749999999999999972
60352	SSA	55.3999999999999986	0.253000000000000003
60352	SA	120.299999999999997	0.394000000000000017
60352	MSF	20.8999999999999986	0.164000000000000007
60352	MF	111.599999999999994	0.0299999999999999989
60352	RHO1	23.6999999999999993	0.0100000000000000002
60352	Q1	222	0.0519999999999999976
60352	T2	72.9000000000000057	0.0389999999999999999
60352	R2	251.900000000000006	0.00700000000000000015
60352	2Q1	25.3000000000000007	0.0160000000000000003
60352	P1	220.400000000000006	0.112000000000000002
60352	2SM2	21.3000000000000007	0.0100000000000000002
60352	M3	119.900000000000006	0.0160000000000000003
60352	L2	47	0.245999999999999996
60352	2MK3	135.099999999999994	0.0459999999999999992
60352	K2	100.400000000000006	0.112000000000000002
60352	M8	200.300000000000011	0.0100000000000000002
60352	MS4	96.5999999999999943	0.0330000000000000016
60353	M2	173.300000000000011	2.41100000000000003
60353	S2	209	0.301999999999999991
60353	N2	164.400000000000006	0.328000000000000014
60353	K1	280.100000000000023	0.328000000000000014
60353	M4	233.300000000000011	0.288999999999999979
60353	O1	248.800000000000011	0.23000000000000001
60353	M6	216.900000000000006	0.161000000000000004
60353	S4	282.800000000000011	0.0160000000000000003
60353	NU2	165.599999999999994	0.0660000000000000031
60353	S6	335.300000000000011	0.0100000000000000002
60353	MU2	137.300000000000011	0.0560000000000000012
60353	2N2	155.800000000000011	0.0429999999999999966
60353	OO1	309.899999999999977	0.0100000000000000002
60353	LDA2	189.900000000000006	0.0160000000000000003
60353	M1	264.5	0.0160000000000000003
60353	J1	295	0.0160000000000000003
60353	SSA	63	0.298999999999999988
60353	SA	119.200000000000003	0.491999999999999993
60353	RHO1	235.599999999999994	0.00700000000000000015
60353	Q1	233.900000000000006	0.0429999999999999966
60353	T2	207.5	0.0160000000000000003
60353	R2	210.5	0.00300000000000000006
60353	2Q1	223.400000000000006	0.00700000000000000015
60353	P1	277.699999999999989	0.112000000000000002
60353	L2	182.099999999999994	0.0660000000000000031
60353	K2	211.800000000000011	0.0820000000000000034
60353	M8	285	0.0560000000000000012
60354	M2	200.5	2.91000000000000014
60354	S2	241.599999999999994	0.33500000000000002
60354	N2	187.5	0.494999999999999996
60354	K1	291.199999999999989	0.322000000000000008
60354	M4	302.800000000000011	0.256000000000000005
60354	O1	269.800000000000011	0.262000000000000011
60354	M6	272	0.161000000000000004
60354	MK3	357.699999999999989	0.0820000000000000034
60354	S4	249.099999999999994	0.0100000000000000002
60354	MN4	286.899999999999977	0.101999999999999993
60354	NU2	173.599999999999994	0.157000000000000001
60354	S6	323.600000000000023	0.00300000000000000006
60354	MU2	317.600000000000023	0.173999999999999988
60354	2N2	119.5	0.0330000000000000016
60354	OO1	54.2999999999999972	0.00700000000000000015
60354	LDA2	205.099999999999994	0.0950000000000000011
60354	S1	240.800000000000011	0.0790000000000000008
60354	M1	325.5	0.0429999999999999966
60354	J1	337.899999999999977	0.00300000000000000006
60354	MM	49.1000000000000014	0.16700000000000001
60354	SSA	57.7000000000000028	0.304999999999999993
60354	SA	121.400000000000006	0.426999999999999991
60354	MSF	31.1000000000000014	0.115000000000000005
60354	MF	89.7999999999999972	0.0490000000000000019
60354	RHO1	154	0.0160000000000000003
60354	Q1	265.5	0.0389999999999999999
60354	T2	206.699999999999989	0.0229999999999999996
60354	R2	101.599999999999994	0.00300000000000000006
60354	2Q1	70.7999999999999972	0.0129999999999999994
60354	P1	293.5	0.0950000000000000011
60354	2SM2	161.300000000000011	0.0160000000000000003
60354	M3	284.399999999999977	0.0299999999999999989
60354	L2	190	0.357999999999999985
60354	2MK3	321.899999999999977	0.0850000000000000061
60354	K2	237.5	0.101999999999999993
60354	M8	17.1999999999999993	0.0820000000000000034
60354	MS4	344.899999999999977	0.0619999999999999996
60355	M2	214.300000000000011	3.27800000000000002
60355	S2	255.400000000000006	0.381000000000000005
60355	N2	203.300000000000011	0.551000000000000045
60355	K1	296.600000000000023	0.331000000000000016
60355	M4	343	0.440000000000000002
60355	O1	277.100000000000023	0.27200000000000002
60355	M6	352.699999999999989	0.0889999999999999958
60355	MK3	19.6999999999999993	0.107999999999999999
60355	S4	315.300000000000011	0.0100000000000000002
60355	MN4	327.600000000000023	0.176999999999999991
60355	NU2	185.900000000000006	0.179999999999999993
60355	S6	49.3999999999999986	0.00300000000000000006
60355	MU2	326	0.203000000000000014
60355	2N2	126.099999999999994	0.0359999999999999973
60355	OO1	131	0.00700000000000000015
60355	LDA2	222.800000000000011	0.107999999999999999
60355	S1	245.400000000000006	0.0660000000000000031
60355	M1	335.800000000000011	0.0429999999999999966
60355	J1	301.399999999999977	0.0200000000000000004
60355	MM	46.2000000000000028	0.23000000000000001
60355	SSA	78.9000000000000057	0.357999999999999985
60355	SA	137.800000000000011	0.412999999999999978
60355	MSF	47.5	0.161000000000000004
60355	MF	128.900000000000006	0.0490000000000000019
60355	RHO1	74.4000000000000057	0.0200000000000000004
60355	Q1	292.600000000000023	0.0589999999999999969
60355	T2	193.800000000000011	0.0359999999999999973
60355	R2	299.899999999999977	0.0100000000000000002
60355	2Q1	95.2999999999999972	0.0200000000000000004
60355	P1	294.399999999999977	0.104999999999999996
60355	2SM2	181.099999999999994	0.0229999999999999996
60355	M3	301.5	0.0389999999999999999
60355	L2	203.900000000000006	0.390000000000000013
60355	2MK3	345.899999999999977	0.112000000000000002
60355	K2	254.400000000000006	0.128000000000000003
60355	M8	76.0999999999999943	0.0459999999999999992
60355	MS4	31	0.0980000000000000038
60356	M2	220.199999999999989	3.27099999999999991
60356	S2	254.199999999999989	0.426999999999999991
60356	N2	190	0.59099999999999997
60356	K1	280.300000000000011	0.226000000000000006
60356	M4	358.5	0.52200000000000002
60356	O1	257.600000000000023	0.223000000000000004
60356	M6	47.3999999999999986	0.147999999999999993
60356	S4	84.5	0.107999999999999999
60356	NU2	194	0.115000000000000005
60356	S6	123.099999999999994	0.0299999999999999989
60356	MU2	37.7000000000000028	0.0749999999999999972
60356	2N2	159.800000000000011	0.0749999999999999972
60356	OO1	301.800000000000011	0.0100000000000000002
60356	LDA2	235.5	0.0229999999999999996
60356	M1	268.800000000000011	0.0160000000000000003
60356	J1	290.600000000000023	0.0160000000000000003
60356	SSA	91.0999999999999943	0.242999999999999994
60356	SA	139.400000000000006	0.353999999999999981
60356	RHO1	248.199999999999989	0.0100000000000000002
60356	Q1	246.699999999999989	0.0429999999999999966
60356	T2	252.800000000000011	0.0259999999999999988
60356	R2	255.099999999999994	0.00300000000000000006
60356	2Q1	236.099999999999994	0.00700000000000000015
60356	P1	278.600000000000023	0.0749999999999999972
60356	L2	251	0.0919999999999999984
60356	K2	256.899999999999977	0.115000000000000005
60356	M8	173.800000000000011	0.0790000000000000008
60357	M2	220.300000000000011	3.67399999999999993
60357	S2	266.399999999999977	0.459000000000000019
60357	N2	203.199999999999989	0.580999999999999961
60357	K1	297.899999999999977	0.360999999999999988
60357	M4	357.300000000000011	0.573999999999999955
60357	O1	279.399999999999977	0.279000000000000026
60357	M6	39.1000000000000014	0.294999999999999984
60357	MK3	28.8999999999999986	0.125
60357	S4	78.2999999999999972	0.00700000000000000015
60357	MN4	340.100000000000023	0.197000000000000008
60357	NU2	198	0.203000000000000014
60357	S6	49.5	0.00300000000000000006
60357	MU2	330.399999999999977	0.233000000000000013
60357	2N2	194.199999999999989	0.0690000000000000058
60357	OO1	3.60000000000000009	0.00700000000000000015
60357	LDA2	229.5	0.135000000000000009
60357	S1	230.599999999999994	0.0820000000000000034
60357	M1	115.200000000000003	0.00700000000000000015
60357	J1	303.300000000000011	0.00700000000000000015
60357	SSA	66.2999999999999972	0.187
60357	SA	88	0.33500000000000002
60357	RHO1	277.5	0.00700000000000000015
60357	Q1	297.5	0.0389999999999999999
60357	T2	262.300000000000011	0.0299999999999999989
60357	2Q1	268.199999999999989	0.00700000000000000015
60357	P1	296.600000000000023	0.101999999999999993
60357	2SM2	121.099999999999994	0.0229999999999999996
60357	M3	91.0999999999999943	0.0359999999999999973
60357	L2	236	0.36399999999999999
60357	2MK3	355.399999999999977	0.138000000000000012
60357	K2	268.300000000000011	0.131000000000000005
60357	M8	173	0.138000000000000012
60357	MS4	47.2000000000000028	0.153999999999999998
60358	M2	146	2.55200000000000005
60358	S2	181.5	0.325000000000000011
60358	N2	130.199999999999989	0.443000000000000005
60358	K1	261.800000000000011	0.331000000000000016
60358	M4	195	0.298999999999999988
60358	O1	246	0.276000000000000023
60358	M6	156.199999999999989	0.117999999999999994
60358	MK3	277.300000000000011	0.0660000000000000031
60358	S4	229.400000000000006	0.00700000000000000015
60358	MN4	178.900000000000006	0.107999999999999999
60358	NU2	121.900000000000006	0.138000000000000012
60358	S6	321.800000000000011	0.00300000000000000006
60358	MU2	263.300000000000011	0.107999999999999999
60358	2N2	125	0.0459999999999999992
60358	OO1	254.199999999999989	0.00700000000000000015
60358	LDA2	154.699999999999989	0.0749999999999999972
60358	S1	208	0.0690000000000000058
60358	M1	337.300000000000011	0.0129999999999999994
60358	J1	242.099999999999994	0.0100000000000000002
60358	MM	58	0.117999999999999994
60358	SSA	56.5	0.183999999999999997
60358	SA	127.700000000000003	0.384000000000000008
60358	MSF	33.5	0.107999999999999999
60358	RHO1	196.5	0.0160000000000000003
60358	Q1	267.800000000000011	0.0330000000000000016
60358	T2	166.699999999999989	0.0229999999999999996
60358	R2	212.800000000000011	0.00300000000000000006
60358	2Q1	284.600000000000023	0.00300000000000000006
60358	P1	252.800000000000011	0.101999999999999993
60358	2SM2	6.40000000000000036	0.0100000000000000002
60358	M3	237.699999999999989	0.0129999999999999994
60358	L2	158.400000000000006	0.248999999999999999
60358	2MK3	242.300000000000011	0.0660000000000000031
60358	K2	182	0.0919999999999999984
60358	M8	186.300000000000011	0.0429999999999999966
60358	MS4	240.099999999999994	0.0850000000000000061
60359	M2	185.800000000000011	2.75300000000000011
60359	S2	225.5	0.304999999999999993
60359	N2	168.699999999999989	0.478999999999999981
60359	K1	283.699999999999989	0.33500000000000002
60359	M4	256.399999999999977	0.276000000000000023
60359	O1	263.800000000000011	0.266000000000000014
60359	M6	248.400000000000006	0.171000000000000013
60359	MK3	332.399999999999977	0.0719999999999999946
60359	MN4	240	0.107999999999999999
60359	NU2	163.199999999999989	0.153999999999999998
60359	MU2	309.100000000000023	0.147999999999999993
60359	2N2	148.599999999999994	0.0490000000000000019
60359	OO1	303.5	0.0100000000000000002
60359	LDA2	196.199999999999989	0.0850000000000000061
60359	S1	240.300000000000011	0.0790000000000000008
60359	M1	352.100000000000023	0.0160000000000000003
60359	J1	311.699999999999989	0.0160000000000000003
60359	MM	27	0.0950000000000000011
60359	SSA	63	0.298999999999999988
60359	SA	119.200000000000003	0.491999999999999993
60359	MSF	17.6999999999999993	0.0889999999999999958
60359	RHO1	264.199999999999989	0.0100000000000000002
60359	Q1	271.899999999999977	0.0389999999999999999
60359	T2	221.5	0.0299999999999999989
60359	R2	227.199999999999989	0.00300000000000000006
60359	2Q1	244.099999999999994	0.00700000000000000015
60359	P1	279.100000000000023	0.101999999999999993
60359	2SM2	119.799999999999997	0.0100000000000000002
60359	M3	262.800000000000011	0.0129999999999999994
60359	L2	197.300000000000011	0.304999999999999993
60359	2MK3	295.600000000000023	0.0749999999999999972
60359	K2	221.699999999999989	0.0980000000000000038
60359	M8	335.600000000000023	0.0519999999999999976
60359	MS4	305.199999999999989	0.0719999999999999946
60360	M2	195.099999999999994	2.70699999999999985
60360	S2	235.099999999999994	0.307999999999999996
60360	N2	175.800000000000011	0.429999999999999993
60360	K1	289.699999999999989	0.343999999999999972
60360	M4	286	0.360999999999999988
60360	O1	273.199999999999989	0.253000000000000003
60360	M6	289.800000000000011	0.157000000000000001
60360	MK3	351.600000000000023	0.0429999999999999966
60360	MN4	271	0.140999999999999986
60360	NU2	171.300000000000011	0.157000000000000001
60360	MU2	312.199999999999989	0.120999999999999996
60360	2N2	147.599999999999994	0.0850000000000000061
60360	OO1	306.199999999999989	0.0100000000000000002
60360	LDA2	198	0.0749999999999999972
60360	S1	233.800000000000011	0.0589999999999999969
60360	M1	281.399999999999977	0.0160000000000000003
60360	J1	298	0.0200000000000000004
60360	MM	66.2000000000000028	0.143999999999999989
60360	SSA	62.2999999999999972	0.157000000000000001
60360	SA	110.200000000000003	0.281999999999999973
60360	MSF	15.0999999999999996	0.203000000000000014
60360	MF	2.39999999999999991	0.120999999999999996
60360	Q1	299.899999999999977	0.0359999999999999973
60360	T2	235	0.0200000000000000004
60360	R2	170	0.0519999999999999976
60360	P1	277.300000000000011	0.101999999999999993
60360	L2	209.5	0.212999999999999995
60360	2MK3	312.800000000000011	0.0749999999999999972
60360	K2	238	0.0749999999999999972
60360	M8	22.8000000000000007	0.0589999999999999969
60360	MS4	339	0.107999999999999999
60361	M2	194.699999999999989	2.7719999999999998
60361	S2	235.099999999999994	0.307999999999999996
60361	N2	177.900000000000006	0.440000000000000002
60361	K1	286.100000000000023	0.343999999999999972
60361	M4	274.800000000000011	0.23000000000000001
60361	O1	270.100000000000023	0.242999999999999994
60361	M6	262	0.164000000000000007
60361	MK3	348	0.0719999999999999946
60361	S4	357.899999999999977	0.00700000000000000015
60361	MN4	258.100000000000023	0.0820000000000000034
60361	NU2	174.199999999999989	0.157000000000000001
60361	S6	314.699999999999989	0.00300000000000000006
60361	MU2	318	0.153999999999999998
60361	2N2	114.599999999999994	0.0490000000000000019
60361	OO1	37.7000000000000028	0.0259999999999999988
60361	LDA2	197.599999999999994	0.0950000000000000011
60361	S1	240.900000000000006	0.0660000000000000031
60361	M1	43.5	0.0160000000000000003
60361	J1	8.90000000000000036	0.0259999999999999988
60361	MM	27	0.0950000000000000011
60361	SSA	63	0.298999999999999988
60361	SA	119.200000000000003	0.491999999999999993
60361	MSF	17.6999999999999993	0.0889999999999999958
60361	RHO1	227.300000000000011	0.0160000000000000003
60361	Q1	237.900000000000006	0.0330000000000000016
60361	T2	221.300000000000011	0.0330000000000000016
60361	R2	199	0.0129999999999999994
60361	2Q1	139.599999999999994	0.0160000000000000003
60361	P1	276.300000000000011	0.101999999999999993
60361	2SM2	43.6000000000000014	0.0160000000000000003
60361	M3	57.6000000000000014	0.0259999999999999988
60361	L2	201.199999999999989	0.294999999999999984
60361	2MK3	309.5	0.0719999999999999946
60361	K2	238	0.120999999999999996
60361	M8	353.399999999999977	0.0589999999999999969
60361	MS4	320.600000000000023	0.0589999999999999969
60362	M2	219.599999999999994	3.51399999999999979
60362	S2	265	0.422999999999999987
60362	N2	205.199999999999989	0.633000000000000007
60362	K1	299.300000000000011	0.347999999999999976
60362	M4	353.300000000000011	0.456000000000000016
60362	O1	276.199999999999989	0.23899999999999999
60362	M6	31.6999999999999993	0.220000000000000001
60362	MK3	28.6999999999999993	0.115000000000000005
60362	S4	42.2999999999999972	0.00300000000000000006
60362	MN4	334.5	0.179999999999999993
60362	NU2	193.300000000000011	0.203000000000000014
60362	S6	113	0.00300000000000000006
60362	MU2	334.399999999999977	0.216999999999999998
60362	2N2	260.199999999999989	0.0519999999999999976
60362	OO1	288.300000000000011	0.0160000000000000003
60362	LDA2	234.900000000000006	0.107999999999999999
60362	S1	236.699999999999989	0.0850000000000000061
60362	M1	322.899999999999977	0.0200000000000000004
60362	J1	30.8000000000000007	0.0259999999999999988
60362	SSA	91.0999999999999943	0.242999999999999994
60362	SA	139.400000000000006	0.353999999999999981
60362	RHO1	271.899999999999977	0.0259999999999999988
60362	Q1	269.600000000000023	0.0259999999999999988
60362	T2	261.199999999999989	0.0359999999999999973
60362	R2	86.2999999999999972	0.0100000000000000002
60362	2Q1	262.800000000000011	0.0100000000000000002
60362	P1	291.199999999999989	0.135000000000000009
60362	2SM2	93.9000000000000057	0.0129999999999999994
60362	M3	306.300000000000011	0.0389999999999999999
60362	L2	230.599999999999994	0.593999999999999972
60362	2MK3	348.5	0.125
60362	K2	261.199999999999989	0.135000000000000009
60362	M8	162.300000000000011	0.0790000000000000008
60362	MS4	41.7000000000000028	0.117999999999999994
60363	M2	114.099999999999994	2.44099999999999984
60363	S2	148	0.328000000000000014
60363	N2	99.2000000000000028	0.471999999999999975
60363	K1	247.400000000000006	0.312
60363	M4	147.400000000000006	0.197000000000000008
60363	O1	226.199999999999989	0.223000000000000004
60363	M6	60	0.107999999999999999
60363	MK3	237.800000000000011	0.0519999999999999976
60363	S4	133.099999999999994	0.00700000000000000015
60363	MN4	127.099999999999994	0.0889999999999999958
60363	NU2	91.2000000000000028	0.120999999999999996
60363	S6	132	0.00300000000000000006
60363	MU2	228.300000000000011	0.101999999999999993
60363	2N2	122.400000000000006	0.0459999999999999992
60363	OO1	215.5	0.0129999999999999994
60363	LDA2	118.900000000000006	0.0619999999999999996
60363	S1	191.400000000000006	0.0850000000000000061
60363	M1	282.300000000000011	0.0160000000000000003
60363	J1	332	0.0229999999999999996
60363	SSA	31.3000000000000007	0.135000000000000009
60363	SA	144.5	0.440000000000000002
60363	RHO1	239.699999999999989	0.0200000000000000004
60363	Q1	236.5	0.0299999999999999989
60363	T2	155.099999999999994	0.0330000000000000016
60363	R2	258.300000000000011	0.00700000000000000015
60363	2Q1	199.199999999999989	0.0160000000000000003
60363	P1	246.099999999999994	0.112000000000000002
60363	2SM2	322.800000000000011	0.00700000000000000015
60363	M3	174.199999999999989	0.0229999999999999996
60363	L2	127.700000000000003	0.341000000000000025
60363	2MK3	197.5	0.0619999999999999996
60363	K2	149	0.0950000000000000011
60363	M8	68.5999999999999943	0.0200000000000000004
60363	MS4	189.699999999999989	0.0589999999999999969
60364	M2	109	2.53600000000000003
60364	S2	143.199999999999989	0.328000000000000014
60364	N2	93.4000000000000057	0.463000000000000023
60364	K1	244.400000000000006	0.291999999999999982
60364	M4	132.5	0.179999999999999993
60364	O1	224.300000000000011	0.223000000000000004
60364	M6	51.7999999999999972	0.107999999999999999
60364	MK3	218.199999999999989	0.0589999999999999969
60364	MN4	115.299999999999997	0.0790000000000000008
60364	NU2	87.7000000000000028	0.135000000000000009
60364	MU2	221.800000000000011	0.104999999999999996
60364	2N2	76.0999999999999943	0.0519999999999999976
60364	OO1	264.399999999999977	0.0100000000000000002
60364	LDA2	114.700000000000003	0.0719999999999999946
60364	S1	200.800000000000011	0.0719999999999999946
60364	M1	302.600000000000023	0.0160000000000000003
60364	J1	265.100000000000023	0.0129999999999999994
60364	SSA	43.6000000000000014	0.120999999999999996
60364	SA	120.099999999999994	0.315000000000000002
60364	RHO1	215.599999999999994	0.00700000000000000015
60364	Q1	233.400000000000006	0.0359999999999999973
60364	T2	135.699999999999989	0.0299999999999999989
60364	R2	144.599999999999994	0.00300000000000000006
60364	2Q1	204.300000000000011	0.00700000000000000015
60364	P1	240.599999999999994	0.0980000000000000038
60364	M3	184.800000000000011	0.0100000000000000002
60364	L2	120	0.245999999999999996
60364	2MK3	185.900000000000006	0.0619999999999999996
60364	K2	142	0.104999999999999996
60364	M8	38.7999999999999972	0.0229999999999999996
60364	MS4	179.800000000000011	0.0519999999999999976
60365	M2	62.6000000000000014	2.54899999999999993
60365	S2	92.7000000000000028	0.471999999999999975
60365	N2	47.5	0.525000000000000022
60365	K1	219	0.350999999999999979
60365	M4	29.3000000000000007	0.112000000000000002
60365	O1	200.800000000000011	0.284999999999999976
60365	M6	214	0.0459999999999999992
60365	MK3	178.599999999999994	0.0359999999999999973
60365	S4	12.6999999999999993	0.00700000000000000015
60365	MN4	10.4000000000000004	0.0519999999999999976
60365	NU2	41.5	0.107999999999999999
60365	S6	333.699999999999989	0.00300000000000000006
60365	MU2	118.400000000000006	0.0519999999999999976
60365	2N2	30.3000000000000007	0.0690000000000000058
60365	OO1	231.099999999999994	0.0129999999999999994
60365	LDA2	70.0999999999999943	0.0519999999999999976
60365	S1	194.199999999999989	0.0490000000000000019
60365	M1	269.699999999999989	0.00700000000000000015
60365	J1	197.800000000000011	0.0229999999999999996
60365	SSA	41.2999999999999972	0.101999999999999993
60365	SA	140.5	0.171000000000000013
60365	RHO1	253	0.0129999999999999994
60365	Q1	212.900000000000006	0.0389999999999999999
60365	T2	42.8999999999999986	0.0429999999999999966
60365	2Q1	155.800000000000011	0.0160000000000000003
60365	P1	214	0.0619999999999999996
60365	2SM2	345.600000000000023	0.00700000000000000015
60365	M3	146.599999999999994	0.0160000000000000003
60365	L2	71	0.161000000000000004
60365	2MK3	132.199999999999989	0.0389999999999999999
60365	K2	86.7999999999999972	0.147999999999999993
60365	M8	127	0.0100000000000000002
60365	MS4	75.5999999999999943	0.0330000000000000016
60366	M2	36.8999999999999986	2.36900000000000022
60366	S2	61.8999999999999986	0.39700000000000002
60366	N2	20.3999999999999986	0.528000000000000025
60366	K1	203.099999999999994	0.338000000000000023
60366	M4	144	0.0259999999999999988
60366	O1	189.599999999999994	0.276000000000000023
60366	M6	51.3999999999999986	0.0129999999999999994
60366	MK3	153.699999999999989	0.0129999999999999994
60366	S4	287.399999999999977	0.00700000000000000015
60366	MN4	162.699999999999989	0.0129999999999999994
60366	NU2	14.1999999999999993	0.107999999999999999
60366	S6	236	0.00300000000000000006
60366	MU2	54	0.0359999999999999973
60366	2N2	356.100000000000023	0.0619999999999999996
60366	OO1	229.199999999999989	0.00300000000000000006
60366	LDA2	47	0.0389999999999999999
60366	S1	158.800000000000011	0.0229999999999999996
60366	M1	238.400000000000006	0.0259999999999999988
60366	J1	193.599999999999994	0.0259999999999999988
60366	MM	101.5	0.0330000000000000016
60366	SSA	61.2000000000000028	0.216999999999999998
60366	SA	128	0.315000000000000002
60366	MSF	10.0999999999999996	0.131000000000000005
60366	MF	106.400000000000006	0.0259999999999999988
60366	RHO1	67.0999999999999943	0.00700000000000000015
60366	Q1	198.900000000000006	0.0459999999999999992
60366	T2	40.3999999999999986	0.0359999999999999973
60366	R2	299	0.0129999999999999994
60366	2Q1	13	0.0100000000000000002
60366	P1	197.699999999999989	0.112000000000000002
60366	2SM2	11.5999999999999996	0.00300000000000000006
60366	M3	106.200000000000003	0.0160000000000000003
60366	L2	26.3000000000000007	0.120999999999999996
60366	2MK3	101.799999999999997	0.0129999999999999994
60366	K2	61.6000000000000014	0.115000000000000005
60366	M8	228.400000000000006	0.00700000000000000015
60366	MS4	155.400000000000006	0.0160000000000000003
60367	M2	31.1000000000000014	2.02099999999999991
60367	S2	56.7999999999999972	0.353999999999999981
60367	N2	10.5999999999999996	0.440000000000000002
60367	K1	201.699999999999989	0.338000000000000023
60367	M4	186.300000000000011	0.0429999999999999966
60367	O1	188.599999999999994	0.27200000000000002
60367	M6	349.5	0.0200000000000000004
60367	MN4	177.800000000000011	0.0229999999999999996
60367	NU2	11.4000000000000004	0.0919999999999999984
60367	MU2	16.8999999999999986	0.0389999999999999999
60367	2N2	356.600000000000023	0.0519999999999999976
60367	OO1	239.300000000000011	0.0129999999999999994
60367	LDA2	55	0.0299999999999999989
60367	S1	133.099999999999994	0.0259999999999999988
60367	M1	221.400000000000006	0.0129999999999999994
60367	J1	194.699999999999989	0.0229999999999999996
60367	SSA	41.2999999999999972	0.101999999999999993
60367	SA	140.5	0.171000000000000013
60367	RHO1	177.400000000000006	0.0100000000000000002
60367	Q1	182.900000000000006	0.0429999999999999966
60367	T2	30.5	0.0359999999999999973
60367	R2	280.300000000000011	0.0100000000000000002
60367	2Q1	175.5	0.00700000000000000015
60367	P1	199.099999999999994	0.112000000000000002
60367	M3	110	0.0100000000000000002
60367	L2	48	0.0660000000000000031
60367	K2	51.8999999999999986	0.0980000000000000038
60367	MS4	205.900000000000006	0.0129999999999999994
60368	M2	24.1000000000000014	1.22999999999999998
60368	S2	47.5	0.223000000000000004
60368	N2	1.89999999999999991	0.281999999999999973
60368	K1	210.599999999999994	0.233000000000000013
60368	M4	179.699999999999989	0.0719999999999999946
60368	O1	198.900000000000006	0.200000000000000011
60368	M6	248.699999999999989	0.0100000000000000002
60368	MK3	17.1000000000000014	0.0200000000000000004
60368	MN4	165.5	0.0359999999999999973
60368	NU2	4.59999999999999964	0.0519999999999999976
60368	MU2	354.199999999999989	0.0229999999999999996
60368	2N2	349.300000000000011	0.0330000000000000016
60368	OO1	222.199999999999989	0.0100000000000000002
60368	LDA2	35	0.0100000000000000002
60368	S1	122.900000000000006	0.0200000000000000004
60368	M1	204.599999999999994	0.0129999999999999994
60368	J1	216.400000000000006	0.0160000000000000003
60368	MM	243.599999999999994	0.0619999999999999996
60368	SSA	43.6000000000000014	0.104999999999999996
60368	SA	153.5	0.200000000000000011
60368	MF	182.199999999999989	0.0459999999999999992
60368	RHO1	193.800000000000011	0.00700000000000000015
60368	Q1	193.400000000000006	0.0330000000000000016
60368	T2	47.3999999999999986	0.0129999999999999994
60368	R2	47.5	0.00300000000000000006
60368	2Q1	187.099999999999994	0.00700000000000000015
60368	P1	203.900000000000006	0.0749999999999999972
60368	L2	43.8999999999999986	0.0519999999999999976
60368	2MK3	13.0999999999999996	0.0200000000000000004
60368	K2	42.6000000000000014	0.0619999999999999996
60368	MS4	203.300000000000011	0.0229999999999999996
60369	M2	0.900000000000000022	1.64399999999999991
60369	S2	24.6000000000000014	0.318000000000000005
60369	N2	342.100000000000023	0.384000000000000008
60369	K1	194.400000000000006	0.288999999999999979
60369	M4	221.5	0.0229999999999999996
60369	O1	185.300000000000011	0.279000000000000026
60369	M6	311.300000000000011	0.0459999999999999992
60369	S4	211.300000000000011	0.0100000000000000002
60369	MN4	185.199999999999989	0.0160000000000000003
60369	NU2	341.600000000000023	0.0749999999999999972
60369	MU2	339.899999999999977	0.0660000000000000031
60369	2N2	328.600000000000023	0.0490000000000000019
60369	OO1	203.400000000000006	0.0129999999999999994
60369	LDA2	11.8000000000000007	0.0100000000000000002
60369	S1	112.700000000000003	0.0299999999999999989
60369	M1	189.800000000000011	0.0200000000000000004
60369	J1	198.900000000000006	0.0229999999999999996
60369	MM	278.899999999999977	0.0889999999999999958
60369	SSA	51.1000000000000014	0.107999999999999999
60369	SA	155.699999999999989	0.203000000000000014
60369	RHO1	181.300000000000011	0.0100000000000000002
60369	Q1	172	0.0519999999999999976
60369	T2	24.6000000000000014	0.0200000000000000004
60369	R2	24.6999999999999993	0.00300000000000000006
60369	2Q1	176.099999999999994	0.00700000000000000015
60369	P1	192.699999999999989	0.101999999999999993
60369	L2	19.5	0.0459999999999999992
60369	K2	23.3999999999999986	0.0820000000000000034
60370	M2	8.59999999999999964	0.996999999999999997
60370	S2	31.5	0.179999999999999993
60370	N2	348.5	0.23000000000000001
60370	K1	210.5	0.179999999999999993
60370	M4	171.599999999999994	0.0660000000000000031
60370	O1	200	0.171000000000000013
60370	M6	268.199999999999989	0.00700000000000000015
60370	MK3	359.5	0.0200000000000000004
60370	S4	210.900000000000006	0.0100000000000000002
60370	MN4	152.5	0.0299999999999999989
60370	NU2	346	0.0459999999999999992
60370	MU2	342	0.0299999999999999989
60370	2N2	333.399999999999977	0.0330000000000000016
60370	OO1	203.699999999999989	0.00700000000000000015
60370	LDA2	20.3999999999999986	0.0100000000000000002
60370	S1	153.800000000000011	0.0100000000000000002
60370	M1	249.800000000000011	0.00300000000000000006
60370	J1	197.800000000000011	0.0100000000000000002
60370	MM	69.5	0.0889999999999999958
60370	SSA	69.2000000000000028	0.147999999999999993
60370	SA	147.199999999999989	0.288999999999999979
60370	RHO1	181.599999999999994	0.0100000000000000002
60370	Q1	191.300000000000011	0.0259999999999999988
60370	T2	6.90000000000000036	0.0200000000000000004
60370	R2	249.800000000000011	0.0100000000000000002
60370	P1	198.900000000000006	0.0619999999999999996
60370	2SM2	28.3999999999999986	0.00300000000000000006
60370	M3	13	0.00700000000000000015
60370	L2	28.1999999999999993	0.0389999999999999999
60370	2MK3	0.900000000000000022	0.0229999999999999996
60370	K2	30.5	0.0490000000000000019
60370	M8	346.300000000000011	0.00700000000000000015
60370	MS4	187.900000000000006	0.0129999999999999994
60371	M2	141.900000000000006	0.197000000000000008
60371	S2	164.199999999999989	0.0299999999999999989
60371	N2	127.099999999999994	0.0459999999999999992
60371	K1	295.600000000000023	0.0790000000000000008
60371	M4	250.099999999999994	0.0100000000000000002
60371	O1	291.5	0.0589999999999999969
60371	M6	194.099999999999994	0.00700000000000000015
60371	S4	83	0.00300000000000000006
60371	NU2	128.699999999999989	0.0100000000000000002
60371	S6	100.400000000000006	0.00300000000000000006
60371	MU2	330.199999999999989	0.00300000000000000006
60371	2N2	112.5	0.00700000000000000015
60371	OO1	299.899999999999977	0.00300000000000000006
60371	M1	291.399999999999977	0.00300000000000000006
60371	J1	296	0.00300000000000000006
60371	SSA	40.2999999999999972	0.125
60371	SA	155.300000000000011	0.200000000000000011
60371	RHO1	291	0.00300000000000000006
60371	Q1	288.100000000000023	0.0100000000000000002
60371	T2	160.599999999999994	0.00300000000000000006
60371	P1	295.5	0.0259999999999999988
60371	L2	159.699999999999989	0.00700000000000000015
60371	K2	166.800000000000011	0.0100000000000000002
60371	M8	272.699999999999989	0.00300000000000000006
60372	M2	142.300000000000011	0.223000000000000004
60372	S2	171.699999999999989	0.0359999999999999973
60372	N2	131.099999999999994	0.0459999999999999992
60372	K1	298.5	0.0749999999999999972
60372	M4	201	0.0160000000000000003
60372	O1	292	0.0619999999999999996
60372	M6	52.7000000000000028	0.0100000000000000002
60372	S4	35.3999999999999986	0.00300000000000000006
60372	NU2	132.599999999999994	0.0100000000000000002
60372	S6	252.699999999999989	0.00300000000000000006
60372	MU2	322	0.00700000000000000015
60372	2N2	119.799999999999997	0.00700000000000000015
60372	OO1	304.399999999999977	0.00300000000000000006
60372	M1	295.100000000000023	0.00300000000000000006
60372	J1	301.199999999999989	0.00700000000000000015
60372	SSA	40.2999999999999972	0.125
60372	SA	155.300000000000011	0.200000000000000011
60372	RHO1	289.399999999999977	0.00300000000000000006
60372	Q1	289	0.0129999999999999994
60372	T2	170.699999999999989	0.00300000000000000006
60372	P1	298.100000000000023	0.0229999999999999996
60372	L2	153.900000000000006	0.00700000000000000015
60372	K2	174.099999999999994	0.0100000000000000002
60372	M8	73.2000000000000028	0.00300000000000000006
60373	M2	131.099999999999994	0.253000000000000003
60373	S2	163.5	0.0389999999999999999
60373	N2	115	0.0459999999999999992
60373	K1	284.300000000000011	0.0619999999999999996
60373	M4	178.800000000000011	0.0200000000000000004
60373	O1	295.100000000000023	0.0719999999999999946
60373	M6	44	0.0100000000000000002
60373	MK3	82.5999999999999943	0.00300000000000000006
60373	S4	128.900000000000006	0.00300000000000000006
60373	MN4	157.900000000000006	0.00700000000000000015
60373	NU2	126.900000000000006	0.0100000000000000002
60373	MU2	265.100000000000023	0.00700000000000000015
60373	2N2	118.099999999999994	0.0100000000000000002
60373	OO1	192.599999999999994	0.00300000000000000006
60373	LDA2	148.5	0.00700000000000000015
60373	S1	246.5	0.0259999999999999988
60373	M1	341.199999999999989	0.00300000000000000006
60373	J1	269.300000000000011	0.00700000000000000015
60373	RHO1	183.699999999999989	0.00700000000000000015
60373	Q1	302.199999999999989	0.00700000000000000015
60373	T2	151.099999999999994	0.0100000000000000002
60373	R2	45.7999999999999972	0.00700000000000000015
60373	2Q1	280.5	0.0100000000000000002
60373	P1	276.300000000000011	0.0299999999999999989
60373	2SM2	57.2000000000000028	0.00300000000000000006
60373	M3	191.599999999999994	0.00300000000000000006
60373	L2	139.400000000000006	0.0160000000000000003
60373	2MK3	62.5	0.00300000000000000006
60373	K2	149.900000000000006	0.0160000000000000003
60373	M8	93.0999999999999943	0.00300000000000000006
60373	MS4	225.699999999999989	0.00700000000000000015
60374	M2	150.300000000000011	0.902000000000000024
60374	S2	181.199999999999989	0.157000000000000001
60374	N2	144.099999999999994	0.150999999999999995
60374	K1	275.399999999999977	0.16700000000000001
60374	M4	213.300000000000011	0.0330000000000000016
60374	O1	259.199999999999989	0.157000000000000001
60374	M6	201.699999999999989	0.0160000000000000003
60374	S4	100.400000000000006	0.00300000000000000006
60374	NU2	145	0.0299999999999999989
60374	S6	57.8999999999999986	0.00300000000000000006
60374	MU2	327.699999999999989	0.0229999999999999996
60374	2N2	137.900000000000006	0.0200000000000000004
60374	OO1	291.600000000000023	0.00700000000000000015
60374	LDA2	164.599999999999994	0.00700000000000000015
60374	M1	267.300000000000011	0.0100000000000000002
60374	J1	283.5	0.0129999999999999994
60374	RHO1	252.199999999999989	0.00700000000000000015
60374	Q1	251.099999999999994	0.0299999999999999989
60374	T2	180	0.0100000000000000002
60374	2Q1	243	0.00300000000000000006
60374	P1	274.199999999999989	0.0560000000000000012
60374	L2	156.5	0.0259999999999999988
60374	K2	183.699999999999989	0.0429999999999999966
60374	M8	169.800000000000011	0.00300000000000000006
60375	M2	162.400000000000006	0.737999999999999989
60375	S2	191.599999999999994	0.112000000000000002
60375	N2	141.099999999999994	0.150999999999999995
60375	K1	279.899999999999977	0.0980000000000000038
60375	M4	217.400000000000006	0.0389999999999999999
60375	O1	293.399999999999977	0.0919999999999999984
60375	M6	243	0.0160000000000000003
60375	S4	190	0.00300000000000000006
60375	NU2	143.900000000000006	0.0299999999999999989
60375	MU2	341	0.0160000000000000003
60375	2N2	119.900000000000006	0.0200000000000000004
60375	OO1	267.899999999999977	0.00300000000000000006
60375	LDA2	175.900000000000006	0.00700000000000000015
60375	M1	286.899999999999977	0.00700000000000000015
60375	J1	274.199999999999989	0.00700000000000000015
60375	SSA	35.7000000000000028	0.125
60375	SA	133.099999999999994	0.266000000000000014
60375	RHO1	299	0.00300000000000000006
60375	Q1	299.699999999999989	0.0160000000000000003
60375	T2	190.5	0.00700000000000000015
60375	2Q1	305.899999999999977	0.00300000000000000006
60375	P1	280.899999999999977	0.0330000000000000016
60375	L2	183.699999999999989	0.0200000000000000004
60375	K2	194	0.0299999999999999989
60375	M8	332.699999999999989	0.00300000000000000006
60376	M2	263.100000000000023	0.61399999999999999
60376	S2	92.5999999999999943	0.0259999999999999988
60376	N2	232.900000000000006	0.0389999999999999999
60376	K1	3.39999999999999991	0.0919999999999999984
60376	M4	359.800000000000011	0.0660000000000000031
60376	O1	339.399999999999977	0.0690000000000000058
60376	M6	118.099999999999994	0.0359999999999999973
60376	S4	12.8000000000000007	0.00700000000000000015
60376	NU2	236.900000000000006	0.00700000000000000015
60376	S6	212.199999999999989	0.00300000000000000006
60376	MU2	282.800000000000011	0.0160000000000000003
60376	2N2	202.699999999999989	0.00700000000000000015
60376	OO1	27.5	0.00300000000000000006
60376	LDA2	184	0.00300000000000000006
60376	M1	351.5	0.00700000000000000015
60376	J1	15.3000000000000007	0.00700000000000000015
60376	RHO1	329.100000000000023	0.00300000000000000006
60376	Q1	327.399999999999977	0.0129999999999999994
60376	T2	99.4000000000000057	0.00300000000000000006
60376	2Q1	315.5	0.00300000000000000006
60376	P1	1.60000000000000009	0.0299999999999999989
60376	L2	293.300000000000011	0.0160000000000000003
60376	K2	78.7999999999999972	0.00700000000000000015
60376	M8	213.199999999999989	0.00300000000000000006
60377	M2	182.900000000000006	0.85299999999999998
60377	S2	210	0.135000000000000009
60377	N2	159.199999999999989	0.179999999999999993
60377	K1	275.5	0.125
60377	M4	281.600000000000023	0.0560000000000000012
60377	O1	295.800000000000011	0.0950000000000000011
60377	M6	337.399999999999977	0.0100000000000000002
60377	MK3	313.199999999999989	0.0200000000000000004
60377	S4	262.800000000000011	0.00300000000000000006
60377	MN4	253.900000000000006	0.0229999999999999996
60377	NU2	154.5	0.0359999999999999973
60377	MU2	199.400000000000006	0.00700000000000000015
60377	2N2	137.300000000000011	0.0200000000000000004
60377	OO1	298.199999999999989	0.00700000000000000015
60377	LDA2	203.599999999999994	0.0200000000000000004
60377	S1	288.399999999999977	0.0330000000000000016
60377	M1	327.800000000000011	0.00300000000000000006
60377	J1	287.199999999999989	0.00700000000000000015
60377	MM	53.7000000000000028	0.0719999999999999946
60377	SSA	57	0.157000000000000001
60377	SA	130.800000000000011	0.366999999999999993
60377	MF	325	0.0259999999999999988
60377	RHO1	268.5	0.00300000000000000006
60377	Q1	267.800000000000011	0.0200000000000000004
60377	T2	201.400000000000006	0.0100000000000000002
60377	R2	120.5	0.00300000000000000006
60377	2Q1	285	0.00300000000000000006
60377	P1	274.800000000000011	0.0490000000000000019
60377	2SM2	51.2000000000000028	0.00300000000000000006
60377	M3	271.399999999999977	0.00700000000000000015
60377	L2	210.300000000000011	0.0519999999999999976
60377	2MK3	313.600000000000023	0.0200000000000000004
60377	K2	205.400000000000006	0.0389999999999999999
60377	MS4	330.100000000000023	0.0160000000000000003
60378	M2	191.5	1.0169999999999999
60378	S2	221.199999999999989	0.161000000000000004
60378	N2	175.400000000000006	0.216999999999999998
60378	K1	282.199999999999989	0.138000000000000012
60378	M4	303.899999999999977	0.0619999999999999996
60378	O1	298.800000000000011	0.107999999999999999
60378	M6	32.3999999999999986	0.0100000000000000002
60378	MK3	315.399999999999977	0.0229999999999999996
60378	S4	284.5	0.00300000000000000006
60378	MN4	282.100000000000023	0.0229999999999999996
60378	NU2	173.199999999999989	0.0589999999999999969
60378	MU2	235.099999999999994	0.0160000000000000003
60378	2N2	148.699999999999989	0.0330000000000000016
60378	OO1	326.800000000000011	0.0100000000000000002
60378	LDA2	230	0.0200000000000000004
60378	S1	276.699999999999989	0.0259999999999999988
60378	M1	263	0.0129999999999999994
60378	J1	298.100000000000023	0.00700000000000000015
60378	RHO1	251.900000000000006	0.0160000000000000003
60378	Q1	266.800000000000011	0.0299999999999999989
60378	T2	222.800000000000011	0.0100000000000000002
60378	R2	126.799999999999997	0.00300000000000000006
60378	2Q1	6.79999999999999982	0.0200000000000000004
60378	P1	295	0.0459999999999999992
60378	2SM2	16.5	0.00300000000000000006
60378	M3	42.5	0.00700000000000000015
60378	L2	198.900000000000006	0.0359999999999999973
60378	2MK3	315.100000000000023	0.0229999999999999996
60378	K2	213.900000000000006	0.0490000000000000019
60378	MS4	354.300000000000011	0.0160000000000000003
60379	M2	194.099999999999994	0.580999999999999961
60379	S2	209	0.104999999999999996
60379	N2	168.099999999999994	0.128000000000000003
60379	K1	305.100000000000023	0.0980000000000000038
60379	M4	243.599999999999994	0.0160000000000000003
60379	O1	325.100000000000023	0.0749999999999999972
60379	M6	277.5	0.0129999999999999994
60379	MK3	312.699999999999989	0.0100000000000000002
60379	S4	272.800000000000011	0.00300000000000000006
60379	MN4	218.699999999999989	0.0100000000000000002
60379	NU2	172.800000000000011	0.0259999999999999988
60379	S6	256.399999999999977	0.00300000000000000006
60379	MU2	102.099999999999994	0.00300000000000000006
60379	2N2	148.900000000000006	0.0160000000000000003
60379	OO1	320.399999999999977	0.00700000000000000015
60379	LDA2	232.800000000000011	0.0129999999999999994
60379	S1	288.600000000000023	0.0459999999999999992
60379	M1	46.1000000000000014	0.00700000000000000015
60379	J1	9.09999999999999964	0.00300000000000000006
60379	SSA	36.1000000000000014	0.112000000000000002
60379	SA	131.400000000000006	0.284999999999999976
60379	RHO1	43.3999999999999986	0.00700000000000000015
60379	Q1	301.600000000000023	0.0200000000000000004
60379	T2	199.5	0.0229999999999999996
60379	R2	337	0.0200000000000000004
60379	2Q1	300.800000000000011	0.00300000000000000006
60379	P1	291	0.0490000000000000019
60379	2SM2	309.300000000000011	0.00300000000000000006
60379	M3	266.600000000000023	0.00700000000000000015
60379	L2	229.900000000000006	0.0560000000000000012
60379	2MK3	308.699999999999989	0.0100000000000000002
60379	K2	238.300000000000011	0.0259999999999999988
60379	MS4	307.399999999999977	0.00300000000000000006
60380	M2	221.400000000000006	1.51600000000000001
60380	S2	261.199999999999989	0.256000000000000005
60380	N2	204.699999999999989	0.281999999999999973
60380	K1	290.899999999999977	0.173999999999999988
60380	M4	293.5	0.0589999999999999969
60380	O1	320.300000000000011	0.120999999999999996
60380	M6	42.7000000000000028	0.0229999999999999996
60380	S4	55.6000000000000014	0.0100000000000000002
60380	NU2	207	0.0560000000000000012
60380	MU2	181.699999999999989	0.0359999999999999973
60380	2N2	188	0.0359999999999999973
60380	OO1	262.600000000000023	0.00700000000000000015
60380	LDA2	239.800000000000011	0.0100000000000000002
60380	M1	306.100000000000023	0.0100000000000000002
60380	J1	277.399999999999977	0.0100000000000000002
60380	SSA	57	0.157000000000000001
60380	SA	130.800000000000011	0.400000000000000022
60380	RHO1	336.5	0.00300000000000000006
60380	Q1	334.899999999999977	0.0229999999999999996
60380	T2	259.699999999999989	0.0160000000000000003
60380	R2	262.699999999999989	0.00300000000000000006
60380	2Q1	346.399999999999977	0.00300000000000000006
60380	P1	293.100000000000023	0.0589999999999999969
60380	L2	238.199999999999989	0.0429999999999999966
60380	K2	264.5	0.0690000000000000058
60380	M8	19.1000000000000014	0.0129999999999999994
60381	M2	255.699999999999989	0.586999999999999966
60381	S2	289.300000000000011	0.0820000000000000034
60381	N2	237.099999999999994	0.115000000000000005
60381	K1	343.600000000000023	0.117999999999999994
60381	M4	349.100000000000023	0.0330000000000000016
60381	O1	358.399999999999977	0.0980000000000000038
60381	M6	73	0.0129999999999999994
60381	MK3	8.59999999999999964	0.0160000000000000003
60381	S4	21.8999999999999986	0.00300000000000000006
60381	MN4	329.199999999999989	0.0129999999999999994
60381	NU2	226.599999999999994	0.0259999999999999988
60381	MU2	341.399999999999977	0.0229999999999999996
60381	2N2	266	0.0129999999999999994
60381	OO1	57.2999999999999972	0.00300000000000000006
60381	LDA2	248.300000000000011	0.0229999999999999996
60381	S1	313.699999999999989	0.0429999999999999966
60381	M1	75.4000000000000057	0.00300000000000000006
60381	J1	131.400000000000006	0.00700000000000000015
60381	SSA	54.2000000000000028	0.157000000000000001
60381	SA	145.199999999999989	0.338000000000000023
60381	RHO1	271.300000000000011	0.0160000000000000003
60381	Q1	308.899999999999977	0.0229999999999999996
60381	T2	203.099999999999994	0.0129999999999999994
60381	R2	240.800000000000011	0.00700000000000000015
60381	2Q1	36.1000000000000014	0.0100000000000000002
60381	P1	342.100000000000023	0.0490000000000000019
60381	2SM2	200.300000000000011	0.00700000000000000015
60381	M3	82.5999999999999943	0.00700000000000000015
60381	L2	274.699999999999989	0.0490000000000000019
60381	2MK3	4.09999999999999964	0.0160000000000000003
60381	K2	280.800000000000011	0.0299999999999999989
60381	MS4	31.5	0.0100000000000000002
60382	M2	258.100000000000023	0.941999999999999948
60382	S2	284.5	0.0560000000000000012
60382	N2	243.199999999999989	0.161000000000000004
60382	K1	332	0.143999999999999989
60382	M4	354.300000000000011	0.0850000000000000061
60382	O1	330.100000000000023	0.0889999999999999958
60382	M6	99.5	0.0459999999999999992
60382	S4	336.800000000000011	0.00700000000000000015
60382	NU2	245.199999999999989	0.0330000000000000016
60382	S6	216.800000000000011	0.00300000000000000006
60382	MU2	80	0.0229999999999999996
60382	2N2	228.400000000000006	0.0229999999999999996
60382	OO1	333.899999999999977	0.00300000000000000006
60382	LDA2	270.300000000000011	0.00700000000000000015
60382	M1	331.100000000000023	0.00700000000000000015
60382	J1	333	0.00700000000000000015
60382	RHO1	329.300000000000011	0.00300000000000000006
60382	Q1	329.199999999999989	0.0160000000000000003
60382	T2	283.5	0.00300000000000000006
60382	2Q1	328.300000000000011	0.00300000000000000006
60382	P1	331.899999999999977	0.0490000000000000019
60382	L2	272.899999999999977	0.0259999999999999988
60382	K2	286.699999999999989	0.0160000000000000003
60382	M8	179.199999999999989	0.00700000000000000015
60383	M2	263.199999999999989	0.78400000000000003
60383	S2	285.600000000000023	0.117999999999999994
60383	N2	240.599999999999994	0.153999999999999998
60383	K1	340.399999999999977	0.164000000000000007
60383	M4	90.5	0.0359999999999999973
60383	O1	355.899999999999977	0.128000000000000003
60383	MK3	82	0.0160000000000000003
60383	MN4	58.1000000000000014	0.0129999999999999994
60383	NU2	245.099999999999994	0.0359999999999999973
60383	2N2	222.800000000000011	0.0160000000000000003
60383	OO1	324.800000000000011	0.00700000000000000015
60383	LDA2	287	0.0200000000000000004
60383	S1	305.800000000000011	0.0619999999999999996
60383	M1	348	0.0100000000000000002
60383	J1	337.199999999999989	0.0100000000000000002
60383	SSA	40.2000000000000028	0.107999999999999999
60383	SA	133.400000000000006	0.281999999999999973
60383	RHO1	2.39999999999999991	0.00700000000000000015
60383	Q1	329.600000000000023	0.0229999999999999996
60383	T2	269.300000000000011	0.0129999999999999994
60383	2Q1	11.1999999999999993	0.00300000000000000006
60383	P1	336.300000000000011	0.0660000000000000031
60383	L2	289.699999999999989	0.0619999999999999996
60383	2MK3	79.5999999999999943	0.0160000000000000003
60383	K2	283.800000000000011	0.0389999999999999999
60383	MS4	129.699999999999989	0.0100000000000000002
60384	M2	262.100000000000023	0.512000000000000011
60384	S2	293	0.0790000000000000008
60384	N2	237.099999999999994	0.101999999999999993
60384	K1	344.5	0.173999999999999988
60384	M4	65.2000000000000028	0.0129999999999999994
60384	O1	355	0.135000000000000009
60384	M6	88.2999999999999972	0.00700000000000000015
60384	MK3	88.0999999999999943	0.0100000000000000002
60384	MN4	31	0.00700000000000000015
60384	NU2	244.800000000000011	0.0229999999999999996
60384	MU2	330.300000000000011	0.00300000000000000006
60384	2N2	190.900000000000006	0.0129999999999999994
60384	OO1	338.600000000000023	0.00700000000000000015
60384	LDA2	285	0.0129999999999999994
60384	S1	301.600000000000023	0.0560000000000000012
60384	M1	29	0.00700000000000000015
60384	J1	319	0.00700000000000000015
60384	MM	52	0.0330000000000000016
60384	SSA	62.2000000000000028	0.120999999999999996
60384	SA	134.199999999999989	0.370999999999999996
60384	MSF	241.099999999999994	0.0200000000000000004
60384	MF	335.800000000000011	0.0299999999999999989
60384	RHO1	348.300000000000011	0.0129999999999999994
60384	Q1	334.300000000000011	0.0299999999999999989
60384	T2	271	0.00700000000000000015
60384	R2	105.400000000000006	0.00700000000000000015
60384	2Q1	325.100000000000023	0.0100000000000000002
60384	P1	330	0.0589999999999999969
60384	2SM2	240.900000000000006	0.00300000000000000006
60384	M3	46.6000000000000014	0.00300000000000000006
60384	L2	289.600000000000023	0.0330000000000000016
60384	2MK3	75.7999999999999972	0.0100000000000000002
60384	K2	288.100000000000023	0.0200000000000000004
60384	MS4	120.299999999999997	0.00300000000000000006
60385	M2	272	0.701999999999999957
60385	S2	302.100000000000023	0.107999999999999999
60385	N2	248.5	0.147999999999999993
60385	K1	343.699999999999989	0.235999999999999988
60385	M4	108.400000000000006	0.0490000000000000019
60385	O1	6.29999999999999982	0.140999999999999986
60385	M6	226.5	0.0100000000000000002
60385	S4	304.5	0.00300000000000000006
60385	NU2	251.699999999999989	0.0299999999999999989
60385	S6	299.800000000000011	0.00300000000000000006
60385	MU2	241.800000000000011	0.0160000000000000003
60385	2N2	225.099999999999994	0.0200000000000000004
60385	OO1	321.199999999999989	0.00700000000000000015
60385	LDA2	285.899999999999977	0.00300000000000000006
60385	M1	354.899999999999977	0.0100000000000000002
60385	J1	332.5	0.0100000000000000002
60385	SSA	44.5	0.117999999999999994
60385	SA	128.400000000000006	0.338000000000000023
60385	RHO1	16	0.00700000000000000015
60385	Q1	17.5	0.0259999999999999988
60385	T2	300.899999999999977	0.00700000000000000015
60385	2Q1	28.6999999999999993	0.00300000000000000006
60385	P1	345.399999999999977	0.0790000000000000008
60385	L2	295.399999999999977	0.0200000000000000004
60385	K2	304.5	0.0299999999999999989
60386	M2	267.600000000000023	0.509000000000000008
60386	S2	297.399999999999977	0.0719999999999999946
60386	N2	245.800000000000011	0.0980000000000000038
60386	K1	346	0.164000000000000007
60386	M4	51.5	0.0129999999999999994
60386	O1	358.399999999999977	0.140999999999999986
60386	M6	105.5	0.00300000000000000006
60386	MK3	89.4000000000000057	0.00700000000000000015
60386	S4	56.2999999999999972	0.00300000000000000006
60386	MN4	28.1999999999999993	0.00700000000000000015
60386	NU2	252.099999999999994	0.0259999999999999988
60386	MU2	344.300000000000011	0.00300000000000000006
60386	2N2	226.800000000000011	0.0100000000000000002
60386	LDA2	308.399999999999977	0.0129999999999999994
60386	S1	292.800000000000011	0.0519999999999999976
60386	M1	77.2999999999999972	0.00300000000000000006
60386	J1	289.199999999999989	0.00700000000000000015
60386	MM	334.899999999999977	0.0359999999999999973
60386	SSA	0.299999999999999989	0.0790000000000000008
60386	SA	129.300000000000011	0.223000000000000004
60386	MSF	257.300000000000011	0.0619999999999999996
60386	MF	179.900000000000006	0.0200000000000000004
60386	RHO1	334.399999999999977	0.00300000000000000006
60386	Q1	340.199999999999989	0.0200000000000000004
60386	T2	253.199999999999989	0.00700000000000000015
60386	2Q1	271.5	0.00300000000000000006
60386	P1	334	0.0619999999999999996
60386	2SM2	245.599999999999994	0.00300000000000000006
60386	M3	115.599999999999994	0.00300000000000000006
60386	L2	297.800000000000011	0.0330000000000000016
60386	2MK3	95.5	0.00700000000000000015
60386	K2	292.100000000000023	0.0259999999999999988
60386	MS4	116.5	0.00300000000000000006
60387	M2	13.9000000000000004	1.03000000000000003
60387	S2	110	0.0919999999999999984
60387	N2	358.100000000000023	0.125
60387	K1	40.7999999999999972	0.203000000000000014
60387	M4	231.699999999999989	0.101999999999999993
60387	O1	44.2999999999999972	0.164000000000000007
60387	M6	85.9000000000000057	0.0490000000000000019
60387	S4	309.899999999999977	0.00300000000000000006
60387	NU2	0.200000000000000011	0.0229999999999999996
60387	MU2	125.900000000000006	0.0259999999999999988
60387	2N2	342.300000000000011	0.0160000000000000003
60387	OO1	37.2999999999999972	0.00700000000000000015
60387	LDA2	58.5	0.00700000000000000015
60387	M1	42.6000000000000014	0.0129999999999999994
60387	J1	39	0.0129999999999999994
60387	RHO1	45.8999999999999986	0.00700000000000000015
60387	Q1	46.1000000000000014	0.0330000000000000016
60387	T2	106.099999999999994	0.00700000000000000015
60387	2Q1	47.7999999999999972	0.00300000000000000006
60387	P1	41.1000000000000014	0.0660000000000000031
60387	L2	29.6999999999999993	0.0299999999999999989
60387	K2	117.700000000000003	0.0259999999999999988
60387	M8	282.899999999999977	0.00300000000000000006
60388	M2	292.5	0.459000000000000019
60388	S2	323.699999999999989	0.0719999999999999946
60388	N2	269.399999999999977	0.0950000000000000011
60388	K1	352.300000000000011	0.187
60388	M4	33.6000000000000014	0.0129999999999999994
60388	O1	356.199999999999989	0.150999999999999995
60388	M6	127.5	0.00700000000000000015
60388	MK3	121.299999999999997	0.0100000000000000002
60388	NU2	269.699999999999989	0.0229999999999999996
60388	2N2	249.300000000000011	0.0129999999999999994
60388	LDA2	311.199999999999989	0.00700000000000000015
60388	S1	288.899999999999977	0.0589999999999999969
60388	SSA	54	0.107999999999999999
60388	SA	130.599999999999994	0.353999999999999981
60388	P1	344.699999999999989	0.0589999999999999969
60388	L2	322.800000000000011	0.0299999999999999989
60388	2MK3	112.200000000000003	0.0100000000000000002
60388	K2	318.399999999999977	0.0229999999999999996
60389	M2	322.699999999999989	0.541000000000000036
60389	S2	355.300000000000011	0.0749999999999999972
60389	N2	298.100000000000023	0.112000000000000002
60389	K1	1.60000000000000009	0.209999999999999992
60389	M4	250.300000000000011	0.00300000000000000006
60389	O1	11.0999999999999996	0.173999999999999988
60389	M6	165.099999999999994	0.00300000000000000006
60389	MK3	167.800000000000011	0.0129999999999999994
60389	MN4	199.599999999999994	0.00300000000000000006
60389	NU2	303.5	0.0259999999999999988
60389	S6	8.69999999999999929	0.00300000000000000006
60389	MU2	352.899999999999977	0.00300000000000000006
60389	2N2	274.300000000000011	0.0100000000000000002
60389	OO1	150.099999999999994	0.00300000000000000006
60389	LDA2	2	0.0129999999999999994
60389	S1	301	0.0619999999999999996
60389	M1	208.699999999999989	0.00300000000000000006
60389	J1	318.5	0.0100000000000000002
60389	SSA	44.5	0.117999999999999994
60389	SA	128.400000000000006	0.338000000000000023
60389	RHO1	351.800000000000011	0.0100000000000000002
60389	Q1	331.600000000000023	0.0229999999999999996
60389	T2	355.800000000000011	0.00700000000000000015
60389	R2	121.799999999999997	0.00300000000000000006
60389	2Q1	161.300000000000011	0.00700000000000000015
60389	P1	346.600000000000023	0.0619999999999999996
60389	2SM2	295.899999999999977	0.00300000000000000006
60389	M3	177	0.00300000000000000006
60389	L2	342.399999999999977	0.0299999999999999989
60389	2MK3	150.400000000000006	0.0129999999999999994
60389	K2	353.800000000000011	0.0229999999999999996
60389	MS4	317.899999999999977	0.00300000000000000006
60390	M2	8.30000000000000071	1.03699999999999992
60390	S2	51.8999999999999986	0.140999999999999986
60390	N2	349.800000000000011	0.203000000000000014
60390	K1	19.3999999999999986	0.248999999999999999
60390	M4	159.400000000000006	0.00700000000000000015
60390	O1	33.8999999999999986	0.194000000000000006
60390	M6	67.7999999999999972	0.0229999999999999996
60390	MK3	238.400000000000006	0.0330000000000000016
60390	MN4	254.800000000000011	0.00300000000000000006
60390	NU2	321.199999999999989	0.0519999999999999976
60390	MU2	87	0.0330000000000000016
60390	2N2	15.9000000000000004	0.0359999999999999973
60390	OO1	62.7000000000000028	0.0129999999999999994
60390	LDA2	4.29999999999999982	0.0299999999999999989
60390	S1	318.5	0.0719999999999999946
60390	M1	116.099999999999994	0.0100000000000000002
60390	J1	106.200000000000003	0.0160000000000000003
60390	SSA	62.2999999999999972	0.115000000000000005
60390	SA	143.5	0.36399999999999999
60390	RHO1	306.800000000000011	0.0129999999999999994
60390	Q1	342.800000000000011	0.0200000000000000004
60390	T2	11.4000000000000004	0.00300000000000000006
60390	R2	60.8999999999999986	0.0100000000000000002
60390	2Q1	29.5	0.0160000000000000003
60390	P1	9.09999999999999964	0.0919999999999999984
60390	2SM2	247.699999999999989	0.00300000000000000006
60390	M3	308	0.0100000000000000002
60390	L2	25.6999999999999993	0.0850000000000000061
60390	2MK3	222.699999999999989	0.0359999999999999973
60390	K2	45.5	0.0490000000000000019
60390	M8	153	0.00300000000000000006
60390	MS4	46.3999999999999986	0.00300000000000000006
60391	M2	346.600000000000023	0.570999999999999952
60391	S2	8	0.0790000000000000008
60391	N2	324.100000000000023	0.120999999999999996
60391	K1	3.29999999999999982	0.226000000000000006
60391	M4	215.099999999999994	0.0129999999999999994
60391	O1	14	0.190000000000000002
60391	MK3	173.5	0.0129999999999999994
60391	NU2	323.699999999999989	0.0200000000000000004
60391	2N2	296.699999999999989	0.0129999999999999994
60391	OO1	352.5	0.0100000000000000002
60391	LDA2	21.3999999999999986	0.0200000000000000004
60391	S1	283.100000000000023	0.0749999999999999972
60391	M1	8.59999999999999964	0.0129999999999999994
60391	J1	332.600000000000023	0.0160000000000000003
60391	SSA	47.8999999999999986	0.173999999999999988
60391	SA	138.300000000000011	0.412999999999999978
60391	RHO1	18.6000000000000014	0.00700000000000000015
60391	Q1	346.5	0.0429999999999999966
60391	T2	7	0.00300000000000000006
60391	2Q1	298.699999999999989	0.0200000000000000004
60391	P1	352.399999999999977	0.0749999999999999972
60391	L2	31.1999999999999993	0.0259999999999999988
60391	K2	5.5	0.0330000000000000016
60392	M2	47.5	0.731999999999999984
60392	S2	92.5999999999999943	0.0980000000000000038
60392	N2	16.8999999999999986	0.131000000000000005
60392	K1	19.1999999999999993	0.256000000000000005
60392	M4	263.399999999999977	0.00700000000000000015
60392	O1	20.8999999999999986	0.173999999999999988
60392	M6	163.699999999999989	0.00300000000000000006
60392	MK3	320.699999999999989	0.0160000000000000003
60392	S4	159.699999999999989	0.00300000000000000006
60392	MN4	244.900000000000006	0.00300000000000000006
60392	NU2	27.3999999999999986	0.0299999999999999989
60392	MU2	149.099999999999994	0.0129999999999999994
60392	2N2	343	0.0129999999999999994
60392	OO1	344.100000000000023	0.00700000000000000015
60392	LDA2	86.7999999999999972	0.0200000000000000004
60392	S1	277.300000000000011	0.0619999999999999996
60392	M1	225.699999999999989	0.0129999999999999994
60392	J1	251.300000000000011	0.0100000000000000002
60392	RHO1	324.699999999999989	0.0200000000000000004
60392	Q1	17.1999999999999993	0.0229999999999999996
60392	T2	104.700000000000003	0.0330000000000000016
60392	R2	170.800000000000011	0.00700000000000000015
60392	2Q1	85.7999999999999972	0.0200000000000000004
60392	P1	1.39999999999999991	0.0660000000000000031
60392	2SM2	147.900000000000006	0.00300000000000000006
60392	L2	87.2000000000000028	0.0589999999999999969
60392	2MK3	301.699999999999989	0.0200000000000000004
60392	K2	108.799999999999997	0.0299999999999999989
60392	MS4	333.699999999999989	0.00300000000000000006
60393	M2	70.5999999999999943	0.983999999999999986
60393	S2	112.900000000000006	0.143999999999999989
60393	N2	43.1000000000000014	0.179999999999999993
60393	K1	21.1000000000000014	0.200000000000000011
60393	M4	120.5	0.0359999999999999973
60393	O1	37.7999999999999972	0.153999999999999998
60393	M6	196.800000000000011	0.0129999999999999994
60393	MK3	299.300000000000011	0.0229999999999999996
60393	S4	224.900000000000006	0.00700000000000000015
60393	MN4	98.5999999999999943	0.0129999999999999994
60393	NU2	40.1000000000000014	0.0490000000000000019
60393	MU2	210.300000000000011	0.0229999999999999996
60393	2N2	34.7999999999999972	0.0160000000000000003
60393	OO1	35.1000000000000014	0.0160000000000000003
60393	LDA2	114.299999999999997	0.0229999999999999996
60393	S1	317.899999999999977	0.0490000000000000019
60393	M1	112.700000000000003	0.0100000000000000002
60393	J1	261.199999999999989	0.0100000000000000002
60393	SSA	53.2000000000000028	0.104999999999999996
60393	SA	127.900000000000006	0.353999999999999981
60393	RHO1	10.1999999999999993	0.0259999999999999988
60393	Q1	22.5	0.0200000000000000004
60393	T2	99.0999999999999943	0.0259999999999999988
60393	R2	320	0.0129999999999999994
60393	2Q1	185	0.0129999999999999994
60393	P1	12.4000000000000004	0.0790000000000000008
60393	2SM2	11.8000000000000007	0.0100000000000000002
60393	M3	205.400000000000006	0.0129999999999999994
60393	L2	84.0999999999999943	0.120999999999999996
60393	2MK3	296.300000000000011	0.0259999999999999988
60393	K2	99.5	0.0490000000000000019
60393	MS4	154.099999999999994	0.0129999999999999994
60394	M2	94	1.42399999999999993
60394	S2	131.5	0.194000000000000006
60394	N2	76.2000000000000028	0.245999999999999996
60394	K1	344.199999999999989	0.104999999999999996
60394	M4	138.699999999999989	0.0850000000000000061
60394	O1	2.5	0.0459999999999999992
60394	M6	101.299999999999997	0.0299999999999999989
60394	MK3	281	0.0299999999999999989
60394	S4	201.599999999999994	0.00700000000000000015
60394	MN4	121	0.0359999999999999973
60394	NU2	68.0999999999999943	0.0690000000000000058
60394	S6	203.699999999999989	0.00300000000000000006
60394	MU2	196.300000000000011	0.0519999999999999976
60394	2N2	7.40000000000000036	0.0429999999999999966
60394	OO1	52.6000000000000014	0.0100000000000000002
60394	LDA2	101.200000000000003	0.0519999999999999976
60394	S1	240.199999999999989	0.0330000000000000016
60394	M1	313.300000000000011	0.00700000000000000015
60394	J1	330.899999999999977	0.0160000000000000003
60394	SSA	53.2000000000000028	0.104999999999999996
60394	SA	127.900000000000006	0.353999999999999981
60394	RHO1	339.5	0.0259999999999999988
60394	Q1	341.100000000000023	0.0299999999999999989
60394	T2	105.5	0.0359999999999999973
60394	R2	96.0999999999999943	0.00700000000000000015
60394	2Q1	336.399999999999977	0.0100000000000000002
60394	P1	331	0.0330000000000000016
60394	2SM2	27.3000000000000007	0.00300000000000000006
60394	M3	195.800000000000011	0.00700000000000000015
60394	L2	90.7000000000000028	0.0980000000000000038
60394	2MK3	256.5	0.0229999999999999996
60394	K2	131	0.0589999999999999969
60394	M8	90.9000000000000057	0.0100000000000000002
60394	MS4	176.099999999999994	0.0259999999999999988
60395	M2	71.9000000000000057	0.925000000000000044
60395	S2	112.799999999999997	0.157000000000000001
60395	N2	44.5	0.171000000000000013
60395	K1	27.6999999999999993	0.276000000000000023
60395	M4	43.2999999999999972	0.0560000000000000012
60395	O1	32.2000000000000028	0.194000000000000006
60395	MK3	348.5	0.0389999999999999999
60395	MN4	16.6999999999999993	0.0229999999999999996
60395	NU2	45.7999999999999972	0.0359999999999999973
60395	MU2	212.300000000000011	0.0259999999999999988
60395	2N2	17.1999999999999993	0.0229999999999999996
60395	OO1	23.1000000000000014	0.00700000000000000015
60395	LDA2	91.7999999999999972	0.0359999999999999973
60395	S1	141.699999999999989	0.0259999999999999988
60395	M1	29.8000000000000007	0.0129999999999999994
60395	J1	25.5	0.0160000000000000003
60395	SSA	53.8999999999999986	0.115000000000000005
60395	SA	104.799999999999997	0.253000000000000003
60395	RHO1	34	0.00700000000000000015
60395	Q1	7.79999999999999982	0.0429999999999999966
60395	T2	81.7999999999999972	0.0330000000000000016
60395	2Q1	36.6000000000000014	0.00700000000000000015
60395	P1	19.5	0.0619999999999999996
60395	2SM2	79.2000000000000028	0.0100000000000000002
60395	L2	106.900000000000006	0.0690000000000000058
60395	2MK3	341.600000000000023	0.0429999999999999966
60395	K2	107.700000000000003	0.0330000000000000016
60395	MS4	72.5	0.0160000000000000003
60396	M2	27.8000000000000007	0.576999999999999957
60396	S2	59.7000000000000028	0.0690000000000000058
60396	N2	354.800000000000011	0.115000000000000005
60396	K1	9.09999999999999964	0.350999999999999979
60396	M4	254.800000000000011	0.0359999999999999973
60396	O1	30.5	0.140999999999999986
60396	M6	112	0.0160000000000000003
60396	S4	351.699999999999989	0.00300000000000000006
60396	NU2	359.199999999999989	0.0229999999999999996
60396	S6	33.2999999999999972	0.00300000000000000006
60396	MU2	203.599999999999994	0.0129999999999999994
60396	2N2	321.5	0.0129999999999999994
60396	OO1	346.100000000000023	0.00700000000000000015
60396	LDA2	42.6000000000000014	0.00300000000000000006
60396	M1	19.3000000000000007	0.0100000000000000002
60396	J1	357.199999999999989	0.0100000000000000002
60396	RHO1	40	0.00700000000000000015
60396	Q1	41.5	0.0259999999999999988
60396	T2	58.3999999999999986	0.00300000000000000006
60396	2Q1	52.7000000000000028	0.00300000000000000006
60396	P1	10.6999999999999993	0.117999999999999994
60396	L2	60.5	0.0160000000000000003
60396	K2	62.2000000000000028	0.0200000000000000004
60397	M2	337	0.52200000000000002
60397	S2	8.09999999999999964	0.0749999999999999972
60397	N2	314.199999999999989	0.112000000000000002
60397	K1	8	0.226000000000000006
60397	M4	246	0.0259999999999999988
60397	O1	15	0.183999999999999997
60397	MK3	176.699999999999989	0.0160000000000000003
60397	MN4	215.5	0.0100000000000000002
60397	NU2	316.699999999999989	0.0229999999999999996
60397	2N2	288	0.0129999999999999994
60397	OO1	94.9000000000000057	0.0160000000000000003
60397	LDA2	7.40000000000000036	0.0129999999999999994
60397	S1	292.899999999999977	0.0690000000000000058
60397	M1	11.4000000000000004	0.0129999999999999994
60397	J1	319.199999999999989	0.0100000000000000002
60397	SSA	53.2000000000000028	0.104999999999999996
60397	SA	127.900000000000006	0.353999999999999981
60397	RHO1	17.8999999999999986	0.00700000000000000015
60397	Q1	342.199999999999989	0.0389999999999999999
60397	T2	6.79999999999999982	0.00300000000000000006
60397	2Q1	21.8000000000000007	0.00700000000000000015
60397	P1	1.30000000000000004	0.0719999999999999946
60397	L2	355.699999999999989	0.0229999999999999996
60397	2MK3	170.099999999999994	0.0160000000000000003
60397	K2	6.29999999999999982	0.0299999999999999989
60398	M2	336.5	0.509000000000000008
60398	S2	7.5	0.0749999999999999972
60398	N2	315.300000000000011	0.115000000000000005
60398	K1	6.90000000000000036	0.216999999999999998
60398	M4	247.199999999999989	0.0330000000000000016
60398	O1	16.3999999999999986	0.183999999999999997
60398	M6	7.20000000000000018	0.0100000000000000002
60398	MK3	179.300000000000011	0.0160000000000000003
60398	S4	160.800000000000011	0.00300000000000000006
60398	MN4	215.5	0.0129999999999999994
60398	NU2	327.199999999999989	0.0229999999999999996
60398	MU2	325.800000000000011	0.0129999999999999994
60398	2N2	268.800000000000011	0.0200000000000000004
60398	OO1	28.1000000000000014	0.0160000000000000003
60398	LDA2	23.6000000000000014	0.0129999999999999994
60398	S1	283.600000000000023	0.0589999999999999969
60398	M1	294.600000000000023	0.0100000000000000002
60398	J1	343.699999999999989	0.0129999999999999994
60398	SSA	53.2000000000000028	0.104999999999999996
60398	SA	127.900000000000006	0.353999999999999981
60398	RHO1	338.5	0.0229999999999999996
60398	Q1	345.199999999999989	0.0519999999999999976
60398	T2	283.899999999999977	0.00300000000000000006
60398	R2	60.3999999999999986	0.00700000000000000015
60398	2Q1	68	0.0200000000000000004
60398	P1	0.299999999999999989	0.0589999999999999969
60398	2SM2	357.899999999999977	0.00300000000000000006
60398	M3	29.1999999999999993	0.00700000000000000015
60398	L2	330.199999999999989	0.0129999999999999994
60398	2MK3	159.400000000000006	0.0129999999999999994
60398	K2	353.5	0.0229999999999999996
60398	M8	245.900000000000006	0.00300000000000000006
60398	MS4	275.600000000000023	0.00700000000000000015
60399	M2	291.600000000000023	0.456000000000000016
60399	S2	319.5	0.0719999999999999946
60399	N2	270.5	0.0950000000000000011
60399	K1	356.699999999999989	0.194000000000000006
60399	M4	58.2999999999999972	0.0129999999999999994
60399	O1	6	0.157000000000000001
60399	M6	159.599999999999994	0.0100000000000000002
60399	NU2	268.5	0.0200000000000000004
60399	2N2	246.699999999999989	0.0129999999999999994
60399	OO1	347.300000000000011	0.00700000000000000015
60399	LDA2	318	0.0100000000000000002
60399	S1	290.5	0.0660000000000000031
60399	M1	1.19999999999999996	0.0100000000000000002
60399	J1	340.899999999999977	0.0100000000000000002
60399	SSA	44.5	0.117999999999999994
60399	SA	128.400000000000006	0.338000000000000023
60399	RHO1	29	0.0129999999999999994
60399	Q1	331.600000000000023	0.0259999999999999988
60399	T2	318.300000000000011	0.00300000000000000006
60399	2Q1	15.0999999999999996	0.00300000000000000006
60399	P1	348.800000000000011	0.0660000000000000031
60399	L2	308.100000000000023	0.0330000000000000016
60399	K2	317.899999999999977	0.0200000000000000004
60400	M2	223.599999999999994	0.468999999999999972
60400	S2	250.300000000000011	0.0660000000000000031
60400	N2	194.900000000000006	0.0889999999999999958
60400	K1	339.300000000000011	0.107999999999999999
60400	M4	286.399999999999977	0.00700000000000000015
60400	O1	351.399999999999977	0.0980000000000000038
60400	M6	336.600000000000023	0.00700000000000000015
60400	MK3	0.400000000000000022	0.00700000000000000015
60400	NU2	202.900000000000006	0.0200000000000000004
60400	MU2	18.3000000000000007	0.00300000000000000006
60400	2N2	169.599999999999994	0.0100000000000000002
60400	LDA2	258.399999999999977	0.00700000000000000015
60400	S1	303.5	0.0359999999999999973
60400	M1	265	0.00700000000000000015
60400	J1	310.800000000000011	0.00700000000000000015
60400	SSA	36.1000000000000014	0.112000000000000002
60400	SA	131.400000000000006	0.284999999999999976
60400	RHO1	305.300000000000011	0.0100000000000000002
60400	Q1	305.300000000000011	0.0160000000000000003
60400	T2	251.5	0.0100000000000000002
60400	2Q1	158.099999999999994	0.00300000000000000006
60400	P1	325.399999999999977	0.0429999999999999966
60400	L2	255.699999999999989	0.0359999999999999973
60400	2MK3	345.5	0.00700000000000000015
60400	K2	257.600000000000023	0.0229999999999999996
60401	M2	207.599999999999994	0.456000000000000016
60401	S2	231.300000000000011	0.0749999999999999972
60401	N2	177.300000000000011	0.101999999999999993
60401	K1	350.699999999999989	0.0660000000000000031
60401	M4	257.199999999999989	0.0129999999999999994
60401	O1	338.899999999999977	0.0589999999999999969
60401	M6	316.5	0.0100000000000000002
60401	NU2	181.400000000000006	0.0200000000000000004
60401	S6	170	0.00300000000000000006
60401	MU2	31.1000000000000014	0.0100000000000000002
60401	2N2	147	0.0129999999999999994
60401	OO1	2.39999999999999991	0.00300000000000000006
60401	LDA2	218.599999999999994	0.00300000000000000006
60401	M1	344.800000000000011	0.00300000000000000006
60401	J1	356.5	0.00300000000000000006
60401	SSA	36.1000000000000014	0.112000000000000002
60401	SA	131.400000000000006	0.284999999999999976
60401	RHO1	333.800000000000011	0.00300000000000000006
60401	Q1	333	0.0129999999999999994
60401	T2	230.300000000000011	0.00300000000000000006
60401	2Q1	327.199999999999989	0.00300000000000000006
60401	P1	349.800000000000011	0.0229999999999999996
60401	L2	237.800000000000011	0.0129999999999999994
60401	K2	233.199999999999989	0.0200000000000000004
60402	M2	198.800000000000011	0.561000000000000054
60402	S2	225.900000000000006	0.0850000000000000061
60402	N2	172.300000000000011	0.117999999999999994
60402	K1	315.600000000000023	0.0889999999999999958
60402	M4	276.5	0.0160000000000000003
60402	O1	332.399999999999977	0.0749999999999999972
60402	M6	301.199999999999989	0.0100000000000000002
60402	MK3	331.800000000000011	0.0100000000000000002
60402	NU2	177.800000000000011	0.0259999999999999988
60402	2N2	149.599999999999994	0.0129999999999999994
60402	OO1	298.800000000000011	0.00300000000000000006
60402	LDA2	229.300000000000011	0.0129999999999999994
60402	S1	290.5	0.0459999999999999992
60402	M1	324	0.00700000000000000015
60402	J1	307.300000000000011	0.00700000000000000015
60402	SSA	36.1000000000000014	0.112000000000000002
60402	SA	131.400000000000006	0.284999999999999976
60402	RHO1	339.600000000000023	0.00300000000000000006
60402	Q1	306.699999999999989	0.0200000000000000004
60402	T2	224.699999999999989	0.00700000000000000015
60402	2Q1	349.100000000000023	0.00300000000000000006
60402	P1	318.899999999999977	0.0389999999999999999
60402	L2	233.800000000000011	0.0389999999999999999
60402	2MK3	324.800000000000011	0.0100000000000000002
60402	K2	223.5	0.0259999999999999988
60403	M2	252	0.855999999999999983
60403	S2	289	0.104999999999999996
60403	N2	228.900000000000006	0.104999999999999996
60403	K1	321.199999999999989	0.112000000000000002
60403	M4	12.6999999999999993	0.0459999999999999992
60403	O1	3.29999999999999982	0.0719999999999999946
60403	M6	120.900000000000006	0.0259999999999999988
60403	S4	90.4000000000000057	0.00300000000000000006
60403	NU2	232	0.0200000000000000004
60403	MU2	61.5	0.0200000000000000004
60403	2N2	205.900000000000006	0.0129999999999999994
60403	OO1	279.199999999999989	0.00300000000000000006
60403	LDA2	269.199999999999989	0.00700000000000000015
60403	M1	342.100000000000023	0.00700000000000000015
60403	J1	300.399999999999977	0.00700000000000000015
60403	RHO1	21.3000000000000007	0.00300000000000000006
60403	Q1	24.1000000000000014	0.0129999999999999994
60403	T2	287.600000000000023	0.00700000000000000015
60403	2Q1	45	0.00300000000000000006
60403	P1	324.399999999999977	0.0359999999999999973
60403	L2	275	0.0229999999999999996
60403	K2	292	0.0299999999999999989
60403	M8	313.899999999999977	0.00300000000000000006
60404	M2	30.6999999999999993	1.33899999999999997
60404	S2	81.5	0.161000000000000004
60404	N2	9.90000000000000036	0.245999999999999996
60404	K1	10.0999999999999996	0.128000000000000003
60404	M4	343.699999999999989	0.183999999999999997
60404	O1	22.1000000000000014	0.120999999999999996
60404	M6	258	0.0359999999999999973
60404	S4	47.3999999999999986	0.00700000000000000015
60404	NU2	12.8000000000000007	0.0490000000000000019
60404	MU2	185.699999999999989	0.0330000000000000016
60404	2N2	348	0.0299999999999999989
60404	OO1	356.399999999999977	0.00300000000000000006
60404	LDA2	54.3999999999999986	0.0100000000000000002
60404	M1	15.3000000000000007	0.0100000000000000002
60404	J1	1.89999999999999991	0.00700000000000000015
60404	SSA	40	0.125
60404	SA	110.599999999999994	0.253000000000000003
60404	RHO1	27.8999999999999986	0.00300000000000000006
60404	Q1	28.5	0.0200000000000000004
60404	T2	79.4000000000000057	0.0100000000000000002
60404	2Q1	33.7999999999999972	0.00300000000000000006
60404	P1	10.6999999999999993	0.0429999999999999966
60404	L2	52.1000000000000014	0.0359999999999999973
60404	K2	85.5999999999999943	0.0429999999999999966
60404	M8	164.400000000000006	0.00700000000000000015
60405	M2	20.3999999999999986	1.33499999999999996
60405	S2	64.2999999999999972	0.171000000000000013
60405	N2	356.5	0.245999999999999996
60405	K1	357	0.150999999999999995
60405	M4	320.899999999999977	0.138000000000000012
60405	O1	22.6000000000000014	0.115000000000000005
60405	M6	191.300000000000011	0.0389999999999999999
60405	MK3	255.400000000000006	0.0389999999999999999
60405	MN4	297.600000000000023	0.0519999999999999976
60405	NU2	1.30000000000000004	0.0560000000000000012
60405	MU2	117.700000000000003	0.0259999999999999988
60405	2N2	323.600000000000023	0.0229999999999999996
60405	OO1	57	0.0100000000000000002
60405	LDA2	45.3999999999999986	0.0429999999999999966
60405	S1	326.300000000000011	0.0389999999999999999
60405	M1	9.69999999999999929	0.00700000000000000015
60405	J1	344.300000000000011	0.0100000000000000002
60405	SSA	40	0.125
60405	SA	110.599999999999994	0.253000000000000003
60405	RHO1	33.6000000000000014	0.00300000000000000006
60405	Q1	345.800000000000011	0.0229999999999999996
60405	T2	104.099999999999994	0.0160000000000000003
60405	R2	85.4000000000000057	0.0129999999999999994
60405	2Q1	48	0.00300000000000000006
60405	P1	4.40000000000000036	0.0429999999999999966
60405	L2	33.5	0.0889999999999999958
60405	2MK3	266.699999999999989	0.0359999999999999973
60405	K2	62.2000000000000028	0.0589999999999999969
60405	M8	106.299999999999997	0.0129999999999999994
60405	MS4	9.19999999999999929	0.0359999999999999973
60406	M2	70.7999999999999972	0.328000000000000014
60406	S2	89.7999999999999972	0.0490000000000000019
60406	N2	56.5	0.0619999999999999996
60406	K1	261.699999999999989	0.0519999999999999976
60406	M4	80.5999999999999943	0.0459999999999999992
60406	O1	260.5	0.0820000000000000034
60406	M6	268	0.0229999999999999996
60406	S4	328	0.00700000000000000015
60406	NU2	58.7000000000000028	0.0129999999999999994
60406	S6	81.2999999999999972	0.00300000000000000006
60406	MU2	52	0.00700000000000000015
60406	2N2	42.7999999999999972	0.0100000000000000002
60406	OO1	263.600000000000023	0.00300000000000000006
60406	LDA2	79.5	0.00300000000000000006
60406	M1	261.399999999999977	0.00700000000000000015
60406	J1	262.899999999999977	0.00700000000000000015
60406	MM	278.899999999999977	0.0889999999999999958
60406	SSA	51.1000000000000014	0.107999999999999999
60406	SA	155.699999999999989	0.203000000000000014
60406	RHO1	260	0.00300000000000000006
60406	Q1	259.899999999999977	0.0160000000000000003
60406	T2	88.9000000000000057	0.00300000000000000006
60406	2Q1	259.199999999999989	0.00300000000000000006
60406	P1	261.300000000000011	0.0160000000000000003
60406	L2	85.4000000000000057	0.0100000000000000002
60406	K2	91.0999999999999943	0.0129999999999999994
60406	M8	278.600000000000023	0.0100000000000000002
60407	M2	21.1000000000000014	0.768000000000000016
60407	S2	53.6000000000000014	0.138000000000000012
60407	N2	7.90000000000000036	0.161000000000000004
60407	K1	203.800000000000011	0.112000000000000002
60407	M4	338.899999999999977	0.0259999999999999988
60407	O1	218	0.131000000000000005
60407	M6	134.900000000000006	0.0229999999999999996
60407	MK3	42.5	0.00700000000000000015
60407	S4	267.199999999999989	0.00300000000000000006
60407	MN4	311.5	0.0129999999999999994
60407	NU2	352.5	0.0299999999999999989
60407	MU2	66	0.00700000000000000015
60407	2N2	357.300000000000011	0.0229999999999999996
60407	OO1	218	0.00300000000000000006
60407	LDA2	24.1999999999999993	0.0129999999999999994
60407	S1	178.800000000000011	0.00700000000000000015
60407	M1	255.599999999999994	0.00300000000000000006
60407	J1	206.599999999999994	0.00700000000000000015
60407	MM	69.5	0.0889999999999999958
60407	SSA	69.2000000000000028	0.147999999999999993
60407	SA	147.199999999999989	0.288999999999999979
60407	RHO1	244.900000000000006	0.0129999999999999994
60407	Q1	221.400000000000006	0.0200000000000000004
60407	T2	39.7999999999999972	0.00300000000000000006
60407	R2	262.899999999999977	0.0160000000000000003
60407	2Q1	197.099999999999994	0.0100000000000000002
60407	P1	208.5	0.0359999999999999973
60407	M3	34.2000000000000028	0.00700000000000000015
60407	L2	21.8000000000000007	0.0359999999999999973
60407	2MK3	30.3000000000000007	0.00700000000000000015
60407	K2	40.7000000000000028	0.0299999999999999989
60407	M8	59.7999999999999972	0.00300000000000000006
60407	MS4	40.6000000000000014	0.0129999999999999994
60408	M2	12.8000000000000007	1.07000000000000006
60408	S2	42.2000000000000028	0.176999999999999991
60408	N2	358.600000000000023	0.226000000000000006
60408	K1	193.800000000000011	0.157000000000000001
60408	M4	328.399999999999977	0.0299999999999999989
60408	O1	208.099999999999994	0.176999999999999991
60408	M6	103.099999999999994	0.0429999999999999966
60408	NU2	0.5	0.0429999999999999966
60408	2N2	344.5	0.0299999999999999989
60408	OO1	179.400000000000006	0.00700000000000000015
60408	LDA2	26.3000000000000007	0.00700000000000000015
60408	M1	200.900000000000006	0.0129999999999999994
60408	J1	186.599999999999994	0.0129999999999999994
60408	RHO1	214.099999999999994	0.00700000000000000015
60408	Q1	215.099999999999994	0.0330000000000000016
60408	T2	42.1000000000000014	0.0100000000000000002
60408	2Q1	222.300000000000011	0.00300000000000000006
60408	P1	193.699999999999989	0.0519999999999999976
60408	L2	26.8999999999999986	0.0299999999999999989
60408	K2	42.2000000000000028	0.0490000000000000019
60409	M2	23	1.78499999999999992
60409	S2	58	0.315000000000000002
60409	N2	11.8000000000000007	0.390000000000000013
60409	K1	201.400000000000006	0.259000000000000008
60409	M4	206.199999999999989	0.0619999999999999996
60409	O1	212.599999999999994	0.266000000000000014
60409	M6	93.9000000000000057	0.0719999999999999946
60409	MK3	357.600000000000023	0.0299999999999999989
60409	S4	303.5	0.0200000000000000004
60409	MN4	210.099999999999994	0.0330000000000000016
60409	NU2	2.29999999999999982	0.0790000000000000008
60409	S6	261.899999999999977	0.00700000000000000015
60409	MU2	60.1000000000000014	0.0790000000000000008
60409	2N2	0.699999999999999956	0.0490000000000000019
60409	OO1	203.900000000000006	0.0129999999999999994
60409	LDA2	358.600000000000023	0.0389999999999999999
60409	S1	167.5	0.0389999999999999999
60409	M1	236.599999999999994	0.0129999999999999994
60409	J1	232.199999999999989	0.0200000000000000004
60409	SSA	33.5	0.164000000000000007
60409	SA	153.800000000000011	0.242999999999999994
60409	RHO1	190.300000000000011	0.0129999999999999994
60409	Q1	202.900000000000006	0.0519999999999999976
60409	T2	28.6999999999999993	0.0359999999999999973
60409	R2	256.699999999999989	0.00700000000000000015
60409	2Q1	158.699999999999989	0.00700000000000000015
60409	P1	204.599999999999994	0.0850000000000000061
60409	2SM2	183	0.00300000000000000006
60409	M3	83.4000000000000057	0.0129999999999999994
60409	L2	1.19999999999999996	0.0950000000000000011
60409	2MK3	4.20000000000000018	0.0299999999999999989
60409	K2	53.2000000000000028	0.0850000000000000061
60409	M8	295.699999999999989	0.00700000000000000015
60409	MS4	214	0.0200000000000000004
60410	M2	32.5	1.27299999999999991
60410	S2	56.2999999999999972	0.223000000000000004
60410	N2	12.3000000000000007	0.288999999999999979
60410	K1	193.400000000000006	0.194000000000000006
60410	M4	295.899999999999977	0.0160000000000000003
60410	O1	213.599999999999994	0.150999999999999995
60410	M6	291.899999999999977	0.0160000000000000003
60410	MK3	79.4000000000000057	0.0100000000000000002
60410	MN4	271.5	0.0100000000000000002
60410	NU2	12	0.0589999999999999969
60410	MU2	21.8000000000000007	0.0299999999999999989
60410	2N2	356.800000000000011	0.0389999999999999999
60410	OO1	215.099999999999994	0.0100000000000000002
60410	LDA2	54.1000000000000014	0.0160000000000000003
60410	S1	100.799999999999997	0.0229999999999999996
60410	M1	211.099999999999994	0.0100000000000000002
60410	J1	200.199999999999989	0.0129999999999999994
60410	SSA	37.6000000000000014	0.128000000000000003
60410	SA	150.599999999999994	0.190000000000000002
60410	RHO1	203	0.0100000000000000002
60410	Q1	194.900000000000006	0.0299999999999999989
60410	T2	44.2000000000000028	0.0200000000000000004
60410	R2	57.3999999999999986	0.00300000000000000006
60410	2Q1	233.5	0.00300000000000000006
60410	P1	201.699999999999989	0.0619999999999999996
60410	M3	72	0.0100000000000000002
60410	L2	47.3999999999999986	0.0589999999999999969
60410	2MK3	94.7000000000000028	0.0129999999999999994
60410	K2	57	0.0619999999999999996
60411	M2	44.2999999999999972	1.12200000000000011
60411	S2	69.5999999999999943	0.197000000000000008
60411	N2	24.1999999999999993	0.248999999999999999
60411	K1	198.400000000000006	0.171000000000000013
60411	M4	325.399999999999977	0.0359999999999999973
60411	O1	216.599999999999994	0.125
60411	M6	333.199999999999989	0.0129999999999999994
60411	S4	307.699999999999989	0.00700000000000000015
60411	NU2	26.8999999999999986	0.0490000000000000019
60411	S6	248	0.00300000000000000006
60411	MU2	19	0.0259999999999999988
60411	2N2	4.29999999999999982	0.0330000000000000016
60411	OO1	180.400000000000006	0.00700000000000000015
60411	LDA2	56.1000000000000014	0.00700000000000000015
60411	M1	207.300000000000011	0.0100000000000000002
60411	J1	189.5	0.0100000000000000002
60411	SSA	37.6000000000000014	0.128000000000000003
60411	SA	150.599999999999994	0.190000000000000002
60411	RHO1	227.300000000000011	0.00300000000000000006
60411	Q1	225.900000000000006	0.0229999999999999996
60411	T2	68.5999999999999943	0.0129999999999999994
60411	2Q1	234.199999999999989	0.00300000000000000006
60411	P1	199.800000000000011	0.0560000000000000012
60411	L2	64.5	0.0330000000000000016
60411	K2	71.7000000000000028	0.0519999999999999976
60412	M2	86.7999999999999972	0.78400000000000003
60412	S2	113	0.112000000000000002
60412	N2	66.9000000000000057	0.138000000000000012
60412	K1	222.400000000000006	0.135000000000000009
60412	M4	32	0.0459999999999999992
60412	O1	248.5	0.0980000000000000038
60412	M6	63.2999999999999972	0.0160000000000000003
60412	S4	45.1000000000000014	0.00300000000000000006
60412	NU2	69.5999999999999943	0.0259999999999999988
60412	S6	117.400000000000006	0.00300000000000000006
60412	MU2	268.600000000000023	0.0200000000000000004
60412	2N2	47	0.0200000000000000004
60412	OO1	196.400000000000006	0.00300000000000000006
60412	LDA2	99	0.00700000000000000015
60412	M1	235.400000000000006	0.00700000000000000015
60412	J1	209.5	0.00700000000000000015
60412	RHO1	259.699999999999989	0.00300000000000000006
60412	Q1	261.5	0.0200000000000000004
60412	T2	112	0.00700000000000000015
60412	2Q1	274.399999999999977	0.00300000000000000006
60412	P1	224.400000000000006	0.0429999999999999966
60412	L2	106.700000000000003	0.0229999999999999996
60412	K2	115.200000000000003	0.0299999999999999989
60413	M2	95.4000000000000057	0.849999999999999978
60413	S2	130.5	0.115000000000000005
60413	N2	68.4000000000000057	0.171000000000000013
60413	K1	234.599999999999994	0.138000000000000012
60413	M4	92.2999999999999972	0.0459999999999999992
60413	O1	248.900000000000006	0.115000000000000005
60413	M6	146.5	0.0129999999999999994
60413	S4	85.0999999999999943	0.00700000000000000015
60413	NU2	72	0.0330000000000000016
60413	S6	194.099999999999994	0.00300000000000000006
60413	MU2	268.5	0.0200000000000000004
60413	2N2	41.5	0.0229999999999999996
60413	OO1	220.300000000000011	0.00700000000000000015
60413	LDA2	111.700000000000003	0.00700000000000000015
60413	M1	241.699999999999989	0.0100000000000000002
60413	J1	227.5	0.0100000000000000002
60413	RHO1	255.099999999999994	0.00300000000000000006
60413	Q1	256.100000000000023	0.0229999999999999996
60413	T2	129.099999999999994	0.00700000000000000015
60413	2Q1	263.199999999999989	0.00300000000000000006
60413	P1	235.699999999999989	0.0459999999999999992
60413	L2	122.400000000000006	0.0229999999999999996
60413	K2	133.300000000000011	0.0330000000000000016
60413	M8	44.7999999999999972	0.00300000000000000006
60414	M2	133.900000000000006	0.751000000000000001
60414	S2	158.900000000000006	0.104999999999999996
60414	N2	118.400000000000006	0.157000000000000001
60414	K1	258.199999999999989	0.131000000000000005
60414	M4	169.900000000000006	0.0229999999999999996
60414	O1	255.099999999999994	0.104999999999999996
60414	M6	168.900000000000006	0.0100000000000000002
60414	S4	78.5999999999999943	0.00300000000000000006
60414	NU2	120.5	0.0299999999999999989
60414	MU2	316.800000000000011	0.0200000000000000004
60414	2N2	103	0.0200000000000000004
60414	OO1	261.399999999999977	0.00300000000000000006
60414	LDA2	145.5	0.00700000000000000015
60414	M1	256.699999999999989	0.00700000000000000015
60414	J1	259.800000000000011	0.0100000000000000002
60414	RHO1	253.800000000000011	0.00300000000000000006
60414	Q1	253.599999999999994	0.0200000000000000004
60414	T2	157.900000000000006	0.00700000000000000015
60414	2Q1	252	0.00300000000000000006
60414	P1	258	0.0429999999999999966
60414	L2	149.300000000000011	0.0200000000000000004
60414	K2	160.900000000000006	0.0299999999999999989
60414	M8	40.7000000000000028	0.00300000000000000006
60415	M2	142.300000000000011	1.07000000000000006
60415	S2	152.099999999999994	0.223000000000000004
60415	N2	119.599999999999994	0.23000000000000001
60415	K1	248.699999999999989	0.153999999999999998
60415	M4	203.599999999999994	0.0850000000000000061
60415	O1	266.199999999999989	0.115000000000000005
60415	M6	260.600000000000023	0.0200000000000000004
60415	MK3	255.900000000000006	0.0229999999999999996
60415	S4	179.699999999999989	0.00700000000000000015
60415	MN4	162	0.0389999999999999999
60415	NU2	100.900000000000006	0.0429999999999999966
60415	MU2	120.900000000000006	0.0160000000000000003
60415	2N2	157.599999999999994	0.0299999999999999989
60415	OO1	337.5	0.0100000000000000002
60415	LDA2	175.599999999999994	0.0129999999999999994
60415	S1	293.600000000000023	0.0589999999999999969
60415	M1	269.100000000000023	0.00700000000000000015
60415	J1	292.399999999999977	0.0100000000000000002
60415	SSA	35.7000000000000028	0.125
60415	SA	133.099999999999994	0.266000000000000014
60415	RHO1	205.800000000000011	0.0100000000000000002
60415	Q1	263	0.0160000000000000003
60415	T2	12.0999999999999996	0.0259999999999999988
60415	R2	349.5	0.0790000000000000008
60415	2Q1	204.400000000000006	0.00300000000000000006
60415	P1	309	0.0259999999999999988
60415	2SM2	309.699999999999989	0.00300000000000000006
60415	M3	264.699999999999989	0.0129999999999999994
60415	L2	185	0.0690000000000000058
60415	2MK3	275.300000000000011	0.0160000000000000003
60415	K2	155.599999999999994	0.0660000000000000031
60415	MS4	261.600000000000023	0.0160000000000000003
60416	M2	220.400000000000006	0.751000000000000001
60416	S2	255.900000000000006	0.117999999999999994
60416	N2	200.699999999999989	0.153999999999999998
60416	K1	297.199999999999989	0.0889999999999999958
60416	M4	5.20000000000000018	0.0229999999999999996
60416	O1	325.100000000000023	0.0790000000000000008
60416	M6	88.9000000000000057	0.0129999999999999994
60416	MK3	53.2999999999999972	0.0100000000000000002
60416	S4	7	0.00300000000000000006
60416	MN4	336.199999999999989	0.0100000000000000002
60416	NU2	189.400000000000006	0.0359999999999999973
60416	MU2	233.400000000000006	0.0200000000000000004
60416	2N2	167.900000000000006	0.0229999999999999996
60416	OO1	34.5	0.0100000000000000002
60416	LDA2	191.199999999999989	0.0160000000000000003
60416	S1	282.600000000000023	0.0160000000000000003
60416	M1	178.400000000000006	0.00300000000000000006
60416	J1	252	0.00700000000000000015
60416	SSA	35.7000000000000028	0.125
60416	SA	133.099999999999994	0.266000000000000014
60416	RHO1	335.600000000000023	0.0160000000000000003
60416	Q1	351.100000000000023	0.0160000000000000003
60416	T2	266	0.0160000000000000003
60416	R2	182.400000000000006	0.00300000000000000006
60416	2Q1	13.5	0.00700000000000000015
60416	P1	300.899999999999977	0.0330000000000000016
60416	2SM2	65.4000000000000057	0.00300000000000000006
60416	M3	35.5	0.00700000000000000015
60416	L2	237	0.0299999999999999989
60416	2MK3	36.1000000000000014	0.0160000000000000003
60416	K2	245.699999999999989	0.0389999999999999999
60416	MS4	51.1000000000000014	0.00700000000000000015
60417	M2	214.599999999999994	0.787000000000000033
60417	S2	249.400000000000006	0.125
60417	N2	192.800000000000011	0.16700000000000001
60417	K1	293.699999999999989	0.0919999999999999984
60417	M4	332.899999999999977	0.0200000000000000004
60417	O1	321.699999999999989	0.0749999999999999972
60417	M6	62.2000000000000028	0.0100000000000000002
60417	MK3	22.8000000000000007	0.0100000000000000002
60417	S4	323.399999999999977	0.00300000000000000006
60417	MN4	306.300000000000011	0.0100000000000000002
60417	NU2	187.699999999999989	0.0359999999999999973
60417	MU2	232	0.0129999999999999994
60417	2N2	170.300000000000011	0.0229999999999999996
60417	OO1	299.399999999999977	0.00700000000000000015
60417	LDA2	229.5	0.0160000000000000003
60417	S1	289.399999999999977	0.0299999999999999989
60417	M1	285	0.00300000000000000006
60417	J1	276.5	0.00700000000000000015
60417	SSA	26.1999999999999993	0.147999999999999993
60417	SA	123.700000000000003	0.377000000000000002
60417	RHO1	312	0.00300000000000000006
60417	Q1	300	0.0160000000000000003
60417	T2	263.800000000000011	0.0100000000000000002
60417	2Q1	154.5	0.00700000000000000015
60417	P1	301.899999999999977	0.0330000000000000016
60417	2SM2	214.099999999999994	0.00300000000000000006
60417	M3	354.600000000000023	0.00700000000000000015
60417	L2	229.900000000000006	0.0490000000000000019
60417	2MK3	30.5	0.0129999999999999994
60417	K2	246.099999999999994	0.0359999999999999973
60417	MS4	26.5	0.00300000000000000006
60418	M2	317.100000000000023	0.935000000000000053
60418	S2	354.899999999999977	0.117999999999999994
60418	N2	299.699999999999989	0.153999999999999998
60418	K1	319.899999999999977	0.125
60418	M4	134.400000000000006	0.0619999999999999996
60418	O1	347.600000000000023	0.0919999999999999984
60418	M6	277.100000000000023	0.0490000000000000019
60418	MK3	125.900000000000006	0.0299999999999999989
60418	S4	145.199999999999989	0.00300000000000000006
60418	MN4	110.900000000000006	0.0259999999999999988
60418	NU2	296.5	0.0589999999999999969
60418	MU2	75.9000000000000057	0.0389999999999999999
60418	2N2	256.5	0.0359999999999999973
60418	OO1	172.099999999999994	0.00300000000000000006
60418	LDA2	341.800000000000011	0.0299999999999999989
60418	S1	297.800000000000011	0.0359999999999999973
60418	M1	90.4000000000000057	0.00700000000000000015
60418	J1	162.300000000000011	0.00700000000000000015
60418	SSA	35.7000000000000028	0.125
60418	SA	133.099999999999994	0.266000000000000014
60418	RHO1	267.300000000000011	0.0100000000000000002
60418	Q1	340	0.0160000000000000003
60418	T2	26.8000000000000007	0.0100000000000000002
60418	R2	58.6000000000000014	0.00700000000000000015
60418	2Q1	260.800000000000011	0.0160000000000000003
60418	P1	328.100000000000023	0.0229999999999999996
60418	2SM2	240.099999999999994	0.0100000000000000002
60418	M3	62.2000000000000028	0.00700000000000000015
60418	L2	344.100000000000023	0.0749999999999999972
60418	2MK3	140.400000000000006	0.0359999999999999973
60418	K2	356.699999999999989	0.0359999999999999973
60418	M8	106.5	0.0129999999999999994
60418	MS4	177.099999999999994	0.0160000000000000003
60419	M2	176.400000000000006	0.603999999999999981
60419	S2	200	0.0919999999999999984
60419	N2	152.300000000000011	0.131000000000000005
60419	K1	276.199999999999989	0.0749999999999999972
60419	M4	204.400000000000006	0.0129999999999999994
60419	O1	298.699999999999989	0.0619999999999999996
60419	M6	265.100000000000023	0.0100000000000000002
60419	NU2	151.300000000000011	0.0259999999999999988
60419	2N2	130.300000000000011	0.0160000000000000003
60419	OO1	253.5	0.00300000000000000006
60419	LDA2	203.800000000000011	0.0129999999999999994
60419	S1	311	0.0259999999999999988
60419	M1	287.399999999999977	0.00300000000000000006
60419	J1	264.899999999999977	0.00700000000000000015
60419	SSA	35.7000000000000028	0.125
60419	SA	133.099999999999994	0.266000000000000014
60419	RHO1	308.399999999999977	0.00300000000000000006
60419	Q1	287.100000000000023	0.0129999999999999994
60419	T2	199.099999999999994	0.00700000000000000015
60419	2Q1	321.100000000000023	0.00300000000000000006
60419	P1	293	0.0299999999999999989
60419	L2	203.300000000000011	0.0359999999999999973
60419	K2	201.300000000000011	0.0259999999999999988
60420	M2	168	0.845999999999999974
60420	S2	193.800000000000011	0.128000000000000003
60420	N2	144.599999999999994	0.173999999999999988
60420	K1	245.400000000000006	0.115000000000000005
60420	M4	218.5	0.0619999999999999996
60420	O1	274.399999999999977	0.0790000000000000008
60420	M6	242.400000000000006	0.00700000000000000015
60420	MK3	282.800000000000011	0.0160000000000000003
60420	S4	247.699999999999989	0.00700000000000000015
60420	MN4	191.900000000000006	0.0259999999999999988
60420	NU2	144.5	0.0389999999999999999
60420	MU2	184.199999999999989	0.0100000000000000002
60420	2N2	108.5	0.0200000000000000004
60420	OO1	290.699999999999989	0.00300000000000000006
60420	LDA2	191.599999999999994	0.0160000000000000003
60420	S1	219.5	0.0129999999999999994
60420	M1	320.800000000000011	0.00300000000000000006
60420	J1	134.800000000000011	0.00300000000000000006
60420	SSA	48	0.0980000000000000038
60420	SA	156	0.298999999999999988
60420	RHO1	238	0.00300000000000000006
60420	Q1	269.199999999999989	0.0160000000000000003
60420	T2	173.599999999999994	0.0129999999999999994
60420	R2	336.300000000000011	0.00300000000000000006
60420	2Q1	193.599999999999994	0.00300000000000000006
60420	P1	249.400000000000006	0.0259999999999999988
60420	2SM2	108.200000000000003	0.00300000000000000006
60420	M3	286.5	0.00700000000000000015
60420	L2	186.099999999999994	0.0429999999999999966
60420	2MK3	304.5	0.0229999999999999996
60420	K2	193.400000000000006	0.0389999999999999999
60420	M8	280	0.00300000000000000006
60420	MS4	255.300000000000011	0.0129999999999999994
60421	M2	103.200000000000003	0.573999999999999955
60421	S2	124.299999999999997	0.0980000000000000038
60421	N2	84	0.125
60421	K1	226.699999999999989	0.0980000000000000038
60421	M4	87.5999999999999943	0.0299999999999999989
60421	O1	245.900000000000006	0.0749999999999999972
60421	M6	97.5999999999999943	0.0100000000000000002
60421	MN4	59.1000000000000014	0.0129999999999999994
60421	NU2	82.7999999999999972	0.0259999999999999988
60421	MU2	82.4000000000000057	0.0129999999999999994
60421	2N2	64.2999999999999972	0.0160000000000000003
60421	OO1	207.400000000000006	0.00300000000000000006
60421	LDA2	112.900000000000006	0.00300000000000000006
60421	S1	334.100000000000023	0.0100000000000000002
60421	M1	236.199999999999989	0.00700000000000000015
60421	J1	217.099999999999994	0.00700000000000000015
60421	SSA	48	0.0980000000000000038
60421	SA	156.300000000000011	0.298999999999999988
60421	RHO1	254	0.00300000000000000006
60421	Q1	239.800000000000011	0.0160000000000000003
60421	T2	113.700000000000003	0.0100000000000000002
60421	2Q1	264.800000000000011	0.00300000000000000006
60421	P1	230.400000000000006	0.0259999999999999988
60421	L2	116	0.0160000000000000003
60421	K2	124.200000000000003	0.0299999999999999989
60422	M2	186.599999999999994	1.30899999999999994
60422	S2	228.699999999999989	0.209999999999999992
60422	N2	179.599999999999994	0.276000000000000023
60422	K1	250	0.176999999999999991
60422	M4	220.400000000000006	0.115000000000000005
60422	O1	286.899999999999977	0.0690000000000000058
60422	M6	235.800000000000011	0.0459999999999999992
60422	S4	349.199999999999989	0.0299999999999999989
60422	NU2	180.599999999999994	0.0519999999999999976
60422	S6	48.3999999999999986	0.00300000000000000006
60422	MU2	350.600000000000023	0.0330000000000000016
60422	2N2	172.599999999999994	0.0359999999999999973
60422	OO1	213.099999999999994	0.00300000000000000006
60422	LDA2	206.099999999999994	0.0100000000000000002
60422	M1	268.300000000000011	0.00700000000000000015
60422	J1	231.699999999999989	0.00700000000000000015
60422	RHO1	302.800000000000011	0.00300000000000000006
60422	Q1	305.300000000000011	0.0129999999999999994
60422	T2	227	0.0129999999999999994
60422	R2	230.300000000000011	0.00300000000000000006
60422	2Q1	323.600000000000023	0.00300000000000000006
60422	P1	252.800000000000011	0.0589999999999999969
60422	L2	193.599999999999994	0.0359999999999999973
60422	K2	232.099999999999994	0.0589999999999999969
60422	M8	252.900000000000006	0.0100000000000000002
60423	M2	264.300000000000011	1.33899999999999997
60423	S2	302.800000000000011	0.164000000000000007
60423	N2	230.900000000000006	0.245999999999999996
60423	K1	296.399999999999977	0.223000000000000004
60423	M4	60.3999999999999986	0.187
60423	O1	325.800000000000011	0.203000000000000014
60423	M6	163.400000000000006	0.0749999999999999972
60423	S4	77.7999999999999972	0.00700000000000000015
60423	NU2	235.5	0.0490000000000000019
60423	S6	264.899999999999977	0.00700000000000000015
60423	MU2	226.300000000000011	0.0299999999999999989
60423	2N2	197.5	0.0330000000000000016
60423	OO1	266.399999999999977	0.0100000000000000002
60423	LDA2	282.199999999999989	0.0100000000000000002
60423	M1	310.699999999999989	0.0129999999999999994
60423	J1	281.600000000000023	0.0160000000000000003
60423	RHO1	336.399999999999977	0.00700000000000000015
60423	Q1	340.300000000000011	0.0359999999999999973
60423	T2	301.100000000000023	0.0100000000000000002
60423	2Q1	356.800000000000011	0.00700000000000000015
60423	P1	298.600000000000023	0.0719999999999999946
60423	L2	297.399999999999977	0.0359999999999999973
60423	K2	305.899999999999977	0.0429999999999999966
60423	M8	327.800000000000011	0.0359999999999999973
60424	M2	47.7000000000000028	0.801000000000000045
60424	S2	72.5999999999999943	0.150999999999999995
60424	N2	29	0.183999999999999997
60424	K1	197.400000000000006	0.128000000000000003
60424	M4	21.3999999999999986	0.0490000000000000019
60424	O1	218.900000000000006	0.0850000000000000061
60424	M6	357.699999999999989	0.0100000000000000002
60424	MK3	129.5	0.0160000000000000003
60424	S4	352.800000000000011	0.0129999999999999994
60424	MN4	356.899999999999977	0.0229999999999999996
60424	NU2	28.8999999999999986	0.0429999999999999966
60424	MU2	50.8999999999999986	0.0229999999999999996
60424	2N2	358.300000000000011	0.0229999999999999996
60424	OO1	169.900000000000006	0.0100000000000000002
60424	LDA2	53.2000000000000028	0.0129999999999999994
60424	S1	99.2999999999999972	0.0100000000000000002
60424	M1	116.200000000000003	0.00300000000000000006
60424	J1	219.300000000000011	0.0100000000000000002
60424	SSA	43.6000000000000014	0.128000000000000003
60424	SA	147	0.20699999999999999
60424	RHO1	188.400000000000006	0.00700000000000000015
60424	Q1	218.300000000000011	0.0259999999999999988
60424	T2	58.7000000000000028	0.0129999999999999994
60424	R2	235.5	0.00700000000000000015
60424	2Q1	129.5	0.00700000000000000015
60424	P1	197.699999999999989	0.0330000000000000016
60424	2SM2	81.7000000000000028	0.00300000000000000006
60424	M3	101	0.0129999999999999994
60424	L2	71.7999999999999972	0.0299999999999999989
60424	2MK3	142.300000000000011	0.0129999999999999994
60424	K2	69.5	0.0359999999999999973
60424	MS4	80.7000000000000028	0.0129999999999999994
60425	M2	41	1.0169999999999999
60425	S2	68.4000000000000057	0.16700000000000001
60425	N2	20.3000000000000007	0.203000000000000014
60425	K1	190.599999999999994	0.138000000000000012
60425	M4	15.6999999999999993	0.0389999999999999999
60425	O1	223.5	0.143999999999999989
60425	M6	344	0.0160000000000000003
60425	S4	344.600000000000023	0.00300000000000000006
60425	NU2	23.1000000000000014	0.0389999999999999999
60425	S6	49.3999999999999986	0.00300000000000000006
60425	MU2	221.099999999999994	0.0229999999999999996
60425	2N2	359.600000000000023	0.0259999999999999988
60425	OO1	157.900000000000006	0.00700000000000000015
60425	LDA2	53.7000000000000028	0.00700000000000000015
60425	M1	206.900000000000006	0.0100000000000000002
60425	J1	174.400000000000006	0.0100000000000000002
60425	SSA	37.6000000000000014	0.128000000000000003
60425	SA	150.599999999999994	0.190000000000000002
60425	RHO1	237.5	0.00700000000000000015
60425	Q1	239.699999999999989	0.0259999999999999988
60425	T2	67.4000000000000057	0.0100000000000000002
60425	2Q1	256	0.00300000000000000006
60425	P1	193.099999999999994	0.0459999999999999992
60425	L2	61.7000000000000028	0.0299999999999999989
60425	K2	70.7000000000000028	0.0459999999999999992
60425	M8	17.5	0.00300000000000000006
60426	M2	53.6000000000000014	1.18399999999999994
60426	S2	80	0.209999999999999992
60426	N2	36.2000000000000028	0.262000000000000011
60426	K1	198.199999999999989	0.16700000000000001
60426	M4	68.9000000000000057	0.0160000000000000003
60426	O1	221	0.125
60426	M6	72.7999999999999972	0.0129999999999999994
60426	MK3	117.299999999999997	0.0129999999999999994
60426	S4	26.3999999999999986	0.0160000000000000003
60426	NU2	33.1000000000000014	0.0490000000000000019
60426	MU2	50.1000000000000014	0.0359999999999999973
60426	2N2	19.5	0.0330000000000000016
60426	OO1	175.300000000000011	0.00700000000000000015
60426	LDA2	66.4000000000000057	0.0229999999999999996
60426	S1	108.599999999999994	0.0330000000000000016
60426	M1	209.5	0.0100000000000000002
60426	J1	186.900000000000006	0.0100000000000000002
60426	SSA	43.6000000000000014	0.128000000000000003
60426	SA	147	0.20699999999999999
60426	RHO1	230.699999999999989	0.00700000000000000015
60426	Q1	202.5	0.0259999999999999988
60426	T2	68.7000000000000028	0.0200000000000000004
60426	R2	81.0999999999999943	0.00300000000000000006
60426	2Q1	243.5	0.00300000000000000006
60426	P1	192.699999999999989	0.0490000000000000019
60426	M3	141.5	0.0100000000000000002
60426	L2	50	0.0490000000000000019
60426	K2	72.2999999999999972	0.0560000000000000012
60426	MS4	196.900000000000006	0.0100000000000000002
60427	M2	52.8999999999999986	1.07899999999999996
60427	S2	78.2999999999999972	0.190000000000000002
60427	N2	33.7000000000000028	0.242999999999999994
60427	K1	196.699999999999989	0.157000000000000001
60427	M4	46.3999999999999986	0.0229999999999999996
60427	O1	221.800000000000011	0.117999999999999994
60427	M6	74.5	0.0100000000000000002
60427	MK3	114.200000000000003	0.0129999999999999994
60427	S4	22.8000000000000007	0.0129999999999999994
60427	MN4	4.40000000000000036	0.0129999999999999994
60427	NU2	33.6000000000000014	0.0490000000000000019
60427	S6	349.300000000000011	0.00300000000000000006
60427	MU2	54	0.0330000000000000016
60427	2N2	20.8000000000000007	0.0259999999999999988
60427	OO1	223	0.00300000000000000006
60427	LDA2	60.3999999999999986	0.0160000000000000003
60427	S1	127	0.0330000000000000016
60427	M1	223.199999999999989	0.00700000000000000015
60427	J1	225	0.00700000000000000015
60427	MM	63	0.0850000000000000061
60427	SSA	62.1000000000000014	0.183999999999999997
60427	SA	146.099999999999994	0.304999999999999993
60427	RHO1	174.800000000000011	0.00300000000000000006
60427	Q1	200.199999999999989	0.0229999999999999996
60427	T2	86.5	0.0200000000000000004
60427	R2	315.5	0.0100000000000000002
60427	2Q1	142.900000000000006	0.00700000000000000015
60427	P1	194.300000000000011	0.0429999999999999966
60427	2SM2	354.300000000000011	0.00300000000000000006
60427	M3	122.400000000000006	0.0100000000000000002
60427	L2	62.5	0.0459999999999999992
60427	2MK3	129.699999999999989	0.0129999999999999994
60427	K2	74.4000000000000057	0.0490000000000000019
60427	MS4	182.5	0.00700000000000000015
60428	M2	129.199999999999989	0.879000000000000004
60428	S2	156.800000000000011	0.125
60428	N2	111	0.190000000000000002
60428	K1	257.199999999999989	0.209999999999999992
60428	M4	163.699999999999989	0.0359999999999999973
60428	O1	278.5	0.138000000000000012
60428	M6	146.800000000000011	0.0299999999999999989
60428	S4	170.900000000000006	0.00300000000000000006
60428	NU2	113.5	0.0359999999999999973
60428	S6	294.699999999999989	0.00300000000000000006
60428	MU2	101.599999999999994	0.0200000000000000004
60428	2N2	93	0.0259999999999999988
60428	OO1	233.199999999999989	0.00700000000000000015
60428	LDA2	142	0.00700000000000000015
60428	M1	266.899999999999977	0.0100000000000000002
60428	J1	242.800000000000011	0.0100000000000000002
60428	SSA	33.8999999999999986	0.120999999999999996
60428	SA	149.199999999999989	0.157000000000000001
60428	RHO1	292.899999999999977	0.00700000000000000015
60428	Q1	290.899999999999977	0.0259999999999999988
60428	T2	155.699999999999989	0.00700000000000000015
60428	2Q1	299.5	0.00300000000000000006
60428	P1	258.800000000000011	0.0690000000000000058
60428	L2	147.199999999999989	0.0259999999999999988
60428	K2	159.099999999999994	0.0330000000000000016
60428	M8	110.299999999999997	0.00300000000000000006
60429	M2	90.5	1.06299999999999994
60429	S2	121.799999999999997	0.150999999999999995
60429	N2	73	0.23000000000000001
60429	K1	233.199999999999989	0.197000000000000008
60429	M4	47.7999999999999972	0.0330000000000000016
60429	O1	255.599999999999994	0.128000000000000003
60429	M6	28.8999999999999986	0.0359999999999999973
60429	S4	90.0999999999999943	0.00300000000000000006
60429	NU2	75.2999999999999972	0.0459999999999999992
60429	S6	69.5	0.00300000000000000006
60429	MU2	59.1000000000000014	0.0259999999999999988
60429	2N2	55.3999999999999986	0.0299999999999999989
60429	OO1	199.800000000000011	0.00300000000000000006
60429	LDA2	105	0.00700000000000000015
60429	M1	243.099999999999994	0.0100000000000000002
60429	J1	221.199999999999989	0.0100000000000000002
60429	SSA	33.8999999999999986	0.120999999999999996
60429	SA	149.199999999999989	0.157000000000000001
60429	RHO1	269	0.00700000000000000015
60429	Q1	267	0.0229999999999999996
60429	T2	120.599999999999994	0.0100000000000000002
60429	2Q1	277.300000000000011	0.00300000000000000006
60429	P1	234.800000000000011	0.0660000000000000031
60429	L2	108.099999999999994	0.0299999999999999989
60429	K2	124.299999999999997	0.0429999999999999966
60429	M8	346.100000000000023	0.00300000000000000006
60430	M2	54.5	1.31200000000000006
60430	S2	86.5999999999999943	0.235999999999999988
60430	N2	38.3999999999999986	0.301999999999999991
60430	K1	196.699999999999989	0.16700000000000001
60430	M4	345.300000000000011	0.0299999999999999989
60430	O1	225.900000000000006	0.125
60430	M6	108.5	0.0259999999999999988
60430	MK3	76.0999999999999943	0.0160000000000000003
60430	S4	44.6000000000000014	0.0129999999999999994
60430	MN4	332.800000000000011	0.0200000000000000004
60430	NU2	33.1000000000000014	0.0490000000000000019
60430	S6	253.099999999999994	0.00300000000000000006
60430	MU2	72.2999999999999972	0.0429999999999999966
60430	2N2	21.6999999999999993	0.0330000000000000016
60430	OO1	188.900000000000006	0.0229999999999999996
60430	LDA2	57.2999999999999972	0.0160000000000000003
60430	S1	144.699999999999989	0.0229999999999999996
60430	M1	259.600000000000023	0.0200000000000000004
60430	J1	214.199999999999989	0.00700000000000000015
60430	SSA	33.8999999999999986	0.120999999999999996
60430	SA	149.199999999999989	0.157000000000000001
60430	RHO1	47.1000000000000014	0.0129999999999999994
60430	Q1	220	0.0299999999999999989
60430	T2	81.7000000000000028	0.0299999999999999989
60430	R2	293.800000000000011	0.0100000000000000002
60430	2Q1	136.199999999999989	0.0129999999999999994
60430	P1	166.099999999999994	0.0389999999999999999
60430	2SM2	118.400000000000006	0.00700000000000000015
60430	M3	167.800000000000011	0.00700000000000000015
60430	L2	30	0.0790000000000000008
60430	2MK3	81	0.0160000000000000003
60430	K2	70	0.0589999999999999969
60430	M8	37.5	0.00300000000000000006
60430	MS4	258.800000000000011	0.00700000000000000015
60431	M2	84.2999999999999972	1.16500000000000004
60431	S2	113.400000000000006	0.200000000000000011
60431	N2	62	0.235999999999999988
60431	K1	222.400000000000006	0.16700000000000001
60431	M4	72.2000000000000028	0.0490000000000000019
60431	O1	243.199999999999989	0.143999999999999989
60431	M6	13.5	0.0229999999999999996
60431	MK3	147.699999999999989	0.0160000000000000003
60431	S4	83.2999999999999972	0.0100000000000000002
60431	MN4	52.2999999999999972	0.0229999999999999996
60431	NU2	60.7000000000000028	0.0589999999999999969
60431	MU2	122.400000000000006	0.0299999999999999989
60431	2N2	29.8000000000000007	0.0160000000000000003
60431	OO1	218.699999999999989	0.00700000000000000015
60431	LDA2	90.5	0.0330000000000000016
60431	S1	161	0.0429999999999999966
60431	M1	277.899999999999977	0.00700000000000000015
60431	J1	225.199999999999989	0.00300000000000000006
60431	SSA	33.8999999999999986	0.120999999999999996
60431	SA	149.199999999999989	0.157000000000000001
60431	RHO1	36.5	0.00700000000000000015
60431	Q1	203	0.0129999999999999994
60431	T2	81.4000000000000057	0.0129999999999999994
60431	R2	155.800000000000011	0.00700000000000000015
60431	2Q1	259.600000000000023	0.0100000000000000002
60431	P1	212.900000000000006	0.0389999999999999999
60431	2SM2	197.5	0.00700000000000000015
60431	M3	181.599999999999994	0.0100000000000000002
60431	L2	80.2000000000000028	0.0519999999999999976
60431	2MK3	169.800000000000011	0.0160000000000000003
60431	K2	102.299999999999997	0.0560000000000000012
60431	M8	257.600000000000023	0.00300000000000000006
60431	MS4	111.599999999999994	0.0100000000000000002
60432	M2	103	1.08899999999999997
60432	S2	138.599999999999994	0.190000000000000002
60432	N2	91	0.23000000000000001
60432	K1	227	0.183999999999999997
60432	M4	117.400000000000006	0.0490000000000000019
60432	O1	250.099999999999994	0.143999999999999989
60432	M6	38.3999999999999986	0.0330000000000000016
60432	S4	127.5	0.00700000000000000015
60432	NU2	92.5999999999999943	0.0459999999999999992
60432	S6	40.5	0.00300000000000000006
60432	MU2	274	0.0259999999999999988
60432	2N2	79.0999999999999943	0.0299999999999999989
60432	OO1	203.900000000000006	0.00700000000000000015
60432	LDA2	119.5	0.00700000000000000015
60432	M1	238.5	0.0100000000000000002
60432	J1	215.599999999999994	0.0129999999999999994
60432	SSA	33.8999999999999986	0.120999999999999996
60432	SA	149.199999999999989	0.157000000000000001
60432	RHO1	260	0.00700000000000000015
60432	Q1	261.600000000000023	0.0299999999999999989
60432	T2	137.099999999999994	0.0100000000000000002
60432	R2	140	0.00300000000000000006
60432	2Q1	273.100000000000023	0.00300000000000000006
60432	P1	228.800000000000011	0.0619999999999999996
60432	L2	114.900000000000006	0.0299999999999999989
60432	K2	141.400000000000006	0.0519999999999999976
60432	M8	57	0.00300000000000000006
60433	M2	124.200000000000003	0.941999999999999948
60433	S2	159.900000000000006	0.150999999999999995
60433	N2	112.299999999999997	0.190000000000000002
60433	K1	242.900000000000006	0.197000000000000008
60433	M4	156.199999999999989	0.0519999999999999976
60433	O1	277.5	0.128000000000000003
60433	M6	124.900000000000006	0.0299999999999999989
60433	S4	277.699999999999989	0.0100000000000000002
60433	NU2	113.900000000000006	0.0359999999999999973
60433	S6	196.599999999999994	0.00300000000000000006
60433	MU2	295	0.0229999999999999996
60433	2N2	100.5	0.0259999999999999988
60433	OO1	208.400000000000006	0.00700000000000000015
60433	LDA2	140.800000000000011	0.00700000000000000015
60433	M1	260.100000000000023	0.0100000000000000002
60433	J1	225.800000000000011	0.0100000000000000002
60433	SSA	33.8999999999999986	0.120999999999999996
60433	SA	149.199999999999989	0.157000000000000001
60433	RHO1	292.300000000000011	0.00700000000000000015
60433	Q1	294.600000000000023	0.0259999999999999988
60433	T2	158.5	0.0100000000000000002
60433	2Q1	311.699999999999989	0.00300000000000000006
60433	P1	245.5	0.0660000000000000031
60433	L2	136.099999999999994	0.0259999999999999988
60433	K2	162.800000000000011	0.0429999999999999966
60433	M8	122.099999999999994	0.00700000000000000015
60434	M2	181.400000000000006	1.21999999999999997
60434	S2	223.599999999999994	0.190000000000000002
60434	N2	170.199999999999989	0.23000000000000001
60434	K1	279.199999999999989	0.194000000000000006
60434	M4	180.800000000000011	0.0619999999999999996
60434	O1	301.199999999999989	0.147999999999999993
60434	M6	323.5	0.0490000000000000019
60434	MK3	256.699999999999989	0.0660000000000000031
60434	S4	311.800000000000011	0.0100000000000000002
60434	MN4	198.699999999999989	0.0259999999999999988
60434	NU2	156.800000000000011	0.0690000000000000058
60434	S6	42.1000000000000014	0.00300000000000000006
60434	MU2	261.399999999999977	0.0589999999999999969
60434	2N2	128.300000000000011	0.0389999999999999999
60434	OO1	278.399999999999977	0.00300000000000000006
60434	LDA2	182.400000000000006	0.0389999999999999999
60434	S1	217.900000000000006	0.0459999999999999992
60434	M1	347.699999999999989	0.0100000000000000002
60434	J1	30.6999999999999993	0.00700000000000000015
60434	SSA	33.8999999999999986	0.120999999999999996
60434	SA	149.199999999999989	0.157000000000000001
60434	RHO1	292.399999999999977	0.0100000000000000002
60434	Q1	308.399999999999977	0.0259999999999999988
60434	T2	209.599999999999994	0.00700000000000000015
60434	R2	230.5	0.00700000000000000015
60434	2Q1	223.800000000000011	0.0129999999999999994
60434	P1	258.5	0.0359999999999999973
60434	2SM2	63.7000000000000028	0.0129999999999999994
60434	M3	243.599999999999994	0.00700000000000000015
60434	L2	183.099999999999994	0.0950000000000000011
60434	2MK3	274.699999999999989	0.0719999999999999946
60434	K2	221.599999999999994	0.0519999999999999976
60434	M8	19	0.0100000000000000002
60434	MS4	223.300000000000011	0.0229999999999999996
60435	M2	155.5	0.85299999999999998
60435	S2	187	0.125
60435	N2	135.900000000000006	0.16700000000000001
60435	K1	264.800000000000011	0.171000000000000013
60435	M4	198.699999999999989	0.0589999999999999969
60435	O1	287.699999999999989	0.135000000000000009
60435	M6	197.300000000000011	0.0459999999999999992
60435	MK3	240.599999999999994	0.0229999999999999996
60435	S4	202.699999999999989	0.00300000000000000006
60435	MN4	180.699999999999989	0.0259999999999999988
60435	NU2	139.099999999999994	0.0459999999999999992
60435	MU2	249.400000000000006	0.0200000000000000004
60435	2N2	124	0.0259999999999999988
60435	LDA2	159.699999999999989	0.0259999999999999988
60435	S1	207.900000000000006	0.0389999999999999999
60435	M1	310.899999999999977	0.00700000000000000015
60435	J1	9.69999999999999929	0.00700000000000000015
60435	SSA	33.8999999999999986	0.120999999999999996
60435	SA	149.199999999999989	0.157000000000000001
60435	RHO1	283.199999999999989	0.00700000000000000015
60435	Q1	285.199999999999989	0.0229999999999999996
60435	T2	186.400000000000006	0.0100000000000000002
60435	R2	86.2000000000000028	0.00300000000000000006
60435	2Q1	198.900000000000006	0.00700000000000000015
60435	P1	251.599999999999994	0.0389999999999999999
60435	2SM2	88.2999999999999972	0.00700000000000000015
60435	M3	195.300000000000011	0.00700000000000000015
60435	L2	179.900000000000006	0.0660000000000000031
60435	2MK3	251.199999999999989	0.0259999999999999988
60435	K2	183.199999999999989	0.0359999999999999973
60435	M8	244.800000000000011	0.00700000000000000015
60435	MS4	246.400000000000006	0.0160000000000000003
60436	M2	202.5	0.967999999999999972
60436	S2	230.199999999999989	0.112000000000000002
60436	N2	181.5	0.203000000000000014
60436	K1	287.899999999999977	0.259000000000000008
60436	M4	242.5	0.0690000000000000058
60436	O1	296.800000000000011	0.153999999999999998
60436	M6	276.5	0.0330000000000000016
60436	S4	277.399999999999977	0.00300000000000000006
60436	NU2	184.300000000000011	0.0389999999999999999
60436	S6	47.5	0.00300000000000000006
60436	MU2	174.900000000000006	0.0229999999999999996
60436	2N2	160.599999999999994	0.0259999999999999988
60436	OO1	277.399999999999977	0.00300000000000000006
60436	LDA2	215.400000000000006	0.00700000000000000015
60436	M1	290.699999999999989	0.0100000000000000002
60436	J1	277	0.0100000000000000002
60436	RHO1	299.899999999999977	0.00700000000000000015
60436	Q1	301.899999999999977	0.0299999999999999989
60436	T2	229	0.00700000000000000015
60436	2Q1	305.199999999999989	0.00300000000000000006
60436	P1	288.5	0.0850000000000000061
60436	L2	223.599999999999994	0.0259999999999999988
60436	K2	232.5	0.0299999999999999989
60436	M8	342.5	0.00700000000000000015
60437	M2	230.699999999999989	1.13500000000000001
60437	S2	268.699999999999989	0.125
60437	N2	214.900000000000006	0.209999999999999992
60437	K1	294.199999999999989	0.183999999999999997
60437	M4	312.899999999999977	0.0619999999999999996
60437	O1	315	0.161000000000000004
60437	M6	18	0.0389999999999999999
60437	MK3	351.800000000000011	0.0359999999999999973
60437	S4	21.8999999999999986	0.00300000000000000006
60437	MN4	293.800000000000011	0.0229999999999999996
60437	NU2	198.5	0.0560000000000000012
60437	S6	87.2000000000000028	0.00300000000000000006
60437	MU2	348.600000000000023	0.0459999999999999992
60437	2N2	235.599999999999994	0.00300000000000000006
60437	OO1	337.899999999999977	0.00300000000000000006
60437	LDA2	239.099999999999994	0.0389999999999999999
60437	S1	246.300000000000011	0.0560000000000000012
60437	M1	5.29999999999999982	0.0200000000000000004
60437	J1	76.5	0.0100000000000000002
60437	SSA	33.8999999999999986	0.120999999999999996
60437	SA	149.199999999999989	0.157000000000000001
60437	RHO1	262.199999999999989	0.0129999999999999994
60437	Q1	323.600000000000023	0.0259999999999999988
60437	T2	251.300000000000011	0.0100000000000000002
60437	R2	329.300000000000011	0.00300000000000000006
60437	2Q1	159.099999999999994	0.00300000000000000006
60437	P1	274.600000000000023	0.0459999999999999992
60437	2SM2	121	0.00700000000000000015
60437	M3	304.199999999999989	0.00700000000000000015
60437	L2	236.599999999999994	0.135000000000000009
60437	2MK3	11.3000000000000007	0.0330000000000000016
60437	K2	262.600000000000023	0.0389999999999999999
60437	M8	101.5	0.0100000000000000002
60437	MS4	355.899999999999977	0.0129999999999999994
60438	M2	248.5	1.3839999999999999
60438	S2	290.300000000000011	0.194000000000000006
60438	N2	240.800000000000011	0.23899999999999999
60438	K1	295.899999999999977	0.248999999999999999
60438	M4	349	0.128000000000000003
60438	O1	326.899999999999977	0.194000000000000006
60438	M6	96.4000000000000057	0.0850000000000000061
60438	S4	217.400000000000006	0.0160000000000000003
60438	NU2	241.800000000000011	0.0459999999999999992
60438	S6	339.300000000000011	0.00700000000000000015
60438	MU2	51.8999999999999986	0.0330000000000000016
60438	2N2	233.099999999999994	0.0330000000000000016
60438	OO1	264.899999999999977	0.0100000000000000002
60438	LDA2	267.899999999999977	0.0100000000000000002
60438	M1	311.199999999999989	0.0129999999999999994
60438	J1	280.5	0.0160000000000000003
60438	SSA	33.8999999999999986	0.120999999999999996
60438	SA	149.199999999999989	0.157000000000000001
60438	RHO1	340.199999999999989	0.00700000000000000015
60438	Q1	342.199999999999989	0.0359999999999999973
60438	T2	288.600000000000023	0.0129999999999999994
60438	R2	292	0.00300000000000000006
60438	2Q1	357.600000000000023	0.00700000000000000015
60438	P1	298.199999999999989	0.0820000000000000034
60438	L2	256.100000000000023	0.0389999999999999999
60438	K2	293.699999999999989	0.0519999999999999976
60438	M8	200.5	0.0259999999999999988
60439	M2	264.100000000000023	1.39100000000000001
60439	S2	315.399999999999977	0.173999999999999988
60439	N2	247.199999999999989	0.226000000000000006
60439	K1	308.399999999999977	0.200000000000000011
60439	M4	60.2999999999999972	0.171000000000000013
60439	O1	329.199999999999989	0.157000000000000001
60439	M6	145.599999999999994	0.0850000000000000061
60439	MK3	56.8999999999999986	0.0560000000000000012
60439	S4	80.4000000000000057	0.00300000000000000006
60439	MN4	43.6000000000000014	0.0589999999999999969
60439	NU2	244	0.0719999999999999946
60439	S6	323.699999999999989	0.00300000000000000006
60439	MU2	28.8999999999999986	0.0719999999999999946
60439	2N2	240.199999999999989	0.0459999999999999992
60439	LDA2	251.699999999999989	0.0589999999999999969
60439	S1	257.699999999999989	0.0589999999999999969
60439	M1	335.300000000000011	0.0100000000000000002
60439	J1	110.299999999999997	0.0100000000000000002
60439	MM	40.2000000000000028	0.248999999999999999
60439	SSA	78.7000000000000028	0.331000000000000016
60439	SA	295.800000000000011	0.176999999999999991
60439	MSF	321.300000000000011	0.245999999999999996
60439	MF	48.3999999999999986	0.0980000000000000038
60439	RHO1	285.399999999999977	0.00300000000000000006
60439	Q1	325.899999999999977	0.0229999999999999996
60439	T2	12.8000000000000007	0.0299999999999999989
60439	R2	262.199999999999989	0.0160000000000000003
60439	2Q1	216.900000000000006	0.0129999999999999994
60439	P1	292.399999999999977	0.0330000000000000016
60439	L2	290.100000000000023	0.143999999999999989
60439	2MK3	64	0.0589999999999999969
60439	K2	290.199999999999989	0.0389999999999999999
60439	M8	321	0.0359999999999999973
60439	MS4	115.5	0.0459999999999999992
60440	M2	46.7000000000000028	1.20100000000000007
60440	S2	74.5999999999999943	0.209999999999999992
60440	N2	28.3000000000000007	0.266000000000000014
60440	K1	200.900000000000006	0.161000000000000004
60440	M4	295.600000000000023	0.0129999999999999994
60440	O1	224.599999999999994	0.138000000000000012
60440	MK3	70	0.0100000000000000002
60440	NU2	26.6000000000000014	0.0519999999999999976
60440	MU2	50.3999999999999986	0.0330000000000000016
60440	2N2	15.9000000000000004	0.0359999999999999973
60440	OO1	177.099999999999994	0.00700000000000000015
60440	LDA2	55.8999999999999986	0.0229999999999999996
60440	S1	110.5	0.0200000000000000004
60440	M1	212.599999999999994	0.0100000000000000002
60440	J1	189.099999999999994	0.0100000000000000002
60440	SSA	33.8999999999999986	0.120999999999999996
60440	SA	149.199999999999989	0.157000000000000001
60440	RHO1	234.800000000000011	0.00700000000000000015
60440	Q1	210.300000000000011	0.0299999999999999989
60440	T2	59.8999999999999986	0.0200000000000000004
60440	R2	75.7000000000000028	0.00300000000000000006
60440	2Q1	248.099999999999994	0.00300000000000000006
60440	P1	199.099999999999994	0.0490000000000000019
60440	M3	125.099999999999994	0.0100000000000000002
60440	L2	45.5	0.0389999999999999999
60440	K2	67.7000000000000028	0.0589999999999999969
60441	M2	51.6000000000000014	1.32200000000000006
60441	S2	81.5999999999999943	0.23899999999999999
60441	N2	38.2999999999999972	0.288999999999999979
60441	K1	201.099999999999994	0.179999999999999993
60441	M4	23.3999999999999986	0.0160000000000000003
60441	O1	222.199999999999989	0.140999999999999986
60441	M6	98.0999999999999943	0.0160000000000000003
60441	MK3	90.7000000000000028	0.0160000000000000003
60441	S4	358.300000000000011	0.0200000000000000004
60441	MN4	339	0.0129999999999999994
60441	NU2	27.6000000000000014	0.0560000000000000012
60441	S6	325.600000000000023	0.00300000000000000006
60441	MU2	72.0999999999999943	0.0330000000000000016
60441	2N2	12	0.0330000000000000016
60441	OO1	193	0.0100000000000000002
60441	LDA2	57	0.0229999999999999996
60441	S1	94	0.0330000000000000016
60441	M1	233.699999999999989	0.0100000000000000002
60441	J1	207	0.0129999999999999994
60441	SSA	33.8999999999999986	0.120999999999999996
60441	SA	149.199999999999989	0.157000000000000001
60441	RHO1	251.800000000000011	0.0200000000000000004
60441	Q1	202.099999999999994	0.0359999999999999973
60441	T2	68.7999999999999972	0.0229999999999999996
60441	R2	355.399999999999977	0.0100000000000000002
60441	2Q1	146.199999999999989	0.00700000000000000015
60441	P1	192.699999999999989	0.0490000000000000019
60441	2SM2	53.2000000000000028	0.00300000000000000006
60441	M3	131.300000000000011	0.0100000000000000002
60441	L2	30.6999999999999993	0.0519999999999999976
60441	2MK3	86.7999999999999972	0.0160000000000000003
60441	K2	78.5999999999999943	0.0660000000000000031
60441	M8	357.300000000000011	0.00300000000000000006
60441	MS4	211.199999999999989	0.0100000000000000002
60442	M2	52.3999999999999986	1.27299999999999991
60442	S2	78.7000000000000028	0.223000000000000004
60442	N2	36.2000000000000028	0.301999999999999991
60442	K1	194.199999999999989	0.173999999999999988
60442	M4	344.699999999999989	0.0259999999999999988
60442	O1	227.900000000000006	0.135000000000000009
60442	M6	78.4000000000000057	0.0200000000000000004
60442	MK3	82	0.0200000000000000004
60442	S4	47.7999999999999972	0.0100000000000000002
60442	MN4	335.399999999999977	0.0229999999999999996
60442	NU2	30.8000000000000007	0.0519999999999999976
60442	MU2	64.7000000000000028	0.0389999999999999999
60442	2N2	17.1999999999999993	0.0330000000000000016
60442	OO1	212.099999999999994	0.0160000000000000003
60442	LDA2	85.2000000000000028	0.0160000000000000003
60442	S1	70.5	0.0200000000000000004
60442	M1	246.599999999999994	0.0129999999999999994
60442	J1	289.399999999999977	0.00300000000000000006
60442	SSA	33.8999999999999986	0.120999999999999996
60442	SA	149.199999999999989	0.157000000000000001
60442	RHO1	251.699999999999989	0.00300000000000000006
60442	Q1	224.099999999999994	0.0299999999999999989
60442	T2	68.5	0.0359999999999999973
60442	R2	117.400000000000006	0.0200000000000000004
60442	2Q1	77.7999999999999972	0.00300000000000000006
60442	P1	187.800000000000011	0.0490000000000000019
60442	2SM2	184.599999999999994	0.00300000000000000006
60442	M3	106.799999999999997	0.00300000000000000006
60442	L2	37.2999999999999972	0.0850000000000000061
60442	2MK3	77.7000000000000028	0.0200000000000000004
60442	K2	83.7999999999999972	0.0660000000000000031
60442	M8	58.6000000000000014	0.00300000000000000006
60442	MS4	226.900000000000006	0.00700000000000000015
60443	M2	21	1.24700000000000011
60443	S2	45.7999999999999972	0.226000000000000006
60443	N2	1.39999999999999991	0.294999999999999984
60443	K1	184.900000000000006	0.190000000000000002
60443	M4	199.699999999999989	0.0160000000000000003
60443	O1	208.900000000000006	0.147999999999999993
60443	M6	293.399999999999977	0.0200000000000000004
60443	MN4	199.199999999999989	0.0100000000000000002
60443	NU2	359.199999999999989	0.0560000000000000012
60443	MU2	13.6999999999999993	0.0389999999999999999
60443	2N2	347.399999999999977	0.0429999999999999966
60443	OO1	215.199999999999989	0.0100000000000000002
60443	LDA2	35.7000000000000028	0.0100000000000000002
60443	S1	83.2999999999999972	0.0359999999999999973
60443	M1	204	0.0129999999999999994
60443	J1	201.5	0.0129999999999999994
60443	SSA	34	0.138000000000000012
60443	SA	152	0.179999999999999993
60443	RHO1	201.099999999999994	0.0100000000000000002
60443	Q1	191.099999999999994	0.0299999999999999989
60443	T2	35.7000000000000028	0.0200000000000000004
60443	R2	46.8999999999999986	0.00300000000000000006
60443	2Q1	232.599999999999994	0.00300000000000000006
60443	P1	188.099999999999994	0.0589999999999999969
60443	L2	28.8000000000000007	0.0459999999999999992
60443	K2	46.3999999999999986	0.0619999999999999996
60443	MS4	147.5	0.0100000000000000002
60444	M2	22.1000000000000014	1.27000000000000002
60444	S2	46.7000000000000028	0.235999999999999988
60444	N2	1.80000000000000004	0.298999999999999988
60444	K1	186.800000000000011	0.194000000000000006
60444	M4	236.800000000000011	0.0200000000000000004
60444	O1	208.599999999999994	0.161000000000000004
60444	M6	287.5	0.0129999999999999994
60444	MK3	50.2999999999999972	0.00700000000000000015
60444	S4	280.5	0.0129999999999999994
60444	MN4	222.599999999999994	0.0160000000000000003
60444	NU2	1.80000000000000004	0.0560000000000000012
60444	S6	198.199999999999989	0.00700000000000000015
60444	MU2	6.90000000000000036	0.0359999999999999973
60444	2N2	346.899999999999977	0.0490000000000000019
60444	OO1	230.400000000000006	0.0100000000000000002
60444	LDA2	26.8000000000000007	0.0160000000000000003
60444	S1	115.400000000000006	0.0160000000000000003
60444	M1	200.300000000000011	0.0259999999999999988
60444	J1	199.400000000000006	0.0129999999999999994
60444	SSA	34	0.138000000000000012
60444	SA	152	0.179999999999999993
60444	RHO1	167.699999999999989	0.0129999999999999994
60444	Q1	201.800000000000011	0.0389999999999999999
60444	T2	49.2000000000000028	0.0200000000000000004
60444	R2	314.800000000000011	0.00700000000000000015
60444	2Q1	353.100000000000023	0.00300000000000000006
60444	P1	185	0.0560000000000000012
60444	M3	58.1000000000000014	0.0129999999999999994
60444	L2	49.3999999999999986	0.0459999999999999992
60444	2MK3	69	0.0100000000000000002
60444	K2	49.6000000000000014	0.0660000000000000031
60444	M8	339.100000000000023	0.00300000000000000006
60444	MS4	170.599999999999994	0.0129999999999999994
60445	M2	5.59999999999999964	1.59099999999999997
60445	S2	29.8999999999999986	0.291999999999999982
60445	N2	345.600000000000023	0.350999999999999979
60445	K1	175.5	0.245999999999999996
60445	M4	201.800000000000011	0.0200000000000000004
60445	O1	201	0.183999999999999997
60445	M6	278.899999999999977	0.0259999999999999988
60445	S4	250.400000000000006	0.0129999999999999994
60445	MN4	190.5	0.0100000000000000002
60445	NU2	343.800000000000011	0.0619999999999999996
60445	S6	145.900000000000006	0.00300000000000000006
60445	MU2	1.19999999999999996	0.0660000000000000031
60445	2N2	332.600000000000023	0.0389999999999999999
60445	OO1	203.699999999999989	0.0129999999999999994
60445	LDA2	24	0.0129999999999999994
60445	S1	126.799999999999997	0.0389999999999999999
60445	M1	250.099999999999994	0.0100000000000000002
60445	J1	202.699999999999989	0.0100000000000000002
60445	SSA	37.2000000000000028	0.120999999999999996
60445	SA	169.5	0.194000000000000006
60445	RHO1	95.5999999999999943	0.0100000000000000002
60445	Q1	178.099999999999994	0.0459999999999999992
60445	T2	8.09999999999999964	0.0259999999999999988
60445	R2	255.800000000000011	0.00700000000000000015
60445	2Q1	169.800000000000011	0.0129999999999999994
60445	P1	179.800000000000011	0.0820000000000000034
60445	2SM2	14.1999999999999993	0.00700000000000000015
60445	M3	45.8999999999999986	0.0160000000000000003
60445	L2	45.3999999999999986	0.0129999999999999994
60445	2MK3	203.599999999999994	0.00300000000000000006
60445	K2	26.6999999999999993	0.0749999999999999972
60445	M8	358.600000000000023	0.00300000000000000006
60445	MS4	94.4000000000000057	0.0129999999999999994
60446	M2	54.1000000000000014	1.37799999999999989
60446	S2	81.7000000000000028	0.23899999999999999
60446	N2	35.1000000000000014	0.304999999999999993
60446	K1	201.199999999999989	0.171000000000000013
60446	M4	4.20000000000000018	0.0100000000000000002
60446	O1	226.5	0.140999999999999986
60446	M6	112.900000000000006	0.0200000000000000004
60446	MK3	73	0.0129999999999999994
60446	S4	16	0.0129999999999999994
60446	MN4	327.100000000000023	0.0100000000000000002
60446	NU2	32.2000000000000028	0.0589999999999999969
60446	MU2	71.7000000000000028	0.0389999999999999999
60446	2N2	23.5	0.0389999999999999999
60446	OO1	243.400000000000006	0.0100000000000000002
60446	LDA2	62.5	0.0259999999999999988
60446	S1	101	0.0359999999999999973
60446	M1	213.800000000000011	0.0100000000000000002
60446	J1	188.699999999999989	0.0100000000000000002
60446	SSA	9.19999999999999929	0.16700000000000001
60446	SA	134	0.233000000000000013
60446	RHO1	237.300000000000011	0.00700000000000000015
60446	Q1	218.5	0.0299999999999999989
60446	T2	69.0999999999999943	0.0229999999999999996
60446	R2	82.9000000000000057	0.00300000000000000006
60446	2Q1	251.5	0.00300000000000000006
60446	P1	198.300000000000011	0.0490000000000000019
60446	M3	120.099999999999994	0.0100000000000000002
60446	L2	64.2999999999999972	0.0690000000000000058
60446	2MK3	103.299999999999997	0.0129999999999999994
60446	K2	82.2999999999999972	0.0660000000000000031
60446	MS4	225.099999999999994	0.0129999999999999994
60447	M2	358	1.6080000000000001
60447	S2	22.1000000000000014	0.288999999999999979
60447	N2	337.800000000000011	0.373999999999999999
60447	K1	172.900000000000006	0.284999999999999976
60447	M4	224.300000000000011	0.0129999999999999994
60447	O1	192.599999999999994	0.194000000000000006
60447	M6	228.099999999999994	0.0330000000000000016
60447	MN4	188.599999999999994	0.0100000000000000002
60447	NU2	336.899999999999977	0.0749999999999999972
60447	MU2	343.899999999999977	0.0560000000000000012
60447	2N2	321.600000000000023	0.0490000000000000019
60447	OO1	193.900000000000006	0.0100000000000000002
60447	LDA2	14.9000000000000004	0.0129999999999999994
60447	S1	96.7999999999999972	0.0359999999999999973
60447	M1	194.099999999999994	0.0100000000000000002
60447	J1	175	0.0160000000000000003
60447	SSA	37.2000000000000028	0.120999999999999996
60447	SA	169.5	0.194000000000000006
60447	RHO1	201.099999999999994	0.00700000000000000015
60447	Q1	178.400000000000006	0.0459999999999999992
60447	T2	351.800000000000011	0.0299999999999999989
60447	R2	23.1000000000000014	0.00300000000000000006
60447	2Q1	212.099999999999994	0.00700000000000000015
60447	P1	173.699999999999989	0.0919999999999999984
60447	M3	36.7000000000000028	0.0129999999999999994
60447	L2	22.3000000000000007	0.0299999999999999989
60447	K2	18.1999999999999993	0.0749999999999999972
60448	M2	87.7999999999999972	0.0790000000000000008
60448	S2	142	0.0229999999999999996
60448	N2	78.4000000000000057	0.0129999999999999994
60448	K1	341.300000000000011	0.0429999999999999966
60448	M4	79.5999999999999943	0.00700000000000000015
60448	O1	256.899999999999977	0.0200000000000000004
60448	M6	320.399999999999977	0.00700000000000000015
60448	NU2	80.2000000000000028	0.00300000000000000006
60448	MU2	234.900000000000006	0.00300000000000000006
60448	MM	18.3999999999999986	0.0660000000000000031
60448	SSA	10.5	0.0850000000000000061
60448	SA	158.900000000000006	0.150999999999999995
60448	Q1	277.899999999999977	0.00300000000000000006
60448	P1	341	0.0129999999999999994
60448	L2	92.4000000000000057	0.00300000000000000006
60448	K2	146.300000000000011	0.00700000000000000015
60449	M2	82.5	0.117999999999999994
60449	S2	162.199999999999989	0.0200000000000000004
60449	N2	66.9000000000000057	0.0200000000000000004
60449	K1	308.5	0.0229999999999999996
60449	M4	72.2000000000000028	0.0100000000000000002
60449	O1	233.900000000000006	0.0359999999999999973
60449	M6	268.300000000000011	0.00700000000000000015
60449	S4	293.399999999999977	0.00300000000000000006
60449	NU2	69.7999999999999972	0.00300000000000000006
60449	MU2	215.699999999999989	0.00300000000000000006
60449	J1	305.100000000000023	0.00300000000000000006
60449	SSA	10.5	0.0850000000000000061
60449	SA	158.900000000000006	0.150999999999999995
60449	RHO1	262.699999999999989	0.00300000000000000006
60449	Q1	265.899999999999977	0.00700000000000000015
60449	P1	308.100000000000023	0.00700000000000000015
60449	L2	85.2000000000000028	0.00300000000000000006
60449	K2	168.099999999999994	0.00300000000000000006
60450	M2	81.0999999999999943	0.125
60450	S2	158.699999999999989	0.0200000000000000004
60450	N2	65.9000000000000057	0.0229999999999999996
60450	K1	336.199999999999989	0.0259999999999999988
60450	M4	69.2999999999999972	0.0100000000000000002
60450	O1	239.099999999999994	0.0299999999999999989
60450	M6	270.100000000000023	0.00700000000000000015
60450	NU2	68.2999999999999972	0.00300000000000000006
60450	MU2	210.400000000000006	0.00300000000000000006
60450	2N2	39.2000000000000028	0.00300000000000000006
60450	J1	322.5	0.00300000000000000006
60450	SSA	10.5	0.0850000000000000061
60450	SA	158.900000000000006	0.150999999999999995
60450	Q1	269.399999999999977	0.00700000000000000015
60450	P1	339.300000000000011	0.00700000000000000015
60450	L2	92.2000000000000028	0.00300000000000000006
60450	K2	164.300000000000011	0.00700000000000000015
60451	M2	16.6000000000000014	0.394000000000000017
60451	S2	32.5	0.0619999999999999996
60451	N2	358.899999999999977	0.0919999999999999984
60451	K1	190.900000000000006	0.0919999999999999984
60451	M4	346.300000000000011	0.0299999999999999989
60451	O1	194.099999999999994	0.0660000000000000031
60451	M6	209.5	0.0129999999999999994
60451	MK3	166.099999999999994	0.0129999999999999994
60451	MN4	327.899999999999977	0.0100000000000000002
60451	NU2	351.5	0.0200000000000000004
60451	MU2	27.3999999999999986	0.0129999999999999994
60451	2N2	351.699999999999989	0.0129999999999999994
60451	OO1	175	0.00300000000000000006
60451	LDA2	41	0.00700000000000000015
60451	S1	248.900000000000006	0.0389999999999999999
60451	M1	210.300000000000011	0.00700000000000000015
60451	J1	211.199999999999989	0.0100000000000000002
60451	MM	56.5	0.0619999999999999996
60451	SSA	56.8999999999999986	0.104999999999999996
60451	SA	154.599999999999994	0.242999999999999994
60451	RHO1	218.400000000000006	0.00700000000000000015
60451	Q1	219.800000000000011	0.0100000000000000002
60451	T2	14.4000000000000004	0.00700000000000000015
60451	R2	238.199999999999989	0.0100000000000000002
60451	2Q1	336.899999999999977	0.00300000000000000006
60451	P1	218.599999999999994	0.0429999999999999966
60451	2SM2	332.199999999999989	0.00300000000000000006
60451	M3	356.300000000000011	0.00300000000000000006
60451	L2	34.2000000000000028	0.0100000000000000002
60451	2MK3	185.5	0.00700000000000000015
60451	K2	23.3999999999999986	0.0129999999999999994
60451	M8	194.199999999999989	0.00300000000000000006
60451	MS4	28.1999999999999993	0.0129999999999999994
60452	M2	0	1.04000000000000004
60452	S2	24.8999999999999986	0.194000000000000006
60452	N2	341.800000000000011	0.223000000000000004
60452	K1	179.800000000000011	0.245999999999999996
60452	M4	176.900000000000006	0.0100000000000000002
60452	O1	183.800000000000011	0.135000000000000009
60452	M6	205	0.0200000000000000004
60452	S4	342.100000000000023	0.00300000000000000006
60452	NU2	344.199999999999989	0.0429999999999999966
60452	S6	106	0.00300000000000000006
60452	MU2	335.699999999999989	0.0259999999999999988
60452	2N2	323.5	0.0299999999999999989
60452	OO1	176.5	0.00700000000000000015
60452	LDA2	11.4000000000000004	0.00700000000000000015
60452	M1	181.900000000000006	0.0100000000000000002
60452	J1	177.5	0.0100000000000000002
60452	MM	18.3999999999999986	0.0660000000000000031
60452	SSA	10.5	0.0850000000000000061
60452	SA	158.900000000000006	0.150999999999999995
60452	RHO1	185.5	0.00700000000000000015
60452	Q1	185.800000000000011	0.0259999999999999988
60452	T2	24.1999999999999993	0.0100000000000000002
60452	2Q1	187.199999999999989	0.00300000000000000006
60452	P1	180.199999999999989	0.0820000000000000034
60452	L2	18.1999999999999993	0.0299999999999999989
60452	K2	26.8999999999999986	0.0519999999999999976
60452	M8	190.599999999999994	0.00300000000000000006
60453	M2	89.2000000000000028	0.143999999999999989
60453	S2	106.099999999999994	0.0229999999999999996
60453	N2	37.5	0.0359999999999999973
60453	K1	292.600000000000023	0.0820000000000000034
60453	M4	140.099999999999994	0.0100000000000000002
60453	O1	226	0.0229999999999999996
60453	M6	17.6000000000000014	0.00300000000000000006
60453	S4	289.600000000000023	0.00300000000000000006
60453	NU2	43.7000000000000028	0.00700000000000000015
60453	MU2	62.1000000000000014	0.00300000000000000006
60453	2N2	335.800000000000011	0.00300000000000000006
60453	M1	270.300000000000011	0.00300000000000000006
60453	J1	312.899999999999977	0.00300000000000000006
60453	Q1	143.699999999999989	0.00300000000000000006
60453	T2	92.2999999999999972	0.00300000000000000006
60453	P1	289.399999999999977	0.0259999999999999988
60453	L2	137.099999999999994	0.00300000000000000006
60453	K2	109.099999999999994	0.00700000000000000015
60453	M8	48.1000000000000014	0.00300000000000000006
60454	M2	353.199999999999989	1.48599999999999999
60454	S2	16.1999999999999993	0.269000000000000017
60454	N2	331.300000000000011	0.347999999999999976
60454	K1	184.599999999999994	0.307999999999999996
60454	O1	186.400000000000006	0.245999999999999996
60454	M6	170.099999999999994	0.0129999999999999994
60454	NU2	335.100000000000023	0.0690000000000000058
60454	MU2	333	0.0519999999999999976
60454	2N2	312.300000000000011	0.0459999999999999992
60454	OO1	205.900000000000006	0.0100000000000000002
60454	LDA2	2.39999999999999991	0.0129999999999999994
60454	S1	192.300000000000011	0.0259999999999999988
60454	M1	196.599999999999994	0.0129999999999999994
60454	J1	192.199999999999989	0.0200000000000000004
60454	SSA	56.8999999999999986	0.128000000000000003
60454	SA	171.699999999999989	0.20699999999999999
60454	RHO1	192.300000000000011	0.0129999999999999994
60454	Q1	180.800000000000011	0.0490000000000000019
60454	T2	358.899999999999977	0.0229999999999999996
60454	R2	17.1000000000000014	0.00300000000000000006
60454	2Q1	188.199999999999989	0.00700000000000000015
60454	P1	186.300000000000011	0.101999999999999993
60454	L2	31.1999999999999993	0.0299999999999999989
60454	K2	16.6999999999999993	0.0690000000000000058
60455	M2	37.2000000000000028	0.138000000000000012
60455	S2	73.7999999999999972	0.0259999999999999988
60455	N2	16.5	0.0330000000000000016
60455	K1	248.599999999999994	0.0330000000000000016
60455	M4	322.600000000000023	0.0129999999999999994
60455	O1	214.699999999999989	0.0299999999999999989
60455	M6	148.800000000000011	0.0100000000000000002
60455	MK3	169.300000000000011	0.00700000000000000015
60455	S4	62	0.00300000000000000006
60455	MN4	314	0.00700000000000000015
60455	NU2	12.0999999999999996	0.00700000000000000015
60455	S6	248.5	0.00300000000000000006
60455	2N2	10	0.00300000000000000006
60455	OO1	234.199999999999989	0.00300000000000000006
60455	S1	346.300000000000011	0.0330000000000000016
60455	J1	275.699999999999989	0.00300000000000000006
60455	MM	63.2999999999999972	0.0980000000000000038
60455	SSA	7.09999999999999964	0.143999999999999989
60455	RHO1	147.699999999999989	0.00300000000000000006
60455	Q1	166.5	0.0100000000000000002
60455	T2	256.699999999999989	0.00700000000000000015
60455	R2	47.2999999999999972	0.00700000000000000015
60455	2Q1	69.9000000000000057	0.00300000000000000006
60455	P1	258.600000000000023	0.0160000000000000003
60455	L2	56.2000000000000028	0.00700000000000000015
60455	2MK3	177	0.00300000000000000006
60455	K2	26	0.00700000000000000015
60455	M8	166	0.00300000000000000006
60455	MS4	340.699999999999989	0.00300000000000000006
60456	M2	5.5	0.443000000000000005
60456	S2	34.6000000000000014	0.0749999999999999972
60456	N2	347.5	0.117999999999999994
60456	K1	191.699999999999989	0.0980000000000000038
60456	M4	338.399999999999977	0.0359999999999999973
60456	O1	198.599999999999994	0.0850000000000000061
60456	M6	210.400000000000006	0.0160000000000000003
60456	NU2	349.899999999999977	0.0229999999999999996
60456	MU2	336.300000000000011	0.0100000000000000002
60456	2N2	329.600000000000023	0.0160000000000000003
60456	OO1	184.699999999999989	0.00300000000000000006
60456	LDA2	18.8999999999999986	0.00300000000000000006
60456	M1	195	0.00700000000000000015
60456	J1	188.199999999999989	0.00700000000000000015
60456	RHO1	201.5	0.00300000000000000006
60456	Q1	201.900000000000006	0.0160000000000000003
60456	T2	33.3999999999999986	0.00700000000000000015
60456	2Q1	205.400000000000006	0.00300000000000000006
60456	P1	192.099999999999994	0.0330000000000000016
60456	L2	23.3000000000000007	0.0160000000000000003
60456	K2	37	0.0200000000000000004
60457	M2	119.799999999999997	0.266000000000000014
60457	S2	152.699999999999989	0.0389999999999999999
60457	N2	63.8999999999999986	0.0459999999999999992
60457	K1	269.300000000000011	0.0950000000000000011
60457	M4	172.699999999999989	0.0299999999999999989
60457	O1	265.399999999999977	0.0980000000000000038
60457	M6	87.7999999999999972	0.00700000000000000015
60457	S4	13.5999999999999996	0.00300000000000000006
60457	NU2	71.4000000000000057	0.0100000000000000002
60457	S6	81.0999999999999943	0.00300000000000000006
60457	MU2	294.199999999999989	0.00700000000000000015
60457	2N2	8	0.00700000000000000015
60457	OO1	273.199999999999989	0.00300000000000000006
60457	LDA2	135.099999999999994	0.00300000000000000006
60457	M1	267.399999999999977	0.00700000000000000015
60457	J1	271.199999999999989	0.00700000000000000015
60457	RHO1	263.800000000000011	0.00300000000000000006
60457	Q1	263.5	0.0200000000000000004
60457	T2	151.400000000000006	0.00300000000000000006
60457	2Q1	261.600000000000023	0.00300000000000000006
60457	P1	269	0.0330000000000000016
60457	L2	175.699999999999989	0.00700000000000000015
60457	K2	155.400000000000006	0.0100000000000000002
60457	M8	138.699999999999989	0.00300000000000000006
60458	M2	87.4000000000000057	0.505000000000000004
60458	S2	126.700000000000003	0.0690000000000000058
60458	N2	68.7000000000000028	0.0919999999999999984
60458	K1	244.800000000000011	0.131000000000000005
60458	M4	101.799999999999997	0.0359999999999999973
60458	O1	253.800000000000011	0.125
60458	M6	313.300000000000011	0.0100000000000000002
60458	S4	65	0.00700000000000000015
60458	NU2	71.2000000000000028	0.0160000000000000003
60458	S6	34.1000000000000014	0.00300000000000000006
60458	MU2	45.8999999999999986	0.0129999999999999994
60458	2N2	50.1000000000000014	0.0129999999999999994
60458	OO1	234.400000000000006	0.00700000000000000015
60458	LDA2	106.700000000000003	0.00300000000000000006
60458	M1	249.099999999999994	0.0100000000000000002
60458	J1	239.699999999999989	0.0100000000000000002
60458	SSA	57.1000000000000014	0.117999999999999994
60458	SA	166	0.216999999999999998
60458	RHO1	258.199999999999989	0.00300000000000000006
60458	Q1	258.5	0.0229999999999999996
60458	T2	125.200000000000003	0.00300000000000000006
60458	2Q1	262.399999999999977	0.00300000000000000006
60458	P1	245.5	0.0429999999999999966
60458	L2	106	0.0129999999999999994
60458	K2	129.800000000000011	0.0200000000000000004
60458	M8	305	0.00300000000000000006
60459	M2	53.2999999999999972	0.76100000000000001
60459	S2	68	0.0950000000000000011
60459	N2	36.8999999999999986	0.153999999999999998
60459	K1	229.800000000000011	0.209999999999999992
60459	M4	346.100000000000023	0.0459999999999999992
60459	O1	230.800000000000011	0.16700000000000001
60459	M6	199.900000000000006	0.0229999999999999996
60459	S4	300.800000000000011	0.0100000000000000002
60459	NU2	39.1000000000000014	0.0299999999999999989
60459	S6	269.600000000000023	0.00300000000000000006
60459	MU2	38.5	0.0200000000000000004
60459	2N2	20.5	0.0200000000000000004
60459	OO1	228.900000000000006	0.00700000000000000015
60459	LDA2	60.1000000000000014	0.00700000000000000015
60459	M1	230.300000000000011	0.0129999999999999994
60459	J1	229.400000000000006	0.0129999999999999994
60459	SSA	57.1000000000000014	0.117999999999999994
60459	SA	166	0.216999999999999998
60459	RHO1	231.199999999999989	0.00700000000000000015
60459	Q1	231.199999999999989	0.0330000000000000016
60459	T2	67.4000000000000057	0.00700000000000000015
60459	2Q1	231.699999999999989	0.00300000000000000006
60459	P1	229.900000000000006	0.0690000000000000058
60459	L2	69.5999999999999943	0.0200000000000000004
60459	K2	69.2000000000000028	0.0259999999999999988
60459	M8	169.800000000000011	0.0100000000000000002
60460	M2	6.40000000000000036	1.496
60460	S2	30	0.235999999999999988
60460	N2	349.399999999999977	0.33500000000000002
60460	K1	197.800000000000011	0.269000000000000017
60460	M4	294.800000000000011	0.0129999999999999994
60460	O1	205	0.209999999999999992
60460	M6	54.3999999999999986	0.0229999999999999996
60460	MK3	15.5	0.0100000000000000002
60460	S4	302.300000000000011	0.0200000000000000004
60460	MN4	228.599999999999994	0.0100000000000000002
60460	NU2	345.600000000000023	0.0660000000000000031
60460	S6	140.800000000000011	0.00300000000000000006
60460	MU2	14.6999999999999993	0.0359999999999999973
60460	2N2	338.399999999999977	0.0459999999999999992
60460	OO1	218.400000000000006	0.0100000000000000002
60460	LDA2	6.70000000000000018	0.0200000000000000004
60460	S1	178.099999999999994	0.0330000000000000016
60460	M1	222.199999999999989	0.0100000000000000002
60460	J1	198.699999999999989	0.0160000000000000003
60460	SSA	43.7000000000000028	0.16700000000000001
60460	SA	166.400000000000006	0.298999999999999988
60460	RHO1	209.599999999999994	0.0100000000000000002
60460	Q1	199.599999999999994	0.0429999999999999966
60460	T2	15.3000000000000007	0.0229999999999999996
60460	R2	243.099999999999994	0.0129999999999999994
60460	2Q1	187.599999999999994	0.00700000000000000015
60460	P1	198.800000000000011	0.0889999999999999958
60460	2SM2	28.6999999999999993	0.00700000000000000015
60460	M3	33.7000000000000028	0.0160000000000000003
60460	L2	8	0.0660000000000000031
60460	2MK3	17	0.0129999999999999994
60460	K2	27.3000000000000007	0.0660000000000000031
60460	M8	118.200000000000003	0.00700000000000000015
60460	MS4	132.199999999999989	0.0200000000000000004
60461	M2	350.800000000000011	1.79800000000000004
60461	S2	10.9000000000000004	0.312
60461	N2	329.5	0.426999999999999991
60461	K1	185.400000000000006	0.304999999999999993
60461	M4	236.199999999999989	0.0160000000000000003
60461	O1	190.800000000000011	0.23899999999999999
60461	M6	254.300000000000011	0.0200000000000000004
60461	S4	265.899999999999977	0.0330000000000000016
60461	NU2	330.800000000000011	0.0820000000000000034
60461	MU2	336.600000000000023	0.0660000000000000031
60461	2N2	310.199999999999989	0.0519999999999999976
60461	OO1	201	0.0160000000000000003
60461	LDA2	15.0999999999999996	0.0160000000000000003
60461	S1	162	0.0389999999999999999
60461	J1	192.099999999999994	0.0200000000000000004
60461	SSA	57.1000000000000014	0.117999999999999994
60461	SA	166	0.216999999999999998
60461	RHO1	170.099999999999994	0.0100000000000000002
60461	Q1	184.199999999999989	0.0490000000000000019
60461	T2	359.5	0.0299999999999999989
60461	R2	237.300000000000011	0.0129999999999999994
60461	P1	187.900000000000006	0.104999999999999996
60461	2SM2	6.70000000000000018	0.0100000000000000002
60461	M3	14	0.0259999999999999988
60461	L2	20.1000000000000014	0.0459999999999999992
60461	2MK3	50	0.0129999999999999994
60461	K2	16.1000000000000014	0.0790000000000000008
60461	M8	169.300000000000011	0.00300000000000000006
60461	MS4	113.200000000000003	0.0359999999999999973
60462	M2	348.399999999999977	1.77200000000000002
60462	S2	11.3000000000000007	0.338000000000000023
60462	N2	328.699999999999989	0.412999999999999978
60462	K1	171.699999999999989	0.301999999999999991
60462	M4	267.300000000000011	0.0200000000000000004
60462	O1	194.900000000000006	0.253000000000000003
60462	M6	252	0.0229999999999999996
60462	S4	326.800000000000011	0.0299999999999999989
60462	NU2	331.300000000000011	0.0790000000000000008
60462	S6	54.8999999999999986	0.0100000000000000002
60462	MU2	325.399999999999977	0.0429999999999999966
60462	2N2	308.800000000000011	0.0560000000000000012
60462	OO1	148.5	0.0100000000000000002
60462	LDA2	359.100000000000023	0.0129999999999999994
60462	M1	183.199999999999989	0.0160000000000000003
60462	J1	160.199999999999989	0.0200000000000000004
60462	SSA	57.1000000000000014	0.117999999999999994
60462	SA	166	0.216999999999999998
60462	RHO1	204.900000000000006	0.0100000000000000002
60462	Q1	206.5	0.0490000000000000019
60462	T2	10.4000000000000004	0.0200000000000000004
60462	R2	12.4000000000000004	0.00300000000000000006
60462	2Q1	218	0.00700000000000000015
60462	P1	173.400000000000006	0.0980000000000000038
60462	L2	8.40000000000000036	0.0490000000000000019
60462	K2	13.1999999999999993	0.0919999999999999984
60462	M8	2	0.00300000000000000006
60463	M2	63.1000000000000014	2.04400000000000004
60463	S2	97.7000000000000028	0.259000000000000008
60463	N2	51	0.412999999999999978
60463	K1	229.800000000000011	0.262000000000000011
60463	M4	6.90000000000000036	0.176999999999999991
60463	O1	233.5	0.197000000000000008
60463	M6	284.199999999999989	0.107999999999999999
60463	MK3	109.799999999999997	0.0429999999999999966
60463	S4	126.799999999999997	0.0129999999999999994
60463	MN4	355.800000000000011	0.0749999999999999972
60463	NU2	41.5	0.0919999999999999984
60463	MU2	150.300000000000011	0.0749999999999999972
60463	2N2	44.5	0.0459999999999999992
60463	OO1	245.400000000000006	0.0100000000000000002
60463	LDA2	56.6000000000000014	0.0619999999999999996
60463	S1	199.300000000000011	0.0690000000000000058
60463	M1	221.800000000000011	0.0100000000000000002
60463	J1	263.600000000000023	0.0160000000000000003
60463	MM	16.3000000000000007	0.0749999999999999972
60463	SSA	24.8999999999999986	0.16700000000000001
60463	MSF	36.6000000000000014	0.0660000000000000031
60463	RHO1	235.099999999999994	0.00700000000000000015
60463	Q1	237.5	0.0429999999999999966
60463	T2	82.5	0.0299999999999999989
60463	R2	99.2000000000000028	0.00300000000000000006
60463	2Q1	237.199999999999989	0.00700000000000000015
60463	P1	236.599999999999994	0.0919999999999999984
60463	M3	147.599999999999994	0.0259999999999999988
60463	L2	58.8999999999999986	0.187
60463	2MK3	100.400000000000006	0.0490000000000000019
60463	K2	95	0.0749999999999999972
60463	M8	253.599999999999994	0.0160000000000000003
60463	MS4	30	0.0589999999999999969
60464	M2	353.100000000000023	1.94599999999999995
60464	S2	14.0999999999999996	0.338000000000000023
60464	N2	333.699999999999989	0.466000000000000025
60464	K1	186.400000000000006	0.315000000000000002
60464	M4	267.699999999999989	0.0359999999999999973
60464	O1	192.599999999999994	0.226000000000000006
60464	M6	25.3999999999999986	0.0200000000000000004
60464	S4	307.399999999999977	0.0359999999999999973
60464	MN4	242.099999999999994	0.0299999999999999989
60464	NU2	331.199999999999989	0.0889999999999999958
60464	MU2	338.600000000000023	0.0690000000000000058
60464	2N2	317.600000000000023	0.0619999999999999996
60464	LDA2	4.5	0.0160000000000000003
60464	S1	136.5	0.0330000000000000016
60464	J1	177.699999999999989	0.0200000000000000004
60464	SSA	50.2999999999999972	0.194000000000000006
60464	SA	165	0.353999999999999981
60464	RHO1	175.300000000000011	0.0160000000000000003
60464	Q1	186.099999999999994	0.0490000000000000019
60464	T2	355.699999999999989	0.0330000000000000016
60464	P1	187.5	0.107999999999999999
60464	M3	25.1000000000000014	0.0359999999999999973
60464	L2	358.300000000000011	0.0619999999999999996
60464	K2	13.1999999999999993	0.0889999999999999958
60464	MS4	154.300000000000011	0.0299999999999999989
60465	M2	38	1.89300000000000002
60465	S2	64	0.259000000000000008
60465	N2	25	0.412999999999999978
60465	K1	202.900000000000006	0.33500000000000002
60465	M4	340.300000000000011	0.0749999999999999972
60465	O1	225.199999999999989	0.190000000000000002
60465	M6	169	0.0660000000000000031
60465	S4	17	0.00300000000000000006
60465	NU2	26.8000000000000007	0.0820000000000000034
60465	S6	352.199999999999989	0.00300000000000000006
60465	MU2	12.1999999999999993	0.0459999999999999992
60465	2N2	11.9000000000000004	0.0560000000000000012
60465	OO1	184.900000000000006	0.00700000000000000015
60465	LDA2	50	0.0129999999999999994
60465	M1	214.5	0.0129999999999999994
60465	J1	193.300000000000011	0.0160000000000000003
60465	MM	16.3000000000000007	0.0749999999999999972
60465	SSA	24.8999999999999986	0.16700000000000001
60465	MSF	36.6000000000000014	0.0660000000000000031
60465	RHO1	234.599999999999994	0.00700000000000000015
60465	Q1	235.599999999999994	0.0359999999999999973
60465	T2	63.1000000000000014	0.0160000000000000003
60465	R2	64.7999999999999972	0.00300000000000000006
60465	2Q1	246	0.00700000000000000015
60465	P1	204.599999999999994	0.107999999999999999
60465	L2	51	0.0519999999999999976
60465	K2	66.2000000000000028	0.0719999999999999946
60465	M8	111.099999999999994	0.00700000000000000015
60466	M2	26.3999999999999986	1.87999999999999989
60466	S2	51.6000000000000014	0.281999999999999973
60466	N2	12.5999999999999996	0.412999999999999978
60466	K1	196.5	0.315000000000000002
60466	M4	330.399999999999977	0.0359999999999999973
60466	O1	214.800000000000011	0.203000000000000014
60466	M6	130.599999999999994	0.0660000000000000031
60466	S4	16.3000000000000007	0.00700000000000000015
60466	NU2	14.4000000000000004	0.0820000000000000034
60466	S6	2.79999999999999982	0.00300000000000000006
60466	MU2	1.19999999999999996	0.0459999999999999992
60466	2N2	358.800000000000011	0.0560000000000000012
60466	OO1	176.5	0.0100000000000000002
60466	LDA2	38	0.0129999999999999994
60466	M1	205.800000000000011	0.0129999999999999994
60466	J1	186.300000000000011	0.0160000000000000003
60466	MM	16.3000000000000007	0.0749999999999999972
60466	SSA	24.8999999999999986	0.16700000000000001
60466	MF	36.6000000000000014	0.0660000000000000031
60466	RHO1	223.699999999999989	0.00700000000000000015
60466	Q1	224.5	0.0389999999999999999
60466	T2	50.5	0.0160000000000000003
60466	R2	52.5	0.00300000000000000006
60466	2Q1	233.5	0.00700000000000000015
60466	P1	197.900000000000006	0.104999999999999996
60466	L2	40.2000000000000028	0.0519999999999999976
60466	K2	53.7000000000000028	0.0749999999999999972
60467	M2	8.59999999999999964	2.06400000000000006
60467	S2	31.6999999999999993	0.298999999999999988
60467	N2	348.399999999999977	0.440000000000000002
60467	K1	195.599999999999994	0.338000000000000023
60467	M4	287.199999999999989	0.0160000000000000003
60467	O1	199.699999999999989	0.220000000000000001
60467	M6	94.5999999999999943	0.0490000000000000019
60467	S4	41.2999999999999972	0.0129999999999999994
60467	NU2	351.100000000000023	0.0850000000000000061
60467	S6	67.7000000000000028	0.00700000000000000015
60467	MU2	189.5	0.0490000000000000019
60467	2N2	328.300000000000011	0.0589999999999999969
60467	OO1	191.5	0.0100000000000000002
60467	LDA2	19.3000000000000007	0.0129999999999999994
60467	M1	197.599999999999994	0.0160000000000000003
60467	J1	193.599999999999994	0.0160000000000000003
60467	RHO1	201.400000000000006	0.0100000000000000002
60467	Q1	201.699999999999989	0.0429999999999999966
60467	T2	30.8000000000000007	0.0160000000000000003
60467	R2	32.6000000000000014	0.00300000000000000006
60467	2Q1	203.699999999999989	0.00700000000000000015
60467	P1	195.900000000000006	0.112000000000000002
60467	L2	28.8000000000000007	0.0589999999999999969
60467	K2	33.6000000000000014	0.0820000000000000034
60467	M8	142.599999999999994	0.0129999999999999994
60468	M2	354.600000000000023	2.2799999999999998
60468	S2	15.8000000000000007	0.387000000000000011
60468	N2	336.699999999999989	0.528000000000000025
60468	K1	190.400000000000006	0.315000000000000002
60468	M4	217.699999999999989	0.0200000000000000004
60468	O1	195.900000000000006	0.226000000000000006
60468	M6	98.7999999999999972	0.0129999999999999994
60468	MK3	121.700000000000003	0.0100000000000000002
60468	S4	355	0.0229999999999999996
60468	MN4	270.699999999999989	0.0160000000000000003
60468	NU2	340.699999999999989	0.104999999999999996
60468	MU2	345.899999999999977	0.0749999999999999972
60468	2N2	322.300000000000011	0.0790000000000000008
60468	OO1	62.2000000000000028	0.0160000000000000003
60468	LDA2	20.8000000000000007	0.0299999999999999989
60468	S1	144.300000000000011	0.0560000000000000012
60468	M1	259.399999999999977	0.0129999999999999994
60468	J1	181.699999999999989	0.0259999999999999988
60468	SSA	50.1000000000000014	0.173999999999999988
60468	SA	170.900000000000006	0.27200000000000002
60468	RHO1	218	0.0459999999999999992
60468	Q1	170	0.0560000000000000012
60468	T2	26.3999999999999986	0.0359999999999999973
60468	R2	359.100000000000023	0.0100000000000000002
60468	2Q1	241.199999999999989	0.0160000000000000003
60468	P1	194.5	0.117999999999999994
60468	M3	55.2000000000000028	0.0490000000000000019
60468	L2	344.800000000000011	0.0429999999999999966
60468	2MK3	133.400000000000006	0.0129999999999999994
60468	K2	20.1000000000000014	0.0980000000000000038
60468	MS4	203.900000000000006	0.0259999999999999988
60469	M2	355.899999999999977	2.35199999999999987
60469	S2	13.0999999999999996	0.377000000000000002
60469	N2	339	0.561000000000000054
60469	K1	188.900000000000006	0.318000000000000005
60469	M4	271	0.0200000000000000004
60469	O1	196.099999999999994	0.23000000000000001
60469	M6	101.5	0.0129999999999999994
60469	MK3	119.400000000000006	0.0129999999999999994
60469	S4	15.1999999999999993	0.0330000000000000016
60469	MN4	267.199999999999989	0.0200000000000000004
60469	NU2	334	0.125
60469	S6	75.5999999999999943	0.00300000000000000006
60469	MU2	355.800000000000011	0.0850000000000000061
60469	2N2	327.800000000000011	0.0850000000000000061
60469	OO1	192.699999999999989	0.0129999999999999994
60469	LDA2	18.1000000000000014	0.0229999999999999996
60469	S1	120.700000000000003	0.0519999999999999976
60469	M1	220	0.0259999999999999988
60469	J1	182.599999999999994	0.0299999999999999989
60469	SSA	50.1000000000000014	0.173999999999999988
60469	SA	32.3999999999999986	0.27200000000000002
60469	RHO1	173.400000000000006	0.0160000000000000003
60469	Q1	180.699999999999989	0.0519999999999999976
60469	T2	33.8999999999999986	0.0330000000000000016
60469	R2	200.900000000000006	0.0589999999999999969
60469	2Q1	321.100000000000023	0.0200000000000000004
60469	P1	188.300000000000011	0.125
60469	2SM2	38.1000000000000014	0.0200000000000000004
60469	M3	53.5	0.0560000000000000012
60469	L2	323.800000000000011	0.0589999999999999969
60469	2MK3	132.699999999999989	0.0129999999999999994
60469	K2	6.40000000000000036	0.125
60469	M8	210.699999999999989	0.00300000000000000006
60469	MS4	223.699999999999989	0.0429999999999999966
60470	M2	357.600000000000023	2.43100000000000005
60470	S2	18.6000000000000014	0.412999999999999978
60470	N2	338.399999999999977	0.583999999999999964
60470	K1	188.800000000000011	0.328000000000000014
60470	M4	262.800000000000011	0.0200000000000000004
60470	O1	192.900000000000006	0.23899999999999999
60470	M6	317.699999999999989	0.0100000000000000002
60470	S4	31.1000000000000014	0.0200000000000000004
60470	MN4	282.800000000000011	0.0200000000000000004
60470	NU2	335.899999999999977	0.107999999999999999
60470	MU2	350.899999999999977	0.0820000000000000034
60470	2N2	320.300000000000011	0.0850000000000000061
60470	OO1	198.800000000000011	0.0160000000000000003
60470	LDA2	12.1999999999999993	0.0160000000000000003
60470	S1	145.400000000000006	0.0619999999999999996
60470	M1	185.699999999999989	0.0129999999999999994
60470	J1	186.199999999999989	0.0229999999999999996
60470	SSA	50.1000000000000014	0.173999999999999988
60470	SA	170.900000000000006	0.27200000000000002
60470	RHO1	194.699999999999989	0.0100000000000000002
60470	Q1	185.099999999999994	0.0519999999999999976
60470	T2	2.29999999999999982	0.0429999999999999966
60470	R2	250.099999999999994	0.0100000000000000002
60470	2Q1	114.599999999999994	0.0100000000000000002
60470	P1	188.199999999999989	0.112000000000000002
60470	2SM2	27.8999999999999986	0.0129999999999999994
60470	M3	59.1000000000000014	0.0660000000000000031
60470	L2	3.89999999999999991	0.0850000000000000061
60470	2MK3	64.2999999999999972	0.0200000000000000004
60470	K2	21.8999999999999986	0.104999999999999996
60470	MS4	240	0.0389999999999999999
60471	M2	128.300000000000011	0.996999999999999997
60471	S2	185	0.0980000000000000038
60471	N2	125.900000000000006	0.147999999999999993
60471	K1	283.100000000000023	0.190000000000000002
60471	M4	108.5	0.140999999999999986
60471	O1	283.199999999999989	0.153999999999999998
60471	M6	89.2999999999999972	0.0790000000000000008
60471	MK3	200.099999999999994	0.0519999999999999976
60471	S4	259	0.00300000000000000006
60471	MN4	95.7999999999999972	0.0490000000000000019
60471	NU2	130.5	0.0560000000000000012
60471	MU2	238.800000000000011	0.0790000000000000008
60471	2N2	186.599999999999994	0.0129999999999999994
60471	OO1	315.699999999999989	0.00300000000000000006
60471	LDA2	148.300000000000011	0.0330000000000000016
60471	S1	230.400000000000006	0.0359999999999999973
60471	M1	40.7999999999999972	0.0200000000000000004
60471	J1	30.6000000000000014	0.00700000000000000015
60471	SSA	50.1000000000000014	0.173999999999999988
60471	SA	170.900000000000006	0.27200000000000002
60471	RHO1	293.300000000000011	0.0100000000000000002
60471	Q1	299.899999999999977	0.0299999999999999989
60471	T2	241.699999999999989	0.0200000000000000004
60471	R2	356.899999999999977	0.0100000000000000002
60471	2Q1	11.5	0.00300000000000000006
60471	P1	270.199999999999989	0.0519999999999999976
60471	2SM2	314.800000000000011	0.00700000000000000015
60471	M3	282.199999999999989	0.0229999999999999996
60471	L2	131.599999999999994	0.140999999999999986
60471	2MK3	189	0.0560000000000000012
60471	K2	152.800000000000011	0.0200000000000000004
60471	M8	89.2000000000000028	0.0200000000000000004
60471	MS4	153.900000000000006	0.0359999999999999973
60472	M2	44	1.85400000000000009
60472	S2	81.5999999999999943	0.259000000000000008
60472	N2	36.1000000000000014	0.394000000000000017
60472	K1	218.699999999999989	0.312
60472	M4	358.100000000000023	0.171000000000000013
60472	O1	218.199999999999989	0.253000000000000003
60472	M6	129.699999999999989	0.0519999999999999976
60472	MK3	133.300000000000011	0.0299999999999999989
60472	S4	128	0.0200000000000000004
60472	MN4	352.899999999999977	0.0919999999999999984
60472	NU2	16.1000000000000014	0.0820000000000000034
60472	S6	262.800000000000011	0.00300000000000000006
60472	MU2	119	0.0950000000000000011
60472	2N2	63.1000000000000014	0.0490000000000000019
60472	OO1	215.099999999999994	0.00300000000000000006
60472	LDA2	37.2999999999999972	0.0619999999999999996
60472	S1	173.099999999999994	0.0619999999999999996
60472	M1	222.800000000000011	0.0330000000000000016
60472	J1	175	0.0229999999999999996
60472	SSA	50.1000000000000014	0.173999999999999988
60472	SA	170.900000000000006	0.27200000000000002
60472	RHO1	272.399999999999977	0.00700000000000000015
60472	Q1	237	0.0589999999999999969
60472	T2	87.4000000000000057	0.0229999999999999996
60472	R2	286.600000000000023	0.00700000000000000015
60472	2Q1	290.300000000000011	0.00300000000000000006
60472	P1	218.300000000000011	0.101999999999999993
60472	2SM2	179.800000000000011	0.0129999999999999994
60472	M3	114.700000000000003	0.0259999999999999988
60472	L2	32.6000000000000014	0.253000000000000003
60472	2MK3	95.9000000000000057	0.0259999999999999988
60472	K2	78.7999999999999972	0.0719999999999999946
60472	M8	117.400000000000006	0.0299999999999999989
60472	MS4	26.8000000000000007	0.0749999999999999972
60473	M2	359	2.3879999999999999
60473	S2	19.8999999999999986	0.404000000000000026
60473	N2	342	0.567999999999999949
60473	K1	193.800000000000011	0.360999999999999988
60473	M4	265	0.0229999999999999996
60473	O1	194.599999999999994	0.226000000000000006
60473	M6	333.300000000000011	0.0129999999999999994
60473	S4	26.1000000000000014	0.0229999999999999996
60473	NU2	344.300000000000011	0.107999999999999999
60473	S6	123.799999999999997	0.00300000000000000006
60473	MU2	338.199999999999989	0.0560000000000000012
60473	2N2	325.100000000000023	0.0749999999999999972
60473	OO1	193.099999999999994	0.0100000000000000002
60473	LDA2	8.69999999999999929	0.0160000000000000003
60473	M1	194.300000000000011	0.0160000000000000003
60473	J1	192.599999999999994	0.0160000000000000003
60473	SSA	50.1000000000000014	0.173999999999999988
60473	SA	170.900000000000006	0.27200000000000002
60473	RHO1	196	0.00700000000000000015
60473	Q1	194.900000000000006	0.0429999999999999966
60473	T2	19	0.0229999999999999996
60473	R2	20.6000000000000014	0.00300000000000000006
60473	2Q1	195	0.00700000000000000015
60473	P1	193.800000000000011	0.117999999999999994
60473	L2	15.9000000000000004	0.0660000000000000031
60473	K2	21.6000000000000014	0.112000000000000002
60473	M8	49.8999999999999986	0.00700000000000000015
60474	M2	42.1000000000000014	1.83699999999999997
60474	S2	70.5	0.269000000000000017
60474	N2	30	0.406999999999999973
60474	K1	228.800000000000011	0.304999999999999993
60474	M4	339.600000000000023	0.147999999999999993
60474	O1	222.400000000000006	0.256000000000000005
60474	M6	115.200000000000003	0.0749999999999999972
60474	S4	70.2000000000000028	0.0129999999999999994
60474	NU2	31.6000000000000014	0.0790000000000000008
60474	S6	177.400000000000006	0.00700000000000000015
60474	MU2	13.8000000000000007	0.0429999999999999966
60474	2N2	17.8999999999999986	0.0519999999999999976
60474	OO1	234.199999999999989	0.0100000000000000002
60474	LDA2	55.2999999999999972	0.0129999999999999994
60474	M1	225.599999999999994	0.0160000000000000003
60474	J1	231.099999999999994	0.0200000000000000004
60474	RHO1	220.300000000000011	0.0100000000000000002
60474	Q1	219.5	0.0490000000000000019
60474	T2	69.4000000000000057	0.0160000000000000003
60474	R2	71.5999999999999943	0.00300000000000000006
60474	2Q1	216.900000000000006	0.00700000000000000015
60474	P1	228.300000000000011	0.101999999999999993
60474	L2	54.2000000000000028	0.0519999999999999976
60474	K2	72.9000000000000057	0.0719999999999999946
60474	M8	75.7000000000000028	0.0259999999999999988
60475	M2	84.7000000000000028	1.41700000000000004
60475	S2	112.799999999999997	0.147999999999999993
60475	N2	80.7000000000000028	0.212999999999999995
60475	K1	252.900000000000006	0.226000000000000006
60475	M4	47.1000000000000014	0.176999999999999991
60475	O1	254.599999999999994	0.190000000000000002
60475	M6	352.100000000000023	0.0820000000000000034
60475	S4	224.300000000000011	0.00700000000000000015
60475	NU2	81.2999999999999972	0.0429999999999999966
60475	S6	41.6000000000000014	0.00300000000000000006
60475	MU2	61.2000000000000028	0.0299999999999999989
60475	2N2	76.2999999999999972	0.0259999999999999988
60475	OO1	248.599999999999994	0.00700000000000000015
60475	LDA2	94.9000000000000057	0.0100000000000000002
60475	M1	253.5	0.0129999999999999994
60475	J1	250	0.0129999999999999994
60475	SSA	50.1000000000000014	0.173999999999999988
60475	SA	170.900000000000006	0.27200000000000002
60475	RHO1	256.5	0.00700000000000000015
60475	Q1	255.900000000000006	0.0359999999999999973
60475	T2	111.900000000000006	0.0100000000000000002
60475	2Q1	256.399999999999977	0.00300000000000000006
60475	P1	253.099999999999994	0.0749999999999999972
60475	L2	89.2000000000000028	0.0389999999999999999
60475	K2	115.299999999999997	0.0389999999999999999
60475	M8	336.600000000000023	0.0259999999999999988
60476	M2	28.3999999999999986	1.66700000000000004
60476	S2	62.3999999999999986	0.226000000000000006
60476	N2	24.8999999999999986	0.318000000000000005
60476	K1	214.099999999999994	0.350999999999999979
60476	M4	319.800000000000011	0.171000000000000013
60476	O1	222.5	0.298999999999999988
60476	M6	177.900000000000006	0.0560000000000000012
60476	S4	78.2000000000000028	0.0160000000000000003
60476	NU2	25.1999999999999993	0.0619999999999999996
60476	S6	219.900000000000006	0.00700000000000000015
60476	MU2	354.600000000000023	0.0389999999999999999
60476	2N2	21	0.0429999999999999966
60476	OO1	206.800000000000011	0.0129999999999999994
60476	LDA2	44.1000000000000014	0.0129999999999999994
60476	M1	218.800000000000011	0.0200000000000000004
60476	J1	211.300000000000011	0.0229999999999999996
60476	RHO1	224.599999999999994	0.0100000000000000002
60476	Q1	226	0.0560000000000000012
60476	T2	60.7999999999999972	0.0129999999999999994
60476	R2	66.7000000000000028	0.00300000000000000006
60476	2Q1	228.699999999999989	0.00700000000000000015
60476	P1	214.800000000000011	0.115000000000000005
60476	L2	31.6000000000000014	0.0459999999999999992
60476	K2	65.2000000000000028	0.0619999999999999996
60476	M8	93.7999999999999972	0.0259999999999999988
60477	M2	0.100000000000000006	2.35199999999999987
60477	S2	20.6000000000000014	0.412999999999999978
60477	N2	342.600000000000023	0.561000000000000054
60477	K1	192.199999999999989	0.318000000000000005
60477	M4	277.800000000000011	0.0160000000000000003
60477	O1	196.900000000000006	0.226000000000000006
60477	M6	322.199999999999989	0.0129999999999999994
60477	MK3	110.200000000000003	0.0129999999999999994
60477	S4	45.2000000000000028	0.0200000000000000004
60477	MN4	302.100000000000023	0.0129999999999999994
60477	NU2	344.600000000000023	0.107999999999999999
60477	S6	162.300000000000011	0.00700000000000000015
60477	MU2	354.399999999999977	0.0749999999999999972
60477	2N2	328.100000000000023	0.0690000000000000058
60477	OO1	124.299999999999997	0.0299999999999999989
60477	LDA2	32.7999999999999972	0.0160000000000000003
60477	S1	127.299999999999997	0.0589999999999999969
60477	M1	227.5	0.0299999999999999989
60477	J1	194.699999999999989	0.0259999999999999988
60477	MM	247.5	0.0160000000000000003
60477	SSA	100.799999999999997	0.131000000000000005
60477	SA	140	0.44900000000000001
60477	MSF	272	0.138000000000000012
60477	MF	8.40000000000000036	0.0889999999999999958
60477	RHO1	249.800000000000011	0.0160000000000000003
60477	Q1	167.699999999999989	0.0459999999999999992
60477	T2	10.8000000000000007	0.0429999999999999966
60477	R2	216.300000000000011	0.0160000000000000003
60477	2Q1	194.199999999999989	0.00300000000000000006
60477	P1	188.099999999999994	0.125
60477	2SM2	13.5	0.00700000000000000015
60477	M3	57.2999999999999972	0.0660000000000000031
60477	L2	342.800000000000011	0.0749999999999999972
60477	2MK3	344.199999999999989	0.0100000000000000002
60477	K2	15	0.0889999999999999958
60477	M8	40.6000000000000014	0.00300000000000000006
60477	MS4	249	0.0389999999999999999
60478	M2	25.3999999999999986	1.50299999999999989
60478	S2	55.3999999999999986	0.164000000000000007
60478	N2	14.4000000000000004	0.269000000000000017
60478	K1	212.199999999999989	0.322000000000000008
60478	M4	329.399999999999977	0.226000000000000006
60478	O1	226.900000000000006	0.294999999999999984
60478	M6	206.699999999999989	0.0589999999999999969
60478	S4	170.900000000000006	0.0100000000000000002
60478	NU2	15.9000000000000004	0.0519999999999999976
60478	S6	169.099999999999994	0.00700000000000000015
60478	MU2	355.199999999999989	0.0359999999999999973
60478	2N2	3.5	0.0359999999999999973
60478	OO1	197.400000000000006	0.0129999999999999994
60478	LDA2	39.3999999999999986	0.0100000000000000002
60478	M1	219.699999999999989	0.0200000000000000004
60478	J1	205.300000000000011	0.0229999999999999996
60478	SSA	50.1000000000000014	0.173999999999999988
60478	SA	170.900000000000006	0.27200000000000002
60478	RHO1	232.400000000000006	0.0100000000000000002
60478	Q1	234.300000000000011	0.0560000000000000012
60478	T2	54.2999999999999972	0.0100000000000000002
60478	2Q1	239.400000000000006	0.00700000000000000015
60478	P1	213.300000000000011	0.104999999999999996
60478	L2	36.1000000000000014	0.0429999999999999966
60478	K2	57.8999999999999986	0.0459999999999999992
60478	M8	124.799999999999997	0.0160000000000000003
60479	M2	29.1000000000000014	2.06700000000000017
60479	S2	63.1000000000000014	0.325000000000000011
60479	N2	20.6000000000000014	0.471999999999999975
60479	K1	213.300000000000011	0.33500000000000002
60479	M4	215.199999999999989	0.157000000000000001
60479	O1	216.599999999999994	0.253000000000000003
60479	M6	71.9000000000000057	0.0950000000000000011
60479	MK3	22.8999999999999986	0.0690000000000000058
60479	S4	110.599999999999994	0.00700000000000000015
60479	MN4	224.400000000000006	0.0619999999999999996
60479	NU2	356.600000000000023	0.0719999999999999946
60479	S6	86	0.00300000000000000006
60479	MU2	91.5	0.0790000000000000008
60479	2N2	38.7999999999999972	0.0719999999999999946
60479	OO1	238.400000000000006	0.0200000000000000004
60479	LDA2	357	0.0560000000000000012
60479	S1	151.800000000000011	0.0490000000000000019
60479	M1	220	0.0229999999999999996
60479	J1	240.099999999999994	0.0259999999999999988
60479	SSA	50.5	0.173999999999999988
60479	SA	176.300000000000011	0.256000000000000005
60479	RHO1	193.5	0.00700000000000000015
60479	Q1	221.800000000000011	0.0589999999999999969
60479	T2	47.8999999999999986	0.0229999999999999996
60479	R2	267.699999999999989	0.0299999999999999989
60479	2Q1	165.400000000000006	0.0129999999999999994
60479	P1	214	0.101999999999999993
60479	2SM2	99.2000000000000028	0.0100000000000000002
60479	M3	145.300000000000011	0.0200000000000000004
60479	L2	25.3999999999999986	0.209999999999999992
60479	2MK3	30.3999999999999986	0.0589999999999999969
60479	K2	61.7999999999999972	0.0889999999999999958
60479	M8	143.800000000000011	0.00300000000000000006
60479	MS4	280.5	0.0589999999999999969
60480	M2	20.6000000000000014	2.1549999999999998
60480	S2	52.1000000000000014	0.381000000000000005
60480	N2	8.30000000000000071	0.502000000000000002
60480	K1	206.599999999999994	0.338000000000000023
60480	M4	192.300000000000011	0.143999999999999989
60480	O1	215.900000000000006	0.248999999999999999
60480	M6	56.7000000000000028	0.0490000000000000019
60480	MK3	18.6999999999999993	0.0519999999999999976
60480	S4	56.2000000000000028	0.0100000000000000002
60480	MN4	187.900000000000006	0.0619999999999999996
60480	NU2	0	0.104999999999999996
60480	S6	222.300000000000011	0.00300000000000000006
60480	MU2	72.9000000000000057	0.0519999999999999976
60480	2N2	9.80000000000000071	0.0490000000000000019
60480	OO1	137.5	0.0229999999999999996
60480	LDA2	18.1000000000000014	0.0200000000000000004
60480	S1	164.599999999999994	0.0429999999999999966
60480	M1	238.400000000000006	0.0490000000000000019
60480	J1	248.300000000000011	0.0229999999999999996
60480	SSA	44.1000000000000014	0.150999999999999995
60480	SA	118.599999999999994	0.220000000000000001
60480	RHO1	262.100000000000023	0.0259999999999999988
60480	Q1	195.599999999999994	0.0490000000000000019
60480	T2	39.5	0.0660000000000000031
60480	R2	315.100000000000023	0.0100000000000000002
60480	2Q1	91.2999999999999972	0.0100000000000000002
60480	P1	204.300000000000011	0.0950000000000000011
60480	2SM2	131.5	0.0129999999999999994
60480	M3	116.799999999999997	0.0229999999999999996
60480	L2	353.399999999999977	0.135000000000000009
60480	2MK3	17.3999999999999986	0.0560000000000000012
60480	K2	48.7000000000000028	0.0749999999999999972
60480	M8	154.099999999999994	0.0129999999999999994
60480	MS4	250.199999999999989	0.0660000000000000031
60481	M2	24.6999999999999993	1.83699999999999997
60481	S2	50.6000000000000014	0.276000000000000023
60481	N2	6.59999999999999964	0.370999999999999996
60481	K1	208.5	0.281999999999999973
60481	M4	24.5	0.0429999999999999966
60481	O1	213.099999999999994	0.209999999999999992
60481	M6	126.5	0.0429999999999999966
60481	MK3	70.7000000000000028	0.0100000000000000002
60481	S4	96.5	0.0100000000000000002
60481	MN4	353.399999999999977	0.0299999999999999989
60481	NU2	8.69999999999999929	0.0889999999999999958
60481	S6	232.800000000000011	0.00300000000000000006
60481	MU2	74.5	0.0259999999999999988
60481	2N2	354.5	0.0459999999999999992
60481	OO1	225.699999999999989	0.0100000000000000002
60481	LDA2	25.5	0.0389999999999999999
60481	S1	181.400000000000006	0.0259999999999999988
60481	M1	280.399999999999977	0.00700000000000000015
60481	J1	210.900000000000006	0.0129999999999999994
60481	SSA	25.5	0.212999999999999995
60481	SA	173.300000000000011	0.194000000000000006
60481	RHO1	211.099999999999994	0.0129999999999999994
60481	Q1	211.599999999999994	0.0429999999999999966
60481	T2	29.8000000000000007	0.0330000000000000016
60481	R2	282.800000000000011	0.0200000000000000004
60481	2Q1	188.599999999999994	0.00700000000000000015
60481	P1	207.800000000000011	0.0889999999999999958
60481	M3	106.599999999999994	0.0330000000000000016
60481	L2	36.2000000000000028	0.0950000000000000011
60481	2MK3	71	0.0160000000000000003
60481	K2	47.2000000000000028	0.0719999999999999946
60481	M8	221	0.00700000000000000015
60481	MS4	359.100000000000023	0.0200000000000000004
60482	M2	56.2999999999999972	1.69300000000000006
60482	S2	96.7999999999999972	0.197000000000000008
60482	N2	45.7999999999999972	0.307999999999999996
60482	K1	228.099999999999994	0.223000000000000004
60482	M4	8.80000000000000071	0.153999999999999998
60482	O1	235.699999999999989	0.20699999999999999
60482	M6	246.400000000000006	0.0660000000000000031
60482	MK3	128.400000000000006	0.0459999999999999992
60482	S4	123.799999999999997	0.00700000000000000015
60482	MN4	7.79999999999999982	0.0660000000000000031
60482	NU2	24	0.0749999999999999972
60482	MU2	163.300000000000011	0.0619999999999999996
60482	2N2	50.5	0.0459999999999999992
60482	OO1	350.800000000000011	0.0200000000000000004
60482	LDA2	76.4000000000000057	0.0429999999999999966
60482	S1	192.400000000000006	0.0719999999999999946
60482	M1	332.5	0.0330000000000000016
60482	J1	281.100000000000023	0.0229999999999999996
60482	SSA	50.1000000000000014	0.173999999999999988
60482	SA	170.900000000000006	0.27200000000000002
60482	RHO1	81.7000000000000028	0.0100000000000000002
60482	Q1	216.5	0.0459999999999999992
60482	T2	130.5	0.0229999999999999996
60482	R2	29.1000000000000014	0.0160000000000000003
60482	2Q1	273.800000000000011	0.00700000000000000015
60482	P1	223.599999999999994	0.0660000000000000031
60482	2SM2	311.300000000000011	0.00300000000000000006
60482	M3	141.599999999999994	0.0259999999999999988
60482	L2	59.5	0.131000000000000005
60482	2MK3	104	0.0389999999999999999
60482	K2	86.7999999999999972	0.0690000000000000058
60482	M8	207.599999999999994	0.0160000000000000003
60482	MS4	46.8999999999999986	0.0519999999999999976
60483	M2	67.7999999999999972	1.60400000000000009
60483	S2	103.900000000000006	0.200000000000000011
60483	N2	58.6000000000000014	0.312
60483	K1	234.800000000000011	0.226000000000000006
60483	M4	37	0.150999999999999995
60483	O1	243.800000000000011	0.176999999999999991
60483	M6	285.199999999999989	0.0790000000000000008
60483	MK3	131.5	0.0299999999999999989
60483	S4	189.099999999999994	0.0100000000000000002
60483	MN4	28.1999999999999993	0.0690000000000000058
60483	NU2	40.7999999999999972	0.0889999999999999958
60483	S6	359.600000000000023	0.00300000000000000006
60483	MU2	173.099999999999994	0.0619999999999999996
60483	2N2	41.2999999999999972	0.0129999999999999994
60483	OO1	193.300000000000011	0.0100000000000000002
60483	LDA2	61	0.0490000000000000019
60483	S1	193.599999999999994	0.0490000000000000019
60483	M1	281.600000000000023	0.0359999999999999973
60483	J1	309.699999999999989	0.00700000000000000015
60483	MM	3.60000000000000009	0.0660000000000000031
60483	SSA	138.699999999999989	0.117999999999999994
60483	SA	131.699999999999989	0.312
60483	MSF	306.600000000000023	0.125
60483	MF	5.20000000000000018	0.0790000000000000008
60483	RHO1	299.800000000000011	0.00700000000000000015
60483	Q1	211.5	0.0359999999999999973
60483	T2	82.5999999999999943	0.0200000000000000004
60483	R2	285.199999999999989	0.0129999999999999994
60483	2Q1	236.300000000000011	0.00700000000000000015
60483	P1	234.599999999999994	0.0660000000000000031
60483	2SM2	283	0.00700000000000000015
60483	M3	141.099999999999994	0.0229999999999999996
60483	L2	55.7999999999999972	0.16700000000000001
60483	2MK3	105	0.0359999999999999973
60483	K2	93.0999999999999943	0.0589999999999999969
60483	M8	274.699999999999989	0.0200000000000000004
60483	MS4	72.7000000000000028	0.0490000000000000019
60484	M2	50.1000000000000014	2.12599999999999989
60484	S2	84.4000000000000057	0.307999999999999996
60484	N2	37.1000000000000014	0.440000000000000002
60484	K1	230.199999999999989	0.307999999999999996
60484	M4	274.899999999999977	0.197000000000000008
60484	O1	234.300000000000011	0.235999999999999988
60484	M6	232.699999999999989	0.0919999999999999984
60484	MK3	60.7000000000000028	0.0490000000000000019
60484	MN4	263.399999999999977	0.0850000000000000061
60484	NU2	31.1000000000000014	0.0950000000000000011
60484	MU2	118.200000000000003	0.0719999999999999946
60484	2N2	34.2999999999999972	0.0490000000000000019
60484	OO1	246.599999999999994	0.0100000000000000002
60484	LDA2	41.5	0.0589999999999999969
60484	S1	190.5	0.0850000000000000061
60484	M1	289.899999999999977	0.0129999999999999994
60484	J1	272.899999999999977	0.0129999999999999994
60484	MM	9.5	0.117999999999999994
60484	SSA	42.8999999999999986	0.147999999999999993
60484	SA	184.800000000000011	0.164000000000000007
60484	MSF	34.7000000000000028	0.135000000000000009
60484	RHO1	235.5	0.0129999999999999994
60484	Q1	234.199999999999989	0.0490000000000000019
60484	T2	85.2000000000000028	0.0299999999999999989
60484	R2	319.899999999999977	0.0229999999999999996
60484	2Q1	238.400000000000006	0.00700000000000000015
60484	P1	219.599999999999994	0.107999999999999999
60484	M3	176.5	0.0429999999999999966
60484	L2	43.7000000000000028	0.150999999999999995
60484	2MK3	62.3999999999999986	0.0490000000000000019
60484	K2	81.0999999999999943	0.0820000000000000034
60484	M8	99.4000000000000057	0.0100000000000000002
60484	MS4	307.300000000000011	0.0619999999999999996
60485	M2	27.5	2.76600000000000001
60485	S2	67	0.400000000000000022
60485	N2	19.6999999999999993	0.603999999999999981
60485	K1	213.800000000000011	0.373999999999999999
60485	M4	225.300000000000011	0.276000000000000023
60485	O1	217.099999999999994	0.284999999999999976
60485	M6	138.800000000000011	0.0589999999999999969
60485	MK3	21.3999999999999986	0.0790000000000000008
60485	S4	37.1000000000000014	0.0129999999999999994
60485	MN4	219.199999999999989	0.120999999999999996
60485	NU2	5.29999999999999982	0.104999999999999996
60485	S6	12.9000000000000004	0.00700000000000000015
60485	MU2	83.7999999999999972	0.143999999999999989
60485	2N2	27.6000000000000014	0.0850000000000000061
60485	OO1	212.099999999999994	0.0359999999999999973
60485	LDA2	341.800000000000011	0.0519999999999999976
60485	S1	152.900000000000006	0.0429999999999999966
60485	M1	270.399999999999977	0.0299999999999999989
60485	J1	264.5	0.0259999999999999988
60485	SSA	50.5	0.173999999999999988
60485	SA	176.300000000000011	0.256000000000000005
60485	RHO1	23.5	0.00300000000000000006
60485	Q1	200	0.0719999999999999946
60485	T2	64	0.0719999999999999946
60485	R2	306.800000000000011	0.0299999999999999989
60485	2Q1	257.399999999999977	0.00700000000000000015
60485	P1	205.699999999999989	0.131000000000000005
60485	2SM2	230.5	0.00700000000000000015
60485	M3	136.300000000000011	0.0850000000000000061
60485	L2	9.09999999999999964	0.245999999999999996
60485	2MK3	11	0.0749999999999999972
60485	K2	50.6000000000000014	0.0919999999999999984
60485	M8	308	0.0160000000000000003
60485	MS4	265.5	0.0889999999999999958
60486	M2	25.1000000000000014	2.56899999999999995
60486	S2	54.3999999999999986	0.322000000000000008
60486	N2	10	0.541000000000000036
60486	K1	205.800000000000011	0.39700000000000002
60486	M4	224.800000000000011	0.226000000000000006
60486	O1	213.099999999999994	0.281999999999999973
60486	M6	167.099999999999994	0.0790000000000000008
60486	S4	22.8000000000000007	0.00300000000000000006
60486	NU2	12	0.104999999999999996
60486	S6	63.7999999999999972	0.00300000000000000006
60486	MU2	203.400000000000006	0.0359999999999999973
60486	2N2	354.699999999999989	0.0719999999999999946
60486	OO1	197.699999999999989	0.0129999999999999994
60486	LDA2	38.7999999999999972	0.0160000000000000003
60486	M1	209.300000000000011	0.0200000000000000004
60486	J1	201.699999999999989	0.0229999999999999996
60486	SSA	50.5	0.173999999999999988
60486	SA	176.300000000000011	0.256000000000000005
60486	RHO1	216.400000000000006	0.0100000000000000002
60486	Q1	216.900000000000006	0.0519999999999999976
60486	T2	53.2999999999999972	0.0200000000000000004
60486	R2	55.6000000000000014	0.00300000000000000006
60486	2Q1	220.699999999999989	0.00700000000000000015
60486	P1	206.300000000000011	0.131000000000000005
60486	L2	40.2999999999999972	0.0719999999999999946
60486	K2	56.7999999999999972	0.0889999999999999958
60486	M8	6.09999999999999964	0.00700000000000000015
60487	M2	6.90000000000000036	2.29000000000000004
60487	S2	31.5	0.381000000000000005
60487	N2	354.600000000000023	0.525000000000000022
60487	K1	197.900000000000006	0.328000000000000014
60487	M4	139.400000000000006	0.0719999999999999946
60487	O1	202.300000000000011	0.242999999999999994
60487	M6	39.2999999999999972	0.0389999999999999999
60487	MK3	305.100000000000023	0.0160000000000000003
60487	S4	263.100000000000023	0.00700000000000000015
60487	MN4	128.599999999999994	0.0359999999999999973
60487	NU2	339.300000000000011	0.115000000000000005
60487	S6	266.5	0.00700000000000000015
60487	MU2	28.3000000000000007	0.0820000000000000034
60487	2N2	340.100000000000023	0.0889999999999999958
60487	OO1	176.699999999999989	0.0129999999999999994
60487	LDA2	2.60000000000000009	0.0359999999999999973
60487	S1	136.800000000000011	0.0330000000000000016
60487	M1	273.199999999999989	0.0229999999999999996
60487	J1	192.300000000000011	0.0200000000000000004
60487	SSA	50.5	0.173999999999999988
60487	SA	176.300000000000011	0.256000000000000005
60487	RHO1	180.800000000000011	0.0100000000000000002
60487	Q1	204.800000000000011	0.0519999999999999976
60487	T2	65.2999999999999972	0.0299999999999999989
60487	R2	263.100000000000023	0.0259999999999999988
60487	2Q1	19.6000000000000014	0.0100000000000000002
60487	P1	200.199999999999989	0.112000000000000002
60487	2SM2	32.8999999999999986	0.0160000000000000003
60487	M3	100.400000000000006	0.0459999999999999992
60487	L2	341.699999999999989	0.0889999999999999958
60487	2MK3	325.399999999999977	0.0299999999999999989
60487	K2	28.6000000000000014	0.107999999999999999
60487	M8	91.5	0.0160000000000000003
60487	MS4	170.599999999999994	0.0229999999999999996
60488	M2	22	2.67700000000000005
60488	S2	47.5	0.440000000000000002
60488	N2	11.5	0.583999999999999964
60488	K1	211.900000000000006	0.36399999999999999
60488	M4	241.300000000000011	0.183999999999999997
60488	O1	207.300000000000011	0.298999999999999988
60488	M6	166.099999999999994	0.0519999999999999976
60488	MK3	17.8000000000000007	0.0690000000000000058
60488	S4	11.0999999999999996	0.0160000000000000003
60488	MN4	230.300000000000011	0.0889999999999999958
60488	NU2	13	0.112000000000000002
60488	S6	7.59999999999999964	0.00700000000000000015
60488	MU2	85.7999999999999972	0.128000000000000003
60488	2N2	348.899999999999977	0.0850000000000000061
60488	OO1	216.599999999999994	0.0589999999999999969
60488	LDA2	337.899999999999977	0.0820000000000000034
60488	S1	180.699999999999989	0.0429999999999999966
60488	M1	178.599999999999994	0.0100000000000000002
60488	J1	258.699999999999989	0.0129999999999999994
60488	SSA	50.5	0.173999999999999988
60488	SA	176.300000000000011	0.256000000000000005
60488	RHO1	204.800000000000011	0.0229999999999999996
60488	Q1	205.5	0.0490000000000000019
60488	T2	72.5	0.0490000000000000019
60488	R2	12.0999999999999996	0.0889999999999999958
60488	2Q1	45.7000000000000028	0.0160000000000000003
60488	P1	215.599999999999994	0.128000000000000003
60488	2SM2	232.699999999999989	0.0100000000000000002
60488	M3	130.099999999999994	0.0619999999999999996
60488	L2	7.5	0.216999999999999998
60488	2MK3	34	0.0389999999999999999
60488	K2	50.7999999999999972	0.0719999999999999946
60488	M8	215.5	0.0129999999999999994
60488	MS4	274.800000000000011	0.0619999999999999996
60489	M2	10.4000000000000004	2.56899999999999995
60489	S2	36.1000000000000014	0.390000000000000013
60489	N2	354.899999999999977	0.563999999999999946
60489	K1	199.699999999999989	0.343999999999999972
60489	M4	209.599999999999994	0.107999999999999999
60489	O1	203.400000000000006	0.259000000000000008
60489	M6	135.300000000000011	0.0200000000000000004
60489	MK3	4.40000000000000036	0.0259999999999999988
60489	MN4	201.400000000000006	0.0459999999999999992
60489	NU2	351.399999999999977	0.115000000000000005
60489	MU2	40	0.0820000000000000034
60489	2N2	343.300000000000011	0.0719999999999999946
60489	OO1	217.300000000000011	0.0160000000000000003
60489	LDA2	356.100000000000023	0.0429999999999999966
60489	S1	173.900000000000006	0.0589999999999999969
60489	M1	243.300000000000011	0.0160000000000000003
60489	J1	213.5	0.0160000000000000003
60489	SSA	50.5	0.173999999999999988
60489	SA	176.300000000000011	0.256000000000000005
60489	RHO1	198	0.0129999999999999994
60489	Q1	198.900000000000006	0.0560000000000000012
60489	T2	19.8999999999999986	0.0490000000000000019
60489	R2	263.800000000000011	0.0160000000000000003
60489	2Q1	207.099999999999994	0.00700000000000000015
60489	P1	198.300000000000011	0.117999999999999994
60489	M3	114.799999999999997	0.0560000000000000012
60489	L2	5	0.112000000000000002
60489	2MK3	30.6000000000000014	0.0160000000000000003
60489	K2	37.1000000000000014	0.0980000000000000038
60489	MS4	237.699999999999989	0.0330000000000000016
60490	M2	49.7000000000000028	3.57600000000000007
60490	S2	95.9000000000000057	0.573999999999999955
60490	N2	44.1000000000000014	0.819999999999999951
60490	K1	200	0.387000000000000011
60490	M4	279.600000000000023	0.416999999999999982
60490	O1	230.099999999999994	0.216999999999999998
60490	M6	179.199999999999989	0.173999999999999988
60490	S4	48.2999999999999972	0.0100000000000000002
60490	NU2	44.8999999999999986	0.161000000000000004
60490	S6	114.599999999999994	0.0100000000000000002
60490	MU2	201.800000000000011	0.0850000000000000061
60490	2N2	38.6000000000000014	0.107999999999999999
60490	OO1	169.900000000000006	0.0100000000000000002
60490	LDA2	71.0999999999999943	0.0259999999999999988
60490	M1	214.900000000000006	0.0160000000000000003
60490	J1	185.099999999999994	0.0160000000000000003
60490	RHO1	243	0.0100000000000000002
60490	Q1	245	0.0429999999999999966
60490	T2	94.0999999999999943	0.0330000000000000016
60490	R2	97.7999999999999972	0.00300000000000000006
60490	2Q1	259.899999999999977	0.00700000000000000015
60490	P1	202.300000000000011	0.128000000000000003
60490	L2	55.2000000000000028	0.101999999999999993
60490	K2	99.7000000000000028	0.157000000000000001
60490	M8	20.5	0.0299999999999999989
60491	M2	40.7000000000000028	3.30399999999999983
60491	S2	76.7999999999999972	0.509000000000000008
60491	N2	30.1999999999999993	0.698999999999999955
60491	K1	221.300000000000011	0.276000000000000023
60491	M4	260	0.27200000000000002
60491	O1	218.300000000000011	0.266000000000000014
60491	M6	142.400000000000006	0.104999999999999996
60491	S4	97.7999999999999972	0.0200000000000000004
60491	NU2	31.6000000000000014	0.135000000000000009
60491	S6	46.7000000000000028	0.00700000000000000015
60491	MU2	281.5	0.0129999999999999994
60491	2N2	19.6999999999999993	0.0919999999999999984
60491	OO1	221	0.0129999999999999994
60491	LDA2	57.3999999999999986	0.0229999999999999996
60491	M1	219	0.0200000000000000004
60491	J1	221	0.0200000000000000004
60491	SSA	51.7999999999999972	0.197000000000000008
60491	SA	176	0.276000000000000023
60491	RHO1	217.699999999999989	0.0100000000000000002
60491	Q1	217.599999999999994	0.0519999999999999976
60491	T2	75.4000000000000057	0.0299999999999999989
60491	R2	78.2999999999999972	0.00300000000000000006
60491	2Q1	216.900000000000006	0.00700000000000000015
60491	P1	221.099999999999994	0.0919999999999999984
60491	L2	51.2999999999999972	0.0919999999999999984
60491	K2	79.7000000000000028	0.138000000000000012
60491	M8	354.800000000000011	0.0160000000000000003
60492	M2	9.59999999999999964	2.8969999999999998
60492	S2	33.2999999999999972	0.498999999999999999
60492	N2	356.300000000000011	0.673000000000000043
60492	K1	198.900000000000006	0.347999999999999976
60492	M4	210.099999999999994	0.0950000000000000011
60492	O1	202.400000000000006	0.256000000000000005
60492	M6	22.1000000000000014	0.0359999999999999973
60492	MK3	15.9000000000000004	0.0200000000000000004
60492	S4	16.1000000000000014	0.0259999999999999988
60492	MN4	203.300000000000011	0.0389999999999999999
60492	NU2	346.699999999999989	0.143999999999999989
60492	S6	276.800000000000011	0.00300000000000000006
60492	MU2	23.3999999999999986	0.0919999999999999984
60492	2N2	332.699999999999989	0.0690000000000000058
60492	OO1	239.199999999999989	0.0129999999999999994
60492	LDA2	13.9000000000000004	0.0459999999999999992
60492	S1	182.699999999999989	0.0560000000000000012
60492	M1	212.800000000000011	0.0160000000000000003
60492	J1	224.400000000000006	0.0160000000000000003
60492	SSA	50.5	0.173999999999999988
60492	SA	176.300000000000011	0.256000000000000005
60492	RHO1	151.5	0.00300000000000000006
60492	Q1	194.099999999999994	0.0560000000000000012
60492	T2	8.80000000000000071	0.0299999999999999989
60492	R2	302.699999999999989	0.0259999999999999988
60492	2Q1	160.300000000000011	0.0100000000000000002
60492	P1	202.400000000000006	0.120999999999999996
60492	2SM2	86.7000000000000028	0.0100000000000000002
60492	M3	135.800000000000011	0.0589999999999999969
60492	L2	347.199999999999989	0.117999999999999994
60492	2MK3	18.1999999999999993	0.0259999999999999988
60492	K2	36.8999999999999986	0.112000000000000002
60492	M8	111.299999999999997	0.0129999999999999994
60492	MS4	245.199999999999989	0.0519999999999999976
60493	M2	25.5	3.21499999999999986
60493	S2	55.7999999999999972	0.541000000000000036
60493	N2	11.8000000000000007	0.679000000000000048
60493	K1	211.800000000000011	0.288999999999999979
60493	M4	252.199999999999989	0.212999999999999995
60493	O1	206	0.233000000000000013
60493	M6	108.200000000000003	0.0459999999999999992
60493	S4	75.2000000000000028	0.0259999999999999988
60493	NU2	13.5999999999999996	0.131000000000000005
60493	S6	13.0999999999999996	0.00700000000000000015
60493	MU2	355.199999999999989	0.0749999999999999972
60493	2N2	357.899999999999977	0.0889999999999999958
60493	OO1	216.199999999999989	0.0100000000000000002
60493	LDA2	39.6000000000000014	0.0229999999999999996
60493	M1	208.400000000000006	0.0160000000000000003
60493	J1	213.599999999999994	0.0160000000000000003
60493	SSA	51.7999999999999972	0.197000000000000008
60493	SA	176	0.276000000000000023
60493	RHO1	204.5	0.0100000000000000002
60493	Q1	203.400000000000006	0.0429999999999999966
60493	T2	54.6000000000000014	0.0330000000000000016
60493	R2	57	0.00300000000000000006
60493	2Q1	201.800000000000011	0.00700000000000000015
60493	P1	211.599999999999994	0.0950000000000000011
60493	L2	39.6000000000000014	0.0889999999999999958
60493	K2	58.2999999999999972	0.147999999999999993
60493	M8	336.800000000000011	0.00700000000000000015
60494	M2	35.1000000000000014	3.97299999999999986
60494	S2	69.9000000000000057	0.640000000000000013
60494	N2	28	0.774000000000000021
60494	K1	205.099999999999994	0.426999999999999991
60494	M4	261.399999999999977	0.318000000000000005
60494	O1	218.300000000000011	0.301999999999999991
60494	M6	223.800000000000011	0.0980000000000000038
60494	S4	299.300000000000011	0.0200000000000000004
60494	NU2	28.8999999999999986	0.147999999999999993
60494	MU2	0.900000000000000022	0.0950000000000000011
60494	2N2	20.8000000000000007	0.101999999999999993
60494	OO1	191.800000000000011	0.0129999999999999994
60494	LDA2	50.7999999999999972	0.0259999999999999988
60494	M1	211.699999999999989	0.0200000000000000004
60494	J1	198.5	0.0229999999999999996
60494	SSA	51.7999999999999972	0.197000000000000008
60494	SA	176	0.276000000000000023
60494	RHO1	223.900000000000006	0.0100000000000000002
60494	Q1	224.699999999999989	0.0589999999999999969
60494	T2	68.4000000000000057	0.0359999999999999973
60494	R2	72.2999999999999972	0.00700000000000000015
60494	2Q1	231.199999999999989	0.00700000000000000015
60494	P1	206.099999999999994	0.140999999999999986
60494	L2	42.5	0.112000000000000002
60494	K2	72.7000000000000028	0.173999999999999988
60494	M8	6.09999999999999964	0.0359999999999999973
60495	M2	34.2000000000000028	3.80200000000000005
60495	S2	71.2999999999999972	0.563999999999999946
60495	N2	22.6000000000000014	0.764000000000000012
60495	K1	213.5	0.387000000000000011
60495	M4	290.5	0.220000000000000001
60495	O1	216	0.266000000000000014
60495	M6	201.5	0.0459999999999999992
60495	MK3	53.1000000000000014	0.0490000000000000019
60495	S4	85.9000000000000057	0.0429999999999999966
60495	MN4	278.199999999999989	0.101999999999999993
60495	NU2	17.1999999999999993	0.161000000000000004
60495	MU2	103.599999999999994	0.164000000000000007
60495	2N2	32.7999999999999972	0.0490000000000000019
60495	OO1	211	0.0100000000000000002
60495	LDA2	14.0999999999999996	0.138000000000000012
60495	S1	169.400000000000006	0.0719999999999999946
60495	M1	214.599999999999994	0.0160000000000000003
60495	J1	212.300000000000011	0.0200000000000000004
60495	SSA	58.7999999999999972	0.203000000000000014
60495	SA	173.599999999999994	0.284999999999999976
60495	RHO1	216.900000000000006	0.0100000000000000002
60495	Q1	212.599999999999994	0.0690000000000000058
60495	T2	65.5	0.0790000000000000008
60495	R2	71.2999999999999972	0.00300000000000000006
60495	2Q1	218.300000000000011	0.00700000000000000015
60495	P1	211.699999999999989	0.135000000000000009
60495	2SM2	140.5	0.0359999999999999973
60495	M3	173.5	0.104999999999999996
60495	L2	18.1999999999999993	0.322000000000000008
60495	2MK3	63.2000000000000028	0.0359999999999999973
60495	K2	61.7999999999999972	0.147999999999999993
60495	M8	356	0.0259999999999999988
60495	MS4	326	0.125
60496	M2	17.8999999999999986	3.32299999999999995
60496	S2	45.7999999999999972	0.518000000000000016
60496	N2	2.20000000000000018	0.717999999999999972
60496	K1	200.699999999999989	0.360999999999999988
60496	M4	248.099999999999994	0.138000000000000012
60496	O1	206.5	0.259000000000000008
60496	M6	60.3999999999999986	0.0200000000000000004
60496	MK3	33.1000000000000014	0.0299999999999999989
60496	S4	49.3999999999999986	0.0229999999999999996
60496	MN4	241.900000000000006	0.0660000000000000031
60496	NU2	355.399999999999977	0.143999999999999989
60496	MU2	50.2000000000000028	0.104999999999999996
60496	2N2	349.100000000000023	0.0919999999999999984
60496	OO1	213.300000000000011	0.0160000000000000003
60496	LDA2	5.59999999999999964	0.0589999999999999969
60496	S1	168.099999999999994	0.0619999999999999996
60496	M1	249.199999999999989	0.0200000000000000004
60496	J1	228	0.0200000000000000004
60496	SSA	51.7999999999999972	0.197000000000000008
60496	SA	176	0.276000000000000023
60496	RHO1	204.699999999999989	0.0100000000000000002
60496	Q1	198.900000000000006	0.0560000000000000012
60496	T2	30.6999999999999993	0.0619999999999999996
60496	R2	285.600000000000023	0.0359999999999999973
60496	2Q1	212.199999999999989	0.00700000000000000015
60496	P1	199.800000000000011	0.128000000000000003
60496	2SM2	122.400000000000006	0.0100000000000000002
60496	M3	152.099999999999994	0.0790000000000000008
60496	L2	12.1999999999999993	0.143999999999999989
60496	2MK3	77	0.0160000000000000003
60496	K2	45.8999999999999986	0.135000000000000009
60496	MS4	274.399999999999977	0.0749999999999999972
60497	M2	30.6999999999999993	3.46499999999999986
60497	S2	52.7999999999999972	0.688999999999999946
60497	N2	19.5	0.859999999999999987
60497	K1	219.5	0.357999999999999985
60497	M4	214.800000000000011	0.223000000000000004
60497	O1	214.400000000000006	0.253000000000000003
60497	M6	141.699999999999989	0.0790000000000000008
60497	S4	47.2000000000000028	0.0229999999999999996
60497	NU2	21	0.16700000000000001
60497	S6	41	0.0129999999999999994
60497	MU2	8.59999999999999964	0.0820000000000000034
60497	2N2	8.30000000000000071	0.115000000000000005
60497	OO1	224.5	0.0100000000000000002
60497	LDA2	40.8999999999999986	0.0229999999999999996
60497	M1	217	0.0160000000000000003
60497	J1	221.900000000000006	0.0200000000000000004
60497	SSA	51.7999999999999972	0.197000000000000008
60497	SA	176	0.276000000000000023
60497	RHO1	212.300000000000011	0.0100000000000000002
60497	Q1	211.900000000000006	0.0490000000000000019
60497	T2	51.8999999999999986	0.0389999999999999999
60497	R2	53.7000000000000028	0.00700000000000000015
60497	2Q1	209.5	0.00700000000000000015
60497	P1	219.099999999999994	0.117999999999999994
60497	L2	41.8999999999999986	0.0980000000000000038
60497	K2	54.6000000000000014	0.187
60497	M8	271.899999999999977	0.0160000000000000003
60498	M2	30.5	3.45100000000000007
60498	S2	51.7000000000000028	0.688999999999999946
60498	N2	19.5	0.85299999999999998
60498	K1	218.800000000000011	0.347999999999999976
60498	M4	204.699999999999989	0.203000000000000014
60498	O1	214.699999999999989	0.253000000000000003
60498	M6	134.300000000000011	0.0790000000000000008
60498	S4	52.8999999999999986	0.0229999999999999996
60498	NU2	20.8999999999999986	0.164000000000000007
60498	S6	32.2999999999999972	0.0129999999999999994
60498	MU2	9.40000000000000036	0.0820000000000000034
60498	2N2	8.40000000000000036	0.115000000000000005
60498	OO1	222.900000000000006	0.0100000000000000002
60498	LDA2	40.2999999999999972	0.0229999999999999996
60498	M1	216.800000000000011	0.0160000000000000003
60498	J1	220.800000000000011	0.0200000000000000004
60498	SSA	51.7999999999999972	0.197000000000000008
60498	SA	176	0.276000000000000023
60498	RHO1	212.900000000000006	0.0100000000000000002
60498	Q1	212.699999999999989	0.0490000000000000019
60498	T2	50.7999999999999972	0.0389999999999999999
60498	R2	52.5	0.00700000000000000015
60498	2Q1	210.599999999999994	0.00700000000000000015
60498	P1	218.5	0.115000000000000005
60498	L2	41.6000000000000014	0.0950000000000000011
60498	K2	53.3999999999999986	0.187
60498	M8	276	0.0129999999999999994
60499	M2	21.1999999999999993	3.15899999999999981
60499	S2	41.5	0.633000000000000007
60499	N2	7	0.76100000000000001
60499	K1	211	0.331000000000000016
60499	M4	219.800000000000011	0.107999999999999999
60499	O1	208.699999999999989	0.233000000000000013
60499	M6	96.2000000000000028	0.0459999999999999992
60499	S4	23.8000000000000007	0.0259999999999999988
60499	NU2	8.90000000000000036	0.147999999999999993
60499	S6	355.600000000000023	0.00300000000000000006
60499	MU2	0.900000000000000022	0.0749999999999999972
60499	2N2	352.899999999999977	0.101999999999999993
60499	OO1	213.400000000000006	0.0100000000000000002
60499	LDA2	30.6000000000000014	0.0229999999999999996
60499	M1	209.900000000000006	0.0160000000000000003
60499	J1	212.199999999999989	0.0200000000000000004
60499	SSA	51.7999999999999972	0.197000000000000008
60499	SA	176	0.276000000000000023
60499	RHO1	207.699999999999989	0.0100000000000000002
60499	Q1	207.599999999999994	0.0459999999999999992
60499	T2	40.7000000000000028	0.0359999999999999973
60499	R2	42.3999999999999986	0.00700000000000000015
60499	2Q1	206.400000000000006	0.00700000000000000015
60499	P1	210.900000000000006	0.107999999999999999
60499	L2	35.3999999999999986	0.0889999999999999958
60499	K2	43.2000000000000028	0.171000000000000013
60499	M8	146.199999999999989	0.00700000000000000015
60500	M2	24.1000000000000014	3.27400000000000002
60500	S2	44.6000000000000014	0.650000000000000022
60500	N2	11	0.801000000000000045
60500	K1	214	0.338000000000000023
60500	M4	215.300000000000011	0.140999999999999986
60500	O1	211.099999999999994	0.242999999999999994
60500	M6	108.799999999999997	0.0619999999999999996
60500	S4	37.5	0.0229999999999999996
60500	NU2	12.6999999999999993	0.153999999999999998
60500	S6	23.5	0.0100000000000000002
60500	MU2	3.70000000000000018	0.0790000000000000008
60500	2N2	357.800000000000011	0.104999999999999996
60500	OO1	216.900000000000006	0.0100000000000000002
60500	LDA2	33.6000000000000014	0.0229999999999999996
60500	M1	212.599999999999994	0.0160000000000000003
60500	J1	215.400000000000006	0.0200000000000000004
60500	SSA	51.7999999999999972	0.197000000000000008
60500	SA	176	0.276000000000000023
60500	RHO1	209.900000000000006	0.0100000000000000002
60500	Q1	209.699999999999989	0.0459999999999999992
60500	T2	43.7000000000000028	0.0389999999999999999
60500	R2	45.3999999999999986	0.00700000000000000015
60500	2Q1	208.300000000000011	0.00700000000000000015
60500	P1	213.800000000000011	0.112000000000000002
60500	L2	37.2999999999999972	0.0919999999999999984
60500	K2	46.2000000000000028	0.176999999999999991
60500	M8	171.199999999999989	0.0100000000000000002
60501	M2	28.6999999999999993	3.46099999999999985
60501	S2	64.4000000000000057	0.538000000000000034
60501	N2	20	0.801000000000000045
60501	K1	206.5	0.357999999999999985
60501	M4	245.199999999999989	0.171000000000000013
60501	O1	211	0.269000000000000017
60501	M6	145.099999999999994	0.0749999999999999972
60501	S4	84	0.0229999999999999996
60501	NU2	21.1000000000000014	0.157000000000000001
60501	S6	201.199999999999989	0.00700000000000000015
60501	MU2	352.800000000000011	0.0820000000000000034
60501	2N2	11.1999999999999993	0.104999999999999996
60501	OO1	204.800000000000011	0.0100000000000000002
60501	LDA2	45.2999999999999972	0.0229999999999999996
60501	M1	209.5	0.0200000000000000004
60501	J1	206.099999999999994	0.0200000000000000004
60501	SSA	51.7999999999999972	0.197000000000000008
60501	SA	176	0.276000000000000023
60501	RHO1	212	0.0100000000000000002
60501	Q1	212.599999999999994	0.0519999999999999976
60501	T2	62.8999999999999986	0.0330000000000000016
60501	R2	66	0.00300000000000000006
60501	2Q1	213.800000000000011	0.00700000000000000015
60501	P1	206.800000000000011	0.117999999999999994
60501	L2	37.5	0.0980000000000000038
60501	K2	67.2999999999999972	0.147999999999999993
60501	M8	336.5	0.0129999999999999994
60502	M2	37.2000000000000028	3.4049999999999998
60502	S2	76.9000000000000057	0.509000000000000008
60502	N2	30.8000000000000007	0.774000000000000021
60502	K1	212.300000000000011	0.373999999999999999
60502	M4	276.5	0.288999999999999979
60502	O1	217.900000000000006	0.269000000000000017
60502	M6	177	0.0749999999999999972
60502	S4	82.0999999999999943	0.0229999999999999996
60502	NU2	31.6999999999999993	0.150999999999999995
60502	S6	233.099999999999994	0.00700000000000000015
60502	MU2	357.300000000000011	0.0820000000000000034
60502	2N2	24.3999999999999986	0.101999999999999993
60502	OO1	209.599999999999994	0.0100000000000000002
60502	LDA2	55.7000000000000028	0.0229999999999999996
60502	M1	215.800000000000011	0.0200000000000000004
60502	J1	211.5	0.0200000000000000004
60502	SSA	51.7999999999999972	0.197000000000000008
60502	SA	176	0.276000000000000023
60502	RHO1	219.300000000000011	0.0100000000000000002
60502	Q1	220	0.0519999999999999976
60502	T2	75.2000000000000028	0.0299999999999999989
60502	R2	78.5999999999999943	0.00300000000000000006
60502	2Q1	221.699999999999989	0.00700000000000000015
60502	P1	212.699999999999989	0.125
60502	L2	43.6000000000000014	0.0950000000000000011
60502	K2	80	0.138000000000000012
60502	M8	353.100000000000023	0.0100000000000000002
60503	M2	20.6999999999999993	3.31999999999999984
60503	S2	52.8999999999999986	0.528000000000000025
60503	N2	8.30000000000000071	0.804000000000000048
60503	K1	196.5	0.36399999999999999
60503	M4	268.199999999999989	0.131000000000000005
60503	O1	205.400000000000006	0.259000000000000008
60503	M6	116.099999999999994	0.0330000000000000016
60503	S4	62.7000000000000028	0.0330000000000000016
60503	NU2	10	0.153999999999999998
60503	S6	128.5	0.0100000000000000002
60503	MU2	348.399999999999977	0.0790000000000000008
60503	2N2	355.899999999999977	0.107999999999999999
60503	OO1	187.800000000000011	0.0100000000000000002
60503	LDA2	35.6000000000000014	0.0229999999999999996
60503	M1	201	0.0200000000000000004
60503	J1	192.300000000000011	0.0200000000000000004
60503	SSA	51.7999999999999972	0.197000000000000008
60503	SA	176	0.276000000000000023
60503	RHO1	209.199999999999989	0.0100000000000000002
60503	Q1	209.900000000000006	0.0490000000000000019
60503	T2	51.7000000000000028	0.0330000000000000016
60503	R2	54.2000000000000028	0.00300000000000000006
60503	2Q1	214.099999999999994	0.00700000000000000015
60503	P1	197.199999999999989	0.120999999999999996
60503	L2	33.1000000000000014	0.0919999999999999984
60503	K2	55.5	0.143999999999999989
60503	M8	272.600000000000023	0.0100000000000000002
60504	M2	23.6999999999999993	3.29099999999999993
60504	S2	56	0.505000000000000004
60504	N2	13.4000000000000004	0.764000000000000012
60504	K1	202.800000000000011	0.353999999999999981
60504	M4	265.600000000000023	0.104999999999999996
60504	O1	204.5	0.245999999999999996
60504	M6	116	0.0299999999999999989
60504	S4	60.6000000000000014	0.0259999999999999988
60504	NU2	14.6999999999999993	0.147999999999999993
60504	MU2	351.399999999999977	0.0790000000000000008
60504	2N2	3.10000000000000009	0.101999999999999993
60504	OO1	205.300000000000011	0.0100000000000000002
60504	LDA2	38.7000000000000028	0.0229999999999999996
60504	M1	204.5	0.0160000000000000003
60504	J1	205	0.0200000000000000004
60504	SSA	51.7999999999999972	0.197000000000000008
60504	SA	176	0.276000000000000023
60504	RHO1	204.699999999999989	0.0100000000000000002
60504	Q1	204.5	0.0459999999999999992
60504	T2	54.6000000000000014	0.0299999999999999989
60504	R2	57.3999999999999986	0.00300000000000000006
60504	2Q1	205.099999999999994	0.00700000000000000015
60504	P1	202.900000000000006	0.117999999999999994
60504	L2	34.2000000000000028	0.0919999999999999984
60504	K2	58.5	0.138000000000000012
60504	M8	252.199999999999989	0.0129999999999999994
60505	M2	31	3.52000000000000002
60505	S2	67.5	0.558000000000000052
60505	N2	22.8000000000000007	0.822999999999999954
60505	K1	206.699999999999989	0.366999999999999993
60505	M4	258.300000000000011	0.150999999999999995
60505	O1	211.400000000000006	0.269000000000000017
60505	M6	153.699999999999989	0.0790000000000000008
60505	S4	93	0.0259999999999999988
60505	NU2	23.8000000000000007	0.161000000000000004
60505	S6	189.699999999999989	0.00700000000000000015
60505	MU2	354.199999999999989	0.0850000000000000061
60505	2N2	14.5	0.107999999999999999
60505	OO1	204.800000000000011	0.0100000000000000002
60505	LDA2	48.1000000000000014	0.0259999999999999988
60505	M1	209.699999999999989	0.0200000000000000004
60505	J1	206.199999999999989	0.0200000000000000004
60505	SSA	51.7999999999999972	0.197000000000000008
60505	SA	176	0.276000000000000023
60505	RHO1	212.300000000000011	0.0100000000000000002
60505	Q1	212.900000000000006	0.0519999999999999976
60505	T2	66	0.0330000000000000016
60505	R2	68.4000000000000057	0.00300000000000000006
60505	2Q1	214.099999999999994	0.00700000000000000015
60505	P1	207	0.120999999999999996
60505	L2	39.2000000000000028	0.0980000000000000038
60505	K2	70.5	0.150999999999999995
60505	M8	312.5	0.0200000000000000004
60506	M2	27	3.31400000000000006
60506	S2	60.7000000000000028	0.502000000000000002
60506	N2	16.6999999999999993	0.751000000000000001
60506	K1	203.199999999999989	0.350999999999999979
60506	M4	280.600000000000023	0.135000000000000009
60506	O1	209.400000000000006	0.259000000000000008
60506	M6	156.699999999999989	0.0259999999999999988
60506	S4	58.6000000000000014	0.0200000000000000004
60506	NU2	18.1000000000000014	0.143999999999999989
60506	S6	119	0.00300000000000000006
60506	MU2	353.100000000000023	0.0790000000000000008
60506	2N2	6.59999999999999964	0.0980000000000000038
60506	OO1	200.300000000000011	0.0100000000000000002
60506	LDA2	42.7000000000000028	0.0229999999999999996
60506	M1	207.099999999999994	0.0200000000000000004
60506	J1	202.900000000000006	0.0200000000000000004
60506	SSA	54.7000000000000028	0.23000000000000001
60506	SA	196.599999999999994	0.281999999999999973
60506	RHO1	210.699999999999989	0.0100000000000000002
60506	Q1	211.300000000000011	0.0490000000000000019
60506	T2	59.2999999999999972	0.0299999999999999989
60506	R2	62.2000000000000028	0.00300000000000000006
60506	2Q1	213.199999999999989	0.00700000000000000015
60506	P1	203.599999999999994	0.115000000000000005
60506	L2	37.2000000000000028	0.0919999999999999984
60506	K2	63.5	0.138000000000000012
60506	M8	321.899999999999977	0.0100000000000000002
60507	M2	41.5	3.82500000000000018
60507	S2	83.7999999999999972	0.586999999999999966
60507	N2	33.3999999999999986	0.778000000000000025
60507	K1	209.800000000000011	0.463000000000000023
60507	M4	231.599999999999994	0.325000000000000011
60507	O1	230.199999999999989	0.322000000000000008
60507	M6	144.400000000000006	0.0459999999999999992
60507	S4	346.800000000000011	0.0200000000000000004
60507	NU2	34.5	0.150999999999999995
60507	S6	314.800000000000011	0.0129999999999999994
60507	MU2	359.199999999999989	0.0919999999999999984
60507	2N2	25.3000000000000007	0.104999999999999996
60507	OO1	189.5	0.0129999999999999994
60507	LDA2	61.1000000000000014	0.0259999999999999988
60507	M1	219.900000000000006	0.0229999999999999996
60507	J1	199.699999999999989	0.0259999999999999988
60507	SSA	54.7000000000000028	0.23000000000000001
60507	SA	196.599999999999994	0.281999999999999973
60507	RHO1	238.900000000000006	0.0129999999999999994
60507	Q1	240.300000000000011	0.0619999999999999996
60507	T2	82.0999999999999943	0.0359999999999999973
60507	R2	85.4000000000000057	0.00300000000000000006
60507	2Q1	250.400000000000006	0.0100000000000000002
60507	P1	211.400000000000006	0.153999999999999998
60507	L2	49.6000000000000014	0.107999999999999999
60507	K2	87.2000000000000028	0.161000000000000004
60507	M8	332.5	0.0299999999999999989
60508	M2	23.3999999999999986	3.20199999999999996
60508	S2	51.1000000000000014	0.525000000000000022
60508	N2	8.09999999999999964	0.740999999999999992
60508	K1	201.199999999999989	0.350999999999999979
60508	M4	303.600000000000023	0.0889999999999999958
60508	O1	208	0.248999999999999999
60508	M6	192.5	0.0229999999999999996
60508	MK3	67.0999999999999943	0.0330000000000000016
60508	S4	2.20000000000000018	0.0259999999999999988
60508	MN4	284.399999999999977	0.0560000000000000012
60508	NU2	359.600000000000023	0.140999999999999986
60508	MU2	52.6000000000000014	0.0919999999999999984
60508	2N2	357.399999999999977	0.0980000000000000038
60508	OO1	216.300000000000011	0.0160000000000000003
60508	LDA2	7.40000000000000036	0.0459999999999999992
60508	S1	170.300000000000011	0.0589999999999999969
60508	M1	213.199999999999989	0.0129999999999999994
60508	J1	229.099999999999994	0.0200000000000000004
60508	SSA	47.7000000000000028	0.370999999999999996
60508	SA	168.199999999999989	0.370999999999999996
60508	RHO1	210.800000000000011	0.0100000000000000002
60508	Q1	201.599999999999994	0.0560000000000000012
60508	T2	30.3000000000000007	0.0519999999999999976
60508	R2	291.300000000000011	0.0229999999999999996
60508	2Q1	214.599999999999994	0.00700000000000000015
60508	P1	202.699999999999989	0.120999999999999996
60508	2SM2	77.2000000000000028	0.0129999999999999994
60508	M3	171.300000000000011	0.0519999999999999976
60508	L2	17.1999999999999993	0.194000000000000006
60508	2MK3	96.4000000000000057	0.0299999999999999989
60508	K2	53.1000000000000014	0.135000000000000009
60508	MS4	285.899999999999977	0.0389999999999999999
60509	M2	32	3.40200000000000014
60509	S2	67.2999999999999972	0.531000000000000028
60509	N2	21.8000000000000007	0.791000000000000036
60509	K1	204.300000000000011	0.36399999999999999
60509	M4	261.800000000000011	0.140999999999999986
60509	O1	212.300000000000011	0.262000000000000011
60509	M6	155.599999999999994	0.0429999999999999966
60509	S4	31.5	0.0259999999999999988
60509	NU2	23.1999999999999993	0.153999999999999998
60509	S6	55.1000000000000014	0.00300000000000000006
60509	MU2	356.5	0.0820000000000000034
60509	2N2	11.6999999999999993	0.104999999999999996
60509	OO1	198.800000000000011	0.0100000000000000002
60509	LDA2	48.3999999999999986	0.0229999999999999996
60509	M1	208.900000000000006	0.0200000000000000004
60509	J1	202	0.0200000000000000004
60509	SSA	54.7000000000000028	0.23000000000000001
60509	SA	196.599999999999994	0.281999999999999973
60509	RHO1	214.599999999999994	0.0100000000000000002
60509	Q1	215.900000000000006	0.0490000000000000019
60509	T2	65.7999999999999972	0.0330000000000000016
60509	R2	68.7999999999999972	0.00300000000000000006
60509	2Q1	218.199999999999989	0.00700000000000000015
60509	P1	204.900000000000006	0.120999999999999996
60509	L2	42.1000000000000014	0.0950000000000000011
60509	K2	70.0999999999999943	0.143999999999999989
60509	M8	326.399999999999977	0.0129999999999999994
60510	M2	28.1000000000000014	3.17300000000000004
60510	S2	58.6000000000000014	0.478999999999999981
60510	N2	15.4000000000000004	0.734999999999999987
60510	K1	199.400000000000006	0.328000000000000014
60510	M4	315.300000000000011	0.0719999999999999946
60510	O1	208.800000000000011	0.248999999999999999
60510	M6	187.400000000000006	0.0200000000000000004
60510	S4	13.8000000000000007	0.0160000000000000003
60510	NU2	17.1000000000000014	0.143999999999999989
60510	S6	346.899999999999977	0.00700000000000000015
60510	MU2	357.5	0.0749999999999999972
60510	2N2	2.60000000000000009	0.0980000000000000038
60510	OO1	191.900000000000006	0.0100000000000000002
60510	LDA2	42.2999999999999972	0.0229999999999999996
60510	M1	204.699999999999989	0.0200000000000000004
60510	J1	196.400000000000006	0.0160000000000000003
60510	SSA	54.7000000000000028	0.23000000000000001
60510	SA	196.599999999999994	0.281999999999999973
60510	RHO1	211.800000000000011	0.0100000000000000002
60510	Q1	212.599999999999994	0.0459999999999999992
60510	T2	57.5	0.0259999999999999988
60510	R2	60	0.00300000000000000006
60510	2Q1	216.199999999999989	0.00700000000000000015
60510	P1	200	0.107999999999999999
60510	L2	40.8999999999999986	0.0889999999999999958
60510	K2	61.1000000000000014	0.131000000000000005
60510	M8	299.600000000000023	0.00700000000000000015
60511	M2	54.7999999999999972	3.06400000000000006
60511	S2	94.4000000000000057	0.44900000000000001
60511	N2	54.3999999999999986	0.646000000000000019
60511	K1	236.300000000000011	0.357999999999999985
60511	M4	348.199999999999989	0.259000000000000008
60511	O1	233.199999999999989	0.253000000000000003
60511	M6	265.300000000000011	0.0889999999999999958
60511	S4	81.0999999999999943	0.0229999999999999996
60511	NU2	54.3999999999999986	0.125
60511	S6	207.800000000000011	0.0100000000000000002
60511	MU2	15.5999999999999996	0.0719999999999999946
60511	2N2	54	0.0850000000000000061
60511	OO1	238.900000000000006	0.0100000000000000002
60511	LDA2	73	0.0200000000000000004
60511	M1	234.5	0.0160000000000000003
60511	J1	237.400000000000006	0.0200000000000000004
60511	SSA	54.7000000000000028	0.23000000000000001
60511	SA	196.599999999999994	0.281999999999999973
60511	RHO1	231.699999999999989	0.0100000000000000002
60511	Q1	232	0.0490000000000000019
60511	T2	92.5	0.0259999999999999988
60511	R2	95.5	0.00300000000000000006
60511	2Q1	230.199999999999989	0.00700000000000000015
60511	P1	236.099999999999994	0.117999999999999994
60511	L2	55.5	0.0850000000000000061
60511	K2	97.5	0.120999999999999996
60511	M8	123	0.00700000000000000015
60512	M2	36.2999999999999972	3.11699999999999999
60512	S2	67.7000000000000028	0.509000000000000008
60512	N2	19.6999999999999993	0.679000000000000048
60512	K1	209.5	0.347999999999999976
60512	M4	207.5	0.131000000000000005
60512	O1	218	0.262000000000000011
60512	M6	165.800000000000011	0.0330000000000000016
60512	MK3	31.6999999999999993	0.0589999999999999969
60512	S4	353.399999999999977	0.0229999999999999996
60512	MN4	205	0.0660000000000000031
60512	NU2	19.1999999999999993	0.164000000000000007
60512	MU2	70.2000000000000028	0.112000000000000002
60512	2N2	340.100000000000023	0.0850000000000000061
60512	OO1	200.900000000000006	0.0100000000000000002
60512	LDA2	30.3999999999999986	0.0749999999999999972
60512	S1	174.300000000000011	0.0619999999999999996
60512	M1	261.699999999999989	0.0299999999999999989
60512	J1	205.199999999999989	0.0200000000000000004
60512	RHO1	221.699999999999989	0.0100000000000000002
60512	Q1	217.199999999999989	0.0589999999999999969
60512	T2	45.8999999999999986	0.0660000000000000031
60512	R2	307	0.0389999999999999999
60512	2Q1	226.400000000000006	0.00700000000000000015
60512	P1	207.199999999999989	0.117999999999999994
60512	2SM2	96.2000000000000028	0.0100000000000000002
60512	M3	183	0.0330000000000000016
60512	L2	29.1999999999999993	0.131000000000000005
60512	2MK3	45.1000000000000014	0.0330000000000000016
60512	K2	66.0999999999999943	0.131000000000000005
60512	M8	317.399999999999977	0.0160000000000000003
60512	MS4	236.800000000000011	0.0719999999999999946
60513	M2	37.3999999999999986	2.99500000000000011
60513	S2	67	0.459000000000000019
60513	N2	25.1999999999999993	0.616999999999999993
60513	K1	212	0.328000000000000014
60513	M4	222	0.107999999999999999
60513	O1	216.900000000000006	0.256000000000000005
60513	M6	161.800000000000011	0.0330000000000000016
60513	MK3	36.8999999999999986	0.0459999999999999992
60513	S4	359.899999999999977	0.0160000000000000003
60513	MN4	223.800000000000011	0.0560000000000000012
60513	NU2	21.5	0.131000000000000005
60513	S6	74.2999999999999972	0.00300000000000000006
60513	MU2	92.0999999999999943	0.112000000000000002
60513	2N2	31.1000000000000014	0.0749999999999999972
60513	OO1	211.199999999999989	0.0299999999999999989
60513	LDA2	16.8000000000000007	0.0660000000000000031
60513	S1	161.199999999999989	0.0459999999999999992
60513	M1	268.699999999999989	0.00700000000000000015
60513	J1	276.800000000000011	0.0229999999999999996
60513	SSA	54.7000000000000028	0.23000000000000001
60513	SA	196.599999999999994	0.281999999999999973
60513	RHO1	201.300000000000011	0.0200000000000000004
60513	Q1	210.099999999999994	0.0429999999999999966
60513	T2	104.700000000000003	0.0519999999999999976
60513	R2	236.800000000000011	0.0560000000000000012
60513	2Q1	308.199999999999989	0.0129999999999999994
60513	P1	208.800000000000011	0.107999999999999999
60513	2SM2	45.5	0.0259999999999999988
60513	M3	179.199999999999989	0.0459999999999999992
60513	L2	15.5	0.164000000000000007
60513	2MK3	43.7999999999999972	0.0299999999999999989
60513	K2	48.2000000000000028	0.138000000000000012
60513	M8	328	0.0200000000000000004
60513	MS4	247.800000000000011	0.0589999999999999969
60514	M2	45.2000000000000028	2.82799999999999985
60514	S2	70.9000000000000057	0.412999999999999978
60514	N2	39.3999999999999986	0.558000000000000052
60514	K1	218.199999999999989	0.343999999999999972
60514	M4	265	0.104999999999999996
60514	O1	227.599999999999994	0.266000000000000014
60514	M6	195.599999999999994	0.0389999999999999999
60514	MK3	64.0999999999999943	0.0490000000000000019
60514	S4	17.1000000000000014	0.0299999999999999989
60514	MN4	266.100000000000023	0.0690000000000000058
60514	NU2	18.1000000000000014	0.0950000000000000011
60514	MU2	112.900000000000006	0.0889999999999999958
60514	2N2	30.3999999999999986	0.101999999999999993
60514	LDA2	19.3000000000000007	0.0719999999999999946
60514	S1	163	0.0490000000000000019
60514	J1	234.099999999999994	0.0359999999999999973
60514	SSA	54.7000000000000028	0.23000000000000001
60514	SA	196.599999999999994	0.281999999999999973
60514	Q1	225.699999999999989	0.0719999999999999946
60514	T2	67.0999999999999943	0.0919999999999999984
60514	R2	13.5999999999999996	0.0690000000000000058
60514	P1	228	0.128000000000000003
60514	M3	213.099999999999994	0.0490000000000000019
60514	L2	26.3000000000000007	0.194000000000000006
60514	2MK3	56.6000000000000014	0.0589999999999999969
60514	K2	60	0.128000000000000003
60514	M8	2.60000000000000009	0.0160000000000000003
60514	MS4	283.899999999999977	0.0490000000000000019
60515	M2	59.7000000000000028	2.36500000000000021
60515	S2	98	0.301999999999999991
60515	N2	57.7999999999999972	0.412999999999999978
60515	K1	221.800000000000011	0.288999999999999979
60515	M4	321.300000000000011	0.140999999999999986
60515	O1	248.5	0.216999999999999998
60515	M6	248.599999999999994	0.0690000000000000058
60515	S4	28.5	0.0129999999999999994
60515	NU2	58	0.0790000000000000008
60515	S6	135.800000000000011	0.00700000000000000015
60515	MU2	21.8000000000000007	0.0560000000000000012
60515	2N2	55.7000000000000028	0.0519999999999999976
60515	OO1	198.5	0.0100000000000000002
60515	LDA2	77.4000000000000057	0.0160000000000000003
60515	M1	235.199999999999989	0.0160000000000000003
60515	J1	210.300000000000011	0.0160000000000000003
60515	SSA	54.7000000000000028	0.23000000000000001
60515	SA	196.599999999999994	0.281999999999999973
60515	RHO1	259.600000000000023	0.00700000000000000015
60515	Q1	261.300000000000011	0.0429999999999999966
60515	T2	96.5	0.0200000000000000004
60515	R2	99.2000000000000028	0.00300000000000000006
60515	2Q1	271.600000000000023	0.00700000000000000015
60515	P1	223.800000000000011	0.0950000000000000011
60515	L2	61.3999999999999986	0.0660000000000000031
60515	K2	101.099999999999994	0.0820000000000000034
60515	M8	79.2000000000000028	0.0200000000000000004
60516	M2	26.8000000000000007	2.93000000000000016
60516	S2	57.2999999999999972	0.190000000000000002
60516	N2	9.90000000000000036	0.622999999999999998
60516	K1	200.699999999999989	0.404000000000000026
60516	M4	152.400000000000006	0.0619999999999999996
60516	O1	216	0.27200000000000002
60516	M6	153.300000000000011	0.0229999999999999996
60516	MK3	24	0.0359999999999999973
60516	S4	340.600000000000023	0.0259999999999999988
60516	MN4	170.400000000000006	0.0330000000000000016
60516	NU2	357.600000000000023	0.117999999999999994
60516	S6	42.3999999999999986	0.00300000000000000006
60516	MU2	52.6000000000000014	0.0790000000000000008
60516	2N2	351.800000000000011	0.0790000000000000008
60516	OO1	183.099999999999994	0.0359999999999999973
60516	LDA2	358.300000000000011	0.0459999999999999992
60516	S1	141.400000000000006	0.0980000000000000038
60516	M1	230.699999999999989	0.0229999999999999996
60516	J1	224.199999999999989	0.0129999999999999994
60516	SSA	54.7000000000000028	0.23000000000000001
60516	SA	119.599999999999994	0.281999999999999973
60516	RHO1	353.399999999999977	0.0129999999999999994
60516	Q1	215.099999999999994	0.0619999999999999996
60516	T2	2.20000000000000018	0.138000000000000012
60516	R2	291.399999999999977	0.27200000000000002
60516	2Q1	125.299999999999997	0.0100000000000000002
60516	P1	186.099999999999994	0.0980000000000000038
60516	2SM2	138.099999999999994	0.00300000000000000006
60516	M3	160	0.0389999999999999999
60516	L2	27	0.135000000000000009
60516	2MK3	356.199999999999989	0.0100000000000000002
60516	K2	146.400000000000006	0.0889999999999999958
60516	M8	273.600000000000023	0.0129999999999999994
60516	MS4	203.300000000000011	0.0389999999999999999
60517	M2	16.3000000000000007	2.80799999999999983
60517	S2	37.6000000000000014	0.443000000000000005
60517	N2	353.699999999999989	0.619999999999999996
60517	K1	192.800000000000011	0.338000000000000023
60517	M4	354.5	0.0330000000000000016
60517	O1	205.400000000000006	0.248999999999999999
60517	M6	138.099999999999994	0.0129999999999999994
60517	MK3	86.0999999999999943	0.0129999999999999994
60517	S4	293.699999999999989	0.0160000000000000003
60517	MN4	310.800000000000011	0.0160000000000000003
60517	NU2	1.30000000000000004	0.125
60517	S6	283.600000000000023	0.00300000000000000006
60517	MU2	4.20000000000000018	0.0850000000000000061
60517	2N2	339.800000000000011	0.0660000000000000031
60517	OO1	207.400000000000006	0.0299999999999999989
60517	LDA2	24	0.0330000000000000016
60517	S1	156.300000000000011	0.0459999999999999992
60517	M1	216.099999999999994	0.0100000000000000002
60517	J1	199.5	0.0160000000000000003
60517	SSA	54.7000000000000028	0.23000000000000001
60517	SA	119.599999999999994	0.281999999999999973
60517	RHO1	264.899999999999977	0.0160000000000000003
60517	Q1	193.400000000000006	0.0519999999999999976
60517	T2	23.5	0.0490000000000000019
60517	R2	257.600000000000023	0.0259999999999999988
60517	2Q1	155.300000000000011	0.00300000000000000006
60517	P1	190.300000000000011	0.117999999999999994
60517	2SM2	31.8000000000000007	0.0229999999999999996
60517	M3	154.099999999999994	0.0389999999999999999
60517	L2	45.2000000000000028	0.0560000000000000012
60517	2MK3	157.300000000000011	0.0299999999999999989
60517	K2	41.6000000000000014	0.104999999999999996
60517	M8	353.100000000000023	0.00300000000000000006
60517	MS4	123.200000000000003	0.0129999999999999994
60518	M2	41	2.98600000000000021
60518	S2	75.5999999999999943	0.463000000000000023
60518	N2	38	0.596999999999999975
60518	K1	208.699999999999989	0.343999999999999972
60518	M4	218.400000000000006	0.157000000000000001
60518	O1	225	0.284999999999999976
60518	M6	149.099999999999994	0.0229999999999999996
60518	S4	27.6000000000000014	0.0359999999999999973
60518	NU2	38.3999999999999986	0.115000000000000005
60518	S6	304.899999999999977	0.00700000000000000015
60518	MU2	202.900000000000006	0.0719999999999999946
60518	2N2	34.7999999999999972	0.0790000000000000008
60518	OO1	196.699999999999989	0.0100000000000000002
60518	LDA2	57.2999999999999972	0.0200000000000000004
60518	M1	217.800000000000011	0.0200000000000000004
60518	J1	203.699999999999989	0.0200000000000000004
60518	SSA	54.7000000000000028	0.23000000000000001
60518	SA	196.599999999999994	0.281999999999999973
60518	RHO1	231.199999999999989	0.0100000000000000002
60518	Q1	232.199999999999989	0.0560000000000000012
60518	T2	74.2000000000000028	0.0259999999999999988
60518	R2	77	0.00300000000000000006
60518	2Q1	239.300000000000011	0.00700000000000000015
60518	P1	209.900000000000006	0.115000000000000005
60518	L2	44.3999999999999986	0.0820000000000000034
60518	K2	78.4000000000000057	0.125
60518	M8	320.399999999999977	0.0259999999999999988
60519	M2	32.8999999999999986	2.94600000000000017
60519	S2	61.2000000000000028	0.446000000000000008
60519	N2	14.6999999999999993	0.646000000000000019
60519	K1	208	0.347999999999999976
60519	M4	193.599999999999994	0.0980000000000000038
60519	O1	215.900000000000006	0.256000000000000005
60519	M6	124.700000000000003	0.0200000000000000004
60519	MK3	28.3000000000000007	0.0429999999999999966
60519	S4	339.699999999999989	0.0200000000000000004
60519	MN4	192.900000000000006	0.0519999999999999976
60519	NU2	11.6999999999999993	0.125
60519	MU2	69.4000000000000057	0.0850000000000000061
60519	2N2	350.600000000000023	0.0850000000000000061
60519	OO1	208.900000000000006	0.0160000000000000003
60519	LDA2	10.1999999999999993	0.0459999999999999992
60519	S1	177.5	0.0490000000000000019
60519	M1	261.699999999999989	0.0129999999999999994
60519	J1	245.099999999999994	0.0160000000000000003
60519	SSA	54.7000000000000028	0.23000000000000001
60519	SA	196.599999999999994	0.281999999999999973
60519	RHO1	234.400000000000006	0.0100000000000000002
60519	Q1	210	0.0519999999999999976
60519	T2	49.3999999999999986	0.0490000000000000019
60519	R2	290.399999999999977	0.0330000000000000016
60519	2Q1	223.599999999999994	0.00700000000000000015
60519	P1	206.400000000000006	0.120999999999999996
60519	2SM2	99.0999999999999943	0.0129999999999999994
60519	M3	171.900000000000006	0.0330000000000000016
60519	L2	37.7999999999999972	0.131000000000000005
60519	2MK3	46.2000000000000028	0.0160000000000000003
60519	K2	67.2999999999999972	0.0980000000000000038
60519	M8	288.199999999999989	0.0129999999999999994
60519	MS4	223.400000000000006	0.0519999999999999976
60520	M2	43.3999999999999986	2.91699999999999982
60520	S2	73.5	0.44900000000000001
60520	N2	33.8999999999999986	0.61399999999999999
60520	K1	225.900000000000006	0.370999999999999996
60520	M4	230.800000000000011	0.153999999999999998
60520	O1	215.800000000000011	0.233000000000000013
60520	M6	92	0.0330000000000000016
60520	S4	356.699999999999989	0.0299999999999999989
60520	NU2	35.2000000000000028	0.117999999999999994
60520	S6	146.800000000000011	0.00700000000000000015
60520	MU2	210.099999999999994	0.0690000000000000058
60520	2N2	24.3999999999999986	0.0820000000000000034
60520	OO1	235.800000000000011	0.0100000000000000002
60520	LDA2	57.3999999999999986	0.0200000000000000004
60520	M1	220.800000000000011	0.0160000000000000003
60520	J1	230.699999999999989	0.0200000000000000004
60520	SSA	54.7000000000000028	0.23000000000000001
60520	SA	196.599999999999994	0.281999999999999973
60520	RHO1	211.5	0.0100000000000000002
60520	Q1	210.900000000000006	0.0459999999999999992
60520	T2	72.2999999999999972	0.0259999999999999988
60520	R2	74.7000000000000028	0.00300000000000000006
60520	2Q1	205.900000000000006	0.00700000000000000015
60520	P1	225.099999999999994	0.120999999999999996
60520	L2	52.7999999999999972	0.0820000000000000034
60520	K2	75.9000000000000057	0.120999999999999996
60520	M8	297.5	0.0330000000000000016
60521	M2	157.5	1.004
60521	S2	221.699999999999989	0.0330000000000000016
60521	N2	168.199999999999989	0.235999999999999988
60521	K1	312.600000000000023	0.259000000000000008
60521	M4	145.099999999999994	0.161000000000000004
60521	O1	322	0.171000000000000013
60521	M6	134.699999999999989	0.0389999999999999999
60521	S4	155.900000000000006	0.0160000000000000003
60521	NU2	166.699999999999989	0.0459999999999999992
60521	S6	190.300000000000011	0.00700000000000000015
60521	MU2	290	0.0229999999999999996
60521	2N2	178.900000000000006	0.0330000000000000016
60521	OO1	303.199999999999989	0.00700000000000000015
60521	LDA2	187.300000000000011	0.00700000000000000015
60521	M1	317.300000000000011	0.0129999999999999994
60521	J1	307.899999999999977	0.0129999999999999994
60521	RHO1	326.100000000000023	0.00700000000000000015
60521	Q1	326.699999999999989	0.0330000000000000016
60521	T2	219.199999999999989	0.00300000000000000006
60521	2Q1	331.399999999999977	0.00300000000000000006
60521	P1	313.300000000000011	0.0850000000000000061
60521	L2	146.699999999999989	0.0299999999999999989
60521	K2	226.900000000000006	0.0100000000000000002
60521	M8	102.200000000000003	0.0129999999999999994
60522	M2	51.8999999999999986	2.16900000000000004
60522	S2	86.5999999999999943	0.226000000000000006
60522	N2	40.2999999999999972	0.384000000000000008
60522	K1	231.199999999999989	0.338000000000000023
60522	M4	355	0.153999999999999998
60522	O1	229.199999999999989	0.360999999999999988
60522	M6	184.099999999999994	0.0560000000000000012
60522	S4	231.099999999999994	0.0100000000000000002
60522	NU2	41.7999999999999972	0.0749999999999999972
60522	S6	32.8999999999999986	0.00300000000000000006
60522	MU2	17.1999999999999993	0.0519999999999999976
60522	2N2	28.6000000000000014	0.0519999999999999976
60522	OO1	233.099999999999994	0.0160000000000000003
60522	LDA2	68	0.0160000000000000003
60522	M1	230.199999999999989	0.0259999999999999988
60522	J1	232.099999999999994	0.0299999999999999989
60522	RHO1	228.400000000000006	0.0129999999999999994
60522	Q1	228.199999999999989	0.0690000000000000058
60522	T2	85.2000000000000028	0.0129999999999999994
60522	R2	88	0.00300000000000000006
60522	2Q1	227.300000000000011	0.0100000000000000002
60522	P1	231	0.112000000000000002
60522	L2	63.5	0.0619999999999999996
60522	K2	89.4000000000000057	0.0619999999999999996
60522	M8	133.900000000000006	0.0129999999999999994
60523	M2	75.9000000000000057	2.08999999999999986
60523	S2	117.900000000000006	0.281999999999999973
60523	N2	66.7000000000000028	0.39700000000000002
60523	K1	241.300000000000011	0.301999999999999991
60523	M4	5.70000000000000018	0.157000000000000001
60523	O1	245.900000000000006	0.235999999999999988
60523	M6	255.099999999999994	0.0790000000000000008
60523	MK3	115.200000000000003	0.0690000000000000058
60523	S4	75.2000000000000028	0.0160000000000000003
60523	MN4	353.899999999999977	0.0790000000000000008
60523	NU2	53.6000000000000014	0.140999999999999986
60523	S6	142.5	0.00300000000000000006
60523	MU2	147.800000000000011	0.115000000000000005
60523	2N2	18.8000000000000007	0.0619999999999999996
60523	OO1	272.600000000000023	0.0100000000000000002
60523	LDA2	65.7000000000000028	0.0429999999999999966
60523	S1	221.800000000000011	0.0330000000000000016
60523	M1	340.800000000000011	0.0299999999999999989
60523	J1	309.399999999999977	0.0129999999999999994
60523	RHO1	240.199999999999989	0.0200000000000000004
60523	Q1	247.800000000000011	0.0560000000000000012
60523	T2	95	0.0519999999999999976
60523	R2	320.800000000000011	0.0330000000000000016
60523	2Q1	192.5	0.00700000000000000015
60523	P1	238.099999999999994	0.0850000000000000061
60523	2SM2	56.7999999999999972	0.0200000000000000004
60523	M3	221.599999999999994	0.0229999999999999996
60523	L2	70.2999999999999972	0.164000000000000007
60523	2MK3	111.700000000000003	0.0619999999999999996
60523	K2	115.700000000000003	0.0589999999999999969
60523	M8	150.199999999999989	0.0160000000000000003
60523	MS4	37.1000000000000014	0.0490000000000000019
60524	M2	68.2999999999999972	1.44999999999999996
60524	S2	100.599999999999994	0.194000000000000006
60524	N2	56.2999999999999972	0.301999999999999991
60524	K1	247.300000000000011	0.147999999999999993
60524	M4	47.1000000000000014	0.0749999999999999972
60524	O1	243.699999999999989	0.107999999999999999
60524	M6	351.399999999999977	0.0589999999999999969
60524	S4	11	0.0100000000000000002
60524	NU2	58	0.0589999999999999969
60524	S6	172.199999999999989	0.00300000000000000006
60524	MU2	35.3999999999999986	0.0359999999999999973
60524	2N2	44.3999999999999986	0.0389999999999999999
60524	OO1	254.800000000000011	0.00300000000000000006
60524	LDA2	83.5	0.0100000000000000002
60524	M1	245.099999999999994	0.00700000000000000015
60524	J1	248.800000000000011	0.0100000000000000002
60524	MM	227.599999999999994	0.0820000000000000034
60524	SSA	54.8999999999999986	0.253000000000000003
60524	SA	189.900000000000006	0.377000000000000002
60524	MSF	197.599999999999994	0.128000000000000003
60524	RHO1	242.5	0.00300000000000000006
60524	Q1	242.400000000000006	0.0200000000000000004
60524	T2	99.2000000000000028	0.0100000000000000002
60524	2Q1	240.800000000000011	0.00300000000000000006
60524	P1	246.900000000000006	0.0490000000000000019
60524	L2	80.7000000000000028	0.0389999999999999999
60524	K2	103.200000000000003	0.0519999999999999976
60524	M8	23.8999999999999986	0.00700000000000000015
60525	M2	46.2999999999999972	2.1030000000000002
60525	S2	75.7000000000000028	0.312
60525	N2	36.3999999999999986	0.429999999999999993
60525	K1	228.099999999999994	0.279000000000000026
60525	M4	282.300000000000011	0.0790000000000000008
60525	O1	220.599999999999994	0.190000000000000002
60525	M6	266.5	0.0330000000000000016
60525	S4	339.699999999999989	0.0200000000000000004
60525	NU2	37.7000000000000028	0.0820000000000000034
60525	MU2	16.8999999999999986	0.0490000000000000019
60525	2N2	26.5	0.0560000000000000012
60525	LDA2	59.7999999999999972	0.0129999999999999994
60525	M1	224.199999999999989	0.0129999999999999994
60525	J1	231.400000000000006	0.0160000000000000003
60525	SSA	55.3999999999999986	0.253000000000000003
60525	SA	190.199999999999989	0.377000000000000002
60525	Q1	217.199999999999989	0.0359999999999999973
60525	T2	74.4000000000000057	0.0160000000000000003
60525	P1	227.5	0.0919999999999999984
60525	L2	56.1000000000000014	0.0589999999999999969
60525	K2	78.0999999999999943	0.0850000000000000061
60525	M8	16.3999999999999986	0.0129999999999999994
60526	M2	45.6000000000000014	1.7649999999999999
60526	S2	72.4000000000000057	0.242999999999999994
60526	N2	32.2000000000000028	0.357999999999999985
60526	K1	225.199999999999989	0.209999999999999992
60526	M4	19.3000000000000007	0.0259999999999999988
60526	O1	219.300000000000011	0.147999999999999993
60526	M6	270.5	0.0589999999999999969
60526	S4	347.300000000000011	0.0160000000000000003
60526	NU2	34	0.0690000000000000058
60526	S6	68.7000000000000028	0.00700000000000000015
60526	MU2	18.8999999999999986	0.0429999999999999966
60526	2N2	18.6999999999999993	0.0490000000000000019
60526	OO1	230.599999999999994	0.00700000000000000015
60526	LDA2	58	0.0129999999999999994
60526	M1	222.400000000000006	0.0100000000000000002
60526	J1	229.300000000000011	0.0100000000000000002
60526	MM	227.599999999999994	0.0820000000000000034
60526	SSA	54.8999999999999986	0.253000000000000003
60526	SA	189.900000000000006	0.377000000000000002
60526	MSF	197.599999999999994	0.128000000000000003
60526	RHO1	216.5	0.00700000000000000015
60526	Q1	216	0.0299999999999999989
60526	T2	71.2000000000000028	0.0129999999999999994
60526	R2	73.4000000000000057	0.00300000000000000006
60526	2Q1	214.099999999999994	0.00300000000000000006
60526	P1	224.800000000000011	0.0690000000000000058
60526	L2	59.1000000000000014	0.0490000000000000019
60526	K2	74.5999999999999943	0.0660000000000000031
60526	M8	301.899999999999977	0.0100000000000000002
60527	M2	20.8999999999999986	2.31300000000000017
60527	S2	43.6000000000000014	0.370999999999999996
60527	N2	5.59999999999999964	0.525000000000000022
60527	K1	199.699999999999989	0.284999999999999976
60527	M4	152.300000000000011	0.0919999999999999984
60527	O1	205.599999999999994	0.20699999999999999
60527	M6	179.199999999999989	0.0229999999999999996
60527	MK3	30.1999999999999993	0.0200000000000000004
60527	S4	292.600000000000023	0.0200000000000000004
60527	MN4	163.199999999999989	0.0299999999999999989
60527	NU2	355.699999999999989	0.112000000000000002
60527	MU2	17	0.0619999999999999996
60527	2N2	345.5	0.0660000000000000031
60527	OO1	193.699999999999989	0.0100000000000000002
60527	LDA2	29.6999999999999993	0.0259999999999999988
60527	S1	156.800000000000011	0.0299999999999999989
60527	M1	230.099999999999994	0.0160000000000000003
60527	J1	219.199999999999989	0.0129999999999999994
60527	MM	230.400000000000006	0.0820000000000000034
60527	SSA	55.3999999999999986	0.253000000000000003
60527	SA	190.199999999999989	0.377000000000000002
60527	MSF	202.699999999999989	0.128000000000000003
60527	RHO1	208.099999999999994	0.00700000000000000015
60527	Q1	199.699999999999989	0.0429999999999999966
60527	T2	35.3999999999999986	0.0389999999999999999
60527	R2	44.5	0.00300000000000000006
60527	2Q1	211.400000000000006	0.00700000000000000015
60527	P1	197.300000000000011	0.0980000000000000038
60527	2SM2	84.7000000000000028	0.0200000000000000004
60527	M3	174.199999999999989	0.0259999999999999988
60527	L2	11.1999999999999993	0.0749999999999999972
60527	2MK3	37.7999999999999972	0.0229999999999999996
60527	K2	41.2999999999999972	0.0980000000000000038
60527	MS4	162.199999999999989	0.0389999999999999999
60528	M2	80.0999999999999943	1.31200000000000006
60528	S2	115.5	0.173999999999999988
60528	N2	72.5	0.248999999999999999
60528	K1	255.800000000000011	0.157000000000000001
60528	M4	90.4000000000000057	0.0160000000000000003
60528	O1	245.5	0.0889999999999999958
60528	M6	50.7999999999999972	0.0749999999999999972
60528	S4	47.3999999999999986	0.0129999999999999994
60528	NU2	73.5999999999999943	0.0490000000000000019
60528	MU2	44.5	0.0299999999999999989
60528	2N2	65	0.0330000000000000016
60528	LDA2	96.5	0.0100000000000000002
60528	M1	251.400000000000006	0.00700000000000000015
60528	SSA	55.3999999999999986	0.253000000000000003
60528	SA	190.199999999999989	0.377000000000000002
60528	Q1	239.599999999999994	0.0160000000000000003
60528	T2	114	0.0100000000000000002
60528	2Q1	233.699999999999989	0.00300000000000000006
60528	P1	255	0.0519999999999999976
60528	L2	87.5	0.0359999999999999973
60528	K2	118.299999999999997	0.0459999999999999992
60528	M8	322.199999999999989	0.0100000000000000002
60529	M2	20	2.35199999999999987
60529	S2	43.5	0.377000000000000002
60529	N2	357.5	0.52200000000000002
60529	K1	192.099999999999994	0.27200000000000002
60529	M4	117.400000000000006	0.0429999999999999966
60529	O1	205.599999999999994	0.209999999999999992
60529	M6	133	0.0129999999999999994
60529	MK3	23.6999999999999993	0.0100000000000000002
60529	S4	276.100000000000023	0.0100000000000000002
60529	MN4	107	0.0129999999999999994
60529	NU2	351.899999999999977	0.0980000000000000038
60529	MU2	9.69999999999999929	0.0660000000000000031
60529	2N2	353.199999999999989	0.0589999999999999969
60529	OO1	203.800000000000011	0.0200000000000000004
60529	LDA2	66.2000000000000028	0.0200000000000000004
60529	S1	172.400000000000006	0.0719999999999999946
60529	M1	235.800000000000011	0.00700000000000000015
60529	J1	206	0.0129999999999999994
60529	MM	230.400000000000006	0.0820000000000000034
60529	SSA	55.3999999999999986	0.253000000000000003
60529	SA	190.199999999999989	0.377000000000000002
60529	MSF	202.699999999999989	0.128000000000000003
60529	RHO1	249.800000000000011	0.0160000000000000003
60529	Q1	196.199999999999989	0.0490000000000000019
60529	T2	50.3999999999999986	0.0519999999999999976
60529	R2	290.100000000000023	0.0359999999999999973
60529	2Q1	69.7000000000000028	0.00700000000000000015
60529	P1	197.900000000000006	0.104999999999999996
60529	2SM2	28.1999999999999993	0.0160000000000000003
60529	M3	151.400000000000006	0.0229999999999999996
60529	L2	55.7999999999999972	0.0359999999999999973
60529	2MK3	150.800000000000011	0.0200000000000000004
60529	K2	40.7999999999999972	0.0850000000000000061
60529	M8	325.300000000000011	0.0100000000000000002
60529	MS4	139	0.0259999999999999988
60530	M2	26.3999999999999986	2.18800000000000017
60530	S2	49.8999999999999986	0.343999999999999972
60530	N2	8.19999999999999929	0.471999999999999975
60530	K1	204.300000000000011	0.276000000000000023
60530	M4	163.800000000000011	0.101999999999999993
60530	O1	211	0.190000000000000002
60530	M6	195.699999999999989	0.0299999999999999989
60530	MK3	22.1999999999999993	0.0259999999999999988
60530	S4	288.899999999999977	0.0129999999999999994
60530	MN4	161.199999999999989	0.0330000000000000016
60530	NU2	5.79999999999999982	0.101999999999999993
60530	MU2	30.8999999999999986	0.0490000000000000019
60530	2N2	349.199999999999989	0.0589999999999999969
60530	OO1	245.5	0.0100000000000000002
60530	LDA2	39.3999999999999986	0.0299999999999999989
60530	S1	170.800000000000011	0.0389999999999999999
60530	M1	249.699999999999989	0.0100000000000000002
60530	J1	209.199999999999989	0.0160000000000000003
60530	SSA	52.7999999999999972	0.304999999999999993
60530	SA	188.199999999999989	0.373999999999999999
60530	RHO1	240.400000000000006	0.00700000000000000015
60530	Q1	207.599999999999994	0.0389999999999999999
60530	T2	40.1000000000000014	0.0389999999999999999
60530	R2	285.699999999999989	0.0200000000000000004
60530	2Q1	198.400000000000006	0.00700000000000000015
60530	P1	201	0.0950000000000000011
60530	2SM2	73.2999999999999972	0.0100000000000000002
60530	M3	155.800000000000011	0.0259999999999999988
60530	L2	29.8999999999999986	0.0749999999999999972
60530	2MK3	44.7999999999999972	0.0160000000000000003
60530	K2	47.6000000000000014	0.0889999999999999958
60530	M8	353.100000000000023	0.0100000000000000002
60530	MS4	179.699999999999989	0.0389999999999999999
60531	M2	50.2000000000000028	1.69300000000000006
60531	S2	78.5	0.233000000000000013
60531	N2	34.3999999999999986	0.328000000000000014
60531	K1	220.199999999999989	0.190000000000000002
60531	M4	312.300000000000011	0.0490000000000000019
60531	O1	226.400000000000006	0.135000000000000009
60531	M6	302.699999999999989	0.0690000000000000058
60531	MK3	75.2999999999999972	0.0389999999999999999
60531	S4	353.5	0.00700000000000000015
60531	MN4	295.600000000000023	0.0259999999999999988
60531	NU2	28.8000000000000007	0.0719999999999999946
60531	MU2	123.900000000000006	0.0359999999999999973
60531	2N2	35.1000000000000014	0.0330000000000000016
60531	OO1	272.5	0.00700000000000000015
60531	LDA2	46.7999999999999972	0.0389999999999999999
60531	S1	210.300000000000011	0.0299999999999999989
60531	M1	244.300000000000011	0.00300000000000000006
60531	J1	224.5	0.0100000000000000002
60531	MM	227.599999999999994	0.0820000000000000034
60531	SSA	54.8999999999999986	0.253000000000000003
60531	SA	189.900000000000006	0.377000000000000002
60531	MSF	197.599999999999994	0.128000000000000003
60531	RHO1	234.900000000000006	0.00300000000000000006
60531	Q1	227.900000000000006	0.0299999999999999989
60531	T2	74.5	0.0259999999999999988
60531	R2	295.5	0.0229999999999999996
60531	2Q1	238.699999999999989	0.0100000000000000002
60531	P1	213.699999999999989	0.0690000000000000058
60531	2SM2	10.4000000000000004	0.00300000000000000006
60531	M3	177.400000000000006	0.0229999999999999996
60531	L2	56.3999999999999986	0.104999999999999996
60531	2MK3	72	0.0359999999999999973
60531	K2	71.5	0.0660000000000000031
60531	M8	38.6000000000000014	0.00700000000000000015
60531	MS4	287.300000000000011	0.0129999999999999994
60532	M2	28.1000000000000014	2.17200000000000015
60532	S2	51.5	0.36399999999999999
60532	N2	10.0999999999999996	0.48899999999999999
60532	K1	203.900000000000006	0.269000000000000017
60532	M4	170.5	0.0790000000000000008
60532	O1	212.199999999999989	0.197000000000000008
60532	M6	212.199999999999989	0.0330000000000000016
60532	MK3	38.2999999999999972	0.0299999999999999989
60532	MN4	171.400000000000006	0.0299999999999999989
60532	NU2	6.59999999999999964	0.107999999999999999
60532	MU2	28.6000000000000014	0.0560000000000000012
60532	2N2	5.59999999999999964	0.0589999999999999969
60532	OO1	195.5	0.0100000000000000002
60532	LDA2	34.1000000000000014	0.0359999999999999973
60532	S1	164.199999999999989	0.0299999999999999989
60532	M1	208	0.0129999999999999994
60532	J1	199.800000000000011	0.0160000000000000003
60532	MM	230.400000000000006	0.0820000000000000034
60532	SSA	55.3999999999999986	0.253000000000000003
60532	SA	190.199999999999989	0.377000000000000002
60532	MSF	202.699999999999989	0.128000000000000003
60532	RHO1	215.800000000000011	0.00700000000000000015
60532	Q1	201	0.0389999999999999999
60532	T2	51.3999999999999986	0.0200000000000000004
60532	R2	51.3999999999999986	0.00300000000000000006
60532	2Q1	220.5	0.00700000000000000015
60532	P1	196.300000000000011	0.0919999999999999984
60532	L2	28.8999999999999986	0.125
60532	K2	50	0.104999999999999996
60532	MS4	180.900000000000006	0.0389999999999999999
60533	M2	27.5	2.14900000000000002
60533	S2	49.5	0.294999999999999984
60533	N2	8.69999999999999929	0.463000000000000023
60533	K1	205	0.27200000000000002
60533	M4	160	0.0919999999999999984
60533	O1	213.099999999999994	0.187
60533	M6	195.800000000000011	0.0359999999999999973
60533	MK3	19.1000000000000014	0.0299999999999999989
60533	S4	299.800000000000011	0.0160000000000000003
60533	MN4	164.099999999999994	0.0359999999999999973
60533	NU2	1.19999999999999996	0.0850000000000000061
60533	S6	16.3999999999999986	0.00700000000000000015
60533	MU2	55.8999999999999986	0.0429999999999999966
60533	2N2	5.90000000000000036	0.0589999999999999969
60533	OO1	172.800000000000011	0.0359999999999999973
60533	LDA2	22.1999999999999993	0.0259999999999999988
60533	S1	162	0.0299999999999999989
60533	M1	235.599999999999994	0.0100000000000000002
60533	J1	155	0.0129999999999999994
60533	MM	230.400000000000006	0.0820000000000000034
60533	SSA	55.3999999999999986	0.253000000000000003
60533	SA	190.199999999999989	0.377000000000000002
60533	MSF	202.699999999999989	0.128000000000000003
60533	MF	116.200000000000003	0.153999999999999998
60533	RHO1	256.199999999999989	0.00700000000000000015
60533	Q1	201.300000000000011	0.0519999999999999976
60533	T2	61.2999999999999972	0.0429999999999999966
60533	R2	197.5	0.0129999999999999994
60533	2Q1	312.899999999999977	0.00700000000000000015
60533	P1	191.400000000000006	0.0889999999999999958
60533	2SM2	141.800000000000011	0.00300000000000000006
60533	M3	157.300000000000011	0.0330000000000000016
60533	L2	50.2999999999999972	0.0889999999999999958
60533	2MK3	27.1999999999999993	0.0160000000000000003
60533	K2	38.5	0.0850000000000000061
60533	M8	350.600000000000023	0.0100000000000000002
60533	MS4	175	0.0299999999999999989
60534	M2	61	1.2629999999999999
60534	S2	87.2999999999999972	0.190000000000000002
60534	N2	52.3999999999999986	0.242999999999999994
60534	K1	242.099999999999994	0.138000000000000012
60534	M4	63.7000000000000028	0.0560000000000000012
60534	O1	234.300000000000011	0.107999999999999999
60534	M6	331	0.0690000000000000058
60534	S4	25.1000000000000014	0.0129999999999999994
60534	NU2	53.5	0.0459999999999999992
60534	S6	333.600000000000023	0.00300000000000000006
60534	MU2	231.5	0.0299999999999999989
60534	2N2	43.7999999999999972	0.0330000000000000016
60534	OO1	249.400000000000006	0.00300000000000000006
60534	LDA2	73.0999999999999943	0.0100000000000000002
60534	M1	238.099999999999994	0.00700000000000000015
60534	J1	245.699999999999989	0.0100000000000000002
60534	SSA	55.3999999999999986	0.253000000000000003
60534	SA	190.199999999999989	0.377000000000000002
60534	RHO1	230.800000000000011	0.00300000000000000006
60534	Q1	230.5	0.0200000000000000004
60534	T2	86.2999999999999972	0.0100000000000000002
60534	2Q1	226.199999999999989	0.00300000000000000006
60534	P1	241.400000000000006	0.0459999999999999992
60534	L2	69.2999999999999972	0.0359999999999999973
60534	K2	89.5	0.0519999999999999976
60534	M8	40.8999999999999986	0.00700000000000000015
60535	M2	74.5	0.876000000000000001
60535	S2	105	0.117999999999999994
60535	N2	56.2999999999999972	0.164000000000000007
60535	K1	247.199999999999989	0.0919999999999999984
60535	M4	351.899999999999977	0.0619999999999999996
60535	O1	256.399999999999977	0.0660000000000000031
60535	M6	10.5	0.0459999999999999992
60535	MK3	124.5	0.0330000000000000016
60535	S4	53.8999999999999986	0.00700000000000000015
60535	MN4	341.100000000000023	0.0259999999999999988
60535	NU2	57	0.0389999999999999999
60535	MU2	158.800000000000011	0.0160000000000000003
60535	2N2	30.3999999999999986	0.0160000000000000003
60535	OO1	215.199999999999989	0.00300000000000000006
60535	LDA2	77.5999999999999943	0.0259999999999999988
60535	S1	221.5	0.0229999999999999996
60535	J1	239.699999999999989	0.00300000000000000006
60535	MM	344.600000000000023	0.0389999999999999999
60535	SSA	54.6000000000000014	0.341000000000000025
60535	SA	206.199999999999989	0.509000000000000008
60535	MSF	257.5	0.0589999999999999969
60535	RHO1	342	0.00300000000000000006
60535	Q1	244.900000000000006	0.0129999999999999994
60535	T2	103.200000000000003	0.0160000000000000003
60535	R2	335.100000000000023	0.0100000000000000002
60535	2Q1	209.400000000000006	0.00300000000000000006
60535	P1	242.300000000000011	0.0359999999999999973
60535	2SM2	158	0.00300000000000000006
60535	M3	230.5	0.0129999999999999994
60535	L2	77	0.0660000000000000031
60535	2MK3	121.799999999999997	0.0259999999999999988
60535	K2	99.2999999999999972	0.0259999999999999988
60535	M8	333	0.0100000000000000002
60535	MS4	11.8000000000000007	0.0129999999999999994
60536	M2	64.2999999999999972	1.2430000000000001
60536	S2	95.2000000000000028	0.173999999999999988
60536	N2	49.7000000000000028	0.256000000000000005
60536	K1	230.400000000000006	0.138000000000000012
60536	M4	41.8999999999999986	0.0490000000000000019
60536	O1	240.199999999999989	0.0980000000000000038
60536	M6	334.300000000000011	0.0690000000000000058
60536	MK3	110.700000000000003	0.0259999999999999988
60536	S4	33.7999999999999972	0.0100000000000000002
60536	MN4	10.5	0.0259999999999999988
60536	NU2	40.7000000000000028	0.0519999999999999976
60536	MU2	155.199999999999989	0.0259999999999999988
60536	2N2	63.2000000000000028	0.0259999999999999988
60536	OO1	264.800000000000011	0.0100000000000000002
60536	LDA2	78	0.0389999999999999999
60536	S1	198.599999999999994	0.0200000000000000004
60536	M1	252.300000000000011	0.00700000000000000015
60536	J1	244.300000000000011	0.00700000000000000015
60536	MM	344.899999999999977	0.0790000000000000008
60536	SSA	27.8999999999999986	0.284999999999999976
60536	SA	159.5	0.502000000000000002
60536	MSF	321	0.0519999999999999976
60536	MF	308	0.0229999999999999996
60536	RHO1	235.900000000000006	0.00300000000000000006
60536	Q1	231.400000000000006	0.0160000000000000003
60536	T2	51.7999999999999972	0.0259999999999999988
60536	R2	243.900000000000006	0.00300000000000000006
60536	2Q1	13.0999999999999996	0.00300000000000000006
60536	P1	227.599999999999994	0.0459999999999999992
60536	2SM2	54.6000000000000014	0.00300000000000000006
60536	M3	288.300000000000011	0.00300000000000000006
60536	L2	67.5999999999999943	0.164000000000000007
60536	2MK3	109.599999999999994	0.0259999999999999988
60536	K2	96.9000000000000057	0.0490000000000000019
60536	M8	42.6000000000000014	0.0100000000000000002
60536	MS4	74.5999999999999943	0.00700000000000000015
60537	M2	15.5999999999999996	2.47699999999999987
60537	S2	35.1000000000000014	0.404000000000000026
60537	N2	352.899999999999977	0.576999999999999957
60537	K1	193.099999999999994	0.357999999999999985
60537	M4	19.1000000000000014	0.0389999999999999999
60537	O1	205.5	0.259000000000000008
60537	M6	92.2000000000000028	0.0200000000000000004
60537	S4	293.600000000000023	0.0160000000000000003
60537	NU2	356	0.112000000000000002
60537	S6	290.5	0.0100000000000000002
60537	MU2	193.199999999999989	0.0589999999999999969
60537	2N2	330.199999999999989	0.0749999999999999972
60537	OO1	180.800000000000011	0.0100000000000000002
60537	LDA2	24.8000000000000007	0.0160000000000000003
60537	M1	199.300000000000011	0.0200000000000000004
60537	J1	187.099999999999994	0.0200000000000000004
60537	SSA	52	0.197000000000000008
60537	SA	193.300000000000011	0.331000000000000016
60537	RHO1	210.900000000000006	0.0100000000000000002
60537	Q1	211.699999999999989	0.0490000000000000019
60537	T2	34.2999999999999972	0.0229999999999999996
60537	R2	35.8999999999999986	0.00300000000000000006
60537	2Q1	217.800000000000011	0.00700000000000000015
60537	P1	194.099999999999994	0.117999999999999994
60537	L2	38.3999999999999986	0.0690000000000000058
60537	K2	36.7000000000000028	0.112000000000000002
60537	M8	332.199999999999989	0.00700000000000000015
60538	M2	108.5	0.440000000000000002
60538	S2	135.099999999999994	0.0519999999999999976
60538	N2	94.0999999999999943	0.0790000000000000008
60538	K1	279.899999999999977	0.0690000000000000058
60538	M4	189.5	0.0259999999999999988
60538	O1	282.399999999999977	0.0519999999999999976
60538	M6	120.900000000000006	0.0330000000000000016
60538	MK3	174.900000000000006	0.0100000000000000002
60538	S4	103.900000000000006	0.00300000000000000006
60538	MN4	158.800000000000011	0.0100000000000000002
60538	NU2	94	0.0200000000000000004
60538	MU2	210	0.0129999999999999994
60538	2N2	82.9000000000000057	0.00700000000000000015
60538	OO1	11.0999999999999996	0.00300000000000000006
60538	LDA2	114.099999999999994	0.0129999999999999994
60538	S1	240.400000000000006	0.0160000000000000003
60538	M1	58.2999999999999972	0.00300000000000000006
60538	J1	231.400000000000006	0.00300000000000000006
60538	SSA	68.0999999999999943	0.281999999999999973
60538	SA	191.300000000000011	0.453000000000000014
60538	RHO1	295	0.00300000000000000006
60538	Q1	277.5	0.0100000000000000002
60538	T2	121.299999999999997	0.00700000000000000015
60538	R2	6.5	0.00300000000000000006
60538	2Q1	291.300000000000011	0.00700000000000000015
60538	P1	269.199999999999989	0.0200000000000000004
60538	M3	280.899999999999977	0.00700000000000000015
60538	L2	115.799999999999997	0.0359999999999999973
60538	2MK3	161.900000000000006	0.0129999999999999994
60538	K2	136.400000000000006	0.0160000000000000003
60538	M8	156.699999999999989	0.00300000000000000006
60538	MS4	251.699999999999989	0.00700000000000000015
60539	M2	130.099999999999994	0.400000000000000022
60539	S2	168.900000000000006	0.0490000000000000019
60539	N2	121.599999999999994	0.0660000000000000031
60539	K1	286.199999999999989	0.0660000000000000031
60539	M4	219.199999999999989	0.0429999999999999966
60539	O1	294.699999999999989	0.0519999999999999976
60539	M6	184.800000000000011	0.0490000000000000019
60539	S4	135	0.00300000000000000006
60539	NU2	123	0.0129999999999999994
60539	MU2	91.0999999999999943	0.0100000000000000002
60539	2N2	113.099999999999994	0.0100000000000000002
60539	OO1	244.800000000000011	0.00300000000000000006
60539	LDA2	148.199999999999989	0.00300000000000000006
60539	M1	288.100000000000023	0.00300000000000000006
60539	J1	272.5	0.00300000000000000006
60539	RHO1	311.699999999999989	0.00300000000000000006
60539	Q1	303.100000000000023	0.0100000000000000002
60539	T2	167.599999999999994	0.00300000000000000006
60539	P1	286.100000000000023	0.0229999999999999996
60539	L2	139.699999999999989	0.0100000000000000002
60539	K2	172.300000000000011	0.0129999999999999994
60539	M8	288.800000000000011	0.0100000000000000002
60540	M2	164.199999999999989	0.400000000000000022
60540	S2	196.599999999999994	0.0490000000000000019
60540	N2	147.199999999999989	0.0660000000000000031
60540	K1	309.899999999999977	0.0719999999999999946
60540	M4	263	0.0129999999999999994
60540	O1	301.899999999999977	0.0459999999999999992
60540	M6	258.899999999999977	0.0229999999999999996
60540	S4	221.300000000000011	0.0100000000000000002
60540	NU2	149.5	0.0129999999999999994
60540	S6	33.7000000000000028	0.00300000000000000006
60540	MU2	131.099999999999994	0.0100000000000000002
60540	2N2	128.900000000000006	0.00700000000000000015
60540	OO1	317.399999999999977	0.00300000000000000006
60540	LDA2	179.599999999999994	0.00300000000000000006
60540	M1	305	0.00300000000000000006
60540	J1	313.199999999999989	0.00300000000000000006
60540	RHO1	297.300000000000011	0.00300000000000000006
60540	Q1	296.800000000000011	0.0100000000000000002
60540	T2	196	0.00300000000000000006
60540	P1	309.199999999999989	0.0229999999999999996
60540	L2	180	0.0100000000000000002
60540	K2	199.099999999999994	0.0129999999999999994
60540	M8	323.899999999999977	0.00300000000000000006
60541	M2	168.900000000000006	0.406999999999999973
60541	S2	202.300000000000011	0.0459999999999999992
60541	N2	155.400000000000006	0.0749999999999999972
60541	K1	302.800000000000011	0.0690000000000000058
60541	M4	247.300000000000011	0.0229999999999999996
60541	O1	305.600000000000023	0.0589999999999999969
60541	M6	233.800000000000011	0.0330000000000000016
60541	MK3	234.800000000000011	0.0100000000000000002
60541	S4	229.800000000000011	0.00300000000000000006
60541	MN4	221.5	0.00700000000000000015
60541	NU2	146.900000000000006	0.0200000000000000004
60541	MU2	298.399999999999977	0.0100000000000000002
60541	2N2	114.299999999999997	0.0100000000000000002
60541	LDA2	179.099999999999994	0.0129999999999999994
60541	S1	252.900000000000006	0.0160000000000000003
60541	M1	45.5	0.00700000000000000015
60541	RHO1	297.399999999999977	0.00300000000000000006
60541	Q1	312.199999999999989	0.0100000000000000002
60541	T2	176.300000000000011	0.00700000000000000015
60541	2Q1	253.5	0.00300000000000000006
60541	P1	295.800000000000011	0.0160000000000000003
60541	2SM2	34.8999999999999986	0.00300000000000000006
60541	M3	332.100000000000023	0.00300000000000000006
60541	L2	162.800000000000011	0.0299999999999999989
60541	2MK3	227	0.0129999999999999994
60541	K2	196.400000000000006	0.0129999999999999994
60541	M8	317.100000000000023	0.00700000000000000015
60541	MS4	300.399999999999977	0.00300000000000000006
60542	M2	27.8000000000000007	2.04400000000000004
60542	S2	50.7999999999999972	0.307999999999999996
60542	N2	12.6999999999999993	0.466000000000000025
60542	K1	206.5	0.315000000000000002
60542	M4	171.800000000000011	0.00700000000000000015
60542	O1	212.099999999999994	0.226000000000000006
60542	M6	120.900000000000006	0.0429999999999999966
60542	MK3	76.4000000000000057	0.0229999999999999996
60542	S4	286.399999999999977	0.0200000000000000004
60542	MN4	196.199999999999989	0.0100000000000000002
60542	NU2	8.09999999999999964	0.101999999999999993
60542	S6	300.800000000000011	0.00700000000000000015
60542	MU2	34	0.0519999999999999976
60542	2N2	345.699999999999989	0.0589999999999999969
60542	OO1	232.300000000000011	0.0100000000000000002
60542	LDA2	56.5	0.0259999999999999988
60542	S1	162.099999999999994	0.0389999999999999999
60542	M1	265.5	0.0100000000000000002
60542	J1	207.900000000000006	0.0160000000000000003
60542	MM	100.400000000000006	0.157000000000000001
60542	SSA	14.6999999999999993	0.284999999999999976
60542	SA	204.900000000000006	0.502000000000000002
60542	MSF	132.599999999999994	0.0980000000000000038
60542	MF	98.4000000000000057	0.0619999999999999996
60542	RHO1	215	0.00700000000000000015
60542	Q1	209.400000000000006	0.0459999999999999992
60542	T2	17.6999999999999993	0.0330000000000000016
60542	R2	286.300000000000011	0.0200000000000000004
60542	2Q1	195.400000000000006	0.0129999999999999994
60542	P1	200.900000000000006	0.104999999999999996
60542	2SM2	128.199999999999989	0.00300000000000000006
60542	M3	179.300000000000011	0.0100000000000000002
60542	L2	19.1000000000000014	0.0790000000000000008
60542	2MK3	76.5	0.0229999999999999996
60542	K2	50.1000000000000014	0.0790000000000000008
60542	M8	270.800000000000011	0.00300000000000000006
60542	MS4	131.300000000000011	0.0200000000000000004
60543	M2	35	2.02099999999999991
60543	S2	57.8999999999999986	0.315000000000000002
60543	N2	20.8999999999999986	0.453000000000000014
60543	K1	213.699999999999989	0.328000000000000014
60543	M4	235.900000000000006	0.0229999999999999996
60543	O1	217.400000000000006	0.23000000000000001
60543	M6	129.5	0.0519999999999999976
60543	MK3	66.7999999999999972	0.0299999999999999989
60543	S4	300.5	0.0259999999999999988
60543	MN4	211.699999999999989	0.0160000000000000003
60543	NU2	20.6999999999999993	0.101999999999999993
60543	S6	322.899999999999977	0.00700000000000000015
60543	MU2	57.2000000000000028	0.0589999999999999969
60543	2N2	353.300000000000011	0.0429999999999999966
60543	OO1	250.800000000000011	0.0100000000000000002
60543	LDA2	62.6000000000000014	0.0330000000000000016
60543	S1	186.199999999999989	0.0330000000000000016
60543	M1	254.400000000000006	0.0160000000000000003
60543	J1	236.800000000000011	0.0160000000000000003
60543	RHO1	221.300000000000011	0.0100000000000000002
60543	Q1	216.5	0.0490000000000000019
60543	T2	55.8999999999999986	0.0299999999999999989
60543	R2	326.5	0.0330000000000000016
60543	2Q1	226.300000000000011	0.0100000000000000002
60543	P1	209.800000000000011	0.112000000000000002
60543	2SM2	322.399999999999977	0.00300000000000000006
60543	M3	231.900000000000006	0.0100000000000000002
60543	L2	14.3000000000000007	0.0889999999999999958
60543	2MK3	60.8999999999999986	0.0229999999999999996
60543	K2	62.8999999999999986	0.0690000000000000058
60543	M8	329.699999999999989	0.00300000000000000006
60543	MS4	186.400000000000006	0.0200000000000000004
60544	M2	14.9000000000000004	2.23099999999999987
60544	S2	34.5	0.366999999999999993
60544	N2	352.399999999999977	0.525000000000000022
60544	K1	195.300000000000011	0.338000000000000023
60544	M4	54.6000000000000014	0.0389999999999999999
60544	O1	202.400000000000006	0.242999999999999994
60544	M6	90.7999999999999972	0.0200000000000000004
60544	MK3	123.799999999999997	0.0129999999999999994
60544	S4	258.199999999999989	0.0160000000000000003
60544	MN4	42.1000000000000014	0.0129999999999999994
60544	NU2	354.5	0.104999999999999996
60544	MU2	357.899999999999977	0.0660000000000000031
60544	2N2	333.600000000000023	0.0719999999999999946
60544	OO1	196	0.0129999999999999994
60544	LDA2	29.1999999999999993	0.0229999999999999996
60544	S1	193.400000000000006	0.0299999999999999989
60544	M1	211.800000000000011	0.0100000000000000002
60544	J1	212.099999999999994	0.0229999999999999996
60544	SSA	52	0.197000000000000008
60544	SA	193.300000000000011	0.331000000000000016
60544	RHO1	212.300000000000011	0.0100000000000000002
60544	Q1	196.699999999999989	0.0490000000000000019
60544	T2	32.6000000000000014	0.0429999999999999966
60544	R2	265.199999999999989	0.0200000000000000004
60544	2Q1	209.5	0.00700000000000000015
60544	P1	192	0.115000000000000005
60544	2SM2	48.5	0.0129999999999999994
60544	M3	124.799999999999997	0.0160000000000000003
60544	L2	49.7999999999999972	0.0690000000000000058
60544	2MK3	134	0.0200000000000000004
60544	K2	37.2000000000000028	0.0889999999999999958
60544	MS4	96.5	0.0330000000000000016
60545	M2	207.900000000000006	0.52200000000000002
60545	S2	244.300000000000011	0.0519999999999999976
60545	N2	188.400000000000006	0.0820000000000000034
60545	K1	315.699999999999989	0.0690000000000000058
60545	M4	338.600000000000023	0.0229999999999999996
60545	O1	320.300000000000011	0.0560000000000000012
60545	M6	340.399999999999977	0.0259999999999999988
60545	MK3	316.5	0.0100000000000000002
60545	S4	305.399999999999977	0.00300000000000000006
60545	MN4	312.899999999999977	0.0100000000000000002
60545	NU2	189.900000000000006	0.0229999999999999996
60545	MU2	333.100000000000023	0.0200000000000000004
60545	2N2	218.800000000000011	0.00300000000000000006
60545	OO1	312.199999999999989	0.00300000000000000006
60545	LDA2	224.900000000000006	0.0160000000000000003
60545	S1	290.800000000000011	0.0129999999999999994
60545	M1	30	0.00300000000000000006
60545	SSA	55.3999999999999986	0.253000000000000003
60545	SA	190.199999999999989	0.377000000000000002
60545	RHO1	282.800000000000011	0.00300000000000000006
60545	Q1	331.699999999999989	0.0100000000000000002
60545	T2	210.800000000000011	0.00700000000000000015
60545	R2	142.699999999999989	0.00300000000000000006
60545	2Q1	85.7000000000000028	0.00300000000000000006
60545	P1	305.800000000000011	0.0200000000000000004
60545	2SM2	108	0.00300000000000000006
60545	M3	39.2000000000000028	0.00700000000000000015
60545	L2	226.800000000000011	0.0519999999999999976
60545	2MK3	298	0.0129999999999999994
60545	K2	233.5	0.0200000000000000004
60545	M8	94.5	0.00700000000000000015
60545	MS4	31.8999999999999986	0.00300000000000000006
60546	M2	54.8999999999999986	1.87999999999999989
60546	S2	88	0.269000000000000017
60546	N2	44.5	0.39700000000000002
60546	K1	225.099999999999994	0.298999999999999988
60546	M4	1.30000000000000004	0.0850000000000000061
60546	O1	227.900000000000006	0.235999999999999988
60546	M6	203.900000000000006	0.104999999999999996
60546	MK3	107.5	0.0299999999999999989
60546	S4	16.3000000000000007	0.0200000000000000004
60546	MN4	338.199999999999989	0.0359999999999999973
60546	NU2	31.6000000000000014	0.0950000000000000011
60546	S6	1.30000000000000004	0.00700000000000000015
60546	MU2	109.400000000000006	0.0589999999999999969
60546	2N2	20.5	0.0519999999999999976
60546	OO1	262.300000000000011	0.00700000000000000015
60546	LDA2	44.5	0.0490000000000000019
60546	S1	196.300000000000011	0.0299999999999999989
60546	M1	288.300000000000011	0.0200000000000000004
60546	J1	258	0.0129999999999999994
60546	MM	74.7999999999999972	0.187
60546	SSA	14.8000000000000007	0.269000000000000017
60546	SA	209	0.422999999999999987
60546	MSF	148.199999999999989	0.0200000000000000004
60546	MF	302.300000000000011	0.0129999999999999994
60546	RHO1	226.5	0.0100000000000000002
60546	Q1	221.699999999999989	0.0459999999999999992
60546	T2	82.4000000000000057	0.0200000000000000004
60546	R2	331.399999999999977	0.00700000000000000015
60546	2Q1	247.400000000000006	0.0100000000000000002
60546	P1	221.800000000000011	0.0919999999999999984
60546	2SM2	146.699999999999989	0.0100000000000000002
60546	M3	244	0.0100000000000000002
60546	L2	39	0.101999999999999993
60546	2MK3	95.2000000000000028	0.0299999999999999989
60546	K2	87.0999999999999943	0.0749999999999999972
60546	M8	88.7000000000000028	0.00700000000000000015
60546	MS4	51.2999999999999972	0.0129999999999999994
60547	M2	25.1000000000000014	1.68599999999999994
60547	S2	47.3999999999999986	0.259000000000000008
60547	N2	7.29999999999999982	0.384000000000000008
60547	K1	215.099999999999994	0.279000000000000026
60547	M4	0.599999999999999978	0.0519999999999999976
60547	O1	202.599999999999994	0.187
60547	M6	137.800000000000011	0.0330000000000000016
60547	S4	219.800000000000011	0.0100000000000000002
60547	NU2	9.59999999999999964	0.0749999999999999972
60547	S6	84.2000000000000028	0.0100000000000000002
60547	MU2	200.400000000000006	0.0389999999999999999
60547	2N2	349.399999999999977	0.0519999999999999976
60547	OO1	227.599999999999994	0.0100000000000000002
60547	LDA2	35.3999999999999986	0.0129999999999999994
60547	M1	208.900000000000006	0.0129999999999999994
60547	J1	221.300000000000011	0.0160000000000000003
60547	SSA	52	0.197000000000000008
60547	SA	193.300000000000011	0.331000000000000016
60547	RHO1	197.199999999999989	0.00700000000000000015
60547	Q1	196.400000000000006	0.0359999999999999973
60547	T2	46.5	0.0160000000000000003
60547	R2	48.2000000000000028	0.00300000000000000006
60547	2Q1	190.199999999999989	0.00700000000000000015
60547	P1	214.199999999999989	0.0919999999999999984
60547	L2	42.8999999999999986	0.0459999999999999992
60547	K2	49.2000000000000028	0.0690000000000000058
60547	M8	11	0.0100000000000000002
60548	M2	104	0.679000000000000048
60548	S2	139.5	0.0790000000000000008
60548	N2	101.099999999999994	0.135000000000000009
60548	K1	264.100000000000023	0.157000000000000001
60548	M4	89.4000000000000057	0.0359999999999999973
60548	O1	265.800000000000011	0.131000000000000005
60548	M6	2.20000000000000018	0.0299999999999999989
60548	MK3	168.699999999999989	0.0129999999999999994
60548	S4	15.8000000000000007	0.00300000000000000006
60548	MN4	78.5999999999999943	0.0160000000000000003
60548	NU2	95.2999999999999972	0.0359999999999999973
60548	MU2	186.199999999999989	0.0359999999999999973
60548	2N2	46.2999999999999972	0.0129999999999999994
60548	OO1	306.300000000000011	0.00300000000000000006
60548	LDA2	108.299999999999997	0.0259999999999999988
60548	S1	244	0.0259999999999999988
60548	M1	341.100000000000023	0.0100000000000000002
60548	J1	253.800000000000011	0.00300000000000000006
60548	MM	79.2000000000000028	0.190000000000000002
60548	SSA	22.6000000000000014	0.276000000000000023
60548	SA	206.900000000000006	0.475999999999999979
60548	MSF	82	0.0980000000000000038
60548	MF	113	0.0660000000000000031
60548	RHO1	263.300000000000011	0.00700000000000000015
60548	Q1	260.300000000000011	0.0259999999999999988
60548	T2	134.5	0.00700000000000000015
60548	R2	32.8999999999999986	0.00700000000000000015
60548	2Q1	258.300000000000011	0.00300000000000000006
60548	P1	257.600000000000023	0.0459999999999999992
60548	2SM2	299.300000000000011	0.00700000000000000015
60548	M3	73.5999999999999943	0.00300000000000000006
60548	L2	93.9000000000000057	0.0519999999999999976
60548	2MK3	156.599999999999994	0.0129999999999999994
60548	K2	131.599999999999994	0.0200000000000000004
60548	M8	217.599999999999994	0.00300000000000000006
60548	MS4	134.099999999999994	0.0100000000000000002
60549	M2	242.900000000000006	0.528000000000000025
60549	S2	284.100000000000023	0.0560000000000000012
60549	N2	227.300000000000011	0.0919999999999999984
60549	K1	333.600000000000023	0.0560000000000000012
60549	M4	82.5	0.0589999999999999969
60549	O1	340.399999999999977	0.0389999999999999999
60549	M6	170.400000000000006	0.0490000000000000019
60549	MK3	13.5	0.0129999999999999994
60549	MN4	62.7000000000000028	0.0160000000000000003
60549	NU2	225.199999999999989	0.0299999999999999989
60549	S6	39.2000000000000028	0.00300000000000000006
60549	MU2	355.600000000000023	0.0229999999999999996
60549	2N2	189	0.0129999999999999994
60549	OO1	283.399999999999977	0.00300000000000000006
60549	LDA2	261.5	0.0129999999999999994
60549	S1	338.800000000000011	0.0100000000000000002
60549	M1	74.5999999999999943	0.00700000000000000015
60549	J1	239.699999999999989	0.00300000000000000006
60549	MM	128.199999999999989	0.150999999999999995
60549	SSA	13.1999999999999993	0.366999999999999993
60549	SA	212.599999999999994	0.622999999999999998
60549	MSF	122	0.0589999999999999969
60549	MF	113.099999999999994	0.0429999999999999966
60549	RHO1	343	0.00300000000000000006
60549	Q1	357.800000000000011	0.00700000000000000015
60549	T2	212.599999999999994	0.0100000000000000002
60549	R2	195.599999999999994	0.00300000000000000006
60549	P1	355.899999999999977	0.0100000000000000002
60549	2SM2	87.2000000000000028	0.00700000000000000015
60549	M3	101.900000000000006	0.0100000000000000002
60549	L2	250.400000000000006	0.0389999999999999999
60549	2MK3	4.40000000000000036	0.0200000000000000004
60549	K2	270.5	0.0160000000000000003
60549	M8	355.100000000000023	0.0129999999999999994
60549	MS4	132.300000000000011	0.0129999999999999994
60550	M2	227.300000000000011	0.630000000000000004
60550	S2	265.699999999999989	0.0690000000000000058
60550	N2	213.900000000000006	0.104999999999999996
60550	K1	324.699999999999989	0.0719999999999999946
60550	M4	37.7999999999999972	0.0490000000000000019
60550	O1	330.899999999999977	0.0519999999999999976
60550	M6	96.7000000000000028	0.0459999999999999992
60550	MK3	350.699999999999989	0.0129999999999999994
60550	S4	9.59999999999999964	0.00300000000000000006
60550	MN4	16.3000000000000007	0.0129999999999999994
60550	NU2	208.099999999999994	0.0330000000000000016
60550	MU2	344.300000000000011	0.0259999999999999988
60550	2N2	168.800000000000011	0.0160000000000000003
60550	OO1	266.100000000000023	0.00300000000000000006
60550	LDA2	243.800000000000011	0.0200000000000000004
60550	S1	324.699999999999989	0.0129999999999999994
60550	M1	61.7999999999999972	0.00700000000000000015
60550	J1	256.399999999999977	0.00300000000000000006
60550	MM	126.099999999999994	0.161000000000000004
60550	SSA	15.5999999999999996	0.33500000000000002
60550	SA	213.199999999999989	0.580999999999999961
60550	MSF	107.299999999999997	0.0589999999999999969
60550	MF	104.799999999999997	0.0389999999999999999
60550	RHO1	290.699999999999989	0.00300000000000000006
60550	Q1	343.199999999999989	0.0100000000000000002
60550	T2	211.199999999999989	0.0100000000000000002
60550	R2	201.599999999999994	0.00300000000000000006
60550	2Q1	279.899999999999977	0.00300000000000000006
60550	P1	344	0.0100000000000000002
60550	2SM2	69	0.00700000000000000015
60550	M3	76.2999999999999972	0.00700000000000000015
60550	L2	229.400000000000006	0.0459999999999999992
60550	2MK3	340	0.0229999999999999996
60550	K2	257.5	0.0200000000000000004
60550	M8	235.199999999999989	0.0100000000000000002
60550	MS4	85.2999999999999972	0.0100000000000000002
60551	M2	256.899999999999977	0.194000000000000006
60551	S2	279.600000000000023	0.0200000000000000004
60551	N2	238.5	0.0299999999999999989
60551	K1	337.199999999999989	0.0160000000000000003
60551	M4	136.800000000000011	0.0389999999999999999
60551	O1	2	0.0160000000000000003
60551	M6	258.399999999999977	0.0330000000000000016
60551	NU2	241	0.00700000000000000015
60551	2N2	220.099999999999994	0.00300000000000000006
60551	Q1	14.1999999999999993	0.00300000000000000006
60551	P1	339	0.00700000000000000015
60551	L2	271.399999999999977	0.0200000000000000004
60551	K2	281.300000000000011	0.00700000000000000015
60552	M2	10.9000000000000004	1.95199999999999996
60552	S2	32.3999999999999986	0.347999999999999976
60552	N2	349.600000000000023	0.481999999999999984
60552	K1	196.400000000000006	0.328000000000000014
60552	O1	200.900000000000006	0.253000000000000003
60552	NU2	352.399999999999977	0.0950000000000000011
60552	MU2	353.100000000000023	0.0589999999999999969
60552	2N2	328.399999999999977	0.0660000000000000031
60552	OO1	191.800000000000011	0.0100000000000000002
60552	LDA2	20.8000000000000007	0.0129999999999999994
60552	M1	198.5	0.0160000000000000003
60552	J1	194.199999999999989	0.0200000000000000004
60552	SSA	52.3999999999999986	0.253000000000000003
60552	SA	197.5	0.341000000000000025
60552	Q1	197.900000000000006	0.0490000000000000019
60552	T2	32.2999999999999972	0.0200000000000000004
60552	P1	190.699999999999989	0.107999999999999999
60552	L2	31	0.0790000000000000008
60552	K2	33.8999999999999986	0.0719999999999999946
60553	M2	228.800000000000011	1.873
60553	S2	251.300000000000011	0.291999999999999982
60553	N2	208.5	0.406999999999999973
60553	K1	135.099999999999994	0.426999999999999991
60553	M4	137.5	0.0459999999999999992
60553	O1	133.699999999999989	0.269000000000000017
60553	M6	288.300000000000011	0.0299999999999999989
60553	S4	293.600000000000023	0.0160000000000000003
60553	NU2	211.300000000000011	0.0790000000000000008
60553	S6	21	0.0100000000000000002
60553	MU2	184.199999999999989	0.0459999999999999992
60553	2N2	188.300000000000011	0.0560000000000000012
60553	OO1	136.400000000000006	0.0129999999999999994
60553	LDA2	239.199999999999989	0.0129999999999999994
60553	M1	134.400000000000006	0.0200000000000000004
60553	J1	135.699999999999989	0.0229999999999999996
60553	RHO1	133.099999999999994	0.0100000000000000002
60553	Q1	133	0.0519999999999999976
60553	T2	250.400000000000006	0.0160000000000000003
60553	R2	252.199999999999989	0.00300000000000000006
60553	2Q1	132.300000000000011	0.00700000000000000015
60553	P1	134.900000000000006	0.140999999999999986
60553	L2	249	0.0519999999999999976
60553	K2	253.099999999999994	0.0790000000000000008
60553	M8	228.099999999999994	0.00700000000000000015
60554	M2	21	1.46700000000000008
60554	S2	48.8999999999999986	0.220000000000000001
60554	N2	358.300000000000011	0.322000000000000008
60554	K1	204.300000000000011	0.27200000000000002
60554	M4	82.2000000000000028	0.0100000000000000002
60554	O1	209.199999999999989	0.203000000000000014
60554	M6	138.800000000000011	0.0200000000000000004
60554	MK3	97.7000000000000028	0.00300000000000000006
60554	S4	258.5	0.0100000000000000002
60554	MN4	192.699999999999989	0.00300000000000000006
60554	NU2	351.199999999999989	0.0619999999999999996
60554	S6	228.900000000000006	0.00300000000000000006
60554	MU2	10.9000000000000004	0.0429999999999999966
60554	2N2	335	0.0299999999999999989
60554	OO1	210.400000000000006	0.0100000000000000002
60554	LDA2	39.6000000000000014	0.0229999999999999996
60554	S1	104.400000000000006	0.0100000000000000002
60554	M1	225.099999999999994	0.0100000000000000002
60554	J1	236	0.0129999999999999994
60554	RHO1	200.5	0.0160000000000000003
60554	Q1	196.099999999999994	0.0459999999999999992
60554	T2	0.400000000000000022	0.0229999999999999996
60554	R2	253.599999999999994	0.0259999999999999988
60554	2Q1	210	0.00300000000000000006
60554	P1	214.099999999999994	0.0820000000000000034
60554	2SM2	50.5	0.0100000000000000002
60554	M3	87.9000000000000057	0.0100000000000000002
60554	L2	50.3999999999999986	0.0429999999999999966
60554	2MK3	99.5	0.00700000000000000015
60554	K2	43.8999999999999986	0.0619999999999999996
60554	M8	208.400000000000006	0.00700000000000000015
60554	MS4	124.599999999999994	0.0160000000000000003
60555	M2	37.1000000000000014	1.17100000000000004
60555	S2	58.8999999999999986	0.143999999999999989
60555	N2	18.1000000000000014	0.256000000000000005
60555	K1	208.400000000000006	0.223000000000000004
60555	M4	327.300000000000011	0.0299999999999999989
60555	O1	225.300000000000011	0.173999999999999988
60555	M6	191.599999999999994	0.0299999999999999989
60555	S4	310.899999999999977	0.00700000000000000015
60555	NU2	20.6000000000000014	0.0490000000000000019
60555	S6	206.300000000000011	0.00300000000000000006
60555	MU2	15.4000000000000004	0.0259999999999999988
60555	2N2	359.100000000000023	0.0330000000000000016
60555	OO1	191.400000000000006	0.00700000000000000015
60555	LDA2	47.2000000000000028	0.00700000000000000015
60555	M1	216.800000000000011	0.0129999999999999994
60555	J1	199.900000000000006	0.0129999999999999994
60555	RHO1	232.599999999999994	0.00700000000000000015
60555	Q1	233.599999999999994	0.0330000000000000016
60555	T2	57.8999999999999986	0.0100000000000000002
60555	2Q1	242.199999999999989	0.00300000000000000006
60555	P1	209.599999999999994	0.0749999999999999972
60555	L2	56.1000000000000014	0.0330000000000000016
60555	K2	60.6000000000000014	0.0389999999999999999
60555	M8	227.300000000000011	0.00300000000000000006
60556	M2	67.2000000000000028	0.515000000000000013
60556	S2	93.5	0.0719999999999999946
60556	N2	57.2999999999999972	0.0950000000000000011
60556	K1	224	0.0919999999999999984
60556	M4	93.7999999999999972	0.0359999999999999973
60556	O1	232.400000000000006	0.0749999999999999972
60556	M6	310.800000000000011	0.0389999999999999999
60556	S4	8.30000000000000071	0.00300000000000000006
60556	NU2	58.7000000000000028	0.0160000000000000003
60556	S6	258.300000000000011	0.00300000000000000006
60556	MU2	40.7999999999999972	0.0129999999999999994
60556	2N2	46.8999999999999986	0.0129999999999999994
60556	OO1	217.5	0.00300000000000000006
60556	LDA2	79.4000000000000057	0.00300000000000000006
60556	M1	230.900000000000006	0.00300000000000000006
60556	J1	221.199999999999989	0.00700000000000000015
60556	RHO1	235.400000000000006	0.00300000000000000006
60556	Q1	235.599999999999994	0.0129999999999999994
60556	T2	92.5	0.00300000000000000006
60556	2Q1	239.599999999999994	0.00300000000000000006
60556	P1	224.800000000000011	0.0299999999999999989
60556	L2	77.2999999999999972	0.0129999999999999994
60556	K2	95.7999999999999972	0.0200000000000000004
60556	M8	359	0.00700000000000000015
60557	M2	115	0.20699999999999999
60557	S2	147.099999999999994	0.0299999999999999989
60557	N2	115.5	0.0330000000000000016
60557	K1	209.099999999999994	0.0459999999999999992
60557	M4	182.599999999999994	0.0229999999999999996
60557	O1	248.599999999999994	0.0259999999999999988
60557	M6	60.8999999999999986	0.0100000000000000002
60557	S4	65.0999999999999943	0.00300000000000000006
60557	NU2	115.5	0.00700000000000000015
60557	S6	4.20000000000000018	0.00300000000000000006
60557	MU2	82.9000000000000057	0.00700000000000000015
60557	2N2	116	0.00300000000000000006
60557	M1	228.699999999999989	0.00300000000000000006
60557	J1	189.5	0.00300000000000000006
60557	Q1	268.199999999999989	0.00700000000000000015
60557	T2	145.900000000000006	0.00300000000000000006
60557	P1	212.099999999999994	0.0160000000000000003
60557	L2	114.5	0.00700000000000000015
60557	K2	149.699999999999989	0.00700000000000000015
60557	M8	154.699999999999989	0.00300000000000000006
60558	M2	7.29999999999999982	1.68599999999999994
60558	S2	27	0.262000000000000011
60558	N2	345.399999999999977	0.400000000000000022
60558	K1	200	0.325000000000000011
60558	M4	133.199999999999989	0.0129999999999999994
60558	O1	206.599999999999994	0.248999999999999999
60558	M6	307.199999999999989	0.0259999999999999988
60558	S4	204	0.0129999999999999994
60558	NU2	346.300000000000011	0.0790000000000000008
60558	MU2	350.300000000000011	0.0519999999999999976
60558	2N2	326.399999999999977	0.0560000000000000012
60558	OO1	217.199999999999989	0.0160000000000000003
60558	LDA2	27.1999999999999993	0.0160000000000000003
60558	S1	174.099999999999994	0.0200000000000000004
60558	M1	218	0.0100000000000000002
60558	J1	211	0.0160000000000000003
60558	SSA	49.2000000000000028	0.203000000000000014
60558	SA	195.300000000000011	0.318000000000000005
60558	RHO1	209.300000000000011	0.0100000000000000002
60558	Q1	198.699999999999989	0.0519999999999999976
60558	T2	12.5	0.0299999999999999989
60558	R2	231.5	0.0100000000000000002
60558	2Q1	213	0.00700000000000000015
60558	P1	201.599999999999994	0.107999999999999999
60558	M3	49.2000000000000028	0.0100000000000000002
60558	L2	41.2999999999999972	0.0429999999999999966
60558	K2	28.8000000000000007	0.0690000000000000058
60558	MS4	91.2999999999999972	0.0160000000000000003
60559	M2	5.5	1.74199999999999999
60559	S2	27.1000000000000014	0.288999999999999979
60559	N2	347.5	0.390000000000000013
60559	K1	201.300000000000011	0.347999999999999976
60559	M4	104	0.0100000000000000002
60559	O1	203.5	0.259000000000000008
60559	M6	293.899999999999977	0.0299999999999999989
60559	S4	232.400000000000006	0.0160000000000000003
60559	NU2	341.399999999999977	0.0850000000000000061
60559	S6	135	0.0200000000000000004
60559	MU2	345.199999999999989	0.0589999999999999969
60559	2N2	336.100000000000023	0.0589999999999999969
60559	OO1	199	0.0100000000000000002
60559	LDA2	15.4000000000000004	0.0129999999999999994
60559	S1	155.099999999999994	0.0229999999999999996
60559	M1	202.300000000000011	0.0200000000000000004
60559	J1	200.199999999999989	0.0200000000000000004
60559	RHO1	204.300000000000011	0.0100000000000000002
60559	Q1	198.699999999999989	0.0660000000000000031
60559	T2	2.60000000000000009	0.0359999999999999973
60559	R2	27.1000000000000014	0.00300000000000000006
60559	2Q1	205.599999999999994	0.00700000000000000015
60559	P1	208.599999999999994	0.112000000000000002
60559	2SM2	15.8000000000000007	0.0160000000000000003
60559	L2	348.800000000000011	0.0389999999999999999
60559	K2	24.8999999999999986	0.0790000000000000008
60559	MS4	91.4000000000000057	0.0160000000000000003
60560	M2	7.20000000000000018	1.6339999999999999
60560	S2	28.1999999999999993	0.253000000000000003
60560	N2	348.600000000000023	0.384000000000000008
60560	K1	201.599999999999994	0.331000000000000016
60560	M4	114.900000000000006	0.0129999999999999994
60560	O1	206	0.242999999999999994
60560	M6	314.100000000000023	0.0259999999999999988
60560	MK3	104.900000000000006	0.00300000000000000006
60560	S4	220.599999999999994	0.0100000000000000002
60560	MN4	124	0.00700000000000000015
60560	NU2	347.600000000000023	0.0749999999999999972
60560	S6	135.400000000000006	0.00700000000000000015
60560	MU2	346.199999999999989	0.0519999999999999976
60560	2N2	335.300000000000011	0.0560000000000000012
60560	OO1	228	0.0100000000000000002
60560	LDA2	47.6000000000000014	0.0160000000000000003
60560	S1	184.5	0.0259999999999999988
60560	M1	251.099999999999994	0.0160000000000000003
60560	J1	205.099999999999994	0.0160000000000000003
60560	SSA	49.2000000000000028	0.203000000000000014
60560	SA	195.300000000000011	0.318000000000000005
60560	RHO1	221.300000000000011	0.0100000000000000002
60560	Q1	192	0.0560000000000000012
60560	T2	19.8999999999999986	0.0330000000000000016
60560	R2	256.399999999999977	0.0129999999999999994
60560	2Q1	161.900000000000006	0.00300000000000000006
60560	P1	200.800000000000011	0.115000000000000005
60560	2SM2	52.6000000000000014	0.0100000000000000002
60560	M3	28.6999999999999993	0.0100000000000000002
60560	L2	348.100000000000023	0.0359999999999999973
60560	2MK3	143.5	0.00700000000000000015
60560	K2	28.1999999999999993	0.0660000000000000031
60560	M8	339.399999999999977	0.00700000000000000015
60560	MS4	94	0.0160000000000000003
60561	M2	119.799999999999997	0.341000000000000025
60561	S2	165.300000000000011	0.0299999999999999989
60561	N2	97.9000000000000057	0.0660000000000000031
60561	K1	284.399999999999977	0.0589999999999999969
60561	M4	165.699999999999989	0.0229999999999999996
60561	O1	281.899999999999977	0.0749999999999999972
60561	M6	33.5	0.0129999999999999994
60561	S4	263.899999999999977	0.00300000000000000006
60561	NU2	100.5	0.0129999999999999994
60561	MU2	263.699999999999989	0.00700000000000000015
60561	2N2	75.2999999999999972	0.0100000000000000002
60561	OO1	296	0.00300000000000000006
60561	LDA2	144.199999999999989	0.00300000000000000006
60561	M1	283.899999999999977	0.00300000000000000006
60561	J1	285.300000000000011	0.00700000000000000015
60561	RHO1	278.199999999999989	0.00300000000000000006
60561	Q1	280.5	0.0129999999999999994
60561	T2	156.599999999999994	0.00300000000000000006
60561	2Q1	274	0.00300000000000000006
60561	P1	284.800000000000011	0.0200000000000000004
60561	L2	142.099999999999994	0.0100000000000000002
60561	K2	167.300000000000011	0.00700000000000000015
60561	M8	81.0999999999999943	0.00300000000000000006
60562	M2	37.7000000000000028	0.734999999999999987
60562	S2	51.2999999999999972	0.107999999999999999
60562	N2	11.0999999999999996	0.16700000000000001
60562	K1	234.800000000000011	0.164000000000000007
60562	M4	257.5	0.0200000000000000004
60562	O1	245.300000000000011	0.143999999999999989
60562	M6	214	0.0100000000000000002
60562	S4	72	0.00300000000000000006
60562	NU2	14.5999999999999996	0.0330000000000000016
60562	S6	113.299999999999997	0.00300000000000000006
60562	MU2	223.5	0.0160000000000000003
60562	2N2	344.399999999999977	0.0229999999999999996
60562	OO1	224.300000000000011	0.00700000000000000015
60562	LDA2	44	0.00700000000000000015
60562	M1	240	0.0100000000000000002
60562	J1	229.599999999999994	0.0129999999999999994
60562	RHO1	249.800000000000011	0.00700000000000000015
60562	Q1	250.5	0.0299999999999999989
60562	T2	50.7999999999999972	0.00700000000000000015
60562	2Q1	255.699999999999989	0.00300000000000000006
60562	P1	235.599999999999994	0.0560000000000000012
60562	L2	64.4000000000000057	0.0200000000000000004
60562	K2	52.3999999999999986	0.0299999999999999989
60562	M8	358.100000000000023	0.00300000000000000006
60563	M2	20.1999999999999993	0.993999999999999995
60563	S2	42.2000000000000028	0.150999999999999995
60563	N2	356.800000000000011	0.23000000000000001
60563	K1	219.699999999999989	0.190000000000000002
60563	M4	189.699999999999989	0.0519999999999999976
60563	O1	232.699999999999989	0.164000000000000007
60563	M6	193.199999999999989	0.0129999999999999994
60563	S4	270.800000000000011	0.00300000000000000006
60563	NU2	359.899999999999977	0.0459999999999999992
60563	S6	72.0999999999999943	0.00300000000000000006
60563	MU2	197.599999999999994	0.0229999999999999996
60563	2N2	333.5	0.0299999999999999989
60563	OO1	206.199999999999989	0.00700000000000000015
60563	LDA2	30.3999999999999986	0.00700000000000000015
60563	M1	226	0.0100000000000000002
60563	J1	212.900000000000006	0.0129999999999999994
60563	RHO1	238.400000000000006	0.00700000000000000015
60563	Q1	239.300000000000011	0.0330000000000000016
60563	T2	41.2999999999999972	0.0100000000000000002
60563	2Q1	245.900000000000006	0.00300000000000000006
60563	P1	220.699999999999989	0.0619999999999999996
60563	L2	43.5	0.0259999999999999988
60563	K2	44	0.0389999999999999999
60563	M8	350.100000000000023	0.00300000000000000006
60564	M2	39.1000000000000014	0.682000000000000051
60564	S2	60.8999999999999986	0.0919999999999999984
60564	N2	11.1999999999999993	0.161000000000000004
60564	K1	241.400000000000006	0.161000000000000004
60564	M4	222.199999999999989	0.0330000000000000016
60564	O1	252.699999999999989	0.138000000000000012
60564	M6	194.400000000000006	0.0200000000000000004
60564	S4	263.300000000000011	0.00300000000000000006
60564	NU2	14.9000000000000004	0.0330000000000000016
60564	S6	90.7000000000000028	0.00300000000000000006
60564	MU2	17.3000000000000007	0.0160000000000000003
60564	2N2	343.300000000000011	0.0229999999999999996
60564	OO1	230.099999999999994	0.00700000000000000015
60564	LDA2	49.2000000000000028	0.00300000000000000006
60564	M1	247	0.0100000000000000002
60564	J1	235.800000000000011	0.0100000000000000002
60564	RHO1	257.600000000000023	0.00700000000000000015
60564	Q1	258.300000000000011	0.0259999999999999988
60564	T2	60	0.00700000000000000015
60564	2Q1	264	0.00300000000000000006
60564	P1	242.300000000000011	0.0519999999999999976
60564	L2	67	0.0200000000000000004
60564	K2	62.6000000000000014	0.0259999999999999988
60564	M8	31	0.00300000000000000006
60565	M2	35.8999999999999986	1.22999999999999998
60565	S2	67.2999999999999972	0.200000000000000011
60565	N2	18.1000000000000014	0.279000000000000026
60565	K1	234.400000000000006	0.190000000000000002
60565	M4	326.600000000000023	0.0160000000000000003
60565	O1	245.800000000000011	0.161000000000000004
60565	M6	112.5	0.0389999999999999999
60565	MK3	253.800000000000011	0.00700000000000000015
60565	MN4	303.800000000000011	0.0129999999999999994
60565	NU2	19.6000000000000014	0.0560000000000000012
60565	MU2	61.8999999999999986	0.0330000000000000016
60565	2N2	346.100000000000023	0.0459999999999999992
60565	OO1	261.600000000000023	0.0100000000000000002
60565	LDA2	21.1999999999999993	0.0229999999999999996
60565	S1	297.399999999999977	0.00700000000000000015
60565	M1	312.899999999999977	0.00700000000000000015
60565	J1	238	0.0100000000000000002
60565	SSA	68.4000000000000057	0.176999999999999991
60565	SA	204.5	0.259000000000000008
60565	Q1	254.300000000000011	0.0330000000000000016
60565	T2	50	0.0299999999999999989
60565	R2	299.699999999999989	0.0129999999999999994
60565	P1	238.800000000000011	0.0519999999999999976
60565	L2	53.7999999999999972	0.0459999999999999992
60565	K2	60.1000000000000014	0.0459999999999999992
60566	M2	20.1000000000000014	1.31200000000000006
60566	S2	47	0.220000000000000001
60566	N2	358.5	0.315000000000000002
60566	K1	222.5	0.200000000000000011
60566	M4	166.599999999999994	0.0129999999999999994
60566	O1	236.599999999999994	0.157000000000000001
60566	M6	48	0.0129999999999999994
60566	S4	264.199999999999989	0.00700000000000000015
60566	MN4	161	0.0100000000000000002
60566	NU2	357.399999999999977	0.0589999999999999969
60566	MU2	10.5	0.0389999999999999999
60566	2N2	342.399999999999977	0.0490000000000000019
60566	OO1	229.300000000000011	0.00700000000000000015
60566	LDA2	35.2000000000000028	0.0129999999999999994
60566	S1	308.5	0.00700000000000000015
60566	M1	247.800000000000011	0.00700000000000000015
60566	J1	225.5	0.0129999999999999994
60566	SSA	51.6000000000000014	0.242999999999999994
60566	SA	190.599999999999994	0.440000000000000002
60566	RHO1	236.699999999999989	0.00700000000000000015
60566	Q1	235.5	0.0330000000000000016
60566	T2	28.5	0.0229999999999999996
60566	R2	272.199999999999989	0.00700000000000000015
60566	P1	226.800000000000011	0.0560000000000000012
60566	2SM2	48.5	0.00300000000000000006
60566	M3	45.6000000000000014	0.00700000000000000015
60566	L2	47.8999999999999986	0.0490000000000000019
60566	K2	45.1000000000000014	0.0560000000000000012
60566	MS4	157.300000000000011	0.00700000000000000015
60567	M2	58	1.21999999999999997
60567	S2	92.5	0.200000000000000011
60567	N2	44.7999999999999972	0.223000000000000004
60567	K1	240.099999999999994	0.179999999999999993
60567	M4	53.2000000000000028	0.0660000000000000031
60567	O1	253	0.147999999999999993
60567	M6	177.099999999999994	0.0429999999999999966
60567	S4	57.5	0.00300000000000000006
60567	NU2	46.6000000000000014	0.0429999999999999966
60567	S6	57.1000000000000014	0.00300000000000000006
60567	MU2	223.400000000000006	0.0299999999999999989
60567	2N2	31.6000000000000014	0.0299999999999999989
60567	OO1	227.099999999999994	0.00700000000000000015
60567	LDA2	74	0.0100000000000000002
60567	M1	246.5	0.0100000000000000002
60567	J1	233.599999999999994	0.0129999999999999994
60567	RHO1	258.600000000000023	0.00700000000000000015
60567	Q1	259.5	0.0299999999999999989
60567	T2	91.0999999999999943	0.0129999999999999994
60567	R2	93.9000000000000057	0.00300000000000000006
60567	2Q1	265.899999999999977	0.00300000000000000006
60567	P1	241	0.0589999999999999969
60567	L2	71.2000000000000028	0.0330000000000000016
60567	K2	95.2999999999999972	0.0560000000000000012
60567	M8	163.900000000000006	0.00700000000000000015
60568	M2	13.8000000000000007	1.33499999999999996
60568	S2	35	0.223000000000000004
60568	N2	354.100000000000023	0.315000000000000002
60568	K1	219	0.190000000000000002
60568	M4	187	0.0100000000000000002
60568	O1	236.199999999999989	0.147999999999999993
60568	S4	258.5	0.00700000000000000015
60568	MN4	173.5	0.00700000000000000015
60568	NU2	353.100000000000023	0.0589999999999999969
60568	MU2	353.399999999999977	0.0429999999999999966
60568	2N2	339.300000000000011	0.0459999999999999992
60568	OO1	226.599999999999994	0.00700000000000000015
60568	LDA2	37.2999999999999972	0.0129999999999999994
60568	S1	249.099999999999994	0.0129999999999999994
60568	M1	253.699999999999989	0.00700000000000000015
60568	J1	216.099999999999994	0.0129999999999999994
60568	SSA	68.4000000000000057	0.176999999999999991
60568	SA	204.5	0.259000000000000008
60568	RHO1	230.400000000000006	0.00700000000000000015
60568	Q1	232.599999999999994	0.0330000000000000016
60568	T2	21.8999999999999986	0.0259999999999999988
60568	R2	251	0.00700000000000000015
60568	P1	219.599999999999994	0.0589999999999999969
60568	2SM2	39.3999999999999986	0.00700000000000000015
60568	M3	36.2999999999999972	0.00700000000000000015
60568	L2	15.1999999999999993	0.0330000000000000016
60568	K2	35.1000000000000014	0.0589999999999999969
60568	MS4	133.300000000000011	0.00700000000000000015
60569	M2	67.0999999999999943	1.16100000000000003
60569	S2	106.599999999999994	0.173999999999999988
60569	N2	49.3999999999999986	0.226000000000000006
60569	K1	251.599999999999994	0.173999999999999988
60569	M4	75.2999999999999972	0.0820000000000000034
60569	O1	264.699999999999989	0.135000000000000009
60569	M6	239.699999999999989	0.0359999999999999973
60569	MK3	306.5	0.0200000000000000004
60569	MN4	50	0.0330000000000000016
60569	NU2	42.7999999999999972	0.0619999999999999996
60569	MU2	144.699999999999989	0.0490000000000000019
60569	2N2	56.1000000000000014	0.0200000000000000004
60569	OO1	245.900000000000006	0.00700000000000000015
60569	LDA2	57	0.0299999999999999989
60569	S1	348.899999999999977	0.0100000000000000002
60569	M1	312.699999999999989	0.00700000000000000015
60569	J1	257.399999999999977	0.00700000000000000015
60569	RHO1	250.099999999999994	0.0100000000000000002
60569	Q1	270.699999999999989	0.0330000000000000016
60569	T2	90.2000000000000028	0.0259999999999999988
60569	R2	186.300000000000011	0.00700000000000000015
60569	2Q1	286.199999999999989	0.00300000000000000006
60569	P1	260.199999999999989	0.0490000000000000019
60569	2SM2	67.7000000000000028	0.00300000000000000006
60569	M3	66.2999999999999972	0.00300000000000000006
60569	L2	45.7999999999999972	0.0850000000000000061
60569	2MK3	345.699999999999989	0.0200000000000000004
60569	K2	94.2000000000000028	0.0459999999999999992
60569	M8	256.600000000000023	0.0129999999999999994
60569	MS4	118.400000000000006	0.0299999999999999989
60570	M2	68.5	1.12200000000000011
60570	S2	108.700000000000003	0.16700000000000001
60570	N2	55.7999999999999972	0.276000000000000023
60570	K1	261.800000000000011	0.209999999999999992
60570	M4	95.2000000000000028	0.0749999999999999972
60570	O1	267.5	0.128000000000000003
60570	M6	227.400000000000006	0.0459999999999999992
60570	S4	131.5	0.00300000000000000006
60570	NU2	57.5	0.0519999999999999976
60570	S6	249.699999999999989	0.00300000000000000006
60570	MU2	28.3999999999999986	0.0259999999999999988
60570	2N2	43	0.0359999999999999973
60570	OO1	256	0.00700000000000000015
60570	LDA2	87.0999999999999943	0.00700000000000000015
60570	M1	264.600000000000023	0.0100000000000000002
60570	J1	258.899999999999977	0.0100000000000000002
60570	RHO1	269.899999999999977	0.00300000000000000006
60570	Q1	270.300000000000011	0.0229999999999999996
60570	T2	107.099999999999994	0.0100000000000000002
60570	2Q1	273.100000000000023	0.00300000000000000006
60570	P1	262.199999999999989	0.0690000000000000058
60570	L2	81.2999999999999972	0.0330000000000000016
60570	K2	111.900000000000006	0.0459999999999999992
60570	M8	240.400000000000006	0.0160000000000000003
60571	M2	76.5999999999999943	1.1120000000000001
60571	S2	122.200000000000003	0.164000000000000007
60571	N2	62.1000000000000014	0.242999999999999994
60571	K1	267.699999999999989	0.197000000000000008
60571	M4	103.099999999999994	0.0719999999999999946
60571	O1	276.800000000000011	0.120999999999999996
60571	M6	224	0.0299999999999999989
60571	S4	171.800000000000011	0.00300000000000000006
60571	NU2	64	0.0459999999999999992
60571	S6	254.099999999999994	0.00300000000000000006
60571	MU2	31.1000000000000014	0.0259999999999999988
60571	2N2	47.5	0.0330000000000000016
60571	OO1	258.5	0.00700000000000000015
60571	LDA2	97.7999999999999972	0.00700000000000000015
60571	M1	272.199999999999989	0.0100000000000000002
60571	J1	263.100000000000023	0.0100000000000000002
60571	RHO1	280.699999999999989	0.00300000000000000006
60571	Q1	281.300000000000011	0.0229999999999999996
60571	T2	120.400000000000006	0.0100000000000000002
60571	2Q1	285.899999999999977	0.00300000000000000006
60571	P1	268.399999999999977	0.0660000000000000031
60571	L2	91.2000000000000028	0.0299999999999999989
60571	K2	125.900000000000006	0.0459999999999999992
60571	M8	260.699999999999989	0.00700000000000000015
60572	M2	75.7000000000000028	1.03299999999999992
60572	S2	120.799999999999997	0.157000000000000001
60572	N2	60.8999999999999986	0.23899999999999999
60572	K1	267.899999999999977	0.190000000000000002
60572	M4	122.900000000000006	0.0619999999999999996
60572	O1	276.800000000000011	0.120999999999999996
60572	M6	166.5	0.0100000000000000002
60572	S4	171.5	0.00300000000000000006
60572	NU2	62.8999999999999986	0.0459999999999999992
60572	MU2	30.6000000000000014	0.0259999999999999988
60572	2N2	46.2000000000000028	0.0330000000000000016
60572	OO1	259	0.00700000000000000015
60572	LDA2	96.5999999999999943	0.00700000000000000015
60572	M1	272.300000000000011	0.0100000000000000002
60572	J1	263.5	0.0100000000000000002
60572	RHO1	280.699999999999989	0.00300000000000000006
60572	Q1	281.300000000000011	0.0229999999999999996
60572	T2	119	0.0100000000000000002
60572	2Q1	285.699999999999989	0.00300000000000000006
60572	P1	268.600000000000023	0.0619999999999999996
60572	L2	90.5	0.0299999999999999989
60572	K2	124.400000000000006	0.0429999999999999966
60572	M8	59.2000000000000028	0.00300000000000000006
60573	M2	52.3999999999999986	1.04000000000000004
60573	S2	87.5	0.161000000000000004
60573	N2	37.7000000000000028	0.200000000000000011
60573	K1	247.900000000000006	0.150999999999999995
60573	M4	358.199999999999989	0.0229999999999999996
60573	O1	264.399999999999977	0.115000000000000005
60573	M6	119.799999999999997	0.0100000000000000002
60573	MK3	263.800000000000011	0.00700000000000000015
60573	S4	353.600000000000023	0.00300000000000000006
60573	MN4	343.5	0.0129999999999999994
60573	NU2	34.1000000000000014	0.0459999999999999992
60573	MU2	122.900000000000006	0.0330000000000000016
60573	2N2	42.2000000000000028	0.0229999999999999996
60573	OO1	253	0.00700000000000000015
60573	LDA2	50	0.0200000000000000004
60573	S1	152.199999999999989	0.00300000000000000006
60573	M1	297.300000000000011	0.00700000000000000015
60573	J1	254.099999999999994	0.00700000000000000015
60573	RHO1	272.600000000000023	0.00700000000000000015
60573	Q1	262.300000000000011	0.0259999999999999988
60573	T2	106.700000000000003	0.0330000000000000016
60573	R2	89.0999999999999943	0.0129999999999999994
60573	2Q1	306.800000000000011	0.00300000000000000006
60573	P1	249.699999999999989	0.0459999999999999992
60573	2SM2	75.7999999999999972	0.00300000000000000006
60573	M3	65.5999999999999943	0.00700000000000000015
60573	L2	56.8999999999999986	0.0660000000000000031
60573	2MK3	340.600000000000023	0.00700000000000000015
60573	K2	80.0999999999999943	0.0429999999999999966
60573	M8	86.4000000000000057	0.00300000000000000006
60573	MS4	62.7999999999999972	0.0100000000000000002
60574	M2	32.8999999999999986	1.1379999999999999
60574	S2	65.5	0.23899999999999999
60574	N2	12.0999999999999996	0.253000000000000003
60574	K1	233.300000000000011	0.135000000000000009
60574	M4	340.800000000000011	0.0200000000000000004
60574	O1	257	0.115000000000000005
60574	M6	88.7000000000000028	0.0229999999999999996
60574	MK3	228.5	0.00700000000000000015
60574	S4	246.099999999999994	0.00300000000000000006
60574	MN4	301.5	0.0100000000000000002
60574	NU2	15.5999999999999996	0.0330000000000000016
60574	MU2	64.9000000000000057	0.0299999999999999989
60574	2N2	341	0.0429999999999999966
60574	OO1	245.699999999999989	0.00700000000000000015
60574	LDA2	352.600000000000023	0.0100000000000000002
60574	S1	225.5	0.0259999999999999988
60574	M1	224.099999999999994	0.00300000000000000006
60574	J1	239.800000000000011	0.0100000000000000002
60574	Q1	257.699999999999989	0.0259999999999999988
60574	T2	52.1000000000000014	0.0490000000000000019
60574	R2	273.199999999999989	0.0519999999999999976
60574	2Q1	247.699999999999989	0.00300000000000000006
60574	P1	257.100000000000023	0.0429999999999999966
60574	M3	79.0999999999999943	0.00700000000000000015
60574	L2	59.6000000000000014	0.0429999999999999966
60574	2MK3	253.5	0.00300000000000000006
60574	K2	38.8999999999999986	0.0589999999999999969
60574	M8	84.9000000000000057	0.00300000000000000006
60574	MS4	52	0.00700000000000000015
60575	M2	15.6999999999999993	1.2629999999999999
60575	S2	36.6000000000000014	0.262000000000000011
60575	N2	352.100000000000023	0.307999999999999996
60575	K1	219.699999999999989	0.164000000000000007
60575	M4	208.400000000000006	0.0100000000000000002
60575	O1	250.800000000000011	0.117999999999999994
60575	M6	69.9000000000000057	0.00300000000000000006
60575	MK3	166.699999999999989	0.00700000000000000015
60575	S4	266.199999999999989	0.00700000000000000015
60575	MN4	181.199999999999989	0.0100000000000000002
60575	NU2	351.5	0.0589999999999999969
60575	S6	101.5	0.00300000000000000006
60575	MU2	0	0.0389999999999999999
60575	2N2	344.300000000000011	0.0429999999999999966
60575	OO1	210.599999999999994	0.0129999999999999994
60575	LDA2	70.2999999999999972	0.0100000000000000002
60575	S1	44.1000000000000014	0.0160000000000000003
60575	M1	236.5	0.0100000000000000002
60575	J1	189.599999999999994	0.0129999999999999994
60575	SSA	68.4000000000000057	0.176999999999999991
60575	SA	204.5	0.259000000000000008
60575	RHO1	226.300000000000011	0.00700000000000000015
60575	Q1	246.699999999999989	0.0259999999999999988
60575	T2	37.5	0.0359999999999999973
60575	R2	98.4000000000000057	0.0229999999999999996
60575	2Q1	295.5	0.00300000000000000006
60575	P1	243.099999999999994	0.0519999999999999976
60575	2SM2	66.4000000000000057	0.00700000000000000015
60575	M3	56.5	0.00700000000000000015
60575	L2	48.2000000000000028	0.0459999999999999992
60575	2MK3	133.099999999999994	0.00700000000000000015
60575	K2	41.5	0.0790000000000000008
60575	MS4	167.699999999999989	0.00700000000000000015
60576	M2	18.5	1.22700000000000009
60576	S2	44.7000000000000028	0.235999999999999988
60576	N2	356.100000000000023	0.301999999999999991
60576	K1	231.5	0.164000000000000007
60576	M4	167.699999999999989	0.0160000000000000003
60576	O1	254	0.115000000000000005
60576	M6	281.800000000000011	0.00300000000000000006
60576	S4	276.199999999999989	0.00300000000000000006
60576	NU2	359.100000000000023	0.0589999999999999969
60576	S6	156	0.00300000000000000006
60576	MU2	352.5	0.0299999999999999989
60576	2N2	333.699999999999989	0.0389999999999999999
60576	OO1	206.800000000000011	0.00300000000000000006
60576	LDA2	30.6999999999999993	0.0100000000000000002
60576	M1	241.900000000000006	0.00700000000000000015
60576	J1	220.199999999999989	0.0100000000000000002
60576	SSA	58.2999999999999972	0.179999999999999993
60576	SA	190.599999999999994	0.27200000000000002
60576	RHO1	263.699999999999989	0.00300000000000000006
60576	Q1	265.199999999999989	0.0229999999999999996
60576	T2	43.6000000000000014	0.0129999999999999994
60576	R2	45.7000000000000028	0.00300000000000000006
60576	2Q1	276.399999999999977	0.00300000000000000006
60576	P1	233.099999999999994	0.0560000000000000012
60576	L2	41.1000000000000014	0.0330000000000000016
60576	K2	46.7999999999999972	0.0619999999999999996
60577	M2	19.6000000000000014	1.22399999999999998
60577	S2	46.7000000000000028	0.226000000000000006
60577	N2	357.399999999999977	0.276000000000000023
60577	K1	237.800000000000011	0.140999999999999986
60577	M4	202.699999999999989	0.0160000000000000003
60577	O1	262.300000000000011	0.112000000000000002
60577	MN4	190.900000000000006	0.0100000000000000002
60577	NU2	359.899999999999977	0.0560000000000000012
60577	MU2	355.699999999999989	0.0389999999999999999
60577	2N2	336.899999999999977	0.0359999999999999973
60577	OO1	213.199999999999989	0.00700000000000000015
60577	LDA2	32.2000000000000028	0.00700000000000000015
60577	M1	250	0.00700000000000000015
60577	J1	225.599999999999994	0.0100000000000000002
60577	SSA	46.2000000000000028	0.203000000000000014
60577	SA	193.699999999999989	0.245999999999999996
60577	MF	349	0.0389999999999999999
60577	RHO1	272.800000000000011	0.00300000000000000006
60577	Q1	274.399999999999977	0.0200000000000000004
60577	T2	45.5	0.0129999999999999994
60577	R2	47.7999999999999972	0.00300000000000000006
60577	2Q1	286.5	0.00300000000000000006
60577	P1	235.199999999999989	0.0429999999999999966
60577	L2	41.7000000000000028	0.0389999999999999999
60577	K2	44.3999999999999986	0.0619999999999999996
60578	M2	41	1.05600000000000005
60578	S2	72.7000000000000028	0.187
60578	N2	24.5	0.233000000000000013
60578	K1	259.699999999999989	0.107999999999999999
60578	M4	323.100000000000023	0.0100000000000000002
60578	O1	284.100000000000023	0.0919999999999999984
60578	M6	169	0.0359999999999999973
60578	MK3	266.100000000000023	0.00700000000000000015
60578	S4	315.699999999999989	0.00700000000000000015
60578	MN4	289.5	0.00700000000000000015
60578	NU2	11.5999999999999996	0.0459999999999999992
60578	MU2	52	0.0259999999999999988
60578	2N2	3.29999999999999982	0.0259999999999999988
60578	OO1	262	0.00700000000000000015
60578	LDA2	56.3999999999999986	0.0160000000000000003
60578	S1	316.100000000000023	0.00300000000000000006
60578	M1	312.600000000000023	0.00300000000000000006
60578	J1	245.099999999999994	0.00700000000000000015
60578	SSA	58.2999999999999972	0.179999999999999993
60578	SA	190.599999999999994	0.27200000000000002
60578	RHO1	288.699999999999989	0.00700000000000000015
60578	Q1	285	0.0229999999999999996
60578	T2	63.5	0.0160000000000000003
60578	R2	268.5	0.00300000000000000006
60578	2Q1	318.399999999999977	0.00300000000000000006
60578	P1	257.5	0.0330000000000000016
60578	2SM2	64.2000000000000028	0.00300000000000000006
60578	M3	84.4000000000000057	0.00300000000000000006
60578	L2	19.8000000000000007	0.0490000000000000019
60578	2MK3	277.800000000000011	0.00300000000000000006
60578	K2	69.9000000000000057	0.0519999999999999976
60578	M8	200.599999999999994	0.00300000000000000006
60578	MS4	149.300000000000011	0.00300000000000000006
60579	M2	20.3999999999999986	1.22399999999999998
60579	S2	44.5	0.245999999999999996
60579	N2	0.800000000000000044	0.279000000000000026
60579	K1	244.800000000000011	0.138000000000000012
60579	O1	268.699999999999989	0.112000000000000002
60579	NU2	3.39999999999999991	0.0519999999999999976
60579	MU2	356.699999999999989	0.0359999999999999973
60579	2N2	341.199999999999989	0.0359999999999999973
60579	SSA	68.7000000000000028	0.203000000000000014
60579	SA	198.800000000000011	0.288999999999999979
60579	Q1	280.5	0.0200000000000000004
60579	T2	44.3999999999999986	0.0129999999999999994
60579	P1	248.400000000000006	0.0429999999999999966
60579	L2	23.1999999999999993	0.0330000000000000016
60579	K2	56.3999999999999986	0.0660000000000000031
60580	M2	25.8000000000000007	1.125
60580	S2	53.2999999999999972	0.212999999999999995
60580	N2	7.40000000000000036	0.259000000000000008
60580	K1	250.5	0.120999999999999996
60580	M4	143.300000000000011	0.0519999999999999976
60580	O1	277.600000000000023	0.104999999999999996
60580	M6	130.599999999999994	0.0100000000000000002
60580	MN4	143.099999999999994	0.0229999999999999996
60580	NU2	3.70000000000000018	0.0490000000000000019
60580	MU2	10.3000000000000007	0.0330000000000000016
60580	2N2	346.5	0.0330000000000000016
60580	OO1	223.300000000000011	0.00700000000000000015
60580	LDA2	42.1000000000000014	0.0129999999999999994
60580	M1	264	0.00700000000000000015
60580	J1	237.099999999999994	0.00700000000000000015
60580	SSA	58.2999999999999972	0.179999999999999993
60580	SA	190.599999999999994	0.27200000000000002
60580	RHO1	289.199999999999989	0.00300000000000000006
60580	Q1	276.300000000000011	0.0259999999999999988
60580	T2	35.2000000000000028	0.0200000000000000004
60580	R2	54.5	0.00300000000000000006
60580	2Q1	304.5	0.00300000000000000006
60580	P1	248.400000000000006	0.0359999999999999973
60580	L2	8.09999999999999964	0.0359999999999999973
60580	K2	54	0.0589999999999999969
60580	MS4	166.900000000000006	0.0259999999999999988
60581	M2	41	0.97799999999999998
60581	S2	71.2999999999999972	0.171000000000000013
60581	N2	21.5	0.216999999999999998
60581	K1	263.199999999999989	0.101999999999999993
60581	M4	69.5	0.0229999999999999996
60581	O1	288.399999999999977	0.0919999999999999984
60581	M6	169.400000000000006	0.0359999999999999973
60581	MK3	275.300000000000011	0.0129999999999999994
60581	NU2	17.6000000000000014	0.0459999999999999992
60581	MU2	45.5	0.0200000000000000004
60581	2N2	6.29999999999999982	0.0299999999999999989
60581	OO1	237.800000000000011	0.00300000000000000006
60581	LDA2	64.5	0.0129999999999999994
60581	M1	275.699999999999989	0.00700000000000000015
60581	J1	250.599999999999994	0.00700000000000000015
60581	SSA	58.2999999999999972	0.179999999999999993
60581	SA	190.599999999999994	0.27200000000000002
60581	RHO1	299.300000000000011	0.00300000000000000006
60581	Q1	298.199999999999989	0.0200000000000000004
60581	T2	61.3999999999999986	0.0200000000000000004
60581	2Q1	313.5	0.00300000000000000006
60581	P1	263.100000000000023	0.0299999999999999989
60581	L2	51	0.0490000000000000019
60581	K2	68.9000000000000057	0.0459999999999999992
60581	MS4	112.400000000000006	0.0129999999999999994
60582	M2	64.0999999999999943	0.889000000000000012
60582	S2	100.200000000000003	0.153999999999999998
60582	N2	44.2000000000000028	0.183999999999999997
60582	K1	282.5	0.0950000000000000011
60582	M4	51	0.0519999999999999976
60582	O1	301.699999999999989	0.0820000000000000034
60582	M6	217.699999999999989	0.0389999999999999999
60582	MK3	289.199999999999989	0.0160000000000000003
60582	S4	41.6000000000000014	0.00300000000000000006
60582	MN4	24.1000000000000014	0.0229999999999999996
60582	NU2	48.3999999999999986	0.0490000000000000019
60582	MU2	120.599999999999994	0.0160000000000000003
60582	2N2	35.1000000000000014	0.0200000000000000004
60582	OO1	256.199999999999989	0.00700000000000000015
60582	LDA2	57.5	0.0229999999999999996
60582	S1	50.8999999999999986	0.00300000000000000006
60582	M1	319.199999999999989	0.00300000000000000006
60582	J1	146.5	0.00300000000000000006
60582	SSA	86.9000000000000057	0.209999999999999992
60582	SA	214.900000000000006	0.429999999999999993
60582	RHO1	348.300000000000011	0.00300000000000000006
60582	Q1	298.399999999999977	0.0200000000000000004
60582	T2	78.7999999999999972	0.0200000000000000004
60582	R2	230	0.00300000000000000006
60582	2Q1	315.800000000000011	0.00700000000000000015
60582	P1	265.100000000000023	0.0259999999999999988
60582	M3	16.5	0.00700000000000000015
60582	L2	78.7000000000000028	0.0490000000000000019
60582	2MK3	324.5	0.0160000000000000003
60582	K2	88.9000000000000057	0.0429999999999999966
60582	M8	209.5	0.0129999999999999994
60582	MS4	101	0.0200000000000000004
60583	M2	65.0999999999999943	0.734999999999999987
60583	S2	93.4000000000000057	0.120999999999999996
60583	N2	48	0.140999999999999986
60583	K1	285.699999999999989	0.0980000000000000038
60583	M4	60.2999999999999972	0.0299999999999999989
60583	O1	301.600000000000023	0.0749999999999999972
60583	M6	219.900000000000006	0.0100000000000000002
60583	S4	0.599999999999999978	0.00300000000000000006
60583	NU2	50.2999999999999972	0.0299999999999999989
60583	MU2	36.7999999999999972	0.0160000000000000003
60583	2N2	31.1000000000000014	0.0200000000000000004
60583	OO1	269.5	0.00300000000000000006
60583	LDA2	78.0999999999999943	0.00700000000000000015
60583	M1	293.5	0.00700000000000000015
60583	J1	277.699999999999989	0.00700000000000000015
60583	SSA	58.2999999999999972	0.179999999999999993
60583	SA	190.599999999999994	0.27200000000000002
60583	RHO1	308.5	0.00300000000000000006
60583	Q1	309.399999999999977	0.0160000000000000003
60583	T2	92.0999999999999943	0.00700000000000000015
60583	2Q1	317.5	0.00300000000000000006
60583	P1	286.899999999999977	0.0330000000000000016
60583	L2	82.0999999999999943	0.0200000000000000004
60583	K2	95.5	0.0330000000000000016
60583	M8	161	0.00300000000000000006
60584	M2	96.7000000000000028	0.65900000000000003
60584	S2	139.5	0.0980000000000000038
60584	N2	82.7000000000000028	0.140999999999999986
60584	K1	304.600000000000023	0.0790000000000000008
60584	M4	133.300000000000011	0.0589999999999999969
60584	O1	317.699999999999989	0.0660000000000000031
60584	M6	306.800000000000011	0.0160000000000000003
60584	S4	160.5	0.00300000000000000006
60584	NU2	84.5999999999999943	0.0259999999999999988
60584	S6	265	0.00300000000000000006
60584	MU2	53.8999999999999986	0.0160000000000000003
60584	2N2	68.5999999999999943	0.0200000000000000004
60584	OO1	291.5	0.00300000000000000006
60584	LDA2	116.599999999999994	0.00300000000000000006
60584	M1	311.100000000000023	0.00300000000000000006
60584	J1	298.100000000000023	0.00700000000000000015
60584	SSA	58.2999999999999972	0.179999999999999993
60584	SA	190.599999999999994	0.27200000000000002
60584	RHO1	323.300000000000011	0.00300000000000000006
60584	Q1	324.199999999999989	0.0129999999999999994
60584	T2	137.800000000000011	0.00700000000000000015
60584	2Q1	330.699999999999989	0.00300000000000000006
60584	P1	305.600000000000023	0.0259999999999999988
60584	L2	110.799999999999997	0.0200000000000000004
60584	K2	143	0.0259999999999999988
60584	M8	352.699999999999989	0.00700000000000000015
60585	M2	102.700000000000003	0.676000000000000045
60585	S2	140.699999999999989	0.104999999999999996
60585	N2	85.2999999999999972	0.157000000000000001
60585	K1	309.5	0.0950000000000000011
60585	M4	140.300000000000011	0.0719999999999999946
60585	O1	322.300000000000011	0.0719999999999999946
60585	M6	317.100000000000023	0.0259999999999999988
60585	S4	220.699999999999989	0.00300000000000000006
60585	NU2	87.5999999999999943	0.0299999999999999989
60585	MU2	64.5999999999999943	0.0160000000000000003
60585	2N2	67.5	0.0200000000000000004
60585	OO1	294.899999999999977	0.00300000000000000006
60585	LDA2	120.299999999999997	0.00300000000000000006
60585	M1	315.300000000000011	0.00700000000000000015
60585	J1	301.800000000000011	0.00700000000000000015
60585	SSA	58.2999999999999972	0.179999999999999993
60585	SA	190.599999999999994	0.27200000000000002
60585	RHO1	328.199999999999989	0.00300000000000000006
60585	Q1	329.399999999999977	0.0129999999999999994
60585	T2	139.199999999999989	0.00700000000000000015
60585	2Q1	336	0.00300000000000000006
60585	P1	310.300000000000011	0.0330000000000000016
60585	L2	120.200000000000003	0.0200000000000000004
60585	K2	143.800000000000011	0.0299999999999999989
60585	M8	14.4000000000000004	0.00700000000000000015
60586	M2	110.099999999999994	0.419999999999999984
60586	S2	148.300000000000011	0.0719999999999999946
60586	N2	85	0.0749999999999999972
60586	K1	313	0.0490000000000000019
60586	M4	154.199999999999989	0.0160000000000000003
60586	O1	357.699999999999989	0.0519999999999999976
60586	M6	350.699999999999989	0.0129999999999999994
60586	NU2	87.9000000000000057	0.0160000000000000003
60586	MU2	72	0.0100000000000000002
60586	2N2	58.3999999999999986	0.0100000000000000002
60586	OO1	268.600000000000023	0.00300000000000000006
60586	LDA2	127.799999999999997	0.00300000000000000006
60586	M1	335.300000000000011	0.00300000000000000006
60586	J1	291.100000000000023	0.00300000000000000006
60586	SSA	58.2999999999999972	0.179999999999999993
60586	SA	190.599999999999994	0.27200000000000002
60586	RHO1	16.3999999999999986	0.00300000000000000006
60586	Q1	19.8000000000000007	0.0100000000000000002
60586	T2	146.599999999999994	0.00300000000000000006
60586	P1	316.300000000000011	0.0160000000000000003
60586	L2	135.699999999999989	0.0129999999999999994
60586	K2	151.199999999999989	0.0200000000000000004
60587	M2	119.799999999999997	0.318000000000000005
60587	S2	149.599999999999994	0.0490000000000000019
60587	N2	100.700000000000003	0.0589999999999999969
60587	K1	335.600000000000023	0.0519999999999999976
60587	M4	219.599999999999994	0.0259999999999999988
60587	O1	344	0.0490000000000000019
60587	M6	335.5	0.0129999999999999994
60587	S4	282.300000000000011	0.00300000000000000006
60587	NU2	103.299999999999997	0.0129999999999999994
60587	MU2	90.0999999999999943	0.00700000000000000015
60587	2N2	80.5	0.00700000000000000015
60587	OO1	326.300000000000011	0.00300000000000000006
60587	LDA2	133.5	0.00300000000000000006
60587	M1	339.600000000000023	0.00300000000000000006
60587	J1	330.800000000000011	0.00300000000000000006
60587	SSA	58.2999999999999972	0.179999999999999993
60587	SA	190.599999999999994	0.27200000000000002
60587	RHO1	347.899999999999977	0.00300000000000000006
60587	Q1	348.5	0.0100000000000000002
60587	T2	148.300000000000011	0.00300000000000000006
60587	P1	336.300000000000011	0.0160000000000000003
60587	L2	138.800000000000011	0.0100000000000000002
60587	K2	151.900000000000006	0.0129999999999999994
60588	M2	140	0.256000000000000005
60588	S2	177.099999999999994	0.0429999999999999966
60588	N2	123.299999999999997	0.0429999999999999966
60588	K1	344.300000000000011	0.0389999999999999999
60588	M4	245.099999999999994	0.0129999999999999994
60588	O1	6.29999999999999982	0.0330000000000000016
60588	M6	3.39999999999999991	0.00700000000000000015
60588	MK3	77.0999999999999943	0.00700000000000000015
60588	MN4	233.5	0.00300000000000000006
60588	NU2	133.800000000000011	0.0100000000000000002
60588	MU2	249.5	0.0100000000000000002
60588	2N2	144.199999999999989	0.00700000000000000015
60588	LDA2	126.900000000000006	0.0100000000000000002
60588	S1	77.5999999999999943	0.0100000000000000002
60588	J1	347	0.00300000000000000006
60588	MM	3.29999999999999982	0.0980000000000000038
60588	SSA	49.1000000000000014	0.262000000000000011
60588	SA	204.199999999999989	0.23000000000000001
60588	MSF	22.3000000000000007	0.0850000000000000061
60588	MF	34.3999999999999986	0.0160000000000000003
60588	RHO1	14.8000000000000007	0.00300000000000000006
60588	Q1	357.5	0.00700000000000000015
60588	T2	176.900000000000006	0.0100000000000000002
60588	R2	152.400000000000006	0.00300000000000000006
60588	P1	328.600000000000023	0.0100000000000000002
60588	M3	194.400000000000006	0.00300000000000000006
60588	L2	181.400000000000006	0.0229999999999999996
60588	2MK3	103.599999999999994	0.00700000000000000015
60588	K2	174.400000000000006	0.0129999999999999994
60588	MS4	275.300000000000011	0.00300000000000000006
60589	M2	41	0.797000000000000042
60589	S2	66.2999999999999972	0.194000000000000006
60589	N2	22.8999999999999986	0.171000000000000013
60589	K1	337.600000000000023	0.212999999999999995
60589	M4	226.199999999999989	0.0229999999999999996
60589	O1	338.800000000000011	0.235999999999999988
60589	M6	113.400000000000006	0.0100000000000000002
60589	MN4	212.699999999999989	0.0160000000000000003
60589	NU2	24.3999999999999986	0.0359999999999999973
60589	MU2	7.5	0.0259999999999999988
60589	2N2	5	0.0229999999999999996
60589	OO1	336.300000000000011	0.0100000000000000002
60589	LDA2	52.7000000000000028	0.00700000000000000015
60589	S1	356.800000000000011	0.0160000000000000003
60589	M1	338.100000000000023	0.0160000000000000003
60589	J1	337	0.0160000000000000003
60589	SSA	51.8999999999999986	0.138000000000000012
60589	SA	198.699999999999989	0.318000000000000005
60589	MF	356.5	0.0389999999999999999
60589	RHO1	339.300000000000011	0.0100000000000000002
60589	Q1	326.399999999999977	0.0589999999999999969
60589	T2	66.2000000000000028	0.0100000000000000002
60589	R2	66.2999999999999972	0.00300000000000000006
60589	2Q1	339.899999999999977	0.00700000000000000015
60589	P1	339.5	0.0690000000000000058
60589	L2	59	0.0229999999999999996
60589	K2	64.7000000000000028	0.0519999999999999976
60589	MS4	211.599999999999994	0.0129999999999999994
60590	M2	164.599999999999994	0.183999999999999997
60590	S2	229	0.0490000000000000019
60590	N2	121	0.0229999999999999996
60590	K1	33.7000000000000028	0.23899999999999999
60590	M4	80	0.0490000000000000019
60590	O1	26.8000000000000007	0.242999999999999994
60590	M6	56.1000000000000014	0.0229999999999999996
60590	MK3	264.600000000000023	0.0259999999999999988
60590	S4	156.199999999999989	0.00300000000000000006
60590	MN4	71.2999999999999972	0.0160000000000000003
60590	NU2	175.599999999999994	0.0100000000000000002
60590	MU2	359.600000000000023	0.0259999999999999988
60590	OO1	38.7999999999999972	0.00300000000000000006
60590	LDA2	185.800000000000011	0.00700000000000000015
60590	S1	139.199999999999989	0.0100000000000000002
60590	M1	79.0999999999999943	0.0129999999999999994
60590	J1	88.2000000000000028	0.0100000000000000002
60590	MM	359.699999999999989	0.0389999999999999999
60590	SSA	79.7000000000000028	0.131000000000000005
60590	SA	186.099999999999994	0.347999999999999976
60590	MSF	18.6999999999999993	0.0589999999999999969
60590	MF	4	0.0490000000000000019
60590	RHO1	14.5	0.0100000000000000002
60590	Q1	16.8000000000000007	0.0560000000000000012
60590	T2	229.800000000000011	0.00300000000000000006
60590	R2	188.900000000000006	0.00700000000000000015
60590	2Q1	13.5999999999999996	0.00700000000000000015
60590	P1	38.8999999999999986	0.0719999999999999946
60590	2SM2	67.5999999999999943	0.00700000000000000015
60590	M3	161.800000000000011	0.00700000000000000015
60590	L2	192.099999999999994	0.0200000000000000004
60590	2MK3	254.900000000000006	0.0229999999999999996
60590	K2	235.800000000000011	0.0200000000000000004
60590	M8	274.100000000000023	0.00300000000000000006
60590	MS4	111.099999999999994	0.0299999999999999989
60591	M2	97.2999999999999972	0.343999999999999972
60591	S2	140.300000000000011	0.0919999999999999984
60591	N2	71.7999999999999972	0.0619999999999999996
60591	K1	21.5	0.269000000000000017
60591	M4	28	0.0459999999999999992
60591	O1	17.1000000000000014	0.245999999999999996
60591	M6	263.199999999999989	0.00700000000000000015
60591	S4	47.1000000000000014	0.00700000000000000015
60591	NU2	75.2999999999999972	0.0129999999999999994
60591	MU2	250.599999999999994	0.0100000000000000002
60591	2N2	46.6000000000000014	0.00700000000000000015
60591	OO1	25.6000000000000014	0.0100000000000000002
60591	LDA2	117.400000000000006	0.00300000000000000006
60591	M1	19.3000000000000007	0.0160000000000000003
60591	J1	23.5	0.0200000000000000004
60591	RHO1	15.3000000000000007	0.0100000000000000002
60591	Q1	15	0.0490000000000000019
60591	T2	138.599999999999994	0.00700000000000000015
60591	2Q1	12.8000000000000007	0.00700000000000000015
60591	P1	21.1999999999999993	0.0889999999999999958
60591	L2	122.900000000000006	0.0100000000000000002
60591	K2	143.800000000000011	0.0259999999999999988
60592	M2	126.400000000000006	0.429999999999999993
60592	S2	155.5	0.131000000000000005
60592	N2	112.200000000000003	0.0820000000000000034
60592	K1	28.3999999999999986	0.294999999999999984
60592	M4	28.1999999999999993	0.0259999999999999988
60592	O1	22.6999999999999993	0.248999999999999999
60592	M6	299.5	0.0100000000000000002
60592	S4	31.5	0.00300000000000000006
60592	NU2	114.099999999999994	0.0160000000000000003
60592	S6	42.2000000000000028	0.00300000000000000006
60592	MU2	294	0.0100000000000000002
60592	2N2	98	0.0100000000000000002
60592	OO1	34	0.0100000000000000002
60592	LDA2	139.800000000000011	0.00300000000000000006
60592	M1	25.5	0.0160000000000000003
60592	J1	31.1000000000000014	0.0200000000000000004
60592	RHO1	20.3000000000000007	0.0100000000000000002
60592	Q1	19.8999999999999986	0.0490000000000000019
60592	T2	154.400000000000006	0.00700000000000000015
60592	2Q1	17.1000000000000014	0.00700000000000000015
60592	P1	27.8999999999999986	0.0980000000000000038
60592	L2	140	0.0129999999999999994
60592	K2	157.900000000000006	0.0359999999999999973
60592	M8	21.6000000000000014	0.00300000000000000006
60593	M2	66.9000000000000057	0.609999999999999987
60593	S2	88.2000000000000028	0.171000000000000013
60593	N2	48.2999999999999972	0.120999999999999996
60593	K1	356.100000000000023	0.294999999999999984
60593	M4	250.699999999999989	0.0299999999999999989
60593	O1	352.199999999999989	0.307999999999999996
60593	MN4	232.300000000000011	0.0160000000000000003
60593	NU2	53.8999999999999986	0.0229999999999999996
60593	MU2	7.09999999999999964	0.0160000000000000003
60593	2N2	35.3999999999999986	0.0160000000000000003
60593	OO1	359.899999999999977	0.0129999999999999994
60593	LDA2	76.7000000000000028	0.00300000000000000006
60593	S1	359.199999999999989	0.0160000000000000003
60593	M1	354.100000000000023	0.0229999999999999996
60593	J1	358.399999999999977	0.0160000000000000003
60593	SSA	56.5	0.135000000000000009
60593	SA	187.800000000000011	0.262000000000000011
60593	MF	354.600000000000023	0.0389999999999999999
60593	RHO1	339.300000000000011	0.0160000000000000003
60593	Q1	342.100000000000023	0.0749999999999999972
60593	T2	73.7999999999999972	0.0129999999999999994
60593	2Q1	326.800000000000011	0.0100000000000000002
60593	P1	358.699999999999989	0.0950000000000000011
60593	L2	95.4000000000000057	0.0160000000000000003
60593	K2	92.4000000000000057	0.0490000000000000019
60593	MS4	247.5	0.0129999999999999994
60594	M2	48.7000000000000028	0.567999999999999949
60594	S2	69.2999999999999972	0.16700000000000001
60594	N2	26.6000000000000014	0.117999999999999994
60594	K1	348	0.281999999999999973
60594	M4	229.800000000000011	0.0200000000000000004
60594	O1	349.100000000000023	0.279000000000000026
60594	M6	129.300000000000011	0.00300000000000000006
60594	S4	340.5	0.00300000000000000006
60594	NU2	29.6000000000000014	0.0229999999999999996
60594	MU2	224.300000000000011	0.0129999999999999994
60594	2N2	4.5	0.0160000000000000003
60594	OO1	347	0.0129999999999999994
60594	LDA2	58.2999999999999972	0.00300000000000000006
60594	M1	348.5	0.0200000000000000004
60594	J1	347.5	0.0229999999999999996
60594	SSA	56.5	0.135000000000000009
60594	SA	187.800000000000011	0.262000000000000011
60594	RHO1	349.5	0.0100000000000000002
60594	Q1	349.600000000000023	0.0519999999999999976
60594	T2	68.5	0.0100000000000000002
60594	2Q1	350.100000000000023	0.00700000000000000015
60594	P1	348.100000000000023	0.0919999999999999984
60594	L2	70.9000000000000057	0.0160000000000000003
60594	K2	71	0.0459999999999999992
60595	M2	131.599999999999994	1.20700000000000007
60595	S2	146	0.381000000000000005
60595	N2	120.099999999999994	0.220000000000000001
60595	K1	0.400000000000000022	0.463000000000000023
60595	M4	37.1000000000000014	0.0229999999999999996
60595	O1	354.5	0.432999999999999996
60595	M6	104	0.0100000000000000002
60595	S4	75.9000000000000057	0.00300000000000000006
60595	NU2	121.700000000000003	0.0429999999999999966
60595	2N2	108.700000000000003	0.0299999999999999989
60595	OO1	6.20000000000000018	0.0200000000000000004
60595	LDA2	138.099999999999994	0.0100000000000000002
60595	M1	357.5	0.0299999999999999989
60595	J1	3.39999999999999991	0.0330000000000000016
60595	SSA	56.5	0.135000000000000009
60595	SA	187.800000000000011	0.262000000000000011
60595	RHO1	352	0.0160000000000000003
60595	Q1	351.600000000000023	0.0820000000000000034
60595	T2	145.400000000000006	0.0229999999999999996
60595	R2	146.400000000000006	0.00300000000000000006
60595	2Q1	348.600000000000023	0.0100000000000000002
60595	P1	0	0.153999999999999998
60595	L2	143.199999999999989	0.0330000000000000016
60595	K2	147.099999999999994	0.101999999999999993
60595	M8	178.800000000000011	0.00300000000000000006
60596	M2	78.7000000000000028	0.44900000000000001
60596	S2	92	0.150999999999999995
60596	N2	66.2000000000000028	0.0950000000000000011
60596	K1	359.5	0.353999999999999981
60596	M4	250	0.0160000000000000003
60596	O1	354.300000000000011	0.36399999999999999
60596	MN4	220.300000000000011	0.0100000000000000002
60596	NU2	82.0999999999999943	0.0160000000000000003
60596	MU2	37.5	0.0129999999999999994
60596	2N2	62.1000000000000014	0.0100000000000000002
60596	OO1	353.899999999999977	0.0129999999999999994
60596	S1	4.59999999999999964	0.0229999999999999996
60596	M1	355.699999999999989	0.0259999999999999988
60596	J1	29.1000000000000014	0.0229999999999999996
60596	SSA	56.5	0.135000000000000009
60596	SA	187.800000000000011	0.262000000000000011
60596	MF	354.600000000000023	0.0389999999999999999
60596	RHO1	338.199999999999989	0.0129999999999999994
60596	Q1	345.5	0.0850000000000000061
60596	T2	86	0.0100000000000000002
60596	2Q1	334.899999999999977	0.0129999999999999994
60596	P1	356.199999999999989	0.112000000000000002
60596	L2	99.0999999999999943	0.0100000000000000002
60596	K2	86.9000000000000057	0.0429999999999999966
60596	MS4	233.699999999999989	0.00700000000000000015
60597	M2	193.099999999999994	1.34200000000000008
60597	S2	215.199999999999989	0.432999999999999996
60597	N2	183.599999999999994	0.220000000000000001
60597	K1	35.2000000000000028	0.580999999999999961
60597	M4	287.5	0.0519999999999999976
60597	O1	25.8000000000000007	0.459000000000000019
60597	NU2	184.900000000000006	0.0429999999999999966
60597	S6	350.600000000000023	0.00300000000000000006
60597	MU2	171	0.0330000000000000016
60597	2N2	174.800000000000011	0.0299999999999999989
60597	OO1	44.1000000000000014	0.0200000000000000004
60597	LDA2	203.300000000000011	0.0100000000000000002
60597	M1	30.3999999999999986	0.0330000000000000016
60597	J1	39.3999999999999986	0.0359999999999999973
60597	SA	150.699999999999989	0.269000000000000017
60597	RHO1	21.8999999999999986	0.0160000000000000003
60597	Q1	21.3000000000000007	0.0889999999999999958
60597	T2	214.400000000000006	0.0259999999999999988
60597	2Q1	16.8000000000000007	0.0129999999999999994
60597	P1	34.5	0.194000000000000006
60597	L2	202	0.0359999999999999973
60597	K2	217	0.117999999999999994
60598	M2	188.800000000000011	1.34499999999999997
60598	S2	211.400000000000006	0.426999999999999991
60598	N2	175.199999999999989	0.23899999999999999
60598	K1	28.1000000000000014	0.570999999999999952
60598	M4	285	0.0459999999999999992
60598	O1	26.6000000000000014	0.485999999999999988
60598	S4	345.399999999999977	0.00700000000000000015
60598	NU2	177	0.0459999999999999992
60598	MU2	166.400000000000006	0.0330000000000000016
60598	2N2	161.900000000000006	0.0330000000000000016
60598	OO1	29.6999999999999993	0.0200000000000000004
60598	LDA2	199.300000000000011	0.0100000000000000002
60598	M1	27.1999999999999993	0.0330000000000000016
60598	J1	28.8000000000000007	0.0359999999999999973
60598	SSA	66.7000000000000028	0.0980000000000000038
60598	SA	167.900000000000006	0.245999999999999996
60598	RHO1	25.5	0.0160000000000000003
60598	Q1	25.8000000000000007	0.0950000000000000011
60598	T2	210.5	0.0229999999999999996
60598	2Q1	25.3999999999999986	0.0129999999999999994
60598	P1	28	0.190000000000000002
60598	L2	202.199999999999989	0.0359999999999999973
60598	K2	213.199999999999989	0.115000000000000005
60599	M2	155.800000000000011	0.928000000000000047
60599	S2	177.5	0.315000000000000002
60599	N2	139.800000000000011	0.194000000000000006
60599	K1	9	0.494999999999999996
60599	M4	124.200000000000003	0.0129999999999999994
60599	O1	7.70000000000000018	0.400000000000000022
60599	M6	108.900000000000006	0.0129999999999999994
60599	S4	312.100000000000023	0.0129999999999999994
60599	NU2	142	0.0359999999999999973
60599	S6	336.800000000000011	0.00300000000000000006
60599	MU2	134.400000000000006	0.0229999999999999996
60599	2N2	124	0.0229999999999999996
60599	OO1	10.0999999999999996	0.0160000000000000003
60599	LDA2	165.900000000000006	0.00700000000000000015
60599	M1	8.30000000000000071	0.0299999999999999989
60599	J1	9.5	0.0330000000000000016
60599	SSA	66.7000000000000028	0.0980000000000000038
60599	SA	167.900000000000006	0.245999999999999996
60599	RHO1	7.29999999999999982	0.0160000000000000003
60599	Q1	7.20000000000000018	0.0790000000000000008
60599	T2	176.599999999999994	0.0160000000000000003
60599	R2	178.300000000000011	0.00300000000000000006
60599	2Q1	6.59999999999999964	0.0100000000000000002
60599	P1	8.90000000000000036	0.164000000000000007
60599	L2	172	0.0259999999999999988
60599	K2	179.199999999999989	0.0850000000000000061
60599	M8	261.800000000000011	0.00300000000000000006
60600	M2	170	0.883000000000000007
60600	S2	184.099999999999994	0.266000000000000014
60600	N2	151.5	0.171000000000000013
60600	K1	25.1999999999999993	0.443000000000000005
60600	M4	146.800000000000011	0.0160000000000000003
60600	O1	13.6999999999999993	0.443000000000000005
60600	M6	174.800000000000011	0.0229999999999999996
60600	S4	357.600000000000023	0.00300000000000000006
60600	NU2	153.900000000000006	0.0330000000000000016
60600	S6	2.89999999999999991	0.00300000000000000006
60600	MU2	156	0.0200000000000000004
60600	2N2	133.300000000000011	0.0229999999999999996
60600	OO1	36.6000000000000014	0.0200000000000000004
60600	LDA2	176.5	0.00700000000000000015
60600	M1	19.5	0.0299999999999999989
60600	J1	30.8999999999999986	0.0330000000000000016
60600	SSA	66.7000000000000028	0.0980000000000000038
60600	SA	167.900000000000006	0.245999999999999996
60600	RHO1	8.90000000000000036	0.0160000000000000003
60600	Q1	8.09999999999999964	0.0850000000000000061
60600	T2	183.599999999999994	0.0129999999999999994
60600	R2	184.599999999999994	0.00300000000000000006
60600	2Q1	2.20000000000000018	0.0100000000000000002
60600	P1	24.3999999999999986	0.143999999999999989
60600	L2	188.400000000000006	0.0259999999999999988
60600	K2	185.300000000000011	0.0719999999999999946
60600	M8	325.800000000000011	0.00300000000000000006
60601	M2	201.300000000000011	0.859999999999999987
60601	S2	224.5	0.248999999999999999
60601	N2	193.199999999999989	0.140999999999999986
60601	K1	45.7000000000000028	0.366999999999999993
60601	M4	272.899999999999977	0.0259999999999999988
60601	O1	34.7999999999999972	0.384000000000000008
60601	M6	250.400000000000006	0.0160000000000000003
60601	S4	357.100000000000023	0.00700000000000000015
60601	NU2	194.199999999999989	0.0299999999999999989
60601	MU2	178.199999999999989	0.0200000000000000004
60601	2N2	184.699999999999989	0.0200000000000000004
60601	OO1	58.7999999999999972	0.0160000000000000003
60601	LDA2	212.099999999999994	0.00700000000000000015
60601	M1	40.7000000000000028	0.0259999999999999988
60601	J1	52.2000000000000028	0.0299999999999999989
60601	SSA	66.7000000000000028	0.0980000000000000038
60601	SA	167.900000000000006	0.245999999999999996
60601	RHO1	29.8000000000000007	0.0160000000000000003
60601	Q1	28.8999999999999986	0.0749999999999999972
60601	T2	223.699999999999989	0.0160000000000000003
60601	R2	225.400000000000006	0.00300000000000000006
60601	2Q1	23.6999999999999993	0.0100000000000000002
60601	P1	44.8999999999999986	0.120999999999999996
60601	L2	208.599999999999994	0.0229999999999999996
60601	K2	226.400000000000006	0.0690000000000000058
60601	M8	314.699999999999989	0.00700000000000000015
60602	M2	171.5	0.855999999999999983
60602	S2	195.800000000000011	0.235999999999999988
60602	N2	160	0.150999999999999995
60602	K1	32.7999999999999972	0.404000000000000026
60602	M4	166.900000000000006	0.0259999999999999988
60602	O1	24.6999999999999993	0.387000000000000011
60602	M6	174.099999999999994	0.0160000000000000003
60602	S4	209.400000000000006	0.00300000000000000006
60602	NU2	161.599999999999994	0.0299999999999999989
60602	S6	269.5	0.00300000000000000006
60602	MU2	147.199999999999989	0.0200000000000000004
60602	2N2	148.599999999999994	0.0200000000000000004
60602	OO1	40.7999999999999972	0.0160000000000000003
60602	LDA2	182.800000000000011	0.00700000000000000015
60602	M1	28.8000000000000007	0.0259999999999999988
60602	J1	36.7000000000000028	0.0299999999999999989
60602	SSA	66.7000000000000028	0.0980000000000000038
60602	SA	167.900000000000006	0.245999999999999996
60602	RHO1	21.3000000000000007	0.0129999999999999994
60602	Q1	20.8000000000000007	0.0749999999999999972
60602	T2	194.800000000000011	0.0129999999999999994
60602	R2	196.800000000000011	0.00300000000000000006
60602	2Q1	16.8000000000000007	0.0100000000000000002
60602	P1	32.2999999999999972	0.131000000000000005
60602	L2	183	0.0229999999999999996
60602	K2	197.699999999999989	0.0619999999999999996
60603	M2	144.800000000000011	0.88600000000000001
60603	S2	157.099999999999994	0.288999999999999979
60603	N2	130.199999999999989	0.176999999999999991
60603	K1	9.30000000000000071	0.478999999999999981
60603	M4	119.799999999999997	0.0560000000000000012
60603	O1	3.29999999999999982	0.443000000000000005
60603	M6	130.099999999999994	0.0259999999999999988
60603	MK3	314.300000000000011	0.0299999999999999989
60603	S4	247.300000000000011	0.0100000000000000002
60603	MN4	86.4000000000000057	0.0229999999999999996
60603	NU2	140.599999999999994	0.0359999999999999973
60603	S6	358.100000000000023	0.00300000000000000006
60603	MU2	58.3999999999999986	0.0259999999999999988
60603	2N2	124.5	0.0229999999999999996
60603	OO1	1.30000000000000004	0.0100000000000000002
60603	LDA2	196.900000000000006	0.0100000000000000002
60603	S1	107.900000000000006	0.0490000000000000019
60603	M1	40.7000000000000028	0.0160000000000000003
60603	J1	15.4000000000000004	0.0259999999999999988
60603	SSA	42.2999999999999972	0.135000000000000009
60603	SA	158.5	0.315000000000000002
60603	MF	342.699999999999989	0.0330000000000000016
60603	RHO1	351.899999999999977	0.0160000000000000003
60603	Q1	353.399999999999977	0.101999999999999993
60603	T2	148.400000000000006	0.0160000000000000003
60603	R2	52.5	0.00700000000000000015
60603	2Q1	342.100000000000023	0.0160000000000000003
60603	P1	6.70000000000000018	0.157000000000000001
60603	2SM2	120.5	0.00300000000000000006
60603	M3	327.800000000000011	0.0100000000000000002
60603	L2	181.099999999999994	0.0330000000000000016
60603	2MK3	298.5	0.0299999999999999989
60603	K2	150.300000000000011	0.0850000000000000061
60603	MS4	141.900000000000006	0.0229999999999999996
60604	M2	172.599999999999994	0.764000000000000012
60604	S2	200.300000000000011	0.20699999999999999
60604	N2	161.599999999999994	0.135000000000000009
60604	K1	35.7000000000000028	0.419999999999999984
60604	M4	219.5	0.0459999999999999992
60604	O1	22.3000000000000007	0.387000000000000011
60604	M6	220.099999999999994	0.0299999999999999989
60604	S4	354.600000000000023	0.00700000000000000015
60604	NU2	163.099999999999994	0.0259999999999999988
60604	S6	325.199999999999989	0.0100000000000000002
60604	MU2	144.900000000000006	0.0200000000000000004
60604	2N2	150.599999999999994	0.0160000000000000003
60604	OO1	49.1000000000000014	0.0160000000000000003
60604	LDA2	185.5	0.00700000000000000015
60604	M1	29.1000000000000014	0.0259999999999999988
60604	J1	42.2999999999999972	0.0299999999999999989
60604	SSA	66.7000000000000028	0.0980000000000000038
60604	SA	167.900000000000006	0.245999999999999996
60604	RHO1	16.6000000000000014	0.0129999999999999994
60604	Q1	15.6999999999999993	0.0749999999999999972
60604	T2	199.199999999999989	0.0129999999999999994
60604	R2	201.400000000000006	0.00300000000000000006
60604	2Q1	9.09999999999999964	0.0100000000000000002
60604	P1	34.7000000000000028	0.140999999999999986
60604	L2	183.599999999999994	0.0229999999999999996
60604	K2	202.599999999999994	0.0560000000000000012
60604	M8	256	0.00700000000000000015
60605	M2	175.5	0.781000000000000028
60605	S2	199.300000000000011	0.197000000000000008
60605	N2	165.900000000000006	0.131000000000000005
60605	K1	34.8999999999999986	0.426999999999999991
60605	M4	204.699999999999989	0.0459999999999999992
60605	O1	23.1999999999999993	0.406999999999999973
60605	M6	213	0.0299999999999999989
60605	S4	11.0999999999999996	0.00700000000000000015
60605	NU2	167.199999999999989	0.0259999999999999988
60605	S6	338.300000000000011	0.0100000000000000002
60605	MU2	151.699999999999989	0.0200000000000000004
60605	2N2	156.400000000000006	0.0160000000000000003
60605	OO1	46.5	0.0160000000000000003
60605	LDA2	186.599999999999994	0.00700000000000000015
60605	M1	29.1000000000000014	0.0299999999999999989
60605	J1	40.7000000000000028	0.0330000000000000016
60605	SSA	66.7000000000000028	0.0980000000000000038
60605	SA	167.900000000000006	0.245999999999999996
60605	RHO1	18.1999999999999993	0.0160000000000000003
60605	Q1	17.5	0.0790000000000000008
60605	T2	198.400000000000006	0.0129999999999999994
60605	2Q1	11.6999999999999993	0.0100000000000000002
60605	P1	34	0.140999999999999986
60605	L2	185.099999999999994	0.0229999999999999996
60605	K2	201.300000000000011	0.0519999999999999976
60605	M8	212	0.00700000000000000015
60606	M2	178	0.65900000000000003
60606	S2	182.400000000000006	0.235999999999999988
60606	N2	170.699999999999989	0.117999999999999994
60606	K1	37.8999999999999986	0.387000000000000011
60606	M4	241	0.0389999999999999999
60606	O1	32.3999999999999986	0.390000000000000013
60606	M6	250.300000000000011	0.0229999999999999996
60606	MK3	100.799999999999997	0.0359999999999999973
60606	S4	337	0.0200000000000000004
60606	MN4	234	0.0129999999999999994
60606	NU2	173.400000000000006	0.0200000000000000004
60606	S6	132.199999999999989	0.00700000000000000015
60606	MU2	317.399999999999977	0.0129999999999999994
60606	2N2	334.600000000000023	0.00300000000000000006
60606	OO1	44.1000000000000014	0.0200000000000000004
60606	LDA2	183	0.0129999999999999994
60606	S1	189.900000000000006	0.0389999999999999999
60606	M1	95.7000000000000028	0.0160000000000000003
60606	J1	34.1000000000000014	0.0299999999999999989
60606	SSA	66.7000000000000028	0.0980000000000000038
60606	SA	167.900000000000006	0.245999999999999996
60606	RHO1	144.699999999999989	0.0100000000000000002
60606	Q1	30.6999999999999993	0.0950000000000000011
60606	T2	278.800000000000011	0.0229999999999999996
60606	R2	130.800000000000011	0.0660000000000000031
60606	2Q1	45	0.0129999999999999994
60606	P1	46.7000000000000028	0.120999999999999996
60606	2SM2	2.39999999999999991	0.00700000000000000015
60606	M3	340.699999999999989	0.0100000000000000002
60606	L2	180	0.0389999999999999999
60606	2MK3	113.5	0.0459999999999999992
60606	K2	201.199999999999989	0.0560000000000000012
60606	M8	357.800000000000011	0.00300000000000000006
60606	MS4	281.800000000000011	0.0200000000000000004
60607	M2	206.699999999999989	0.599999999999999978
60607	S2	251.800000000000011	0.101999999999999993
60607	N2	196.699999999999989	0.0919999999999999984
60607	K1	63.5	0.370999999999999996
60607	M4	342.300000000000011	0.0229999999999999996
60607	O1	53.6000000000000014	0.350999999999999979
60607	M6	303.300000000000011	0.0129999999999999994
60607	S4	287.899999999999977	0.00300000000000000006
60607	NU2	198	0.0200000000000000004
60607	S6	46	0.00700000000000000015
60607	MU2	161.5	0.0129999999999999994
60607	2N2	186.699999999999989	0.0129999999999999994
60607	OO1	73.4000000000000057	0.0160000000000000003
60607	LDA2	227.599999999999994	0.00300000000000000006
60607	M1	58.6000000000000014	0.0259999999999999988
60607	J1	68.4000000000000057	0.0259999999999999988
60607	SSA	66.7000000000000028	0.0980000000000000038
60607	SA	167.900000000000006	0.245999999999999996
60607	RHO1	49.3999999999999986	0.0129999999999999994
60607	Q1	48.7000000000000028	0.0690000000000000058
60607	T2	250	0.00700000000000000015
60607	2Q1	43.7999999999999972	0.0100000000000000002
60607	P1	62.7999999999999972	0.120999999999999996
60607	L2	216.599999999999994	0.0160000000000000003
60607	K2	255.5	0.0259999999999999988
60607	M8	141.800000000000011	0.00300000000000000006
60608	M2	162.699999999999989	0.65900000000000003
60608	S2	207.900000000000006	0.173999999999999988
60608	N2	154.900000000000006	0.131000000000000005
60608	K1	28.3999999999999986	0.373999999999999999
60608	M4	183.900000000000006	0.0330000000000000016
60608	O1	20.3999999999999986	0.387000000000000011
60608	M6	201.300000000000011	0.0259999999999999988
60608	MK3	30	0.0200000000000000004
60608	S4	313.300000000000011	0.0200000000000000004
60608	MN4	130.300000000000011	0.0100000000000000002
60608	NU2	152.400000000000006	0.0359999999999999973
60608	S6	106.599999999999994	0.00700000000000000015
60608	MU2	18	0.0129999999999999994
60608	2N2	125.700000000000003	0.0100000000000000002
60608	OO1	26.5	0.0330000000000000016
60608	LDA2	203.699999999999989	0.0259999999999999988
60608	S1	160.400000000000006	0.0589999999999999969
60608	M1	279.800000000000011	0.00700000000000000015
60608	J1	4	0.0259999999999999988
60608	SSA	66.7000000000000028	0.0980000000000000038
60608	SA	167.900000000000006	0.245999999999999996
60608	RHO1	83.2999999999999972	0.0229999999999999996
60608	Q1	22.6000000000000014	0.0820000000000000034
60608	T2	90.2999999999999972	0.0589999999999999969
60608	R2	2.5	0.104999999999999996
60608	2Q1	13.3000000000000007	0.0229999999999999996
60608	P1	39.7000000000000028	0.112000000000000002
60608	M3	2.20000000000000018	0.0100000000000000002
60608	L2	171.800000000000011	0.0429999999999999966
60608	2MK3	42	0.0200000000000000004
60608	K2	209.699999999999989	0.107999999999999999
60608	M8	315.300000000000011	0.00300000000000000006
60608	MS4	215	0.0160000000000000003
60609	M2	157.800000000000011	0.481999999999999984
60609	S2	170.199999999999989	0.16700000000000001
60609	N2	149.5	0.115000000000000005
60609	K1	27.5	0.412999999999999978
60609	M4	264.300000000000011	0.0160000000000000003
60609	O1	18.1000000000000014	0.412999999999999978
60609	M6	93.2000000000000028	0.0100000000000000002
60609	NU2	150.5	0.0200000000000000004
60609	S6	326.300000000000011	0.00300000000000000006
60609	MU2	145.199999999999989	0.0100000000000000002
60609	2N2	141.199999999999989	0.0129999999999999994
60609	OO1	36.7999999999999972	0.0160000000000000003
60609	LDA2	163.5	0.00300000000000000006
60609	M1	22.8999999999999986	0.0299999999999999989
60609	J1	32.1000000000000014	0.0330000000000000016
60609	SSA	66.7000000000000028	0.0980000000000000038
60609	SA	167.900000000000006	0.245999999999999996
60609	RHO1	14.3000000000000007	0.0160000000000000003
60609	Q1	13.5	0.0820000000000000034
60609	T2	169.699999999999989	0.0100000000000000002
60609	2Q1	9	0.0100000000000000002
60609	P1	26.8000000000000007	0.135000000000000009
60609	L2	166.300000000000011	0.0129999999999999994
60609	K2	171.199999999999989	0.0459999999999999992
60609	M8	354.699999999999989	0.00300000000000000006
60610	M2	256.899999999999977	0.36399999999999999
60610	S2	275.699999999999989	0.104999999999999996
60610	N2	244	0.0589999999999999969
60610	K1	95	0.291999999999999982
60610	M4	66.5	0.0160000000000000003
60610	O1	86.7999999999999972	0.256000000000000005
60610	MK3	270.100000000000023	0.0389999999999999999
60610	NU2	255.800000000000011	0.0200000000000000004
60610	MU2	73.4000000000000057	0.0259999999999999988
60610	2N2	231.300000000000011	0.00700000000000000015
60610	OO1	103.099999999999994	0.0100000000000000002
60610	LDA2	271.800000000000011	0.0100000000000000002
60610	S1	174.800000000000011	0.0589999999999999969
60610	M1	148.599999999999994	0.0129999999999999994
60610	J1	99	0.0200000000000000004
60610	MM	2.10000000000000009	0.0619999999999999996
60610	SA	150.699999999999989	0.269000000000000017
60610	MSF	6.70000000000000018	0.0459999999999999992
60610	RHO1	53.7999999999999972	0.0129999999999999994
60610	Q1	82.7999999999999972	0.0490000000000000019
60610	T2	274.800000000000011	0.00700000000000000015
60610	R2	249.199999999999989	0.0100000000000000002
60610	2Q1	78.5999999999999943	0.00700000000000000015
60610	P1	101.5	0.0790000000000000008
60610	L2	270.399999999999977	0.0259999999999999988
60610	2MK3	256.800000000000011	0.0389999999999999999
60610	K2	267.600000000000023	0.0560000000000000012
60610	MS4	104.700000000000003	0.0129999999999999994
60611	M2	189.199999999999989	0.357999999999999985
60611	S2	190.699999999999989	0.0950000000000000011
60611	N2	175.5	0.0660000000000000031
60611	K1	52.5	0.390000000000000013
60611	M4	253.699999999999989	0.0129999999999999994
60611	O1	37.1000000000000014	0.384000000000000008
60611	M6	224.699999999999989	0.00300000000000000006
60611	S4	279.5	0.00300000000000000006
60611	NU2	177.400000000000006	0.0129999999999999994
60611	MU2	187.300000000000011	0.0100000000000000002
60611	2N2	162.400000000000006	0.00700000000000000015
60611	OO1	67.5999999999999943	0.0160000000000000003
60611	LDA2	189.300000000000011	0.00300000000000000006
60611	M1	44.7000000000000028	0.0259999999999999988
60611	J1	59.6000000000000014	0.0299999999999999989
60611	SSA	66.7000000000000028	0.0980000000000000038
60611	SA	167.900000000000006	0.245999999999999996
60611	RHO1	30.8999999999999986	0.0129999999999999994
60611	Q1	29.6999999999999993	0.0749999999999999972
60611	T2	190.400000000000006	0.00700000000000000015
60611	2Q1	21.8000000000000007	0.0100000000000000002
60611	P1	51.2999999999999972	0.128000000000000003
60611	L2	203.099999999999994	0.0100000000000000002
60611	K2	191.099999999999994	0.0259999999999999988
60611	M8	35.8999999999999986	0.00300000000000000006
60612	M2	155.900000000000006	0.36399999999999999
60612	S2	158.800000000000011	0.131000000000000005
60612	N2	143.199999999999989	0.0690000000000000058
60612	K1	30.1000000000000014	0.409999999999999976
60612	M4	71.9000000000000057	0.0229999999999999996
60612	O1	21.1000000000000014	0.377000000000000002
60612	M6	168.599999999999994	0.0100000000000000002
60612	S4	240.800000000000011	0.00300000000000000006
60612	NU2	144.900000000000006	0.0129999999999999994
60612	MU2	152.900000000000006	0.0100000000000000002
60612	2N2	130.400000000000006	0.0100000000000000002
60612	OO1	38.8999999999999986	0.0160000000000000003
60612	LDA2	157.199999999999989	0.00300000000000000006
60612	M1	25.6000000000000014	0.0259999999999999988
60612	J1	34.3999999999999986	0.0299999999999999989
60612	SSA	66.7000000000000028	0.0980000000000000038
60612	SA	167.900000000000006	0.245999999999999996
60612	RHO1	17.3000000000000007	0.0129999999999999994
60612	Q1	16.6999999999999993	0.0719999999999999946
60612	T2	158.5	0.00700000000000000015
60612	2Q1	12.3000000000000007	0.0100000000000000002
60612	P1	29.3999999999999986	0.135000000000000009
60612	L2	168.199999999999989	0.0100000000000000002
60612	K2	159	0.0359999999999999973
60613	M2	214.800000000000011	0.36399999999999999
60613	S2	176.400000000000006	0.0660000000000000031
60613	N2	208.400000000000006	0.0619999999999999996
60613	K1	57.6000000000000014	0.377000000000000002
60613	M4	305.699999999999989	0.00700000000000000015
60613	O1	48.5	0.36399999999999999
60613	M6	304.699999999999989	0.00700000000000000015
60613	MK3	185	0.0100000000000000002
60613	S4	339	0.00700000000000000015
60613	NU2	213.400000000000006	0.0160000000000000003
60613	MU2	43.1000000000000014	0.0259999999999999988
60613	2N2	0.5	0.00300000000000000006
60613	OO1	193.099999999999994	0.0100000000000000002
60613	LDA2	263.5	0.0129999999999999994
60613	S1	225	0.0129999999999999994
60613	M1	116.599999999999994	0.0330000000000000016
60613	J1	38.3999999999999986	0.0259999999999999988
60613	SSA	66.7000000000000028	0.0980000000000000038
60613	SA	167.900000000000006	0.245999999999999996
60613	RHO1	17.3000000000000007	0.00700000000000000015
60613	Q1	54.7999999999999972	0.0749999999999999972
60613	T2	305	0.0330000000000000016
60613	R2	29.8000000000000007	0.0790000000000000008
60613	2Q1	139.599999999999994	0.0129999999999999994
60613	P1	58.6000000000000014	0.135000000000000009
60613	2SM2	99.4000000000000057	0.00300000000000000006
60613	M3	343.300000000000011	0.00700000000000000015
60613	L2	227.900000000000006	0.0229999999999999996
60613	2MK3	193.5	0.0160000000000000003
60613	K2	202.5	0.117999999999999994
60613	M8	87.7999999999999972	0.00300000000000000006
60613	MS4	355.5	0.00700000000000000015
60614	M2	165	0.357999999999999985
60614	S2	170.300000000000011	0.135000000000000009
60614	N2	156.300000000000011	0.0660000000000000031
60614	K1	40.6000000000000014	0.422999999999999987
60614	M4	230.5	0.0100000000000000002
60614	O1	31.8999999999999986	0.343999999999999972
60614	M6	206.199999999999989	0.00700000000000000015
60614	S4	120	0.00300000000000000006
60614	NU2	157.5	0.0129999999999999994
60614	MU2	159.800000000000011	0.0100000000000000002
60614	2N2	147.699999999999989	0.0100000000000000002
60614	OO1	49.7999999999999972	0.0129999999999999994
60614	LDA2	167.400000000000006	0.00300000000000000006
60614	M1	36.3999999999999986	0.0229999999999999996
60614	J1	45	0.0259999999999999988
60614	SSA	66.7000000000000028	0.0980000000000000038
60614	SA	167.900000000000006	0.245999999999999996
60614	RHO1	28.5	0.0129999999999999994
60614	Q1	27.6000000000000014	0.0660000000000000031
60614	T2	169.800000000000011	0.00700000000000000015
60614	2Q1	23.8000000000000007	0.0100000000000000002
60614	P1	40	0.140999999999999986
60614	L2	173.400000000000006	0.0100000000000000002
60614	K2	170.699999999999989	0.0359999999999999973
60614	M8	236.900000000000006	0.00300000000000000006
60615	M2	230	0.481999999999999984
60615	S2	230.800000000000011	0.140999999999999986
60615	N2	215.400000000000006	0.0950000000000000011
60615	K1	69.2000000000000028	0.475999999999999979
60615	M4	11.0999999999999996	0.0129999999999999994
60615	O1	62.7000000000000028	0.366999999999999993
60615	M6	71.9000000000000057	0.00700000000000000015
60615	S4	2	0.00700000000000000015
60615	NU2	217.400000000000006	0.0200000000000000004
60615	S6	36.7999999999999972	0.00300000000000000006
60615	MU2	229.300000000000011	0.0129999999999999994
60615	2N2	200.800000000000011	0.0129999999999999994
60615	OO1	75.5999999999999943	0.0160000000000000003
60615	LDA2	230.400000000000006	0.00300000000000000006
60615	M1	66	0.0259999999999999988
60615	J1	72.4000000000000057	0.0299999999999999989
60615	SSA	66.7000000000000028	0.0980000000000000038
60615	SA	167.900000000000006	0.245999999999999996
60615	RHO1	60	0.0129999999999999994
60615	Q1	59.5	0.0719999999999999946
60615	T2	230.699999999999989	0.0100000000000000002
60615	2Q1	56.2999999999999972	0.0100000000000000002
60615	P1	68.7000000000000028	0.157000000000000001
60615	L2	244.599999999999994	0.0129999999999999994
60615	K2	230.800000000000011	0.0389999999999999999
60615	M8	132	0.00300000000000000006
60616	M2	246.300000000000011	0.52200000000000002
60616	S2	261.600000000000023	0.107999999999999999
60616	N2	238.800000000000011	0.0820000000000000034
60616	K1	77.2000000000000028	0.426999999999999991
60616	M4	39.8999999999999986	0.0200000000000000004
60616	O1	65.2999999999999972	0.412999999999999978
60616	M6	93.5999999999999943	0.00700000000000000015
60616	MK3	246.099999999999994	0.0589999999999999969
60616	S4	75.5999999999999943	0.00700000000000000015
60616	MN4	348.800000000000011	0.00300000000000000006
60616	NU2	220.300000000000011	0.0200000000000000004
60616	MU2	28.6999999999999993	0.0519999999999999976
60616	2N2	61.6000000000000014	0.0259999999999999988
60616	OO1	105.099999999999994	0.0229999999999999996
60616	LDA2	246.900000000000006	0.0389999999999999999
60616	S1	178.5	0.147999999999999993
60616	M1	178.099999999999994	0.0299999999999999989
60616	J1	59.8999999999999986	0.0330000000000000016
60616	SSA	66.7000000000000028	0.0980000000000000038
60616	SA	167.900000000000006	0.245999999999999996
60616	RHO1	130.400000000000006	0.0259999999999999988
60616	Q1	70.2999999999999972	0.0850000000000000061
60616	T2	243.300000000000011	0.0330000000000000016
60616	R2	155.599999999999994	0.0749999999999999972
60616	2Q1	79.7999999999999972	0.0200000000000000004
60616	P1	106.5	0.135000000000000009
60616	2SM2	73.2000000000000028	0.0100000000000000002
60616	M3	96.5	0.00700000000000000015
60616	L2	235.400000000000006	0.0429999999999999966
60616	2MK3	231.699999999999989	0.0719999999999999946
60616	K2	281.5	0.0660000000000000031
60616	M8	264.5	0.00300000000000000006
60616	MS4	90	0.00700000000000000015
60617	M2	188.900000000000006	0.360999999999999988
60617	S2	205	0.115000000000000005
60617	N2	184.400000000000006	0.0660000000000000031
60617	K1	55.3999999999999986	0.390000000000000013
60617	M4	317.800000000000011	0.0129999999999999994
60617	O1	48.6000000000000014	0.366999999999999993
60617	S4	353.399999999999977	0.00700000000000000015
60617	NU2	185	0.0129999999999999994
60617	S6	115.200000000000003	0.00300000000000000006
60617	MU2	174.400000000000006	0.0100000000000000002
60617	2N2	180.5	0.00700000000000000015
60617	OO1	62.5	0.0160000000000000003
60617	LDA2	196.400000000000006	0.00300000000000000006
60617	M1	52.2000000000000028	0.0259999999999999988
60617	J1	59.2000000000000028	0.0299999999999999989
60617	SSA	66.7000000000000028	0.0980000000000000038
60617	SA	167.900000000000006	0.245999999999999996
60617	RHO1	45.7000000000000028	0.0129999999999999994
60617	Q1	45.1000000000000014	0.0719999999999999946
60617	T2	204.400000000000006	0.00700000000000000015
60617	2Q1	41.2999999999999972	0.0100000000000000002
60617	P1	54.8999999999999986	0.128000000000000003
60617	L2	193.699999999999989	0.0100000000000000002
60617	K2	206.400000000000006	0.0299999999999999989
60617	M8	130.099999999999994	0.00300000000000000006
60618	M2	282.300000000000011	0.481999999999999984
60618	S2	300.5	0.115000000000000005
60618	N2	275.100000000000023	0.0850000000000000061
60618	K1	99.5	0.370999999999999996
60618	M4	84.7999999999999972	0.0200000000000000004
60618	O1	87.2999999999999972	0.353999999999999981
60618	M6	174.800000000000011	0.00700000000000000015
60618	S4	195.599999999999994	0.00300000000000000006
60618	NU2	276.600000000000023	0.0160000000000000003
60618	S6	50	0.00300000000000000006
60618	MU2	264.899999999999977	0.0100000000000000002
60618	2N2	266.199999999999989	0.0100000000000000002
60618	OO1	115.299999999999997	0.0129999999999999994
60618	LDA2	290.699999999999989	0.00300000000000000006
60618	M1	94.2000000000000028	0.0229999999999999996
60618	J1	107.700000000000003	0.0259999999999999988
60618	SSA	66.7000000000000028	0.0980000000000000038
60618	SA	167.900000000000006	0.245999999999999996
60618	RHO1	81.5	0.0129999999999999994
60618	Q1	80.4000000000000057	0.0690000000000000058
60618	T2	298.199999999999989	0.00700000000000000015
60618	2Q1	73.7999999999999972	0.0100000000000000002
60618	P1	98.5999999999999943	0.120999999999999996
60618	L2	285.600000000000023	0.0129999999999999994
60618	K2	302.100000000000023	0.0299999999999999989
60618	M8	299.5	0.00300000000000000006
60619	M2	117.799999999999997	0.558000000000000052
60619	S2	127.599999999999994	0.187
60619	N2	111.799999999999997	0.131000000000000005
60619	K1	8.69999999999999929	0.485999999999999988
60619	M4	56.7999999999999972	0.00700000000000000015
60619	O1	3	0.446000000000000008
60619	M6	68.5999999999999943	0.00700000000000000015
60619	MK3	322.199999999999989	0.0129999999999999994
60619	S4	199.300000000000011	0.00700000000000000015
60619	MN4	67.2000000000000028	0.00700000000000000015
60619	NU2	113.299999999999997	0.0229999999999999996
60619	S6	39.7000000000000028	0.00300000000000000006
60619	MU2	66.7000000000000028	0.0229999999999999996
60619	2N2	91.7000000000000028	0.0229999999999999996
60619	OO1	23.5	0.0160000000000000003
60619	LDA2	103.900000000000006	0.00700000000000000015
60619	S1	91.5999999999999943	0.0889999999999999958
60619	M1	28	0.0160000000000000003
60619	J1	41.1000000000000014	0.0200000000000000004
60619	SSA	66.7000000000000028	0.0980000000000000038
60619	SA	167.900000000000006	0.245999999999999996
60619	RHO1	346.399999999999977	0.0229999999999999996
60619	Q1	352	0.0919999999999999984
60619	T2	255.300000000000011	0.00300000000000000006
60619	R2	156.5	0.0299999999999999989
60619	2Q1	354.100000000000023	0.0100000000000000002
60619	P1	359.5	0.125
60619	2SM2	116.200000000000003	0.0100000000000000002
60619	M3	289.199999999999989	0.0129999999999999994
60619	L2	124.900000000000006	0.0100000000000000002
60619	2MK3	317.600000000000023	0.0299999999999999989
60619	K2	128.800000000000011	0.0560000000000000012
60619	M8	40.6000000000000014	0.00300000000000000006
60619	MS4	17.1999999999999993	0.0100000000000000002
60620	M2	130.400000000000006	0.541000000000000036
60620	S2	141.699999999999989	0.242999999999999994
60620	N2	122.099999999999994	0.117999999999999994
60620	K1	20.3999999999999986	0.468999999999999972
60620	M4	57.2999999999999972	0.0359999999999999973
60620	O1	10.5999999999999996	0.456000000000000016
60620	MK3	291.399999999999977	0.0229999999999999996
60620	NU2	117.5	0.0200000000000000004
60620	MU2	64	0.0259999999999999988
60620	2N2	73.9000000000000057	0.0229999999999999996
60620	OO1	48.5	0.0160000000000000003
60620	LDA2	282.699999999999989	0.0129999999999999994
60620	S1	111.200000000000003	0.0299999999999999989
60620	M1	3.39999999999999991	0.0100000000000000002
60620	J1	28.3999999999999986	0.0259999999999999988
60620	RHO1	4	0.0259999999999999988
60620	Q1	2.79999999999999982	0.0950000000000000011
60620	2Q1	14.4000000000000004	0.0129999999999999994
60620	P1	13.9000000000000004	0.153999999999999998
60620	2SM2	107.900000000000006	0.00700000000000000015
60620	L2	207.099999999999994	0.0100000000000000002
60620	2MK3	289.100000000000023	0.0229999999999999996
60620	K2	133.900000000000006	0.0749999999999999972
60620	M8	121.700000000000003	0.00300000000000000006
60620	MS4	65.7000000000000028	0.0259999999999999988
60621	M2	137.300000000000011	0.509000000000000008
60621	S2	152.5	0.203000000000000014
60621	N2	132.5	0.104999999999999996
60621	K1	24.3000000000000007	0.491999999999999993
60621	M4	63.2999999999999972	0.0229999999999999996
60621	O1	14.1999999999999993	0.453000000000000014
60621	M6	141.400000000000006	0.0100000000000000002
60621	MK3	307.899999999999977	0.0129999999999999994
60621	MN4	50.7000000000000028	0.0100000000000000002
60621	NU2	139.300000000000011	0.0200000000000000004
60621	MU2	77.5	0.0160000000000000003
60621	2N2	114.200000000000003	0.0160000000000000003
60621	OO1	36	0.0129999999999999994
60621	S1	130.5	0.0619999999999999996
60621	M1	357.199999999999989	0.0129999999999999994
60621	J1	29.3000000000000007	0.0259999999999999988
60621	RHO1	351	0.0259999999999999988
60621	Q1	7	0.0889999999999999958
60621	T2	167.400000000000006	0.0129999999999999994
60621	2Q1	10.5	0.0129999999999999994
60621	P1	14.1999999999999993	0.147999999999999993
60621	M3	303	0.0100000000000000002
60621	L2	176.300000000000011	0.0100000000000000002
60621	2MK3	298	0.0200000000000000004
60621	K2	146.400000000000006	0.0560000000000000012
60621	MS4	68.4000000000000057	0.0160000000000000003
60622	M2	172.099999999999994	0.528000000000000025
60622	S2	187	0.179999999999999993
60622	N2	165.099999999999994	0.0950000000000000011
60622	K1	39.7999999999999972	0.525000000000000022
60622	M4	155.400000000000006	0.0129999999999999994
60622	O1	27.1999999999999993	0.485999999999999988
60622	M6	178.900000000000006	0.0129999999999999994
60622	MK3	53.1000000000000014	0.0129999999999999994
60622	NU2	177.699999999999989	0.0229999999999999996
60622	MU2	19.1000000000000014	0.0200000000000000004
60622	2N2	163.300000000000011	0.0100000000000000002
60622	OO1	52.2000000000000028	0.0200000000000000004
60622	LDA2	207.699999999999989	0.0100000000000000002
60622	S1	135.699999999999989	0.0560000000000000012
60622	M1	46.5	0.0160000000000000003
60622	J1	74.4000000000000057	0.0229999999999999996
60622	SSA	48.2000000000000028	0.140999999999999986
60622	SA	155	0.350999999999999979
60622	MF	193.199999999999989	0.0359999999999999973
60622	RHO1	356.100000000000023	0.0160000000000000003
60622	Q1	15.1999999999999993	0.0919999999999999984
60622	T2	160	0.0100000000000000002
60622	2Q1	5.59999999999999964	0.0160000000000000003
60622	P1	46.2000000000000028	0.164000000000000007
60622	L2	206.099999999999994	0.0259999999999999988
60622	2MK3	29.1999999999999993	0.0129999999999999994
60622	K2	187.800000000000011	0.0690000000000000058
60623	M2	226.5	0.406999999999999973
60623	S2	261.199999999999989	0.153999999999999998
60623	N2	224.300000000000011	0.0749999999999999972
60623	K1	62.7999999999999972	0.498999999999999999
60623	M4	351.699999999999989	0.0100000000000000002
60623	O1	61.7999999999999972	0.440000000000000002
60623	M6	284.399999999999977	0.00700000000000000015
60623	S4	100	0.00700000000000000015
60623	NU2	224.599999999999994	0.0129999999999999994
60623	MU2	27.1999999999999993	0.0100000000000000002
60623	2N2	222.199999999999989	0.0100000000000000002
60623	OO1	63.6000000000000014	0.0200000000000000004
60623	LDA2	242.5	0.00300000000000000006
60623	M1	62.2999999999999972	0.0330000000000000016
60623	J1	63.2000000000000028	0.0359999999999999973
60623	RHO1	61.3999999999999986	0.0160000000000000003
60623	Q1	61.2999999999999972	0.0850000000000000061
60623	T2	259.800000000000011	0.0100000000000000002
60623	2Q1	60.8999999999999986	0.0100000000000000002
60623	P1	62.7999999999999972	0.164000000000000007
60623	L2	229.599999999999994	0.0100000000000000002
60623	K2	264	0.0429999999999999966
60624	M2	197	0.573999999999999955
60624	S2	211.699999999999989	0.187
60624	N2	191.300000000000011	0.0980000000000000038
60624	K1	49.8999999999999986	0.548000000000000043
60624	M4	230.800000000000011	0.0100000000000000002
60624	O1	37.7000000000000028	0.509000000000000008
60624	MK3	129	0.0129999999999999994
60624	NU2	198.699999999999989	0.0299999999999999989
60624	MU2	20.6999999999999993	0.0299999999999999989
60624	2N2	193.5	0.0129999999999999994
60624	OO1	62	0.0200000000000000004
60624	LDA2	226.199999999999989	0.0129999999999999994
60624	S1	138.5	0.0560000000000000012
60624	M1	79.2999999999999972	0.0160000000000000003
60624	J1	91.0999999999999943	0.0259999999999999988
60624	SSA	41	0.107999999999999999
60624	SA	150.800000000000011	0.301999999999999991
60624	RHO1	4.20000000000000018	0.0160000000000000003
60624	Q1	26.1999999999999993	0.0950000000000000011
60624	T2	187.099999999999994	0.0129999999999999994
60624	2Q1	9.5	0.0160000000000000003
60624	P1	57.6000000000000014	0.161000000000000004
60624	L2	219.800000000000011	0.0359999999999999973
60624	K2	215	0.0820000000000000034
60625	M2	205.599999999999994	0.633000000000000007
60625	S2	221.5	0.212999999999999995
60625	N2	193.5	0.104999999999999996
60625	K1	63.7000000000000028	0.509000000000000008
60625	M4	265.399999999999977	0.0200000000000000004
60625	O1	42.8999999999999986	0.481999999999999984
60625	M6	317.199999999999989	0.0160000000000000003
60625	NU2	195.199999999999989	0.0200000000000000004
60625	MU2	189.400000000000006	0.0160000000000000003
60625	2N2	181.800000000000011	0.0129999999999999994
60625	OO1	84.4000000000000057	0.0200000000000000004
60625	LDA2	212.900000000000006	0.00300000000000000006
60625	M1	53.2999999999999972	0.0330000000000000016
60625	J1	73.7000000000000028	0.0389999999999999999
60625	SSA	41	0.107999999999999999
60625	SA	150.800000000000011	0.301999999999999991
60625	RHO1	34	0.0200000000000000004
60625	Q1	32.6000000000000014	0.0950000000000000011
60625	T2	220.800000000000011	0.0129999999999999994
60625	R2	222.800000000000011	0.00300000000000000006
60625	2Q1	22.3000000000000007	0.0129999999999999994
60625	P1	62.1000000000000014	0.16700000000000001
60625	L2	218	0.0160000000000000003
60625	K2	222.800000000000011	0.0589999999999999969
60626	M2	214.900000000000006	0.656000000000000028
60626	S2	233.900000000000006	0.20699999999999999
60626	N2	209.599999999999994	0.101999999999999993
60626	K1	56.7999999999999972	0.576999999999999957
60626	O1	43.8999999999999986	0.52200000000000002
60626	MK3	215.800000000000011	0.0229999999999999996
60626	NU2	213.400000000000006	0.0330000000000000016
60626	MU2	18.5	0.0429999999999999966
60626	2N2	237.099999999999994	0.0129999999999999994
60626	OO1	69.7000000000000028	0.0229999999999999996
60626	LDA2	242.599999999999994	0.0160000000000000003
60626	S1	141.5	0.0719999999999999946
60626	M1	100.200000000000003	0.0200000000000000004
60626	J1	106.299999999999997	0.0299999999999999989
60626	SSA	38.8999999999999986	0.187
60626	SA	138.5	0.426999999999999991
60626	MSF	38	0.0389999999999999999
60626	MF	194	0.0589999999999999969
60626	RHO1	1.60000000000000009	0.0200000000000000004
60626	Q1	35.2999999999999972	0.0980000000000000038
60626	T2	233	0.0129999999999999994
60626	R2	171.400000000000006	0.0100000000000000002
60626	2Q1	3.20000000000000018	0.0129999999999999994
60626	P1	65.4000000000000057	0.16700000000000001
60626	2SM2	98.2999999999999972	0.0129999999999999994
60626	L2	227.599999999999994	0.0519999999999999976
60626	2MK3	203.400000000000006	0.0299999999999999989
60626	K2	232.900000000000006	0.0980000000000000038
60627	M2	201	0.721999999999999975
60627	S2	220.599999999999994	0.23899999999999999
60627	N2	191.5	0.131000000000000005
60627	K1	55.6000000000000014	0.485999999999999988
60627	M4	263.300000000000011	0.0259999999999999988
60627	O1	41.7999999999999972	0.52200000000000002
60627	M6	311.600000000000023	0.0299999999999999989
60627	S4	262.699999999999989	0.00300000000000000006
60627	NU2	192.699999999999989	0.0229999999999999996
60627	S6	264.600000000000023	0.00700000000000000015
60627	MU2	181.199999999999989	0.0160000000000000003
60627	2N2	181.5	0.0160000000000000003
60627	OO1	69.7999999999999972	0.0229999999999999996
60627	LDA2	209.800000000000011	0.00700000000000000015
60627	M1	49	0.0359999999999999973
60627	J1	63	0.0389999999999999999
60627	SSA	41	0.107999999999999999
60627	SA	150.800000000000011	0.301999999999999991
60627	RHO1	36	0.0200000000000000004
60627	Q1	34.7999999999999972	0.101999999999999993
60627	T2	219.900000000000006	0.0129999999999999994
60627	R2	221.599999999999994	0.00300000000000000006
60627	2Q1	28.3000000000000007	0.0129999999999999994
60627	P1	54.6000000000000014	0.161000000000000004
60627	L2	210	0.0200000000000000004
60627	K2	222.099999999999994	0.0619999999999999996
60627	M8	68.4000000000000057	0.00300000000000000006
60628	M2	200.400000000000006	0.72799999999999998
60628	S2	217.599999999999994	0.248999999999999999
60628	N2	195.400000000000006	0.135000000000000009
60628	K1	51.7000000000000028	0.603999999999999981
60628	M4	264.399999999999977	0.0359999999999999973
60628	O1	39.8999999999999986	0.54500000000000004
60628	M6	328.600000000000023	0.0299999999999999989
60628	MK3	144.599999999999994	0.0299999999999999989
60628	MN4	246.300000000000011	0.0129999999999999994
60628	NU2	203.5	0.0359999999999999973
60628	MU2	14.0999999999999996	0.0389999999999999999
60628	2N2	190.400000000000006	0.0160000000000000003
60628	OO1	186.099999999999994	0.0129999999999999994
60628	LDA2	213.400000000000006	0.0160000000000000003
60628	S1	138.699999999999989	0.0889999999999999958
60628	M1	117.200000000000003	0.0160000000000000003
60628	J1	103.400000000000006	0.0299999999999999989
60628	SSA	59.7000000000000028	0.0749999999999999972
60628	SA	148.900000000000006	0.281999999999999973
60628	RHO1	10.0999999999999996	0.0160000000000000003
60628	Q1	26.3000000000000007	0.101999999999999993
60628	T2	196.300000000000011	0.0100000000000000002
60628	R2	218.400000000000006	0.00300000000000000006
60628	2Q1	7.90000000000000036	0.0259999999999999988
60628	P1	57.7000000000000028	0.179999999999999993
60628	2SM2	83.4000000000000057	0.0100000000000000002
60628	L2	218.199999999999989	0.0359999999999999973
60628	2MK3	136.199999999999989	0.0299999999999999989
60628	K2	219.099999999999994	0.107999999999999999
60628	MS4	280.399999999999977	0.0160000000000000003
60629	M2	123.099999999999994	0.807000000000000051
60629	S2	141	0.315000000000000002
60629	N2	120.299999999999997	0.150999999999999995
60629	K1	12.4000000000000004	0.518000000000000016
60629	M4	76	0.0299999999999999989
60629	O1	3.60000000000000009	0.494999999999999996
60629	MK3	331.699999999999989	0.0100000000000000002
60629	MN4	51	0.0160000000000000003
60629	NU2	121.599999999999994	0.0330000000000000016
60629	2N2	110.099999999999994	0.0160000000000000003
60629	OO1	4.70000000000000018	0.0160000000000000003
60629	LDA2	131.400000000000006	0.00700000000000000015
60629	S1	93.7999999999999972	0.0429999999999999966
60629	M1	15.6999999999999993	0.0229999999999999996
60629	J1	20.8000000000000007	0.0330000000000000016
60629	SSA	48.2000000000000028	0.120999999999999996
60629	SA	151.900000000000006	0.298999999999999988
60629	RHO1	341.800000000000011	0.0160000000000000003
60629	Q1	348	0.104999999999999996
60629	T2	119.099999999999994	0.0229999999999999996
60629	R2	141.699999999999989	0.00300000000000000006
60629	2Q1	340.800000000000011	0.0160000000000000003
60629	P1	12.5	0.173999999999999988
60629	M3	298.600000000000023	0.0100000000000000002
60629	L2	143.099999999999994	0.0229999999999999996
60629	2MK3	309	0.0129999999999999994
60629	K2	134.599999999999994	0.0889999999999999958
60629	MS4	90.5	0.0200000000000000004
60630	M2	242.199999999999989	0.679000000000000048
60630	S2	262	0.245999999999999996
60630	N2	237.900000000000006	0.125
60630	K1	68.7000000000000028	0.646000000000000019
60630	M4	17	0.0259999999999999988
60630	O1	57.8999999999999986	0.531000000000000028
60630	M6	69.4000000000000057	0.00300000000000000006
60630	S4	137.300000000000011	0.00300000000000000006
60630	NU2	238.5	0.0259999999999999988
60630	S6	242.099999999999994	0.00300000000000000006
60630	MU2	58.5	0.0160000000000000003
60630	2N2	233.5	0.0160000000000000003
60630	OO1	78.7999999999999972	0.0229999999999999996
60630	LDA2	250.800000000000011	0.00300000000000000006
60630	M1	63.2000000000000028	0.0389999999999999999
60630	J1	73.5	0.0429999999999999966
60630	RHO1	53.3999999999999986	0.0200000000000000004
60630	Q1	52.7000000000000028	0.101999999999999993
60630	T2	261.199999999999989	0.0129999999999999994
60630	R2	263	0.00300000000000000006
60630	2Q1	47.5	0.0129999999999999994
60630	P1	67.7999999999999972	0.212999999999999995
60630	L2	246.400000000000006	0.0200000000000000004
60630	K2	263.600000000000023	0.0660000000000000031
60630	M8	205.800000000000011	0.00300000000000000006
60631	M2	134	0.935000000000000053
60631	S2	153.099999999999994	0.381000000000000005
60631	N2	127.5	0.157000000000000001
60631	K1	14.0999999999999996	0.61399999999999999
60631	M4	127.299999999999997	0.0229999999999999996
60631	O1	5.09999999999999964	0.471999999999999975
60631	M6	187.800000000000011	0.00300000000000000006
60631	S4	294.899999999999977	0.00700000000000000015
60631	NU2	128.400000000000006	0.0299999999999999989
60631	S6	339.100000000000023	0.00700000000000000015
60631	MU2	114.799999999999997	0.0229999999999999996
60631	2N2	121	0.0200000000000000004
60631	OO1	23.1999999999999993	0.0200000000000000004
60631	LDA2	142.900000000000006	0.00700000000000000015
60631	M1	9.69999999999999929	0.0330000000000000016
60631	J1	18.6000000000000014	0.0359999999999999973
60631	SSA	48.2000000000000028	0.120999999999999996
60631	SA	151.900000000000006	0.298999999999999988
60631	RHO1	1.30000000000000004	0.0160000000000000003
60631	Q1	0.699999999999999956	0.0919999999999999984
60631	T2	152.400000000000006	0.0229999999999999996
60631	R2	153.900000000000006	0.00300000000000000006
60631	2Q1	356.199999999999989	0.0129999999999999994
60631	P1	13.5	0.203000000000000014
60631	L2	140.400000000000006	0.0259999999999999988
60631	K2	154.699999999999989	0.104999999999999996
60631	M8	164.699999999999989	0.00300000000000000006
60632	M2	193.699999999999989	0.85299999999999998
60632	S2	246.599999999999994	0.350999999999999979
60632	N2	195.900000000000006	0.157000000000000001
60632	K1	38.2000000000000028	0.538000000000000034
60632	M4	321.300000000000011	0.0519999999999999976
60632	O1	48.5	0.481999999999999984
60632	M6	160	0.00700000000000000015
60632	S4	53.7000000000000028	0.0259999999999999988
60632	NU2	195.599999999999994	0.0299999999999999989
60632	S6	184	0.00300000000000000006
60632	MU2	141.5	0.0200000000000000004
60632	2N2	198	0.0200000000000000004
60632	OO1	28.6999999999999993	0.0200000000000000004
60632	LDA2	217.900000000000006	0.00700000000000000015
60632	M1	43.6000000000000014	0.0359999999999999973
60632	J1	33.5	0.0389999999999999999
60632	SSA	48.2000000000000028	0.120999999999999996
60632	SA	151.900000000000006	0.298999999999999988
60632	RHO1	52.7999999999999972	0.0200000000000000004
60632	Q1	53.2999999999999972	0.0919999999999999984
60632	T2	244.599999999999994	0.0229999999999999996
60632	R2	248.199999999999989	0.00300000000000000006
60632	2Q1	58.5	0.0129999999999999994
60632	P1	38.8999999999999986	0.176999999999999991
60632	L2	190.800000000000011	0.0229999999999999996
60632	K2	250.900000000000006	0.0950000000000000011
60632	M8	9.90000000000000036	0.00300000000000000006
60633	M2	236.199999999999989	0.695999999999999952
60633	S2	289.399999999999977	0.245999999999999996
60633	N2	236.900000000000006	0.0850000000000000061
60633	K1	86.5	0.357999999999999985
60633	M4	51.2000000000000028	0.0820000000000000034
60633	O1	76.2999999999999972	0.390000000000000013
60633	M6	275.199999999999989	0.0160000000000000003
60633	MK3	239.900000000000006	0.125
60633	S4	139.300000000000011	0.0129999999999999994
60633	MN4	51.3999999999999986	0.0229999999999999996
60633	NU2	211.699999999999989	0.0299999999999999989
60633	MU2	359.800000000000011	0.0850000000000000061
60633	2N2	180	0.0490000000000000019
60633	OO1	155	0.0330000000000000016
60633	LDA2	145.400000000000006	0.00700000000000000015
60633	S1	188	0.0429999999999999966
60633	M1	191.199999999999989	0.0259999999999999988
60633	J1	95	0.0259999999999999988
60633	RHO1	56.6000000000000014	0.0100000000000000002
60633	Q1	59	0.0719999999999999946
60633	T2	287.199999999999989	0.0129999999999999994
60633	R2	291.5	0.00300000000000000006
60633	2Q1	52.7999999999999972	0.0429999999999999966
60633	P1	83.5999999999999943	0.135000000000000009
60633	2SM2	20.1999999999999993	0.00700000000000000015
60633	M3	32.7000000000000028	0.00700000000000000015
60633	L2	259	0.0490000000000000019
60633	2MK3	222.5	0.112000000000000002
60633	K2	265.600000000000023	0.140999999999999986
60633	M8	95.5	0.00300000000000000006
60633	MS4	91.0999999999999943	0.0519999999999999976
60634	M2	328	0.138000000000000012
60634	S2	358	0.0359999999999999973
60634	N2	333.800000000000011	0.0160000000000000003
60634	K1	166.400000000000006	0.112000000000000002
60634	M4	209.800000000000011	0.0160000000000000003
60634	O1	143.900000000000006	0.135000000000000009
60634	M6	79.5	0.00300000000000000006
60634	NU2	333	0.00300000000000000006
60634	MU2	269	0.00300000000000000006
60634	2N2	339.600000000000023	0.00300000000000000006
60634	OO1	188.800000000000011	0.00700000000000000015
60634	M1	155.099999999999994	0.0100000000000000002
60634	J1	177.5	0.0100000000000000002
60634	RHO1	134.099999999999994	0.00700000000000000015
60634	Q1	132.599999999999994	0.0259999999999999988
60634	T2	356.699999999999989	0.00300000000000000006
60634	2Q1	121.5	0.00300000000000000006
60634	P1	164.599999999999994	0.0359999999999999973
60634	L2	322.199999999999989	0.00300000000000000006
60634	K2	0.299999999999999989	0.0100000000000000002
60635	M2	300.699999999999989	0.341000000000000025
60635	S2	351.600000000000023	0.135000000000000009
60635	N2	290.399999999999977	0.0429999999999999966
60635	K1	135.599999999999994	0.223000000000000004
60635	M4	172.800000000000011	0.0429999999999999966
60635	O1	125.799999999999997	0.259000000000000008
60635	M6	75.9000000000000057	0.00700000000000000015
60635	MK3	340.600000000000023	0.0719999999999999946
60635	S4	273.699999999999989	0.00300000000000000006
60635	MN4	160.199999999999989	0.0129999999999999994
60635	NU2	279.699999999999989	0.0129999999999999994
60635	MU2	74.4000000000000057	0.0459999999999999992
60635	2N2	249.099999999999994	0.0359999999999999973
60635	OO1	118.299999999999997	0.00700000000000000015
60635	LDA2	256.300000000000011	0.0100000000000000002
60635	S1	187.5	0.0299999999999999989
60635	M1	225.300000000000011	0.0200000000000000004
60635	J1	182.800000000000011	0.0129999999999999994
60635	RHO1	151.800000000000011	0.0160000000000000003
60635	Q1	101.799999999999997	0.0359999999999999973
60635	T2	349.5	0.00700000000000000015
60635	2Q1	85.0999999999999943	0.0259999999999999988
60635	P1	135	0.0889999999999999958
60635	2SM2	71.4000000000000057	0.0100000000000000002
60635	M3	165.400000000000006	0.00300000000000000006
60635	L2	336.699999999999989	0.0229999999999999996
60635	2MK3	323.800000000000011	0.0660000000000000031
60635	K2	341.5	0.101999999999999993
60635	MS4	211	0.0259999999999999988
60636	M2	246.199999999999989	0.563999999999999946
60636	S2	290.199999999999989	0.173999999999999988
60636	N2	245.199999999999989	0.0850000000000000061
60636	K1	106.200000000000003	0.27200000000000002
60636	M4	77.0999999999999943	0.0690000000000000058
60636	O1	81.9000000000000057	0.373999999999999999
60636	M6	302.399999999999977	0.0129999999999999994
60636	S4	173.400000000000006	0.0129999999999999994
60636	NU2	245.300000000000011	0.0160000000000000003
60636	S6	335.100000000000023	0.00300000000000000006
60636	MU2	175.800000000000011	0.0129999999999999994
60636	2N2	244.300000000000011	0.0100000000000000002
60636	OO1	130.400000000000006	0.0160000000000000003
60636	LDA2	266.5	0.00300000000000000006
60636	M1	94	0.0259999999999999988
60636	J1	118.299999999999997	0.0299999999999999989
60636	RHO1	71.4000000000000057	0.0129999999999999994
60636	Q1	69.7000000000000028	0.0719999999999999946
60636	T2	288.300000000000011	0.0100000000000000002
60636	2Q1	57.7000000000000028	0.0100000000000000002
60636	P1	104.299999999999997	0.0889999999999999958
60636	L2	247	0.0129999999999999994
60636	K2	293.800000000000011	0.0459999999999999992
60636	M8	111.5	0.00300000000000000006
60637	M2	336.800000000000011	0.171000000000000013
60637	S2	356.600000000000023	0.0389999999999999999
60637	N2	329.899999999999977	0.0200000000000000004
60637	K1	165.199999999999989	0.135000000000000009
60637	M4	227.400000000000006	0.0200000000000000004
60637	O1	158.199999999999989	0.161000000000000004
60637	M6	172.199999999999989	0.00300000000000000006
60637	MK3	23.3999999999999986	0.0330000000000000016
60637	S4	333.399999999999977	0.00300000000000000006
60637	MN4	225.5	0.00700000000000000015
60637	NU2	330.800000000000011	0.00300000000000000006
60637	MU2	110.200000000000003	0.0259999999999999988
60637	2N2	323.100000000000023	0.00300000000000000006
60637	OO1	172.099999999999994	0.00700000000000000015
60637	S1	202.699999999999989	0.0259999999999999988
60637	M1	161.599999999999994	0.0100000000000000002
60637	J1	168.699999999999989	0.0129999999999999994
60637	RHO1	155.099999999999994	0.00700000000000000015
60637	Q1	154.599999999999994	0.0299999999999999989
60637	T2	355.699999999999989	0.00300000000000000006
60637	2Q1	151.199999999999989	0.00300000000000000006
60637	P1	164.599999999999994	0.0429999999999999966
60637	2SM2	135.199999999999989	0.00300000000000000006
60637	M3	29.3999999999999986	0.00300000000000000006
60637	L2	343.600000000000023	0.00300000000000000006
60637	2MK3	7.70000000000000018	0.0299999999999999989
60637	K2	358.199999999999989	0.0100000000000000002
60637	MS4	262.899999999999977	0.0100000000000000002
60638	M2	334.600000000000023	0.187
60638	S2	17.5	0.0389999999999999999
60638	N2	13.6999999999999993	0.0229999999999999996
60638	K1	161.599999999999994	0.125
60638	M4	206.699999999999989	0.0160000000000000003
60638	O1	152.400000000000006	0.150999999999999995
60638	NU2	8.5	0.00300000000000000006
60638	MU2	263.600000000000023	0.00300000000000000006
60638	2N2	52.8999999999999986	0.00300000000000000006
60638	OO1	170.599999999999994	0.00700000000000000015
60638	M1	157	0.0100000000000000002
60638	J1	166	0.0129999999999999994
60638	RHO1	148.5	0.00700000000000000015
60638	Q1	147.900000000000006	0.0299999999999999989
60638	T2	15.6999999999999993	0.00300000000000000006
60638	2Q1	143.400000000000006	0.00300000000000000006
60638	P1	160.800000000000011	0.0429999999999999966
60638	L2	295.399999999999977	0.00300000000000000006
60638	K2	21	0.0100000000000000002
60639	M2	248.5	0.586999999999999966
60639	S2	299.800000000000011	0.179999999999999993
60639	N2	251.900000000000006	0.0749999999999999972
60639	K1	101.200000000000003	0.27200000000000002
60639	M4	73.0999999999999943	0.0950000000000000011
60639	O1	97.5999999999999943	0.301999999999999991
60639	M6	273.800000000000011	0.0160000000000000003
60639	S4	169.099999999999994	0.0100000000000000002
60639	NU2	251.5	0.0129999999999999994
60639	MU2	174.800000000000011	0.0129999999999999994
60639	2N2	255.5	0.0100000000000000002
60639	OO1	104.700000000000003	0.0129999999999999994
60639	LDA2	272.300000000000011	0.00300000000000000006
60639	M1	99.2999999999999972	0.0200000000000000004
60639	J1	102.900000000000006	0.0229999999999999996
60639	RHO1	96	0.0100000000000000002
60639	Q1	95.7000000000000028	0.0589999999999999969
60639	T2	297.600000000000023	0.0100000000000000002
60639	2Q1	93.9000000000000057	0.00700000000000000015
60639	P1	100.799999999999997	0.0889999999999999958
60639	L2	245	0.0100000000000000002
60639	K2	304	0.0490000000000000019
60639	M8	116.400000000000006	0.00300000000000000006
60640	M2	204.5	1.23999999999999999
60640	S2	244.800000000000011	0.406999999999999973
60640	N2	201.800000000000011	0.179999999999999993
60640	K1	55.6000000000000014	0.446000000000000008
60640	M4	324.399999999999977	0.0719999999999999946
60640	O1	42.6000000000000014	0.491999999999999993
60640	M6	289.199999999999989	0.00700000000000000015
60640	S4	72.9000000000000057	0.0200000000000000004
60640	NU2	202.199999999999989	0.0359999999999999973
60640	S6	200.199999999999989	0.00300000000000000006
60640	MU2	138.300000000000011	0.0299999999999999989
60640	2N2	199.300000000000011	0.0229999999999999996
60640	OO1	68.5	0.0200000000000000004
60640	LDA2	223.199999999999989	0.0100000000000000002
60640	M1	49	0.0359999999999999973
60640	J1	62	0.0389999999999999999
60640	RHO1	37	0.0200000000000000004
60640	Q1	36.1000000000000014	0.0950000000000000011
60640	T2	243.199999999999989	0.0229999999999999996
60640	R2	246.400000000000006	0.00300000000000000006
60640	2Q1	29.6999999999999993	0.0129999999999999994
60640	P1	54.5	0.147999999999999993
60640	L2	207.099999999999994	0.0259999999999999988
60640	K2	248.099999999999994	0.112000000000000002
60641	M2	261.199999999999989	0.688999999999999946
60641	S2	311.199999999999989	0.23000000000000001
60641	N2	253.699999999999989	0.107999999999999999
60641	K1	110.299999999999997	0.266000000000000014
60641	M4	86.7999999999999972	0.0749999999999999972
60641	O1	93.2999999999999972	0.373999999999999999
60641	M6	12	0.0100000000000000002
60641	S4	242.300000000000011	0.0160000000000000003
60641	NU2	254.699999999999989	0.0200000000000000004
60641	S6	280.899999999999977	0.00300000000000000006
60641	MU2	186	0.0160000000000000003
60641	2N2	246.199999999999989	0.0129999999999999994
60641	OO1	127.200000000000003	0.0160000000000000003
60641	LDA2	284.399999999999977	0.00700000000000000015
60641	M1	101.799999999999997	0.0259999999999999988
60641	J1	118.700000000000003	0.0299999999999999989
60641	RHO1	86	0.0129999999999999994
60641	Q1	84.7999999999999972	0.0719999999999999946
60641	T2	309.100000000000023	0.0129999999999999994
60641	R2	313.199999999999989	0.00300000000000000006
60641	2Q1	76.4000000000000057	0.0100000000000000002
60641	P1	108.900000000000006	0.0889999999999999958
60641	L2	268.699999999999989	0.0160000000000000003
60641	K2	315.199999999999989	0.0619999999999999996
60641	M8	237.199999999999989	0.00300000000000000006
60642	M2	270.800000000000011	0.695999999999999952
60642	S2	314.800000000000011	0.203000000000000014
60642	N2	276	0.0889999999999999958
60642	K1	96.0999999999999943	0.266000000000000014
60642	M4	92.2000000000000028	0.0589999999999999969
60642	O1	85.0999999999999943	0.298999999999999988
60642	M6	114.599999999999994	0.00700000000000000015
60642	S4	201.300000000000011	0.0129999999999999994
60642	NU2	275.300000000000011	0.0160000000000000003
60642	S6	287.800000000000011	0.00300000000000000006
60642	MU2	201.699999999999989	0.0160000000000000003
60642	2N2	281.300000000000011	0.0129999999999999994
60642	OO1	107	0.0129999999999999994
60642	LDA2	291.100000000000023	0.00700000000000000015
60642	M1	90.5	0.0200000000000000004
60642	J1	101.599999999999994	0.0229999999999999996
60642	RHO1	80.2999999999999972	0.0100000000000000002
60642	Q1	79.5	0.0589999999999999969
60642	T2	312.899999999999977	0.0129999999999999994
60642	R2	316.600000000000023	0.00300000000000000006
60642	2Q1	74.0999999999999943	0.00700000000000000015
60642	P1	95.2000000000000028	0.0889999999999999958
60642	L2	265.5	0.0129999999999999994
60642	K2	318.399999999999977	0.0560000000000000012
60642	M8	357.699999999999989	0.00300000000000000006
60643	M2	243.199999999999989	0.787000000000000033
60643	S2	282.699999999999989	0.245999999999999996
60643	N2	241.800000000000011	0.112000000000000002
60643	K1	90.7000000000000028	0.256000000000000005
60643	M4	43.8999999999999986	0.0619999999999999996
60643	O1	68.4000000000000057	0.36399999999999999
60643	M6	42.1000000000000014	0.0100000000000000002
60643	S4	135.5	0.0160000000000000003
60643	NU2	242	0.0229999999999999996
60643	S6	265.399999999999977	0.00300000000000000006
60643	MU2	178.199999999999989	0.0200000000000000004
60643	2N2	240.5	0.0160000000000000003
60643	OO1	112.900000000000006	0.0160000000000000003
60643	LDA2	261.399999999999977	0.00700000000000000015
60643	M1	79.5999999999999943	0.0259999999999999988
60643	J1	101.799999999999997	0.0299999999999999989
60643	SSA	201.199999999999989	0.0299999999999999989
60643	SA	280.600000000000023	0.115000000000000005
60643	RHO1	58.7999999999999972	0.0129999999999999994
60643	Q1	57.2000000000000028	0.0690000000000000058
60643	T2	281	0.0160000000000000003
60643	R2	284.300000000000011	0.00300000000000000006
60643	2Q1	46.2999999999999972	0.0100000000000000002
60643	P1	88.9000000000000057	0.0850000000000000061
60643	L2	244.400000000000006	0.0160000000000000003
60643	K2	285.899999999999977	0.0660000000000000031
60643	M8	202.099999999999994	0.00300000000000000006
60644	M2	216.5	1.00099999999999989
60644	S2	253.599999999999994	0.304999999999999993
60644	N2	212.400000000000006	0.147999999999999993
60644	K1	71.5999999999999943	0.343999999999999972
60644	M4	4.5	0.104999999999999996
60644	O1	54.2999999999999972	0.39700000000000002
60644	M6	232.599999999999994	0.00300000000000000006
60644	S4	99.7999999999999972	0.0229999999999999996
60644	NU2	212.900000000000006	0.0299999999999999989
60644	S6	216.099999999999994	0.00300000000000000006
60644	MU2	153.699999999999989	0.0229999999999999996
60644	2N2	208.400000000000006	0.0200000000000000004
60644	OO1	88.7999999999999972	0.0160000000000000003
60644	LDA2	233.599999999999994	0.00700000000000000015
60644	M1	62.7999999999999972	0.0299999999999999989
60644	J1	80.2000000000000028	0.0299999999999999989
60644	SSA	201.199999999999989	0.0229999999999999996
60644	SA	280.600000000000023	0.0850000000000000061
60644	RHO1	46.7999999999999972	0.0160000000000000003
60644	Q1	45.6000000000000014	0.0749999999999999972
60644	T2	252	0.0160000000000000003
60644	R2	255.099999999999994	0.00300000000000000006
60644	2Q1	37	0.0100000000000000002
60644	P1	70.2000000000000028	0.115000000000000005
60644	L2	220.400000000000006	0.0200000000000000004
60644	K2	256.600000000000023	0.0820000000000000034
60645	M2	188.900000000000006	1.24700000000000011
60645	S2	225.699999999999989	0.39700000000000002
60645	N2	181.900000000000006	0.216999999999999998
60645	K1	35	0.554000000000000048
60645	M4	252.400000000000006	0.0259999999999999988
60645	O1	26.8999999999999986	0.52200000000000002
60645	M6	195.699999999999989	0.0129999999999999994
60645	MK3	169.099999999999994	0.0229999999999999996
60645	S4	330.699999999999989	0.00300000000000000006
60645	MN4	229.5	0.0100000000000000002
60645	NU2	181	0.0560000000000000012
60645	S6	267.699999999999989	0.00300000000000000006
60645	MU2	292	0.0459999999999999992
60645	2N2	183.300000000000011	0.0229999999999999996
60645	OO1	106.400000000000006	0.0100000000000000002
60645	LDA2	233.099999999999994	0.0299999999999999989
60645	S1	135	0.0229999999999999996
60645	M1	90.7000000000000028	0.0160000000000000003
60645	J1	58.6000000000000014	0.0299999999999999989
60645	SSA	41.1000000000000014	0.104999999999999996
60645	SA	140	0.390000000000000013
60645	RHO1	359.5	0.0259999999999999988
60645	Q1	11.9000000000000004	0.117999999999999994
60645	T2	219.800000000000011	0.0299999999999999989
60645	R2	51.3999999999999986	0.0490000000000000019
60645	2Q1	342	0.0160000000000000003
60645	P1	26.8999999999999986	0.190000000000000002
60645	2SM2	87.7000000000000028	0.0160000000000000003
60645	M3	36.7000000000000028	0.00300000000000000006
60645	L2	198.599999999999994	0.0560000000000000012
60645	2MK3	160.5	0.0299999999999999989
60645	K2	224.099999999999994	0.0980000000000000038
60645	M8	225	0.00300000000000000006
60645	MS4	292	0.0160000000000000003
60646	M2	187	1.17799999999999994
60646	S2	215.300000000000011	0.453000000000000014
60646	N2	181	0.16700000000000001
60646	K1	32.2999999999999972	0.478999999999999981
60646	M4	285.199999999999989	0.0589999999999999969
60646	O1	25.5	0.502000000000000002
60646	M6	212.900000000000006	0.0100000000000000002
60646	S4	335.399999999999977	0.0160000000000000003
60646	NU2	181.800000000000011	0.0330000000000000016
60646	MU2	158.699999999999989	0.0259999999999999988
60646	2N2	174.800000000000011	0.0229999999999999996
60646	OO1	40.7000000000000028	0.0200000000000000004
60646	LDA2	200.400000000000006	0.00700000000000000015
60646	M1	29.1999999999999993	0.0359999999999999973
60646	J1	36.6000000000000014	0.0389999999999999999
60646	SA	136.400000000000006	0.315000000000000002
60646	RHO1	22.3000000000000007	0.0200000000000000004
60646	Q1	21.8000000000000007	0.0980000000000000038
60646	T2	214.199999999999989	0.0259999999999999988
60646	R2	216.199999999999989	0.00300000000000000006
60646	2Q1	18.6000000000000014	0.0129999999999999994
60646	P1	31.8000000000000007	0.157000000000000001
60646	L2	194	0.0330000000000000016
60646	K2	217.599999999999994	0.120999999999999996
60646	M8	301.300000000000011	0.00300000000000000006
60647	M2	197.699999999999989	1.19700000000000006
60647	S2	221.199999999999989	0.509000000000000008
60647	N2	189.800000000000011	0.190000000000000002
60647	K1	35.2999999999999972	0.478999999999999981
60647	M4	5.70000000000000018	0.0459999999999999992
60647	O1	31.1000000000000014	0.468999999999999972
60647	MK3	161.699999999999989	0.0850000000000000061
60647	MN4	12.6999999999999993	0.0259999999999999988
60647	NU2	197.199999999999989	0.0459999999999999992
60647	MU2	316.100000000000023	0.0619999999999999996
60647	2N2	155.400000000000006	0.0429999999999999966
60647	OO1	87.2000000000000028	0.0719999999999999946
60647	LDA2	195.300000000000011	0.0299999999999999989
60647	S1	116.400000000000006	0.0259999999999999988
60647	M1	166.300000000000011	0.0299999999999999989
60647	SSA	43.2999999999999972	0.128000000000000003
60647	SA	135.699999999999989	0.381000000000000005
60647	RHO1	62.7999999999999972	0.0259999999999999988
60647	Q1	18.1000000000000014	0.0980000000000000038
60647	T2	185.599999999999994	0.0589999999999999969
60647	R2	54.7000000000000028	0.0889999999999999958
60647	2Q1	353.699999999999989	0.0259999999999999988
60647	P1	45.2999999999999972	0.173999999999999988
60647	2SM2	2.89999999999999991	0.0259999999999999988
60647	L2	218.099999999999994	0.0690000000000000058
60647	2MK3	144.099999999999994	0.0589999999999999969
60647	K2	185.699999999999989	0.179999999999999993
60647	MS4	25.6000000000000014	0.0589999999999999969
60648	M2	197.900000000000006	1.16799999999999993
60648	S2	224.800000000000011	0.485999999999999988
60648	N2	193.5	0.216999999999999998
60648	K1	30.8000000000000007	0.567999999999999949
60648	O1	27.6000000000000014	0.502000000000000002
60648	MK3	132.800000000000011	0.0429999999999999966
60648	NU2	246.199999999999989	0.0389999999999999999
60648	MU2	308.399999999999977	0.0200000000000000004
60648	2N2	189.099999999999994	0.0299999999999999989
60648	OO1	33.8999999999999986	0.0200000000000000004
60648	LDA2	217.5	0.0299999999999999989
60648	S1	109.299999999999997	0.0889999999999999958
60648	M1	29.1000000000000014	0.0359999999999999973
60648	J1	32.3999999999999986	0.0389999999999999999
60648	SSA	53.6000000000000014	0.0950000000000000011
60648	SA	138.800000000000011	0.328000000000000014
60648	RHO1	1.5	0.0389999999999999999
60648	Q1	11.8000000000000007	0.138000000000000012
60648	T2	162.300000000000011	0.0359999999999999973
60648	R2	224.800000000000011	0.00300000000000000006
60648	2Q1	24.3000000000000007	0.0129999999999999994
60648	P1	34.2999999999999972	0.150999999999999995
60648	2SM2	25.8999999999999986	0.0100000000000000002
60648	M3	220.599999999999994	0.0200000000000000004
60648	L2	253	0.0459999999999999992
60648	2MK3	128.099999999999994	0.0459999999999999992
60648	K2	212.300000000000011	0.125
60648	MS4	42.2999999999999972	0.0100000000000000002
60649	M2	208.199999999999989	1.18799999999999994
60649	S2	234.300000000000011	0.456000000000000016
60649	N2	203.5	0.212999999999999995
60649	K1	36.1000000000000014	0.599999999999999978
60649	M4	19	0.0100000000000000002
60649	O1	29.6000000000000014	0.531000000000000028
60649	MK3	151.400000000000006	0.0490000000000000019
60649	NU2	196.699999999999989	0.0519999999999999976
60649	MU2	334.199999999999989	0.0299999999999999989
60649	2N2	198.900000000000006	0.0299999999999999989
60649	OO1	42.5	0.0229999999999999996
60649	LDA2	220.199999999999989	0.00700000000000000015
60649	S1	111.799999999999997	0.0490000000000000019
60649	M1	32.7999999999999972	0.0359999999999999973
60649	J1	46.1000000000000014	0.0359999999999999973
60649	SSA	43.2999999999999972	0.128000000000000003
60649	SA	135.699999999999989	0.381000000000000005
60649	RHO1	26.6999999999999993	0.0200000000000000004
60649	Q1	16.5	0.117999999999999994
60649	T2	234.199999999999989	0.0259999999999999988
60649	R2	201.800000000000011	0.0299999999999999989
60649	2Q1	23	0.0129999999999999994
60649	P1	39.6000000000000014	0.183999999999999997
60649	2SM2	64.7000000000000028	0.0129999999999999994
60649	L2	228.599999999999994	0.0429999999999999966
60649	2MK3	133.5	0.0459999999999999992
60649	K2	229.199999999999989	0.135000000000000009
60649	MS4	51.7000000000000028	0.0160000000000000003
60650	M2	200.300000000000011	0.839999999999999969
60650	S2	221.800000000000011	0.315000000000000002
60650	N2	190.099999999999994	0.157000000000000001
60650	K1	29.8000000000000007	0.563999999999999946
60650	M4	352	0.0160000000000000003
60650	O1	24	0.515000000000000013
60650	MK3	115.799999999999997	0.0129999999999999994
60650	NU2	191.599999999999994	0.0299999999999999989
60650	MU2	57.7000000000000028	0.0299999999999999989
60650	2N2	180	0.0200000000000000004
60650	OO1	35.5	0.0229999999999999996
60650	LDA2	210.199999999999989	0.00700000000000000015
60650	S1	77.5	0.0359999999999999973
60650	M1	26.8000000000000007	0.0359999999999999973
60650	J1	44.1000000000000014	0.0389999999999999999
60650	SSA	47.3999999999999986	0.120999999999999996
60650	SA	134	0.377000000000000002
60650	RHO1	21.5	0.0200000000000000004
60650	Q1	1.89999999999999991	0.125
60650	T2	221.699999999999989	0.0160000000000000003
60650	R2	221.800000000000011	0.00300000000000000006
60650	2Q1	18.1000000000000014	0.0129999999999999994
60650	P1	31.3000000000000007	0.173999999999999988
60650	2SM2	96.7999999999999972	0.0160000000000000003
60650	L2	235.300000000000011	0.0389999999999999999
60650	K2	232.800000000000011	0.104999999999999996
60651	M2	209.300000000000011	0.676000000000000045
60651	S2	235	0.266000000000000014
60651	N2	211.199999999999989	0.125
60651	K1	29.5	0.567999999999999949
60651	M4	1.39999999999999991	0.0200000000000000004
60651	O1	27	0.494999999999999996
60651	M6	162	0.00700000000000000015
60651	S4	211.599999999999994	0.0129999999999999994
60651	NU2	210.800000000000011	0.0229999999999999996
60651	S6	255.099999999999994	0.00700000000000000015
60651	MU2	183.699999999999989	0.0160000000000000003
60651	2N2	213.300000000000011	0.0160000000000000003
60651	OO1	31.8000000000000007	0.0200000000000000004
60651	LDA2	221.199999999999989	0.00300000000000000006
60651	M1	28.1999999999999993	0.0330000000000000016
60651	J1	30.3000000000000007	0.0389999999999999999
60651	SSA	47.3999999999999986	0.120999999999999996
60651	SA	134	0.377000000000000002
60651	RHO1	26.1999999999999993	0.0200000000000000004
60651	Q1	25.8999999999999986	0.0950000000000000011
60651	T2	234	0.0160000000000000003
60651	R2	236	0.00300000000000000006
60651	2Q1	25	0.0129999999999999994
60651	P1	29.3000000000000007	0.187
60651	L2	207.900000000000006	0.0200000000000000004
60651	K2	237.099999999999994	0.0719999999999999946
60652	M2	210.599999999999994	0.724999999999999978
60652	S2	231.199999999999989	0.294999999999999984
60652	N2	199.099999999999994	0.115000000000000005
60652	K1	33.1000000000000014	0.576999999999999957
60652	M4	345.699999999999989	0.0330000000000000016
60652	O1	24.8999999999999986	0.494999999999999996
60652	M6	202.300000000000011	0.00700000000000000015
60652	S4	66.5	0.0129999999999999994
60652	NU2	200.599999999999994	0.0229999999999999996
60652	MU2	190.599999999999994	0.0160000000000000003
60652	2N2	185.199999999999989	0.0129999999999999994
60652	OO1	41.3999999999999986	0.0200000000000000004
60652	LDA2	219.900000000000006	0.00700000000000000015
60652	M1	29	0.0359999999999999973
60652	J1	37.2999999999999972	0.0389999999999999999
60652	SSA	47.3999999999999986	0.120999999999999996
60652	SA	134	0.377000000000000002
60652	RHO1	21.3000000000000007	0.0200000000000000004
60652	Q1	20.8000000000000007	0.0950000000000000011
60652	T2	230.199999999999989	0.0160000000000000003
60652	R2	231.900000000000006	0.00300000000000000006
60652	2Q1	16.8000000000000007	0.0129999999999999994
60652	P1	32.5	0.190000000000000002
60652	L2	220	0.0200000000000000004
60652	K2	232.900000000000006	0.0790000000000000008
60652	M8	305.199999999999989	0.00300000000000000006
60653	M2	212.5	0.622999999999999998
60653	S2	240.900000000000006	0.233000000000000013
60653	N2	193.199999999999989	0.104999999999999996
60653	K1	34.1000000000000014	0.498999999999999999
60653	M4	27.6000000000000014	0.0229999999999999996
60653	O1	32.2000000000000028	0.440000000000000002
60653	M6	181.400000000000006	0.00700000000000000015
60653	S4	125	0.00700000000000000015
60653	NU2	195.900000000000006	0.0200000000000000004
60653	S6	32.2000000000000028	0.00700000000000000015
60653	MU2	184	0.0160000000000000003
60653	2N2	173.400000000000006	0.0129999999999999994
60653	OO1	35.7999999999999972	0.0200000000000000004
60653	LDA2	225.800000000000011	0.00300000000000000006
60653	M1	33.1000000000000014	0.0330000000000000016
60653	J1	35	0.0359999999999999973
60653	SSA	28.6999999999999993	0.117999999999999994
60653	SA	145.099999999999994	0.245999999999999996
60653	RHO1	31.1999999999999993	0.0160000000000000003
60653	Q1	31.1999999999999993	0.0850000000000000061
60653	T2	239.900000000000006	0.0129999999999999994
60653	R2	242.199999999999989	0.00300000000000000006
60653	2Q1	30.3000000000000007	0.0100000000000000002
60653	P1	34	0.164000000000000007
60653	L2	232	0.0160000000000000003
60653	K2	243.199999999999989	0.0619999999999999996
60653	M8	231	0.00300000000000000006
60654	M2	233.800000000000011	0.633000000000000007
60654	S2	256.899999999999977	0.223000000000000004
60654	N2	214.900000000000006	0.125
60654	K1	42.6000000000000014	0.586999999999999966
60654	M4	76.4000000000000057	0.0129999999999999994
60654	O1	36.7000000000000028	0.468999999999999972
60654	M6	327.100000000000023	0.00300000000000000006
60654	S4	212.699999999999989	0.00700000000000000015
60654	NU2	217.699999999999989	0.0229999999999999996
60654	S6	283.300000000000011	0.00300000000000000006
60654	MU2	210.400000000000006	0.0160000000000000003
60654	2N2	197.300000000000011	0.0160000000000000003
60654	OO1	50.8999999999999986	0.0200000000000000004
60654	LDA2	244.800000000000011	0.00300000000000000006
60654	M1	40.2999999999999972	0.0330000000000000016
60654	J1	47.2999999999999972	0.0359999999999999973
60654	SSA	47.3999999999999986	0.120999999999999996
60654	SA	134	0.377000000000000002
60654	RHO1	33.7999999999999972	0.0160000000000000003
60654	Q1	33.2999999999999972	0.0919999999999999984
60654	T2	256.5	0.0129999999999999994
60654	R2	258.300000000000011	0.00300000000000000006
60654	2Q1	29.8000000000000007	0.0129999999999999994
60654	P1	42.1000000000000014	0.194000000000000006
60654	L2	250.800000000000011	0.0160000000000000003
60654	K2	258.899999999999977	0.0619999999999999996
60654	M8	276.699999999999989	0.00300000000000000006
60655	M2	220.5	0.63600000000000001
60655	S2	249.400000000000006	0.248999999999999999
60655	N2	205.5	0.117999999999999994
60655	K1	33.7999999999999972	0.567999999999999949
60655	M4	1.19999999999999996	0.0200000000000000004
60655	O1	31.8000000000000007	0.456000000000000016
60655	M6	225.699999999999989	0.00700000000000000015
60655	S4	147.300000000000011	0.0100000000000000002
60655	NU2	207.800000000000011	0.0229999999999999996
60655	S6	63.5	0.00700000000000000015
60655	MU2	191.900000000000006	0.0129999999999999994
60655	2N2	189.699999999999989	0.0160000000000000003
60655	OO1	35.6000000000000014	0.0200000000000000004
60655	LDA2	233.800000000000011	0.00300000000000000006
60655	M1	32.7000000000000028	0.0330000000000000016
60655	J1	34.6000000000000014	0.0359999999999999973
60655	SSA	47.3999999999999986	0.120999999999999996
60655	SA	134	0.377000000000000002
60655	RHO1	31.1000000000000014	0.0160000000000000003
60655	Q1	30.8999999999999986	0.0889999999999999958
60655	T2	248.300000000000011	0.0129999999999999994
60655	R2	250.5	0.00300000000000000006
60655	2Q1	30.1999999999999993	0.0100000000000000002
60655	P1	33.7000000000000028	0.187
60655	L2	236.300000000000011	0.0160000000000000003
60655	K2	251.699999999999989	0.0690000000000000058
60656	M2	241.099999999999994	0.54500000000000004
60656	S2	254.099999999999994	0.190000000000000002
60656	N2	237	0.104999999999999996
60656	K1	34.7000000000000028	0.586999999999999966
60656	M4	59.2000000000000028	0.0229999999999999996
60656	O1	37.5	0.443000000000000005
60656	M6	38.1000000000000014	0.00700000000000000015
60656	S4	43.7999999999999972	0.00300000000000000006
60656	NU2	237.5	0.0200000000000000004
60656	S6	227.699999999999989	0.0100000000000000002
60656	MU2	228.099999999999994	0.0129999999999999994
60656	2N2	232.800000000000011	0.0129999999999999994
60656	OO1	31.8999999999999986	0.0200000000000000004
60656	LDA2	247.099999999999994	0.00300000000000000006
60656	M1	36.1000000000000014	0.0330000000000000016
60656	J1	33.2999999999999972	0.0359999999999999973
60656	RHO1	38.6000000000000014	0.0160000000000000003
60656	Q1	38.7999999999999972	0.0850000000000000061
60656	T2	253.5	0.0100000000000000002
60656	2Q1	40.2000000000000028	0.0129999999999999994
60656	P1	34.8999999999999986	0.194000000000000006
60656	L2	245.199999999999989	0.0160000000000000003
60656	K2	255.099999999999994	0.0519999999999999976
60656	M8	274.800000000000011	0.00300000000000000006
60657	M2	242.800000000000011	0.400000000000000022
60657	S2	274.600000000000023	0.147999999999999993
60657	N2	247.300000000000011	0.0820000000000000034
60657	K1	42.7999999999999972	0.489999999999999991
60657	M4	63.2999999999999972	0.0200000000000000004
60657	O1	36.8999999999999986	0.440000000000000002
60657	S4	203.699999999999989	0.0100000000000000002
60657	NU2	247.099999999999994	0.0200000000000000004
60657	MU2	210.900000000000006	0.0100000000000000002
60657	2N2	250.300000000000011	0.0100000000000000002
60657	OO1	48.8999999999999986	0.0200000000000000004
60657	M1	40	0.0299999999999999989
60657	J1	45.8999999999999986	0.0400000000000000008
60657	RHO1	34.5	0.0200000000000000004
60657	Q1	34	0.0899999999999999967
60657	T2	273.5	0.0100000000000000002
60657	2Q1	30.5	0.0100000000000000002
60657	P1	42.3999999999999986	0.160000000000000003
60657	L2	233.900000000000006	0.0100000000000000002
60657	K2	277.100000000000023	0.0400000000000000008
60658	M2	232.699999999999989	0.315000000000000002
60658	S2	251.400000000000006	0.0850000000000000061
60658	N2	201	0.0490000000000000019
60658	K1	37.2999999999999972	0.446000000000000008
60658	M4	77.7999999999999972	0.0200000000000000004
60658	O1	31.3999999999999986	0.419999999999999984
60658	M6	177.900000000000006	0.00300000000000000006
60658	S4	151.199999999999989	0.00700000000000000015
60658	NU2	202	0.0100000000000000002
60658	S6	123.700000000000003	0.00300000000000000006
60658	MU2	214.400000000000006	0.00700000000000000015
60658	2N2	180.800000000000011	0.00300000000000000006
60658	OO1	44	0.0200000000000000004
60658	LDA2	241.300000000000011	0.00300000000000000006
60658	M1	34.6000000000000014	0.0299999999999999989
60658	J1	40.7000000000000028	0.0330000000000000016
60658	SSA	28.6999999999999993	0.117999999999999994
60658	SA	145.099999999999994	0.245999999999999996
60658	RHO1	28.8999999999999986	0.0160000000000000003
60658	Q1	28.3999999999999986	0.0790000000000000008
60658	T2	250.699999999999989	0.00700000000000000015
60658	2Q1	25.5	0.0100000000000000002
60658	P1	36.8999999999999986	0.147999999999999993
60658	L2	265.100000000000023	0.00700000000000000015
60658	K2	252.800000000000011	0.0229999999999999996
60658	M8	159.400000000000006	0.00300000000000000006
60659	M2	256.899999999999977	0.406999999999999973
60659	S2	285	0.131000000000000005
60659	N2	245.099999999999994	0.0719999999999999946
60659	K1	52.7999999999999972	0.443000000000000005
60659	M4	75	0.0200000000000000004
60659	O1	45.7000000000000028	0.39700000000000002
60659	M6	250.300000000000011	0.00300000000000000006
60659	MK3	254.900000000000006	0.0259999999999999988
60659	S4	190.800000000000011	0.00700000000000000015
60659	MN4	43.8999999999999986	0.00700000000000000015
60659	NU2	262	0.0200000000000000004
60659	S6	271.699999999999989	0.00300000000000000006
60659	MU2	58.2999999999999972	0.0200000000000000004
60659	2N2	258.600000000000023	0.00700000000000000015
60659	OO1	101.900000000000006	0.0200000000000000004
60659	LDA2	293.600000000000023	0.0100000000000000002
60659	S1	85.5	0.0259999999999999988
60659	M1	125.400000000000006	0.0129999999999999994
60659	J1	81.0999999999999943	0.0200000000000000004
60659	SSA	45.5	0.161000000000000004
60659	SA	145.5	0.357999999999999985
60659	MSF	32.6000000000000014	0.0560000000000000012
60659	RHO1	16.8000000000000007	0.0200000000000000004
60659	Q1	30.6999999999999993	0.0889999999999999958
60659	T2	305.100000000000023	0.0100000000000000002
60659	R2	246.699999999999989	0.00700000000000000015
60659	2Q1	344.699999999999989	0.00700000000000000015
60659	P1	55.6000000000000014	0.135000000000000009
60659	2SM2	148.5	0.00700000000000000015
60659	M3	322.300000000000011	0.00700000000000000015
60659	L2	263.100000000000023	0.0229999999999999996
60659	2MK3	249.199999999999989	0.0229999999999999996
60659	K2	258	0.0519999999999999976
60659	MS4	94.5999999999999943	0.00700000000000000015
60660	M2	273.699999999999989	0.422999999999999987
60660	S2	298.899999999999977	0.138000000000000012
60660	N2	270.600000000000023	0.0660000000000000031
60660	K1	59.5	0.48899999999999999
60660	M4	120.700000000000003	0.0200000000000000004
60660	O1	51.7000000000000028	0.422999999999999987
60660	S4	207.300000000000011	0.00700000000000000015
60660	NU2	271.699999999999989	0.0129999999999999994
60660	S6	80.7000000000000028	0.00300000000000000006
60660	MU2	248.400000000000006	0.0100000000000000002
60660	2N2	262.5	0.00700000000000000015
60660	OO1	66.4000000000000057	0.0160000000000000003
60660	LDA2	286.100000000000023	0.00300000000000000006
60660	M1	55.2999999999999972	0.0299999999999999989
60660	J1	62.2999999999999972	0.0330000000000000016
60660	SSA	28.6999999999999993	0.117999999999999994
60660	SA	145.099999999999994	0.245999999999999996
60660	RHO1	48.8999999999999986	0.0160000000000000003
60660	Q1	48.1000000000000014	0.0820000000000000034
60660	T2	297.699999999999989	0.00700000000000000015
60660	2Q1	44	0.0100000000000000002
60660	P1	59	0.164000000000000007
60660	L2	283.5	0.0100000000000000002
60660	K2	300.699999999999989	0.0359999999999999973
60661	M2	273	0.281999999999999973
60661	S2	290.800000000000011	0.0820000000000000034
60661	N2	272.800000000000011	0.0459999999999999992
60661	K1	65.5	0.373999999999999999
60661	M4	112.599999999999994	0.0129999999999999994
60661	O1	55.7999999999999972	0.328000000000000014
60661	MK3	290.100000000000023	0.0259999999999999988
60661	S4	232.400000000000006	0.00300000000000000006
60661	MN4	75.5	0.00700000000000000015
60661	NU2	276.600000000000023	0.0129999999999999994
60661	MU2	61.2000000000000028	0.0200000000000000004
60661	2N2	342.899999999999977	0.0129999999999999994
60661	OO1	82	0.0200000000000000004
60661	LDA2	308.899999999999977	0.0200000000000000004
60661	S1	46.6000000000000014	0.0229999999999999996
60661	M1	143.5	0.0160000000000000003
60661	J1	79.2999999999999972	0.0160000000000000003
60661	SSA	28.6999999999999993	0.117999999999999994
60661	SA	145.099999999999994	0.245999999999999996
60661	RHO1	21.1000000000000014	0.0129999999999999994
60661	Q1	53.5	0.0790000000000000008
60661	T2	24	0.00700000000000000015
60661	R2	359.199999999999989	0.0100000000000000002
60661	2Q1	5	0.0129999999999999994
60661	P1	80.4000000000000057	0.125
60661	2SM2	151.800000000000011	0.00700000000000000015
60661	M3	346.5	0.00700000000000000015
60661	L2	285	0.0200000000000000004
60661	2MK3	271.199999999999989	0.0229999999999999996
60661	K2	267.399999999999977	0.0490000000000000019
60661	MS4	135.699999999999989	0.00700000000000000015
60662	M2	313.199999999999989	0.233000000000000013
60662	S2	340.300000000000011	0.0719999999999999946
60662	N2	301.800000000000011	0.0429999999999999966
60662	K1	85.9000000000000057	0.370999999999999996
60662	M4	177.400000000000006	0.0160000000000000003
60662	O1	76.2000000000000028	0.318000000000000005
60662	M6	46.7000000000000028	0.00300000000000000006
60662	NU2	305.100000000000023	0.0100000000000000002
60662	MU2	287.699999999999989	0.00700000000000000015
60662	2N2	289.600000000000023	0.00700000000000000015
60662	OO1	95.5	0.0129999999999999994
60662	M1	81	0.0229999999999999996
60662	J1	90.4000000000000057	0.0259999999999999988
60662	SSA	28.6999999999999993	0.117999999999999994
60662	SA	145.099999999999994	0.245999999999999996
60662	RHO1	72.2000000000000028	0.0129999999999999994
60662	Q1	71.5	0.0619999999999999996
60662	T2	339	0.00300000000000000006
60662	2Q1	67	0.0100000000000000002
60662	P1	85.2000000000000028	0.120999999999999996
60662	L2	325.300000000000011	0.00700000000000000015
60662	K2	342.5	0.0200000000000000004
60663	M2	303.199999999999989	0.312
60663	S2	341.699999999999989	0.101999999999999993
60663	N2	286.699999999999989	0.0619999999999999996
60663	K1	63.1000000000000014	0.440000000000000002
60663	M4	236.900000000000006	0.0100000000000000002
60663	O1	56.8999999999999986	0.426999999999999991
60663	M6	349.199999999999989	0.00700000000000000015
60663	S4	48.3999999999999986	0.00700000000000000015
60663	NU2	288.5	0.0129999999999999994
60663	S6	345.699999999999989	0.00700000000000000015
60663	MU2	264.899999999999977	0.00700000000000000015
60663	2N2	273.899999999999977	0.00700000000000000015
60663	OO1	70.2999999999999972	0.0200000000000000004
60663	LDA2	321.600000000000023	0.00300000000000000006
60663	M1	60.2999999999999972	0.0299999999999999989
60663	J1	67	0.0330000000000000016
60663	SSA	28.6999999999999993	0.117999999999999994
60663	SA	145.099999999999994	0.245999999999999996
60663	RHO1	54	0.0160000000000000003
60663	Q1	53.5	0.0820000000000000034
60663	T2	341.199999999999989	0.00700000000000000015
60663	2Q1	50.2000000000000028	0.0100000000000000002
60663	P1	62.6000000000000014	0.147999999999999993
60663	L2	320.199999999999989	0.0100000000000000002
60663	K2	344.899999999999977	0.0259999999999999988
60663	M8	0.800000000000000044	0.00300000000000000006
60664	M2	21.6000000000000014	0.0389999999999999999
60664	S2	59.6000000000000014	0.0160000000000000003
60664	N2	340.199999999999989	0.00300000000000000006
60664	K1	58.2999999999999972	0.315000000000000002
60664	M4	346.699999999999989	0.0299999999999999989
60664	O1	48.6000000000000014	0.291999999999999982
60664	M6	292.300000000000011	0.00300000000000000006
60664	MK3	51.1000000000000014	0.0100000000000000002
60664	S4	116.599999999999994	0.0129999999999999994
60664	MN4	307.399999999999977	0.0129999999999999994
60664	NU2	358.899999999999977	0.00300000000000000006
60664	S6	247.300000000000011	0.00300000000000000006
60664	MU2	135.800000000000011	0.0100000000000000002
60664	2N2	124.400000000000006	0.00700000000000000015
60664	OO1	43.6000000000000014	0.0200000000000000004
60664	LDA2	17.6000000000000014	0.00300000000000000006
60664	S1	118.200000000000003	0.0100000000000000002
60664	M1	36.2999999999999972	0.0100000000000000002
60664	J1	95.2999999999999972	0.0129999999999999994
60664	SSA	28.6999999999999993	0.117999999999999994
60664	SA	145.099999999999994	0.245999999999999996
60664	RHO1	36.2999999999999972	0.0129999999999999994
60664	Q1	40.3999999999999986	0.0560000000000000012
60664	T2	142.800000000000011	0.00300000000000000006
60664	R2	71.4000000000000057	0.00700000000000000015
60664	2Q1	324.600000000000023	0.00700000000000000015
60664	P1	58.5	0.0980000000000000038
60664	2SM2	256	0.00300000000000000006
60664	M3	317.300000000000011	0.00300000000000000006
60664	L2	14.5	0.00700000000000000015
60664	2MK3	41.8999999999999986	0.0100000000000000002
60664	M8	54.8999999999999986	0.00300000000000000006
60664	MS4	3.79999999999999982	0.0129999999999999994
60665	M2	128.900000000000006	0.128000000000000003
60665	S2	132.699999999999989	0.0589999999999999969
60665	N2	142.900000000000006	0.0259999999999999988
60665	K1	33.5	0.48899999999999999
60665	M4	30.5	0.0820000000000000034
60665	O1	23.1999999999999993	0.463000000000000023
60665	M6	316.399999999999977	0.0259999999999999988
60665	S4	158.099999999999994	0.0299999999999999989
60665	MN4	348.600000000000023	0.0429999999999999966
60665	NU2	138.599999999999994	0.00700000000000000015
60665	S6	284	0.00700000000000000015
60665	MU2	115.299999999999997	0.00700000000000000015
60665	2N2	117.099999999999994	0.00700000000000000015
60665	OO1	56.1000000000000014	0.0259999999999999988
60665	LDA2	240.800000000000011	0.00300000000000000006
60665	S1	143.5	0.0259999999999999988
60665	M1	50.5	0.0299999999999999989
60665	J1	22.6999999999999993	0.0359999999999999973
60665	SSA	39.7999999999999972	0.150999999999999995
60665	SA	152	0.370999999999999996
60665	RHO1	2.39999999999999991	0.0229999999999999996
60665	Q1	13.0999999999999996	0.0919999999999999984
60665	T2	139.199999999999989	0.00700000000000000015
60665	R2	1.30000000000000004	0.00300000000000000006
60665	2Q1	18.3000000000000007	0.00700000000000000015
60665	P1	33.1000000000000014	0.153999999999999998
60665	2SM2	200.400000000000006	0.00300000000000000006
60665	M3	215.800000000000011	0.00300000000000000006
60665	L2	351.100000000000023	0.00300000000000000006
60665	K2	110.900000000000006	0.0160000000000000003
60665	MS4	48.3999999999999986	0.0490000000000000019
60666	M2	130.699999999999989	0.120999999999999996
60666	S2	125.900000000000006	0.0619999999999999996
60666	N2	140.699999999999989	0.0259999999999999988
60666	K1	33.7000000000000028	0.481999999999999984
60666	M4	33.7999999999999972	0.0980000000000000038
60666	O1	21.8999999999999986	0.456000000000000016
60666	M6	317.5	0.0459999999999999992
60666	S4	155.300000000000011	0.0200000000000000004
60666	NU2	141.5	0.00700000000000000015
60666	S6	340.199999999999989	0.0160000000000000003
60666	MU2	135.5	0.00300000000000000006
60666	2N2	148.099999999999994	0.00300000000000000006
60666	OO1	45.5	0.0200000000000000004
60666	M1	27.8999999999999986	0.0330000000000000016
60666	J1	39.5	0.0359999999999999973
60666	RHO1	16.8999999999999986	0.0160000000000000003
60666	Q1	16.1000000000000014	0.0889999999999999958
60666	T2	126	0.00300000000000000006
60666	2Q1	10.1999999999999993	0.0129999999999999994
60666	P1	32.8999999999999986	0.161000000000000004
60666	L2	122.299999999999997	0.00300000000000000006
60666	K2	125.5	0.0160000000000000003
60666	M8	198.099999999999994	0.00300000000000000006
60667	M2	167.599999999999994	0.107999999999999999
60667	S2	195.099999999999994	0.0429999999999999966
60667	N2	232.699999999999989	0.0129999999999999994
60667	K1	60.6000000000000014	0.509000000000000008
60667	M4	121.299999999999997	0.0200000000000000004
60667	O1	41.1000000000000014	0.456000000000000016
60667	M6	12.4000000000000004	0.0200000000000000004
60667	S4	247.5	0.00700000000000000015
60667	NU2	223.900000000000006	0.00300000000000000006
60667	S6	6.90000000000000036	0.00300000000000000006
60667	MU2	140	0.00300000000000000006
60667	2N2	297.699999999999989	0.00300000000000000006
60667	OO1	80.0999999999999943	0.0200000000000000004
60667	M1	50.8999999999999986	0.0330000000000000016
60667	J1	70.2999999999999972	0.0359999999999999973
60667	SSA	45.2999999999999972	0.153999999999999998
60667	SA	149.300000000000011	0.373999999999999999
60667	RHO1	32.7000000000000028	0.0160000000000000003
60667	Q1	31.3999999999999986	0.0889999999999999958
60667	T2	194	0.00300000000000000006
60667	2Q1	21.8000000000000007	0.0129999999999999994
60667	P1	59.2000000000000028	0.16700000000000001
60667	L2	102.5	0.00300000000000000006
60667	K2	197.400000000000006	0.0100000000000000002
60667	M8	99.7999999999999972	0.00300000000000000006
60668	M2	96.4000000000000057	0.112000000000000002
60668	S2	98.4000000000000057	0.0560000000000000012
60668	N2	102.200000000000003	0.0259999999999999988
60668	K1	17.6000000000000014	0.459000000000000019
60668	M4	324.100000000000023	0.0690000000000000058
60668	O1	6.59999999999999964	0.44900000000000001
60668	M6	209.300000000000011	0.0200000000000000004
60668	S4	105.5	0.0100000000000000002
60668	NU2	102	0.00300000000000000006
60668	S6	225.300000000000011	0.00700000000000000015
60668	MU2	93.7000000000000028	0.00300000000000000006
60668	2N2	104.799999999999997	0.00300000000000000006
60668	OO1	28.6000000000000014	0.0200000000000000004
60668	M1	12.0999999999999996	0.0330000000000000016
60668	J1	23	0.0359999999999999973
60668	SSA	39.7999999999999972	0.150999999999999995
60668	SA	152	0.370999999999999996
60668	RHO1	1.89999999999999991	0.0160000000000000003
60668	Q1	1.19999999999999996	0.0850000000000000061
60668	T2	98.5	0.00300000000000000006
60668	2Q1	355.800000000000011	0.0100000000000000002
60668	P1	16.8000000000000007	0.150999999999999995
60668	L2	91.9000000000000057	0.00300000000000000006
60668	K2	98.4000000000000057	0.0129999999999999994
60668	M8	240.400000000000006	0.00300000000000000006
60669	M2	136.099999999999994	0.0950000000000000011
60669	S2	149.599999999999994	0.0389999999999999999
60669	N2	156.300000000000011	0.0200000000000000004
60669	K1	34.7999999999999972	0.466000000000000025
60669	M4	346	0.0100000000000000002
60669	O1	25.6000000000000014	0.446000000000000008
60669	M6	95.2999999999999972	0.00700000000000000015
60669	MK3	84.7000000000000028	0.00700000000000000015
60669	S4	67.7999999999999972	0.00300000000000000006
60669	MN4	299.800000000000011	0.00300000000000000006
60669	NU2	159.099999999999994	0.00300000000000000006
60669	MU2	180.5	0.00300000000000000006
60669	2N2	139.900000000000006	0.00300000000000000006
60669	OO1	22.6000000000000014	0.0229999999999999996
60669	LDA2	100.200000000000003	0.00300000000000000006
60669	S1	164.699999999999989	0.0200000000000000004
60669	M1	67.5999999999999943	0.0200000000000000004
60669	J1	51.3999999999999986	0.0259999999999999988
60669	SSA	45.2999999999999972	0.153999999999999998
60669	SA	149.300000000000011	0.373999999999999999
60669	RHO1	15.8000000000000007	0.0229999999999999996
60669	Q1	12	0.0950000000000000011
60669	T2	93.5	0.00300000000000000006
60669	R2	203.099999999999994	0.00300000000000000006
60669	2Q1	346.300000000000011	0.0129999999999999994
60669	P1	37.7999999999999972	0.147999999999999993
60669	2SM2	331.100000000000023	0.00300000000000000006
60669	M3	266.300000000000011	0.00300000000000000006
60669	L2	116.5	0.00700000000000000015
60669	2MK3	69	0.00700000000000000015
60669	K2	118.599999999999994	0.0259999999999999988
60669	MS4	355.699999999999989	0.00300000000000000006
60670	M2	91	0.112000000000000002
60670	S2	92.9000000000000057	0.0519999999999999976
60670	N2	104.5	0.0229999999999999996
60670	K1	17.1000000000000014	0.468999999999999972
60670	M4	314.100000000000023	0.0330000000000000016
60670	O1	9	0.459000000000000019
60670	M6	71.7000000000000028	0.0129999999999999994
60670	S4	84.7999999999999972	0.0100000000000000002
60670	MN4	281.399999999999977	0.0160000000000000003
60670	NU2	118.799999999999997	0.00300000000000000006
60670	S6	169.699999999999989	0.00300000000000000006
60670	MU2	84.0999999999999943	0.00700000000000000015
60670	2N2	122.200000000000003	0.00300000000000000006
60670	OO1	37.2000000000000028	0.0200000000000000004
60670	S1	102.099999999999994	0.0259999999999999988
60670	M1	39.2999999999999972	0.0129999999999999994
60670	J1	22.1000000000000014	0.0259999999999999988
60670	SSA	68.9000000000000057	0.161000000000000004
60670	SA	160.699999999999989	0.33500000000000002
60670	MSF	25.8999999999999986	0.0330000000000000016
60670	RHO1	351.800000000000011	0.0229999999999999996
60670	Q1	354.399999999999977	0.104999999999999996
60670	T2	109.099999999999994	0.00300000000000000006
60670	R2	346.899999999999977	0.00300000000000000006
60670	2Q1	334.899999999999977	0.0100000000000000002
60670	P1	16.8000000000000007	0.150999999999999995
60670	2SM2	175.699999999999989	0.00300000000000000006
60670	M3	170.400000000000006	0.00300000000000000006
60670	L2	39.2999999999999972	0.00300000000000000006
60670	2MK3	275.199999999999989	0.00300000000000000006
60670	K2	77.9000000000000057	0.0160000000000000003
60670	MS4	327.100000000000023	0.0160000000000000003
60671	M2	170.099999999999994	0.0160000000000000003
60671	S2	157	0.00700000000000000015
60671	N2	176.199999999999989	0.00300000000000000006
60671	K1	106.099999999999994	0.147999999999999993
60671	O1	95.9000000000000057	0.153999999999999998
60671	M6	117.900000000000006	0.00300000000000000006
60671	MK3	258.699999999999989	0.00300000000000000006
60671	S4	126.799999999999997	0.00300000000000000006
60671	2N2	192	0.00300000000000000006
60671	OO1	105.400000000000006	0.0160000000000000003
60671	LDA2	260.5	0.00300000000000000006
60671	S1	126	0.00700000000000000015
60671	M1	118.200000000000003	0.00700000000000000015
60671	J1	172.199999999999989	0.00300000000000000006
60671	SSA	43.2000000000000028	0.157000000000000001
60671	SA	148.300000000000011	0.284999999999999976
60671	RHO1	77.4000000000000057	0.00300000000000000006
60671	Q1	91.4000000000000057	0.0259999999999999988
60671	2Q1	15.8000000000000007	0.0129999999999999994
60671	P1	112.5	0.0429999999999999966
60671	M3	171	0.00300000000000000006
60671	L2	258.199999999999989	0.00300000000000000006
60671	2MK3	268.5	0.00300000000000000006
60671	K2	223.099999999999994	0.00300000000000000006
60672	M2	90.2999999999999972	0.104999999999999996
60672	S2	97.2999999999999972	0.0519999999999999976
60672	N2	105.599999999999994	0.0200000000000000004
60672	K1	19.1000000000000014	0.466000000000000025
60672	M4	318.100000000000023	0.0259999999999999988
60672	O1	10.6999999999999993	0.44900000000000001
60672	MN4	282.199999999999989	0.0129999999999999994
60672	NU2	103.5	0.00300000000000000006
60672	2N2	120.900000000000006	0.00300000000000000006
60672	OO1	27.5	0.0200000000000000004
60672	S1	92.2999999999999972	0.0100000000000000002
60672	M1	14.9000000000000004	0.0330000000000000016
60672	J1	23.5	0.0299999999999999989
60672	MM	321.5	0.0589999999999999969
60672	SSA	70.0999999999999943	0.164000000000000007
60672	SA	160.099999999999994	0.312
60672	MSF	218	0.0490000000000000019
60672	MF	13.6999999999999993	0.0359999999999999973
60672	RHO1	7.09999999999999964	0.0160000000000000003
60672	Q1	357.800000000000011	0.0980000000000000038
60672	T2	97.2999999999999972	0.00300000000000000006
60672	2Q1	2.29999999999999982	0.0129999999999999994
60672	P1	20	0.147999999999999993
60672	L2	75	0.00300000000000000006
60672	K2	97.2000000000000028	0.0129999999999999994
60672	MS4	329	0.0129999999999999994
60673	M2	179.5	0.115000000000000005
60673	S2	214.199999999999989	0.0259999999999999988
60673	N2	211.300000000000011	0.0160000000000000003
60673	K1	54.2999999999999972	0.502000000000000002
60673	M4	94.0999999999999943	0.0100000000000000002
60673	O1	43.8999999999999986	0.481999999999999984
60673	M6	337.5	0.00300000000000000006
60673	MK3	194.5	0.0160000000000000003
60673	S4	325.800000000000011	0.00300000000000000006
60673	MN4	76.7999999999999972	0.0100000000000000002
60673	NU2	163.800000000000011	0.00700000000000000015
60673	MU2	259.699999999999989	0.00300000000000000006
60673	2N2	186.300000000000011	0.0299999999999999989
60673	OO1	50.6000000000000014	0.0389999999999999999
60673	LDA2	156	0.00700000000000000015
60673	S1	156.199999999999989	0.0389999999999999999
60673	M1	59.6000000000000014	0.0299999999999999989
60673	J1	56.3999999999999986	0.0200000000000000004
60673	SSA	43.2000000000000028	0.157000000000000001
60673	SA	148.300000000000011	0.284999999999999976
60673	RHO1	4.70000000000000018	0.0229999999999999996
60673	Q1	32.8999999999999986	0.0980000000000000038
60673	T2	72.5999999999999943	0.00300000000000000006
60673	R2	222.699999999999989	0.0229999999999999996
60673	2Q1	2.89999999999999991	0.0359999999999999973
60673	P1	57	0.138000000000000012
60673	2SM2	348.399999999999977	0.00300000000000000006
60673	M3	81.7999999999999972	0.00700000000000000015
60673	L2	194.099999999999994	0.0100000000000000002
60673	2MK3	215.199999999999989	0.0100000000000000002
60673	K2	206.699999999999989	0.0459999999999999992
60673	M8	137.900000000000006	0.00300000000000000006
60673	MS4	101.700000000000003	0.0100000000000000002
60674	M2	187.900000000000006	0.0660000000000000031
60674	S2	208.800000000000011	0.0259999999999999988
60674	N2	173	0.0100000000000000002
60674	K1	68.0999999999999943	0.466000000000000025
60674	M4	50.7000000000000028	0.00700000000000000015
60674	O1	54.2999999999999972	0.409999999999999976
60674	M6	209.199999999999989	0.00300000000000000006
60674	S4	184.099999999999994	0.00300000000000000006
60674	OO1	81.2999999999999972	0.0160000000000000003
60674	M1	61.2000000000000028	0.0299999999999999989
60674	J1	74.7999999999999972	0.0330000000000000016
60674	SSA	43.2000000000000028	0.157000000000000001
60674	SA	148.300000000000011	0.284999999999999976
60674	RHO1	48.5	0.0160000000000000003
60674	Q1	47.5	0.0790000000000000008
60674	T2	192.599999999999994	0.00300000000000000006
60674	2Q1	40.8999999999999986	0.0100000000000000002
60674	P1	67	0.153999999999999998
60674	K2	211.199999999999989	0.00700000000000000015
60675	M2	218.199999999999989	0.115000000000000005
60675	S2	249.300000000000011	0.0820000000000000034
60675	N2	224.599999999999994	0.0429999999999999966
60675	K1	84.7999999999999972	0.387000000000000011
60675	M4	203	0.0160000000000000003
60675	O1	63.3999999999999986	0.416999999999999982
60675	M6	103.599999999999994	0.00700000000000000015
60675	S4	299.399999999999977	0.00300000000000000006
60675	NU2	224	0.00700000000000000015
60675	S6	199	0.00300000000000000006
60675	MU2	187.5	0.00300000000000000006
60675	2N2	230.199999999999989	0.00700000000000000015
60675	OO1	105.200000000000003	0.0160000000000000003
60675	M1	74	0.0299999999999999989
60675	J1	95.0999999999999943	0.0330000000000000016
60675	SSA	43.2000000000000028	0.157000000000000001
60675	SA	148.300000000000011	0.284999999999999976
60675	RHO1	54	0.0160000000000000003
60675	Q1	53	0.0790000000000000008
60675	T2	248.099999999999994	0.00700000000000000015
60675	2Q1	42	0.0100000000000000002
60675	P1	83.2000000000000028	0.128000000000000003
60675	L2	212.5	0.00300000000000000006
60675	K2	251.800000000000011	0.0229999999999999996
60675	M8	332.100000000000023	0.00300000000000000006
60676	M2	188	0.125
60676	S2	226.099999999999994	0.0619999999999999996
60676	N2	221.900000000000006	0.0129999999999999994
60676	K1	61.2000000000000028	0.528000000000000025
60676	M4	127.900000000000006	0.0200000000000000004
60676	O1	48.2999999999999972	0.494999999999999996
60676	M6	55.1000000000000014	0.00300000000000000006
60676	MK3	228.300000000000011	0.0200000000000000004
60676	S4	329.600000000000023	0.00700000000000000015
60676	MN4	98.2000000000000028	0.0160000000000000003
60676	NU2	192.599999999999994	0.0100000000000000002
60676	S6	3.29999999999999982	0.00300000000000000006
60676	MU2	282.100000000000023	0.00300000000000000006
60676	2N2	179	0.0330000000000000016
60676	OO1	52.5	0.0429999999999999966
60676	LDA2	116.099999999999994	0.00700000000000000015
60676	S1	163.800000000000011	0.0490000000000000019
60676	M1	72.5	0.0330000000000000016
60676	J1	62.5	0.0229999999999999996
60676	SSA	43.2000000000000028	0.157000000000000001
60676	SA	148.300000000000011	0.284999999999999976
60676	RHO1	7.20000000000000018	0.0200000000000000004
60676	Q1	34.3999999999999986	0.101999999999999993
60676	T2	178	0.00700000000000000015
60676	R2	259	0.00700000000000000015
60676	2Q1	18.5	0.0200000000000000004
60676	P1	67	0.157000000000000001
60676	2SM2	316.399999999999977	0.00700000000000000015
60676	M3	119.299999999999997	0.00300000000000000006
60676	L2	164.599999999999994	0.0100000000000000002
60676	2MK3	227.300000000000011	0.0160000000000000003
60676	K2	202.300000000000011	0.0459999999999999992
60676	MS4	143.5	0.0129999999999999994
60677	M2	196.199999999999989	0.131000000000000005
60677	S2	234.900000000000006	0.0690000000000000058
60677	N2	228.800000000000011	0.0160000000000000003
60677	K1	64.7999999999999972	0.538000000000000034
60677	M4	146.400000000000006	0.0259999999999999988
60677	O1	51.6000000000000014	0.498999999999999999
60677	M6	90.4000000000000057	0.00700000000000000015
60677	MK3	231	0.0229999999999999996
60677	S4	347.300000000000011	0.00700000000000000015
60677	MN4	115.799999999999997	0.0200000000000000004
60677	NU2	211.5	0.0100000000000000002
60677	S6	46.1000000000000014	0.00300000000000000006
60677	MU2	285	0.00300000000000000006
60677	2N2	184.800000000000011	0.0330000000000000016
60677	OO1	53.2000000000000028	0.0429999999999999966
60677	LDA2	128	0.00700000000000000015
60677	S1	167.900000000000006	0.0519999999999999976
60677	M1	77.9000000000000057	0.0330000000000000016
60677	J1	67.2000000000000028	0.0259999999999999988
60677	SSA	43.2000000000000028	0.157000000000000001
60677	SA	148.300000000000011	0.284999999999999976
60677	RHO1	21.8999999999999986	0.0200000000000000004
60677	Q1	36.8999999999999986	0.0980000000000000038
60677	T2	173.699999999999989	0.00700000000000000015
60677	R2	262.5	0.00700000000000000015
60677	2Q1	27.3000000000000007	0.0200000000000000004
60677	P1	71	0.161000000000000004
60677	2SM2	337.300000000000011	0.00300000000000000006
60677	M3	130.599999999999994	0.00700000000000000015
60677	L2	160.300000000000011	0.0100000000000000002
60677	2MK3	228.800000000000011	0.0200000000000000004
60677	K2	207.400000000000006	0.0459999999999999992
60677	M8	309.899999999999977	0.00300000000000000006
60677	MS4	162.900000000000006	0.0160000000000000003
60678	M2	193.699999999999989	0.0749999999999999972
60678	S2	281.800000000000011	0.0160000000000000003
60678	N2	223	0.0129999999999999994
60678	K1	65.4000000000000057	0.422999999999999987
60678	M4	78.4000000000000057	0.00700000000000000015
60678	O1	55.6000000000000014	0.459000000000000019
60678	M6	243.199999999999989	0.00300000000000000006
60678	S4	226.400000000000006	0.00300000000000000006
60678	NU2	213.400000000000006	0.00300000000000000006
60678	S6	81.7999999999999972	0.00300000000000000006
60678	MU2	94.7000000000000028	0.00300000000000000006
60678	2N2	286.899999999999977	0.00300000000000000006
60678	OO1	75.2999999999999972	0.0200000000000000004
60678	M1	60.5	0.0330000000000000016
60678	J1	70.2999999999999972	0.0359999999999999973
60678	SSA	43.2000000000000028	0.157000000000000001
60678	SA	148.300000000000011	0.284999999999999976
60678	RHO1	51.3999999999999986	0.0160000000000000003
60678	Q1	50.7000000000000028	0.0889999999999999958
60678	2Q1	45.7999999999999972	0.0129999999999999994
60678	P1	64.7000000000000028	0.140999999999999986
60678	L2	171	0.00300000000000000006
60678	K2	286	0.00300000000000000006
60678	M8	176.400000000000006	0.00300000000000000006
60679	M2	186.199999999999989	0.0519999999999999976
60679	S2	113	0.0330000000000000016
60679	N2	196.5	0.0129999999999999994
60679	K1	64.7999999999999972	0.390000000000000013
60679	M4	353.199999999999989	0.00700000000000000015
60679	O1	53.7000000000000028	0.387000000000000011
60679	M6	223.599999999999994	0.00300000000000000006
60679	S4	162.400000000000006	0.00300000000000000006
60679	NU2	191.300000000000011	0.00300000000000000006
60679	S6	37.2999999999999972	0.00300000000000000006
60679	OO1	75.9000000000000057	0.0160000000000000003
60679	M1	59.2999999999999972	0.0259999999999999988
60679	J1	70.2999999999999972	0.0299999999999999989
60679	SSA	43.2000000000000028	0.157000000000000001
60679	SA	148.300000000000011	0.284999999999999976
60679	RHO1	48.7000000000000028	0.0129999999999999994
60679	Q1	48.2000000000000028	0.0749999999999999972
60679	T2	112.5	0.00300000000000000006
60679	2Q1	42.7000000000000028	0.0100000000000000002
60679	P1	64	0.128000000000000003
60679	K2	107.400000000000006	0.0100000000000000002
60679	M8	6.29999999999999982	0.00300000000000000006
60680	M2	178.599999999999994	0.0980000000000000038
60680	S2	203.5	0.0389999999999999999
60680	N2	200.900000000000006	0.0129999999999999994
60680	K1	56.7000000000000028	0.48899999999999999
60680	M4	52.3999999999999986	0.0100000000000000002
60680	O1	45.3999999999999986	0.463000000000000023
60680	M6	222.400000000000006	0.00300000000000000006
60680	MK3	206.699999999999989	0.0100000000000000002
60680	S4	204.699999999999989	0.00300000000000000006
60680	MN4	13.4000000000000004	0.00700000000000000015
60680	NU2	190.800000000000011	0.00700000000000000015
60680	MU2	262.699999999999989	0.00300000000000000006
60680	2N2	175.400000000000006	0.0229999999999999996
60680	OO1	48.8999999999999986	0.0389999999999999999
60680	LDA2	153	0.00300000000000000006
60680	S1	161.599999999999994	0.0299999999999999989
60680	M1	70.9000000000000057	0.0299999999999999989
60680	J1	63.3999999999999986	0.0229999999999999996
60680	SSA	43.2000000000000028	0.157000000000000001
60680	SA	148.300000000000011	0.284999999999999976
60680	RHO1	21.6999999999999993	0.0160000000000000003
60680	Q1	31.5	0.0980000000000000038
60680	T2	171.900000000000006	0.00300000000000000006
60680	R2	281.899999999999977	0.00300000000000000006
60680	2Q1	18.5	0.0229999999999999996
60680	P1	60.5	0.140999999999999986
60680	2SM2	342.100000000000023	0.00300000000000000006
60680	M3	111	0.00300000000000000006
60680	L2	152.300000000000011	0.00700000000000000015
60680	2MK3	199	0.0100000000000000002
60680	K2	191.5	0.0330000000000000016
60680	MS4	49	0.00300000000000000006
60681	M2	185.400000000000006	0.0980000000000000038
60681	S2	203.5	0.0519999999999999976
60681	N2	201.699999999999989	0.0200000000000000004
60681	K1	65.4000000000000057	0.52200000000000002
60681	M4	31.6000000000000014	0.0100000000000000002
60681	O1	51.1000000000000014	0.475999999999999979
60681	M6	243.099999999999994	0.00700000000000000015
60681	S4	176.800000000000011	0.00300000000000000006
60681	NU2	200.599999999999994	0.00300000000000000006
60681	S6	255.099999999999994	0.00300000000000000006
60681	MU2	167	0.00300000000000000006
60681	2N2	220.599999999999994	0.00300000000000000006
60681	OO1	79.5999999999999943	0.0200000000000000004
60681	M1	58.2999999999999972	0.0330000000000000016
60681	J1	72.2999999999999972	0.0359999999999999973
60681	SSA	43.2000000000000028	0.157000000000000001
60681	SA	148.300000000000011	0.284999999999999976
60681	RHO1	45.2000000000000028	0.0160000000000000003
60681	Q1	44	0.0919999999999999984
60681	T2	203	0.00300000000000000006
60681	2Q1	36.8999999999999986	0.0129999999999999994
60681	P1	64.2999999999999972	0.173999999999999988
60681	L2	167.900000000000006	0.00300000000000000006
60681	K2	203.900000000000006	0.0129999999999999994
60681	M8	279.5	0.00300000000000000006
60682	M2	170.300000000000011	0.0820000000000000034
60682	S2	163.699999999999989	0.0299999999999999989
60682	N2	184.099999999999994	0.0160000000000000003
60682	K1	52.2000000000000028	0.505000000000000004
60682	O1	42.2999999999999972	0.494999999999999996
60682	NU2	182.300000000000011	0.00300000000000000006
60682	2N2	197.900000000000006	0.00300000000000000006
60682	OO1	29.6000000000000014	0.0519999999999999976
60682	S1	93.7000000000000028	0.0100000000000000002
60682	M1	103.200000000000003	0.0100000000000000002
60682	J1	78.2999999999999972	0.0229999999999999996
60682	SSA	43.2000000000000028	0.157000000000000001
60682	SA	148.300000000000011	0.284999999999999976
60682	RHO1	22.5	0.0200000000000000004
60682	Q1	30.1000000000000014	0.107999999999999999
60682	T2	164	0.00300000000000000006
60682	2Q1	11.5999999999999996	0.0100000000000000002
60682	P1	54.8999999999999986	0.150999999999999995
60682	L2	156.5	0.00300000000000000006
60682	K2	188	0.0299999999999999989
60683	M2	151.800000000000011	0.0359999999999999973
60683	S2	235.599999999999994	0.00300000000000000006
60683	N2	60.3999999999999986	0.0100000000000000002
60683	K1	98.5	0.235999999999999988
60683	M4	117.5	0.0100000000000000002
60683	O1	96.7999999999999972	0.248999999999999999
60683	M6	276.5	0.00700000000000000015
60683	S4	98	0.00700000000000000015
60683	NU2	72.5999999999999943	0.00300000000000000006
60683	S6	69.5	0.00300000000000000006
60683	OO1	100.299999999999997	0.0100000000000000002
60683	M1	97.7000000000000028	0.0160000000000000003
60683	J1	99.4000000000000057	0.0200000000000000004
60683	RHO1	96.0999999999999943	0.0100000000000000002
60683	Q1	95.9000000000000057	0.0490000000000000019
60683	2Q1	95.0999999999999943	0.00700000000000000015
60683	P1	98.4000000000000057	0.0790000000000000008
60683	M8	24.6000000000000014	0.00300000000000000006
60684	M2	135.699999999999989	0.0389999999999999999
60684	S2	136.300000000000011	0.0200000000000000004
60684	N2	120.200000000000003	0.00700000000000000015
60684	K1	49.2000000000000028	0.360999999999999988
60684	M4	321.899999999999977	0.0160000000000000003
60684	O1	43.2000000000000028	0.353999999999999981
60684	S4	146.099999999999994	0.00700000000000000015
60684	NU2	128.199999999999989	0.00300000000000000006
60684	S6	98	0.00300000000000000006
60684	OO1	55.2999999999999972	0.0160000000000000003
60684	M1	46.2000000000000028	0.0259999999999999988
60684	J1	52.2000000000000028	0.0299999999999999989
60684	SSA	43.2000000000000028	0.157000000000000001
60684	SA	148.300000000000011	0.284999999999999976
60684	RHO1	40.6000000000000014	0.0129999999999999994
60684	Q1	40.2999999999999972	0.0690000000000000058
60684	2Q1	37.2000000000000028	0.0100000000000000002
60684	P1	48.7000000000000028	0.120999999999999996
60684	K2	133.800000000000011	0.00700000000000000015
60684	M8	120	0.00300000000000000006
60685	M2	175.400000000000006	0.0229999999999999996
60685	S2	210.800000000000011	0.0200000000000000004
60685	N2	109.900000000000006	0.00300000000000000006
60685	K1	95.7000000000000028	0.223000000000000004
60685	M4	59.5	0.00300000000000000006
60685	O1	94.2000000000000028	0.226000000000000006
60685	M6	107.900000000000006	0.00300000000000000006
60685	S4	230.099999999999994	0.00300000000000000006
60685	OO1	97.2999999999999972	0.0100000000000000002
60685	M1	95	0.0160000000000000003
60685	J1	96.5	0.0200000000000000004
60685	RHO1	93.5	0.0100000000000000002
60685	Q1	93.4000000000000057	0.0429999999999999966
60685	2Q1	92.5999999999999943	0.00700000000000000015
60685	P1	95.5999999999999943	0.0719999999999999946
60685	K2	213.599999999999994	0.00700000000000000015
60685	M8	296.300000000000011	0.00300000000000000006
60686	M2	102.099999999999994	0.0619999999999999996
60686	S2	128.5	0.0490000000000000019
60686	N2	130.900000000000006	0.0259999999999999988
60686	K1	31.5	0.307999999999999996
60686	M4	307.399999999999977	0.0259999999999999988
60686	O1	26.6999999999999993	0.301999999999999991
60686	M6	80.5	0.00700000000000000015
60686	S4	149.900000000000006	0.0129999999999999994
60686	NU2	127	0.00700000000000000015
60686	S6	138.199999999999989	0.00300000000000000006
60686	MU2	260.5	0.00300000000000000006
60686	2N2	159.699999999999989	0.00300000000000000006
60686	OO1	36.2999999999999972	0.0129999999999999994
60686	M1	29.1000000000000014	0.0229999999999999996
60686	J1	33.8999999999999986	0.0229999999999999996
60686	RHO1	24.6999999999999993	0.0129999999999999994
60686	Q1	24.3000000000000007	0.0589999999999999969
60686	T2	127.5	0.00300000000000000006
60686	2Q1	22	0.00700000000000000015
60686	P1	31.1000000000000014	0.101999999999999993
60686	L2	73.2000000000000028	0.00300000000000000006
60686	K2	130.699999999999989	0.0129999999999999994
60686	M8	210.5	0.00700000000000000015
60687	M2	170.599999999999994	0.0490000000000000019
60687	S2	222	0.0200000000000000004
60687	N2	207.099999999999994	0.0100000000000000002
60687	K1	64.7000000000000028	0.36399999999999999
60687	M4	84.4000000000000057	0.0100000000000000002
60687	O1	55.8999999999999986	0.377000000000000002
60687	M6	263.100000000000023	0.00700000000000000015
60687	MK3	198.199999999999989	0.0129999999999999994
60687	S4	196.099999999999994	0.00300000000000000006
60687	MN4	62.6000000000000014	0.00300000000000000006
60687	NU2	223.800000000000011	0.0100000000000000002
60687	MU2	236.099999999999994	0.00300000000000000006
60687	2N2	54.5	0.0129999999999999994
60687	OO1	58.6000000000000014	0.0359999999999999973
60687	LDA2	143.300000000000011	0.00700000000000000015
60687	S1	216.5	0.0100000000000000002
60687	M1	18.6999999999999993	0.00300000000000000006
60687	J1	102.799999999999997	0.0160000000000000003
60687	SSA	51.2999999999999972	0.164000000000000007
60687	SA	156.300000000000011	0.262000000000000011
60687	RHO1	25	0.0160000000000000003
60687	Q1	42.1000000000000014	0.0749999999999999972
60687	T2	159.900000000000006	0.00700000000000000015
60687	R2	223.5	0.00300000000000000006
60687	2Q1	208.5	0.00300000000000000006
60687	P1	57.7000000000000028	0.104999999999999996
60687	2SM2	146.199999999999989	0.00300000000000000006
60687	M3	212.099999999999994	0.00300000000000000006
60687	2MK3	171.300000000000011	0.0129999999999999994
60687	K2	201	0.0200000000000000004
60687	MS4	112	0.00700000000000000015
60688	M2	179.800000000000011	0.0660000000000000031
60688	S2	207.099999999999994	0.0330000000000000016
60688	N2	248.5	0.00700000000000000015
60688	K1	59.6000000000000014	0.478999999999999981
60688	M4	105.200000000000003	0.0129999999999999994
60688	O1	50.3999999999999986	0.453000000000000014
60688	M6	294.100000000000023	0.00300000000000000006
60688	MK3	182	0.0160000000000000003
60688	S4	234	0.00700000000000000015
60688	MN4	80.7000000000000028	0.0100000000000000002
60688	NU2	303.600000000000023	0.00300000000000000006
60688	S6	10.0999999999999996	0.00300000000000000006
60688	MU2	214.599999999999994	0.00300000000000000006
60688	2N2	323.600000000000023	0.0200000000000000004
60688	OO1	47.5	0.0359999999999999973
60688	LDA2	279	0.00300000000000000006
60688	S1	164.099999999999994	0.0429999999999999966
60688	M1	193.699999999999989	0.0100000000000000002
60688	J1	127	0.0299999999999999989
60688	SSA	54	0.187
60688	SA	150.599999999999994	0.235999999999999988
60688	RHO1	68.5999999999999943	0.0200000000000000004
60688	Q1	42.7000000000000028	0.0950000000000000011
60688	T2	141.699999999999989	0.00700000000000000015
60688	R2	210.599999999999994	0.00700000000000000015
60688	2Q1	100.299999999999997	0.0229999999999999996
60688	P1	54.8999999999999986	0.138000000000000012
60688	M3	311.5	0.00300000000000000006
60688	L2	297.899999999999977	0.00300000000000000006
60688	2MK3	195	0.0160000000000000003
60688	K2	205.5	0.0299999999999999989
60688	MS4	141.400000000000006	0.00700000000000000015
60689	M2	159.400000000000006	0.0589999999999999969
60689	S2	235.699999999999989	0.0359999999999999973
60689	N2	220.099999999999994	0.0200000000000000004
60689	K1	60.3999999999999986	0.518000000000000016
60689	M4	149.099999999999994	0.0129999999999999994
60689	O1	58.2999999999999972	0.491999999999999993
60689	M6	303.199999999999989	0.00700000000000000015
60689	S4	262.5	0.00700000000000000015
60689	NU2	212	0.00300000000000000006
60689	S6	313.699999999999989	0.00300000000000000006
60689	2N2	280.699999999999989	0.00300000000000000006
60689	OO1	62.5	0.0200000000000000004
60689	M1	59.3999999999999986	0.0359999999999999973
60689	J1	61.5	0.0389999999999999999
60689	SSA	54	0.187
60689	SA	150.599999999999994	0.235999999999999988
60689	RHO1	57.3999999999999986	0.0200000000000000004
60689	Q1	57.2999999999999972	0.0950000000000000011
60689	T2	232.599999999999994	0.00300000000000000006
60689	2Q1	56.2999999999999972	0.0129999999999999994
60689	P1	60.2999999999999972	0.171000000000000013
60689	L2	98.7999999999999972	0.00300000000000000006
60689	K2	241.900000000000006	0.0100000000000000002
60689	M8	23.1000000000000014	0.00300000000000000006
60690	M2	141.900000000000006	0.0330000000000000016
60690	S2	148.800000000000011	0.0299999999999999989
60690	N2	273.800000000000011	0.0200000000000000004
60690	K1	70.2000000000000028	0.52200000000000002
60690	M4	214.599999999999994	0.0129999999999999994
60690	O1	67.4000000000000057	0.498999999999999999
60690	M6	31	0.00300000000000000006
60690	S4	332	0.0100000000000000002
60690	NU2	256.100000000000023	0.00300000000000000006
60690	S6	192	0.00300000000000000006
60690	2N2	45.7000000000000028	0.00300000000000000006
60690	OO1	73	0.0229999999999999996
60690	M1	68.7999999999999972	0.0359999999999999973
60690	J1	71.5999999999999943	0.0389999999999999999
60690	SSA	54	0.187
60690	SA	150.599999999999994	0.235999999999999988
60690	RHO1	66.2000000000000028	0.0200000000000000004
60690	Q1	66	0.0980000000000000038
60690	T2	148.5	0.00300000000000000006
60690	2Q1	64.5999999999999943	0.0129999999999999994
60690	P1	70	0.173999999999999988
60690	K2	149.300000000000011	0.00700000000000000015
60690	M8	58.1000000000000014	0.00300000000000000006
60691	M2	132.5	0.0490000000000000019
60691	S2	117.299999999999997	0.0229999999999999996
60691	K1	50.6000000000000014	0.463000000000000023
60691	O1	41.8999999999999986	0.453000000000000014
60691	OO1	56.3999999999999986	0.0359999999999999973
60691	S1	290	0.0129999999999999994
60691	M1	99.5	0.0299999999999999989
60691	J1	65.9000000000000057	0.0200000000000000004
60691	SSA	51.2999999999999972	0.164000000000000007
60691	SA	156.300000000000011	0.262000000000000011
60691	RHO1	15.6999999999999993	0.0160000000000000003
60691	Q1	26.6000000000000014	0.0980000000000000038
60691	2Q1	46.2000000000000028	0.0100000000000000002
60691	P1	49.8999999999999986	0.140999999999999986
60691	K2	222.800000000000011	0.0160000000000000003
60692	M2	132.5	0.0490000000000000019
60692	S2	117.299999999999997	0.0229999999999999996
60692	K1	50.6000000000000014	0.463000000000000023
60692	O1	41.8999999999999986	0.453000000000000014
60692	OO1	56.3999999999999986	0.0359999999999999973
60692	S1	290	0.0129999999999999994
60692	M1	99.5	0.0299999999999999989
60692	J1	65.9000000000000057	0.0200000000000000004
60692	SSA	51.2999999999999972	0.164000000000000007
60692	SA	156.300000000000011	0.262000000000000011
60692	RHO1	15.6999999999999993	0.0160000000000000003
60692	Q1	26.6000000000000014	0.0980000000000000038
60692	2Q1	46.2000000000000028	0.0100000000000000002
60692	P1	49.8999999999999986	0.140999999999999986
60692	K2	222.800000000000011	0.0160000000000000003
60693	M2	188.699999999999989	0.0919999999999999984
60693	S2	294.100000000000023	0.0719999999999999946
60693	N2	262.300000000000011	0.0200000000000000004
60693	K1	67.2000000000000028	0.468999999999999972
60693	M4	199.800000000000011	0.00700000000000000015
60693	O1	55	0.541000000000000036
60693	S4	261.5	0.00300000000000000006
60693	NU2	252.400000000000006	0.00300000000000000006
60693	S6	156.800000000000011	0.00300000000000000006
60693	MU2	83.2999999999999972	0.00300000000000000006
60693	2N2	335.800000000000011	0.00300000000000000006
60693	OO1	79.4000000000000057	0.0229999999999999996
60693	M1	61.2000000000000028	0.0389999999999999999
60693	J1	73.2000000000000028	0.0429999999999999966
60693	SSA	15.6999999999999993	0.164000000000000007
60693	SA	156.300000000000011	0.262000000000000011
60693	RHO1	49.7999999999999972	0.0200000000000000004
60693	Q1	49	0.104999999999999996
60693	T2	289.899999999999977	0.00300000000000000006
60693	2Q1	43	0.0129999999999999994
60693	P1	66.2999999999999972	0.153999999999999998
60693	L2	115.200000000000003	0.00300000000000000006
60693	K2	302.600000000000023	0.0200000000000000004
60693	M8	178.599999999999994	0.00300000000000000006
60694	M2	181.5	0.0820000000000000034
60694	S2	290.399999999999977	0.0359999999999999973
60694	N2	269.800000000000011	0.0129999999999999994
60694	K1	62.7000000000000028	0.44900000000000001
60694	M4	150.300000000000011	0.00700000000000000015
60694	O1	53.2999999999999972	0.512000000000000011
60694	M6	255.599999999999994	0.00300000000000000006
60694	S4	358.100000000000023	0.00300000000000000006
60694	NU2	258	0.00300000000000000006
60694	S6	154.199999999999989	0.00300000000000000006
60694	MU2	72.5	0.00300000000000000006
60694	2N2	358.199999999999989	0.00300000000000000006
60694	OO1	72.0999999999999943	0.0229999999999999996
60694	M1	58	0.0359999999999999973
60694	J1	67.2999999999999972	0.0389999999999999999
60694	SSA	51.2999999999999972	0.164000000000000007
60694	SA	156.300000000000011	0.262000000000000011
60694	RHO1	49.2999999999999972	0.0200000000000000004
60694	Q1	48.6000000000000014	0.0980000000000000038
60694	T2	286.100000000000023	0.00300000000000000006
60694	2Q1	44	0.0129999999999999994
60694	P1	62	0.147999999999999993
60694	L2	93.0999999999999943	0.00300000000000000006
60694	K2	299.300000000000011	0.0100000000000000002
60694	M8	251.699999999999989	0.00300000000000000006
60695	M2	214.900000000000006	0.0749999999999999972
60695	S2	209.400000000000006	0.0560000000000000012
60695	N2	272.199999999999989	0.0100000000000000002
60695	K1	70.2999999999999972	0.478999999999999981
60695	M4	181.900000000000006	0.0200000000000000004
60695	O1	56.1000000000000014	0.463000000000000023
60695	M6	218.300000000000011	0.00700000000000000015
60695	S4	217.199999999999989	0.00300000000000000006
60695	NU2	264.600000000000023	0.00300000000000000006
60695	S6	78.5	0.00300000000000000006
60695	MU2	44.3999999999999986	0.00300000000000000006
60695	OO1	84.4000000000000057	0.0200000000000000004
60695	M1	63.2999999999999972	0.0330000000000000016
60695	J1	77.2999999999999972	0.0359999999999999973
60695	RHO1	50.1000000000000014	0.0160000000000000003
60695	Q1	49.1000000000000014	0.0889999999999999958
60695	T2	209.599999999999994	0.00300000000000000006
60695	2Q1	42.1000000000000014	0.0129999999999999994
60695	P1	69.2000000000000028	0.157000000000000001
60695	L2	157.599999999999994	0.00300000000000000006
60695	K2	208.900000000000006	0.0160000000000000003
60695	M8	79.5	0.0100000000000000002
60696	M2	214.599999999999994	0.0820000000000000034
60696	S2	264.5	0.0519999999999999976
60696	N2	255.800000000000011	0.0160000000000000003
60696	K1	70	0.518000000000000016
60696	M4	202.800000000000011	0.0100000000000000002
60696	O1	59.7999999999999972	0.48899999999999999
60696	MK3	251.699999999999989	0.0200000000000000004
60696	S4	338.699999999999989	0.00700000000000000015
60696	MN4	155.400000000000006	0.00700000000000000015
60696	NU2	274.699999999999989	0.00300000000000000006
60696	2N2	334.600000000000023	0.00700000000000000015
60696	OO1	57.2000000000000028	0.0389999999999999999
60696	LDA2	195.400000000000006	0.00300000000000000006
60696	S1	211.300000000000011	0.0660000000000000031
60696	M1	124.200000000000003	0.0200000000000000004
60696	J1	100.799999999999997	0.0229999999999999996
60696	SSA	31.6999999999999993	0.164000000000000007
60696	SA	128.300000000000011	0.347999999999999976
60696	RHO1	45.8999999999999986	0.0200000000000000004
60696	Q1	50	0.0980000000000000038
60696	T2	120.599999999999994	0.00700000000000000015
60696	R2	262.199999999999989	0.00700000000000000015
60696	2Q1	54.7000000000000028	0.0129999999999999994
60696	P1	73.4000000000000057	0.143999999999999989
60696	2SM2	78.9000000000000057	0.00300000000000000006
60696	M3	137.400000000000006	0.00300000000000000006
60696	L2	224.800000000000011	0.00300000000000000006
60696	2MK3	236.099999999999994	0.0160000000000000003
60696	K2	230.400000000000006	0.0429999999999999966
60696	MS4	235.400000000000006	0.00300000000000000006
60697	M2	211.599999999999994	0.0820000000000000034
60697	S2	275.5	0.0519999999999999976
60697	N2	267.5	0.0160000000000000003
60697	K1	68.2000000000000028	0.548000000000000043
60697	M4	200.099999999999994	0.0160000000000000003
60697	O1	71	0.498999999999999999
60697	M6	190.900000000000006	0.00300000000000000006
60697	S4	12.1999999999999993	0.00700000000000000015
60697	NU2	269.300000000000011	0.00300000000000000006
60697	S6	22.3999999999999986	0.00300000000000000006
60697	MU2	139.699999999999989	0.00300000000000000006
60697	2N2	277.600000000000023	0.00300000000000000006
60697	OO1	65.5999999999999943	0.0200000000000000004
60697	M1	69.5999999999999943	0.0359999999999999973
60697	J1	66.9000000000000057	0.0389999999999999999
60697	RHO1	72.0999999999999943	0.0160000000000000003
60697	Q1	72.2999999999999972	0.0980000000000000038
60697	T2	271.5	0.00300000000000000006
60697	2Q1	72.7000000000000028	0.0129999999999999994
60697	P1	68.4000000000000057	0.179999999999999993
60697	K2	280.800000000000011	0.0129999999999999994
60697	M8	351.399999999999977	0.00300000000000000006
60698	M2	260.100000000000023	0.0820000000000000034
60698	S2	330.199999999999989	0.112000000000000002
60698	N2	336.399999999999977	0.0560000000000000012
60698	K1	102.799999999999997	0.554000000000000048
60698	M4	348.600000000000023	0.0259999999999999988
60698	O1	86.7999999999999972	0.567999999999999949
60698	M6	32	0.00300000000000000006
60698	NU2	326.199999999999989	0.0100000000000000002
60698	S6	49.8999999999999986	0.00300000000000000006
60698	MU2	14.3000000000000007	0.00300000000000000006
60698	2N2	52.7000000000000028	0.00700000000000000015
60698	OO1	118.799999999999997	0.0229999999999999996
60698	M1	94.7999999999999972	0.0389999999999999999
60698	J1	110.700000000000003	0.0459999999999999992
60698	RHO1	79.9000000000000057	0.0229999999999999996
60698	Q1	78.7999999999999972	0.112000000000000002
60698	T2	327.399999999999977	0.00700000000000000015
60698	2Q1	70.9000000000000057	0.0160000000000000003
60698	P1	101.599999999999994	0.183999999999999997
60698	L2	183.800000000000011	0.00300000000000000006
60698	K2	335.899999999999977	0.0299999999999999989
60698	M8	18.5	0.00300000000000000006
60699	M2	153.099999999999994	0.0749999999999999972
60699	S2	226.099999999999994	0.0850000000000000061
60699	N2	218.199999999999989	0.0330000000000000016
60699	K1	45.3999999999999986	0.456000000000000016
60699	M4	116.400000000000006	0.0429999999999999966
60699	O1	38.5	0.505000000000000004
60699	M6	305.199999999999989	0.00300000000000000006
60699	S4	274	0.0160000000000000003
60699	NU2	209.5	0.00700000000000000015
60699	S6	57.7000000000000028	0.00300000000000000006
60699	MU2	80.0999999999999943	0.00300000000000000006
60699	2N2	283.300000000000011	0.00300000000000000006
60699	OO1	52.2999999999999972	0.0229999999999999996
60699	M1	41.8999999999999986	0.0359999999999999973
60699	J1	48.7999999999999972	0.0389999999999999999
60699	SSA	51.2999999999999972	0.164000000000000007
60699	SA	156.300000000000011	0.262000000000000011
60699	RHO1	35.5	0.0200000000000000004
60699	Q1	35	0.0980000000000000038
60699	T2	223.099999999999994	0.00700000000000000015
60699	2Q1	31.6000000000000014	0.0129999999999999994
60699	P1	44.8999999999999986	0.150999999999999995
60699	L2	88	0.00300000000000000006
60699	K2	232	0.0229999999999999996
60699	M8	256.899999999999977	0.00300000000000000006
60700	M2	136.699999999999989	0.107999999999999999
60700	S2	168.5	0.0820000000000000034
60700	N2	172.199999999999989	0.0160000000000000003
60700	K1	34	0.54500000000000004
60700	M4	94.5	0.0429999999999999966
60700	O1	29.3999999999999986	0.48899999999999999
60700	M6	234	0.0100000000000000002
60700	S4	212.300000000000011	0.0259999999999999988
60700	NU2	170.199999999999989	0.00300000000000000006
60700	S6	237.599999999999994	0.00300000000000000006
60700	MU2	105.599999999999994	0.00300000000000000006
60700	OO1	38.3999999999999986	0.0200000000000000004
60700	M1	31.6999999999999993	0.0359999999999999973
60700	J1	36.1000000000000014	0.0389999999999999999
60700	SSA	51.2999999999999972	0.164000000000000007
60700	SA	156.300000000000011	0.262000000000000011
60700	RHO1	27.6000000000000014	0.0160000000000000003
60700	Q1	27.1000000000000014	0.0950000000000000011
60700	T2	167.699999999999989	0.00700000000000000015
60700	2Q1	24	0.0129999999999999994
60700	P1	33.6000000000000014	0.179999999999999993
60700	K2	171.099999999999994	0.0229999999999999996
60700	M8	28.6000000000000014	0.00300000000000000006
60701	M2	146	0.107999999999999999
60701	S2	164.800000000000011	0.0719999999999999946
60701	N2	177.5	0.0299999999999999989
60701	K1	37.6000000000000014	0.509000000000000008
60701	M4	90.5	0.0359999999999999973
60701	O1	31.1999999999999993	0.478999999999999981
60701	M6	241.300000000000011	0.00700000000000000015
60701	MK3	92.7000000000000028	0.00700000000000000015
60701	S4	192.699999999999989	0.00700000000000000015
60701	MN4	53	0.0160000000000000003
60701	NU2	132.099999999999994	0.00300000000000000006
60701	S6	153.300000000000011	0.00300000000000000006
60701	MU2	141.5	0.00300000000000000006
60701	2N2	179.699999999999989	0.0100000000000000002
60701	OO1	48	0.0229999999999999996
60701	LDA2	51	0.00300000000000000006
60701	S1	130.699999999999989	0.0490000000000000019
60701	M1	71.9000000000000057	0.0229999999999999996
60701	J1	48.2000000000000028	0.0299999999999999989
60701	RHO1	348.600000000000023	0.0160000000000000003
60701	Q1	18.8999999999999986	0.112000000000000002
60701	T2	128.400000000000006	0.0100000000000000002
60701	R2	12.5999999999999996	0.0100000000000000002
60701	2Q1	353	0.0229999999999999996
60701	P1	35.7999999999999972	0.147999999999999993
60701	2SM2	261.300000000000011	0.00300000000000000006
60701	M3	325.199999999999989	0.00300000000000000006
60701	L2	141.300000000000011	0.00300000000000000006
60701	2MK3	59.6000000000000014	0.00300000000000000006
60701	K2	125.099999999999994	0.0299999999999999989
60701	MS4	97.2000000000000028	0.0100000000000000002
60702	M2	134.400000000000006	0.101999999999999993
60702	S2	143.400000000000006	0.0490000000000000019
60702	N2	157.5	0.0229999999999999996
60702	K1	32	0.485999999999999988
60702	M4	63.7000000000000028	0.0229999999999999996
60702	O1	23.3999999999999986	0.481999999999999984
60702	S4	175	0.00300000000000000006
60702	NU2	155.400000000000006	0.00700000000000000015
60702	MU2	120.5	0.00300000000000000006
60702	2N2	184.5	0.00300000000000000006
60702	OO1	40.8999999999999986	0.0200000000000000004
60702	M1	27.8999999999999986	0.0330000000000000016
60702	J1	36.3999999999999986	0.0389999999999999999
60702	RHO1	19.6000000000000014	0.0200000000000000004
60702	Q1	19.1000000000000014	0.0950000000000000011
60702	T2	140.199999999999989	0.00300000000000000006
60702	2Q1	14.6999999999999993	0.0129999999999999994
60702	P1	31.3999999999999986	0.161000000000000004
60702	L2	109.700000000000003	0.00300000000000000006
60702	K2	145	0.0129999999999999994
60703	M2	134.900000000000006	0.0919999999999999984
60703	S2	155.300000000000011	0.0589999999999999969
60703	N2	171.599999999999994	0.0200000000000000004
60703	K1	32.3999999999999986	0.502000000000000002
60703	M4	72.2999999999999972	0.0259999999999999988
60703	O1	24.8000000000000007	0.475999999999999979
60703	M6	185.699999999999989	0.00300000000000000006
60703	MK3	81.5	0.0100000000000000002
60703	S4	191.599999999999994	0.0100000000000000002
60703	MN4	26	0.0100000000000000002
60703	NU2	167.5	0.00300000000000000006
60703	MU2	137.199999999999989	0.00700000000000000015
60703	2N2	180.5	0.00700000000000000015
60703	OO1	38.1000000000000014	0.0229999999999999996
60703	LDA2	60.2000000000000028	0.00300000000000000006
60703	S1	146.599999999999994	0.0259999999999999988
60703	M1	53.1000000000000014	0.0160000000000000003
60703	J1	52.5	0.0330000000000000016
60703	SSA	47.6000000000000014	0.20699999999999999
60703	SA	143.599999999999994	0.429999999999999993
60703	RHO1	8.69999999999999929	0.0229999999999999996
60703	Q1	14.9000000000000004	0.0980000000000000038
60703	T2	125	0.00700000000000000015
60703	R2	4.70000000000000018	0.00300000000000000006
60703	2Q1	358.5	0.0160000000000000003
60703	P1	26.8999999999999986	0.140999999999999986
60703	2SM2	21.3999999999999986	0.00300000000000000006
60703	M3	297.399999999999977	0.00300000000000000006
60703	L2	230.199999999999989	0.00300000000000000006
60703	2MK3	63.6000000000000014	0.0100000000000000002
60703	K2	130.099999999999994	0.0229999999999999996
60703	MS4	94.5999999999999943	0.0100000000000000002
60704	M2	142	0.0950000000000000011
60704	S2	163.5	0.0490000000000000019
60704	N2	202.800000000000011	0.0299999999999999989
60704	K1	33.7999999999999972	0.471999999999999975
60704	M4	92.5	0.0229999999999999996
60704	O1	28.3000000000000007	0.509000000000000008
60704	S4	129.099999999999994	0.0100000000000000002
60704	NU2	194.599999999999994	0.00700000000000000015
60704	S6	344.100000000000023	0.00300000000000000006
60704	MU2	303.399999999999977	0.00300000000000000006
60704	2N2	263.600000000000023	0.00300000000000000006
60704	OO1	39.2999999999999972	0.0229999999999999996
60704	M1	31.1000000000000014	0.0359999999999999973
60704	J1	36.6000000000000014	0.0389999999999999999
60704	RHO1	25.8999999999999986	0.0200000000000000004
60704	Q1	25.6000000000000014	0.0980000000000000038
60704	T2	162.699999999999989	0.00300000000000000006
60704	2Q1	22.8000000000000007	0.0129999999999999994
60704	P1	33.3999999999999986	0.157000000000000001
60704	L2	81.2000000000000028	0.00300000000000000006
60704	K2	165.300000000000011	0.0129999999999999994
60704	M8	6.29999999999999982	0.00700000000000000015
60705	M2	145.599999999999994	0.0919999999999999984
60705	S2	167.199999999999989	0.0619999999999999996
60705	N2	183.599999999999994	0.0200000000000000004
60705	K1	37.1000000000000014	0.502000000000000002
60705	M4	92	0.0229999999999999996
60705	O1	29.5	0.471999999999999975
60705	M6	202.900000000000006	0.00300000000000000006
60705	MK3	108	0.0100000000000000002
60705	S4	211.699999999999989	0.0100000000000000002
60705	MN4	42.1000000000000014	0.0100000000000000002
60705	NU2	184.800000000000011	0.00300000000000000006
60705	MU2	128.800000000000011	0.00300000000000000006
60705	2N2	191.300000000000011	0.00700000000000000015
60705	OO1	41.3999999999999986	0.0229999999999999996
60705	LDA2	90.5999999999999943	0.00300000000000000006
60705	S1	150.400000000000006	0.0299999999999999989
60705	M1	64.2999999999999972	0.0200000000000000004
60705	J1	50.7000000000000028	0.0299999999999999989
60705	SSA	40	0.190000000000000002
60705	SA	141.300000000000011	0.377000000000000002
60705	RHO1	12.5999999999999996	0.0229999999999999996
60705	Q1	17.3999999999999986	0.101999999999999993
60705	T2	112	0.00700000000000000015
60705	2Q1	6.20000000000000018	0.0160000000000000003
60705	P1	32.7999999999999972	0.143999999999999989
60705	M3	292.899999999999977	0.00300000000000000006
60705	L2	181.599999999999994	0.00300000000000000006
60705	2MK3	92.0999999999999943	0.00700000000000000015
60705	K2	144.699999999999989	0.0259999999999999988
60705	MS4	114.400000000000006	0.00700000000000000015
60706	M2	170.199999999999989	0.0690000000000000058
60706	S2	191.599999999999994	0.0459999999999999992
60706	N2	207	0.0129999999999999994
60706	K1	47.7999999999999972	0.463000000000000023
60706	M4	121.099999999999994	0.0160000000000000003
60706	O1	39.5	0.426999999999999991
60706	M6	245	0.00300000000000000006
60706	MK3	136.699999999999989	0.0100000000000000002
60706	S4	243.699999999999989	0.00700000000000000015
60706	MN4	72.2000000000000028	0.0100000000000000002
60706	NU2	305.5	0.00300000000000000006
60706	MU2	321.699999999999989	0.00300000000000000006
60706	2N2	3.79999999999999982	0.00700000000000000015
60706	OO1	28.1999999999999993	0.0229999999999999996
60706	LDA2	18.8999999999999986	0.00300000000000000006
60706	S1	217.5	0.0160000000000000003
60706	M1	59.6000000000000014	0.0200000000000000004
60706	J1	81	0.0259999999999999988
60706	SSA	40	0.190000000000000002
60706	SA	141.300000000000011	0.509000000000000008
60706	RHO1	35	0.0330000000000000016
60706	Q1	35.8999999999999986	0.104999999999999996
60706	T2	72.9000000000000057	0.00300000000000000006
60706	R2	275.100000000000023	0.00300000000000000006
60706	2Q1	318.699999999999989	0.0100000000000000002
60706	P1	51.5	0.140999999999999986
60706	2SM2	2.29999999999999982	0.0100000000000000002
60706	M3	141.599999999999994	0.00300000000000000006
60706	L2	49	0.00300000000000000006
60706	2MK3	89.4000000000000057	0.0100000000000000002
60706	K2	176.900000000000006	0.0299999999999999989
60706	MS4	114.599999999999994	0.0100000000000000002
60707	M2	153.099999999999994	0.112000000000000002
60707	S2	179.599999999999994	0.0660000000000000031
60707	N2	167.5	0.0229999999999999996
60707	K1	37.6000000000000014	0.525000000000000022
60707	M4	104.599999999999994	0.0259999999999999988
60707	O1	29.6999999999999993	0.485999999999999988
60707	M6	209.099999999999994	0.00300000000000000006
60707	MK3	106.799999999999997	0.00700000000000000015
60707	S4	220.5	0.0100000000000000002
60707	MN4	59.8999999999999986	0.0129999999999999994
60707	NU2	194.199999999999989	0.00700000000000000015
60707	MU2	144.900000000000006	0.0100000000000000002
60707	2N2	210.099999999999994	0.0160000000000000003
60707	OO1	38.5	0.0200000000000000004
60707	LDA2	111.299999999999997	0.00700000000000000015
60707	S1	149.699999999999989	0.0560000000000000012
60707	M1	87.7999999999999972	0.0129999999999999994
60707	J1	68.5999999999999943	0.0299999999999999989
60707	SSA	57.8999999999999986	0.157000000000000001
60707	SA	121.900000000000006	0.318000000000000005
60707	RHO1	10.5999999999999996	0.0160000000000000003
60707	Q1	21.5	0.104999999999999996
60707	T2	188.900000000000006	0.00300000000000000006
60707	R2	113.700000000000003	0.00300000000000000006
60707	2Q1	0.200000000000000011	0.0330000000000000016
60707	P1	34.3999999999999986	0.140999999999999986
60707	2SM2	231.900000000000006	0.00700000000000000015
60707	M3	231	0.00700000000000000015
60707	L2	111.299999999999997	0.00700000000000000015
60707	2MK3	84.4000000000000057	0.00700000000000000015
60707	K2	156.400000000000006	0.0389999999999999999
60707	MS4	111.599999999999994	0.0129999999999999994
60708	M2	135.5	0.107999999999999999
60708	S2	185.5	0.0660000000000000031
60708	N2	246.400000000000006	0.00300000000000000006
60708	K1	38.2999999999999972	0.52200000000000002
60708	M4	115.900000000000006	0.0299999999999999989
60708	O1	26.8000000000000007	0.531000000000000028
60708	M6	173.699999999999989	0.00300000000000000006
60708	S4	250.400000000000006	0.0200000000000000004
60708	S6	352.5	0.00300000000000000006
60708	MU2	268.100000000000023	0.00300000000000000006
60708	OO1	49.7999999999999972	0.0229999999999999996
60708	M1	32.6000000000000014	0.0389999999999999999
60708	J1	44	0.0429999999999999966
60708	RHO1	21.8000000000000007	0.0200000000000000004
60708	Q1	21.1000000000000014	0.101999999999999993
60708	T2	183.5	0.00300000000000000006
60708	2Q1	15.4000000000000004	0.0129999999999999994
60708	P1	37.3999999999999986	0.173999999999999988
60708	L2	24.6000000000000014	0.00300000000000000006
60708	K2	189.599999999999994	0.0160000000000000003
60708	M8	14.4000000000000004	0.00300000000000000006
60709	M2	181.599999999999994	0.143999999999999989
60709	S2	204.400000000000006	0.0519999999999999976
60709	N2	204.900000000000006	0.0359999999999999973
60709	K1	56.7000000000000028	0.54500000000000004
60709	M4	170.400000000000006	0.0330000000000000016
60709	O1	41.8999999999999986	0.459000000000000019
60709	M6	284.300000000000011	0.00700000000000000015
60709	S4	218.099999999999994	0.00300000000000000006
60709	NU2	200.900000000000006	0.00700000000000000015
60709	S6	228.199999999999989	0.00300000000000000006
60709	MU2	165.400000000000006	0.00300000000000000006
60709	2N2	230.099999999999994	0.00700000000000000015
60709	OO1	71.0999999999999943	0.0200000000000000004
60709	M1	49.2000000000000028	0.0330000000000000016
60709	J1	63.7000000000000028	0.0359999999999999973
60709	SSA	40	0.190000000000000002
60709	SA	141.300000000000011	0.377000000000000002
60709	RHO1	35.2000000000000028	0.0160000000000000003
60709	Q1	34.7999999999999972	0.0889999999999999958
60709	T2	205.699999999999989	0.00300000000000000006
60709	2Q1	28	0.0129999999999999994
60709	P1	55.6000000000000014	0.179999999999999993
60709	L2	154.599999999999994	0.00300000000000000006
60709	K2	204.800000000000011	0.0129999999999999994
60710	M2	180.300000000000011	0.104999999999999996
60710	S2	210	0.0790000000000000008
60710	N2	219.300000000000011	0.0330000000000000016
60710	K1	47.3999999999999986	0.551000000000000045
60710	M4	160.5	0.0259999999999999988
60710	O1	39.2999999999999972	0.551000000000000045
60710	M6	314.800000000000011	0.00300000000000000006
60710	MK3	158.199999999999989	0.0160000000000000003
60710	S4	310	0.0100000000000000002
60710	MN4	134.900000000000006	0.0100000000000000002
60710	NU2	268.699999999999989	0.00700000000000000015
60710	S6	184.199999999999989	0.00300000000000000006
60710	MU2	143.199999999999989	0.0100000000000000002
60710	2N2	144.300000000000011	0.0200000000000000004
60710	OO1	53.2999999999999972	0.0589999999999999969
60710	LDA2	317.699999999999989	0.00700000000000000015
60710	S1	182	0.0560000000000000012
60710	M1	98	0.0200000000000000004
60710	J1	38.6000000000000014	0.0299999999999999989
60710	SSA	40	0.190000000000000002
60710	SA	141.300000000000011	0.377000000000000002
60710	RHO1	1.10000000000000009	0.0490000000000000019
60710	Q1	17.6999999999999993	0.117999999999999994
60710	T2	159.800000000000011	0.0100000000000000002
60710	R2	219.099999999999994	0.0100000000000000002
60710	2Q1	259	0.00300000000000000006
60710	P1	50.2999999999999972	0.161000000000000004
60710	2SM2	245.5	0.00700000000000000015
60710	M3	232	0.00700000000000000015
60710	L2	107.299999999999997	0.00300000000000000006
60710	2MK3	134.300000000000011	0.0129999999999999994
60710	K2	182.800000000000011	0.0490000000000000019
60710	M8	0.800000000000000044	0.00300000000000000006
60710	MS4	194.5	0.0100000000000000002
60711	M2	194.400000000000006	0.125
60711	S2	208.199999999999989	0.107999999999999999
60711	N2	242.400000000000006	0.0330000000000000016
60711	K1	47.7000000000000028	0.663000000000000034
60711	M4	166.599999999999994	0.0259999999999999988
60711	O1	38.7999999999999972	0.538000000000000034
60711	M6	347.800000000000011	0.00700000000000000015
60711	S4	343.300000000000011	0.0100000000000000002
60711	NU2	235.300000000000011	0.00700000000000000015
60711	S6	322.199999999999989	0.00300000000000000006
60711	MU2	180.199999999999989	0.00300000000000000006
60711	OO1	57	0.0200000000000000004
60711	M1	43.5	0.0389999999999999999
60711	J1	52.5	0.0429999999999999966
60711	SSA	57.8999999999999986	0.157000000000000001
60711	SA	121.900000000000006	0.318000000000000005
60711	RHO1	34.7999999999999972	0.0229999999999999996
60711	Q1	34.2999999999999972	0.101999999999999993
60711	T2	207.5	0.00700000000000000015
60711	2Q1	30.3999999999999986	0.0129999999999999994
60711	P1	47	0.220000000000000001
60711	L2	149.400000000000006	0.00300000000000000006
60711	K2	209.300000000000011	0.0299999999999999989
60712	M2	181.900000000000006	0.101999999999999993
60712	S2	185.199999999999989	0.0490000000000000019
60712	N2	160.400000000000006	0.0299999999999999989
60712	K1	49.1000000000000014	0.485999999999999988
60712	M4	157.400000000000006	0.0259999999999999988
60712	O1	38	0.548000000000000043
60712	M6	51.7000000000000028	0.00300000000000000006
60712	S4	173.400000000000006	0.0129999999999999994
60712	NU2	163.300000000000011	0.00700000000000000015
60712	S6	69.5	0.00300000000000000006
60712	MU2	0.900000000000000022	0.00300000000000000006
60712	2N2	138.900000000000006	0.00300000000000000006
60712	OO1	60.2999999999999972	0.0229999999999999996
60712	M1	43.6000000000000014	0.0389999999999999999
60712	J1	54.6000000000000014	0.0429999999999999966
60712	RHO1	33.2000000000000028	0.0200000000000000004
60712	Q1	32.3999999999999986	0.104999999999999996
60712	T2	185.099999999999994	0.00300000000000000006
60712	2Q1	26.8999999999999986	0.0129999999999999994
60712	P1	48.2999999999999972	0.161000000000000004
60712	L2	203.400000000000006	0.00300000000000000006
60712	K2	185.5	0.0129999999999999994
60712	M8	302.100000000000023	0.00300000000000000006
60713	M2	197.900000000000006	0.0950000000000000011
60713	S2	221	0.0950000000000000011
60713	N2	256.800000000000011	0.0330000000000000016
60713	K1	53	0.627000000000000002
60713	M4	174.5	0.0229999999999999996
60713	O1	43.7000000000000028	0.509000000000000008
60713	M6	344.600000000000023	0.00700000000000000015
60713	S4	25.6999999999999993	0.00700000000000000015
60713	NU2	249	0.00700000000000000015
60713	MU2	173.199999999999989	0.00300000000000000006
60713	2N2	325.800000000000011	0.00300000000000000006
60713	OO1	62.5	0.0200000000000000004
60713	M1	48.5	0.0359999999999999973
60713	J1	57.8999999999999986	0.0389999999999999999
60713	RHO1	39.6000000000000014	0.0200000000000000004
60713	Q1	39.2000000000000028	0.0980000000000000038
60713	T2	219	0.00700000000000000015
60713	2Q1	34.8999999999999986	0.0129999999999999994
60713	P1	52.2999999999999972	0.20699999999999999
60713	L2	147	0.00300000000000000006
60713	K2	222.900000000000006	0.0259999999999999988
60713	M8	318.899999999999977	0.00300000000000000006
60714	M2	182.099999999999994	0.120999999999999996
60714	S2	206.699999999999989	0.0950000000000000011
60714	N2	216.900000000000006	0.0330000000000000016
60714	K1	45.7999999999999972	0.561000000000000054
60714	M4	162.800000000000011	0.0229999999999999996
60714	O1	37.7000000000000028	0.558000000000000052
60714	M6	298.800000000000011	0.00300000000000000006
60714	MK3	147	0.0129999999999999994
60714	S4	305.5	0.0100000000000000002
60714	MN4	133.900000000000006	0.00700000000000000015
60714	NU2	292.600000000000023	0.00700000000000000015
60714	MU2	156.400000000000006	0.00700000000000000015
60714	2N2	140	0.0129999999999999994
60714	OO1	49.8999999999999986	0.0660000000000000031
60714	LDA2	283.899999999999977	0.00300000000000000006
60714	S1	172.400000000000006	0.0719999999999999946
60714	M1	94.5	0.0200000000000000004
60714	J1	34.7999999999999972	0.0299999999999999989
60714	SSA	40.1000000000000014	0.173999999999999988
60714	SA	131	0.220000000000000001
60714	RHO1	0.599999999999999978	0.0459999999999999992
60714	Q1	16.1999999999999993	0.117999999999999994
60714	T2	159.099999999999994	0.0129999999999999994
60714	R2	277.399999999999977	0.0100000000000000002
60714	2Q1	169.800000000000011	0.00300000000000000006
60714	P1	46.7999999999999972	0.161000000000000004
60714	2SM2	233.099999999999994	0.0100000000000000002
60714	M3	217.5	0.00700000000000000015
60714	L2	170.900000000000006	0.00700000000000000015
60714	2MK3	129	0.0129999999999999994
60714	K2	178.099999999999994	0.0429999999999999966
60714	MS4	202	0.0100000000000000002
60715	M2	189.099999999999994	0.107999999999999999
60715	S2	201.699999999999989	0.101999999999999993
60715	N2	234.699999999999989	0.0259999999999999988
60715	K1	45.5	0.656000000000000028
60715	M4	141.800000000000011	0.0160000000000000003
60715	O1	37.2999999999999972	0.525000000000000022
60715	M6	265.699999999999989	0.00700000000000000015
60715	S4	293.300000000000011	0.00700000000000000015
60715	NU2	231.300000000000011	0.00700000000000000015
60715	S6	288.800000000000011	0.00300000000000000006
60715	MU2	175.5	0.00300000000000000006
60715	2N2	245.300000000000011	0.00300000000000000006
60715	OO1	54.1000000000000014	0.0200000000000000004
60715	M1	41.5	0.0359999999999999973
60715	J1	49.7999999999999972	0.0389999999999999999
60715	RHO1	34	0.0200000000000000004
60715	Q1	33.2000000000000028	0.101999999999999993
60715	T2	200.300000000000011	0.00700000000000000015
60715	2Q1	29.5	0.0129999999999999994
60715	P1	44.8999999999999986	0.216999999999999998
60715	L2	141.300000000000011	0.00300000000000000006
60715	K2	202.900000000000006	0.0299999999999999989
60715	M8	288.300000000000011	0.00300000000000000006
60716	M2	170.199999999999989	0.112000000000000002
60716	S2	194.5	0.0820000000000000034
60716	N2	195.5	0.0229999999999999996
60716	K1	42.8999999999999986	0.563999999999999946
60716	M4	135	0.0229999999999999996
60716	O1	33.2000000000000028	0.518000000000000016
60716	M6	269	0.00300000000000000006
60716	MK3	122.5	0.0100000000000000002
60716	S4	255.800000000000011	0.0100000000000000002
60716	MN4	93.5999999999999943	0.0100000000000000002
60716	MU2	170.199999999999989	0.00300000000000000006
60716	2N2	217.400000000000006	0.0100000000000000002
60716	OO1	28.5	0.0229999999999999996
60716	LDA2	154	0.00700000000000000015
60716	S1	148.099999999999994	0.0490000000000000019
60716	M1	62.6000000000000014	0.0229999999999999996
60716	J1	56.7000000000000028	0.0299999999999999989
60716	SSA	65.7000000000000028	0.235999999999999988
60716	SA	154.199999999999989	0.298999999999999988
60716	RHO1	21.1999999999999993	0.0200000000000000004
60716	Q1	23.5	0.112000000000000002
60716	T2	137.699999999999989	0.0100000000000000002
60716	R2	304.800000000000011	0.00300000000000000006
60716	2Q1	353.600000000000023	0.0160000000000000003
60716	P1	42.2000000000000028	0.153999999999999998
60716	2SM2	328.899999999999977	0.00300000000000000006
60716	M3	279.600000000000023	0.00300000000000000006
60716	L2	117	0.00300000000000000006
60716	2MK3	92	0.0100000000000000002
60716	K2	166.199999999999989	0.0359999999999999973
60716	MS4	149.900000000000006	0.0100000000000000002
60717	M2	160.300000000000011	0.157000000000000001
60717	S2	185.900000000000006	0.0850000000000000061
60717	N2	145.800000000000011	0.0259999999999999988
60717	K1	50.1000000000000014	0.471999999999999975
60717	M4	132.900000000000006	0.0259999999999999988
60717	O1	33.2000000000000028	0.485999999999999988
60717	M6	332.5	0.00300000000000000006
60717	S4	184.900000000000006	0.0100000000000000002
60717	NU2	141.699999999999989	0.00700000000000000015
60717	S6	120.299999999999997	0.00300000000000000006
60717	MU2	128.800000000000011	0.00300000000000000006
60717	OO1	65.7000000000000028	0.0160000000000000003
60717	M1	40.7999999999999972	0.0330000000000000016
60717	J1	56.1000000000000014	0.0330000000000000016
60717	RHO1	26.3000000000000007	0.0160000000000000003
60717	Q1	25.3999999999999986	0.0919999999999999984
60717	T2	184.199999999999989	0.00300000000000000006
60717	2Q1	17.8000000000000007	0.0100000000000000002
60717	P1	48.8999999999999986	0.157000000000000001
60717	L2	196.5	0.00300000000000000006
60717	K2	188.199999999999989	0.0229999999999999996
60718	M2	189	0.104999999999999996
60718	S2	198	0.0950000000000000011
60718	N2	231.400000000000006	0.0299999999999999989
60718	K1	44.3999999999999986	0.653000000000000025
60718	M4	138.599999999999994	0.0160000000000000003
60718	O1	37.1000000000000014	0.528000000000000025
60718	M6	281.199999999999989	0.00300000000000000006
60718	S4	305.100000000000023	0.00700000000000000015
60718	NU2	223.800000000000011	0.00700000000000000015
60718	S6	285.199999999999989	0.00300000000000000006
60718	MU2	178.900000000000006	0.00300000000000000006
60718	2N2	245.900000000000006	0.00300000000000000006
60718	OO1	52	0.0200000000000000004
60718	M1	40.8999999999999986	0.0389999999999999999
60718	J1	48.2000000000000028	0.0389999999999999999
60718	RHO1	34.2000000000000028	0.0200000000000000004
60718	Q1	33.5	0.101999999999999993
60718	T2	196.5	0.00700000000000000015
60718	2Q1	30.3000000000000007	0.0129999999999999994
60718	P1	43.7999999999999972	0.216999999999999998
60718	L2	143	0.00300000000000000006
60718	K2	198.800000000000011	0.0259999999999999988
60719	M2	175.699999999999989	0.128000000000000003
60719	S2	216	0.107999999999999999
60719	N2	237.099999999999994	0.0359999999999999973
60719	K1	51.5	0.531000000000000028
60719	M4	185.300000000000011	0.0200000000000000004
60719	O1	39.7999999999999972	0.554000000000000048
60719	M6	339.699999999999989	0.00300000000000000006
60719	S4	219.300000000000011	0.00300000000000000006
60719	NU2	228.900000000000006	0.00700000000000000015
60719	S6	43	0.00300000000000000006
60719	MU2	317.600000000000023	0.00300000000000000006
60719	2N2	298.5	0.00300000000000000006
60719	OO1	63.2999999999999972	0.0229999999999999996
60719	M1	45.7000000000000028	0.0389999999999999999
60719	J1	57.3999999999999986	0.0429999999999999966
60719	RHO1	34.7000000000000028	0.0200000000000000004
60719	Q1	33.8999999999999986	0.107999999999999999
60719	T2	214.400000000000006	0.00700000000000000015
60719	2Q1	28.1000000000000014	0.0129999999999999994
60719	P1	50.6000000000000014	0.176999999999999991
60719	L2	114.299999999999997	0.00300000000000000006
60719	K2	219.300000000000011	0.0299999999999999989
60719	M8	91.4000000000000057	0.00300000000000000006
60720	M2	185.5	0.190000000000000002
60720	S2	202.699999999999989	0.0919999999999999984
60720	N2	166	0.0459999999999999992
60720	K1	63.7000000000000028	0.475999999999999979
60720	M4	194.400000000000006	0.0229999999999999996
60720	O1	41.5	0.475999999999999979
60720	S4	249.599999999999994	0.0129999999999999994
60720	NU2	164.400000000000006	0.0100000000000000002
60720	S6	262.399999999999977	0.00300000000000000006
60720	MU2	163.199999999999989	0.00300000000000000006
60720	2N2	85.4000000000000057	0.00300000000000000006
60720	OO1	71.5999999999999943	0.0160000000000000003
60720	M1	49.5	0.0330000000000000016
60720	J1	65.4000000000000057	0.0299999999999999989
60720	RHO1	34.5	0.0160000000000000003
60720	Q1	33.2000000000000028	0.0919999999999999984
60720	T2	202.800000000000011	0.00300000000000000006
60720	2Q1	25.3999999999999986	0.0129999999999999994
60720	P1	62.2000000000000028	0.157000000000000001
60720	L2	212.800000000000011	0.00300000000000000006
60720	K2	204.099999999999994	0.0229999999999999996
60720	M8	263.899999999999977	0.00300000000000000006
60721	M2	200.900000000000006	0.223000000000000004
60721	S2	223.400000000000006	0.115000000000000005
60721	N2	178.199999999999989	0.0619999999999999996
60721	K1	72.2000000000000028	0.494999999999999996
60721	M4	257.899999999999977	0.0389999999999999999
60721	O1	47.5	0.475999999999999979
60721	M6	305.199999999999989	0.00300000000000000006
60721	S4	287.399999999999977	0.0129999999999999994
60721	NU2	182.300000000000011	0.0129999999999999994
60721	S6	49	0.00300000000000000006
60721	MU2	170.800000000000011	0.00300000000000000006
60721	2N2	129	0.00300000000000000006
60721	OO1	82.0999999999999943	0.0129999999999999994
60721	LDA2	224.199999999999989	0.00300000000000000006
60721	M1	56.8999999999999986	0.0330000000000000016
60721	J1	75.0999999999999943	0.0299999999999999989
60721	RHO1	39.6000000000000014	0.0160000000000000003
60721	Q1	38.2999999999999972	0.0919999999999999984
60721	T2	220.900000000000006	0.00700000000000000015
60721	2Q1	29.1999999999999993	0.0129999999999999994
60721	P1	70.5999999999999943	0.164000000000000007
60721	L2	208.5	0.00300000000000000006
60721	K2	225.900000000000006	0.0299999999999999989
60721	M8	25.8000000000000007	0.00300000000000000006
60722	M2	200.599999999999994	0.153999999999999998
60722	S2	226.699999999999989	0.104999999999999996
60722	N2	228.199999999999989	0.0359999999999999973
60722	K1	53.8999999999999986	0.593999999999999972
60722	M4	236.900000000000006	0.0229999999999999996
60722	O1	43.2999999999999972	0.561000000000000054
60722	M6	33.8999999999999986	0.00300000000000000006
60722	MK3	179.300000000000011	0.0200000000000000004
60722	S4	6.29999999999999982	0.0100000000000000002
60722	MN4	191	0.0100000000000000002
60722	NU2	258.300000000000011	0.00300000000000000006
60722	MU2	204.699999999999989	0.00700000000000000015
60722	2N2	255.300000000000011	0.0160000000000000003
60722	OO1	36.5	0.0330000000000000016
60722	LDA2	194.699999999999989	0.0100000000000000002
60722	S1	168.5	0.0589999999999999969
60722	M1	100	0.0200000000000000004
60722	J1	75.7999999999999972	0.0259999999999999988
60722	SSA	62.1000000000000014	0.161000000000000004
60722	SA	132.699999999999989	0.23000000000000001
60722	RHO1	32.5	0.0229999999999999996
60722	Q1	33.7000000000000028	0.120999999999999996
60722	T2	162.599999999999994	0.0100000000000000002
60722	R2	233.599999999999994	0.00700000000000000015
60722	2Q1	24.1999999999999993	0.0200000000000000004
60722	P1	54.5	0.16700000000000001
60722	2SM2	293.100000000000023	0.00700000000000000015
60722	M3	281.600000000000023	0.00700000000000000015
60722	L2	185.199999999999989	0.0100000000000000002
60722	2MK3	157.5	0.0160000000000000003
60722	K2	187.400000000000006	0.0589999999999999969
60722	MS4	271.699999999999989	0.0100000000000000002
60723	M2	159.900000000000006	0.115000000000000005
60723	S2	178.699999999999989	0.0690000000000000058
60723	N2	174.099999999999994	0.0299999999999999989
60723	K1	37	0.498999999999999999
60723	M4	111.400000000000006	0.0229999999999999996
60723	O1	31.1999999999999993	0.505000000000000004
60723	M6	279.699999999999989	0.00300000000000000006
60723	S4	214.199999999999989	0.00700000000000000015
60723	NU2	174.300000000000011	0.00700000000000000015
60723	MU2	140.699999999999989	0.00300000000000000006
60723	2N2	186.199999999999989	0.00300000000000000006
60723	OO1	42.6000000000000014	0.0200000000000000004
60723	M1	34	0.0359999999999999973
60723	J1	39.6000000000000014	0.0389999999999999999
60723	SSA	57	0.194000000000000006
60723	SA	139.300000000000011	0.259000000000000008
60723	RHO1	29	0.0200000000000000004
60723	Q1	28.3999999999999986	0.0980000000000000038
60723	T2	177.800000000000011	0.00300000000000000006
60723	2Q1	25.8000000000000007	0.0129999999999999994
60723	P1	36.5	0.164000000000000007
60723	L2	145.400000000000006	0.00300000000000000006
60723	K2	180.699999999999989	0.0200000000000000004
60724	M2	199.199999999999989	0.212999999999999995
60724	S2	219.199999999999989	0.120999999999999996
60724	N2	193.300000000000011	0.0490000000000000019
60724	K1	68.7000000000000028	0.512000000000000011
60724	M4	248	0.0330000000000000016
60724	O1	48.3999999999999986	0.502000000000000002
60724	S4	322.100000000000023	0.0100000000000000002
60724	NU2	196	0.0100000000000000002
60724	S6	295.899999999999977	0.00300000000000000006
60724	MU2	176.099999999999994	0.00300000000000000006
60724	2N2	173.900000000000006	0.00300000000000000006
60724	OO1	76.7999999999999972	0.0160000000000000003
60724	M1	56.3999999999999986	0.0359999999999999973
60724	J1	72.4000000000000057	0.0330000000000000016
60724	RHO1	41.3999999999999986	0.0200000000000000004
60724	Q1	40.2999999999999972	0.0980000000000000038
60724	T2	219.199999999999989	0.00700000000000000015
60724	2Q1	33.1000000000000014	0.0129999999999999994
60724	P1	67.2000000000000028	0.171000000000000013
60724	L2	197.599999999999994	0.00300000000000000006
60724	K2	220.800000000000011	0.0330000000000000016
60724	M8	38.5	0.00300000000000000006
60725	M2	200	0.200000000000000011
60725	S2	222.699999999999989	0.115000000000000005
60725	N2	188.5	0.0519999999999999976
60725	K1	65.5999999999999943	0.515000000000000013
60725	M4	248	0.0359999999999999973
60725	O1	44.1000000000000014	0.512000000000000011
60725	M6	326.199999999999989	0.00300000000000000006
60725	S4	320.5	0.0129999999999999994
60725	NU2	190.400000000000006	0.0100000000000000002
60725	S6	212.300000000000011	0.00300000000000000006
60725	MU2	176.300000000000011	0.00300000000000000006
60725	2N2	173.099999999999994	0.00300000000000000006
60725	OO1	78.5	0.0160000000000000003
60725	M1	52.8999999999999986	0.0359999999999999973
60725	J1	70.4000000000000057	0.0359999999999999973
60725	SSA	57	0.194000000000000006
60725	SA	139.300000000000011	0.259000000000000008
60725	RHO1	36.1000000000000014	0.0200000000000000004
60725	Q1	34.8999999999999986	0.101999999999999993
60725	T2	220.699999999999989	0.00700000000000000015
60725	2Q1	26.5	0.0129999999999999994
60725	P1	64.0999999999999943	0.171000000000000013
60725	L2	205.300000000000011	0.00700000000000000015
60725	K2	224.599999999999994	0.0299999999999999989
60725	M8	320.600000000000023	0.00300000000000000006
60726	M2	206.900000000000006	0.157000000000000001
60726	S2	228.400000000000006	0.117999999999999994
60726	N2	226.5	0.0429999999999999966
60726	K1	57.6000000000000014	0.586999999999999966
60726	M4	246.599999999999994	0.0330000000000000016
60726	O1	47.1000000000000014	0.573999999999999955
60726	M6	26.3999999999999986	0.00700000000000000015
60726	MK3	184	0.0229999999999999996
60726	S4	33.3999999999999986	0.0129999999999999994
60726	MN4	205.099999999999994	0.0129999999999999994
60726	NU2	141.699999999999989	0.00700000000000000015
60726	MU2	27.3999999999999986	0.00700000000000000015
60726	2N2	134.400000000000006	0.0160000000000000003
60726	OO1	54.1000000000000014	0.0490000000000000019
60726	LDA2	4.59999999999999964	0.00300000000000000006
60726	S1	167.599999999999994	0.0850000000000000061
60726	M1	96	0.0359999999999999973
60726	J1	51.8999999999999986	0.0359999999999999973
60726	SSA	40.7000000000000028	0.262000000000000011
60726	SA	138.5	0.435999999999999999
60726	RHO1	15.5	0.0459999999999999992
60726	Q1	29.6999999999999993	0.125
60726	T2	214.699999999999989	0.0100000000000000002
60726	R2	238.400000000000006	0.00700000000000000015
60726	2Q1	8.69999999999999929	0.0100000000000000002
60726	P1	49.8999999999999986	0.190000000000000002
60726	2SM2	260.100000000000023	0.0100000000000000002
60726	M3	286.100000000000023	0.0100000000000000002
60726	L2	142.699999999999989	0.0100000000000000002
60726	2MK3	169.5	0.0229999999999999996
60726	K2	205.5	0.0359999999999999973
60726	MS4	286.699999999999989	0.0160000000000000003
60727	M2	168.800000000000011	0.117999999999999994
60727	S2	187.599999999999994	0.0919999999999999984
60727	N2	199.300000000000011	0.0259999999999999988
60727	K1	39.8999999999999986	0.563999999999999946
60727	M4	139.5	0.0299999999999999989
60727	O1	30.6999999999999993	0.525000000000000022
60727	M6	248.199999999999989	0.00300000000000000006
60727	MK3	138.599999999999994	0.0100000000000000002
60727	S4	262	0.00700000000000000015
60727	MN4	93.0999999999999943	0.0129999999999999994
60727	NU2	259.300000000000011	0.00300000000000000006
60727	MU2	161.400000000000006	0.00700000000000000015
60727	2N2	185.900000000000006	0.0100000000000000002
60727	OO1	37.8999999999999986	0.0299999999999999989
60727	LDA2	103.700000000000003	0.00300000000000000006
60727	S1	133.199999999999989	0.0490000000000000019
60727	M1	55.7000000000000028	0.0200000000000000004
60727	J1	54.2999999999999972	0.0299999999999999989
60727	SSA	57	0.194000000000000006
60727	SA	139.300000000000011	0.259000000000000008
60727	RHO1	9.69999999999999929	0.0229999999999999996
60727	Q1	17	0.117999999999999994
60727	T2	73.0999999999999943	0.00700000000000000015
60727	R2	123.599999999999994	0.00300000000000000006
60727	2Q1	352	0.0200000000000000004
60727	P1	40.5	0.143999999999999989
60727	2SM2	3.39999999999999991	0.00300000000000000006
60727	M3	308.800000000000011	0.00300000000000000006
60727	L2	185.800000000000011	0.00700000000000000015
60727	2MK3	108.599999999999994	0.0100000000000000002
60727	K2	163.800000000000011	0.0299999999999999989
60727	MS4	167.400000000000006	0.0129999999999999994
60728	M2	194.699999999999989	0.107999999999999999
60728	S2	206.599999999999994	0.0820000000000000034
60728	N2	221.099999999999994	0.0259999999999999988
60728	K1	52.3999999999999986	0.554000000000000048
60728	M4	180.099999999999994	0.0200000000000000004
60728	O1	42	0.551000000000000045
60728	MK3	187.800000000000011	0.0129999999999999994
60728	S4	341	0.00700000000000000015
60728	MN4	146.699999999999989	0.0100000000000000002
60728	NU2	315.600000000000023	0.00700000000000000015
60728	MU2	161.699999999999989	0.00700000000000000015
60728	2N2	204.599999999999994	0.0100000000000000002
60728	OO1	43.2999999999999972	0.0690000000000000058
60728	LDA2	219.199999999999989	0.00300000000000000006
60728	S1	136.900000000000006	0.0560000000000000012
60728	M1	93.5	0.0200000000000000004
60728	J1	35	0.0160000000000000003
60728	SSA	40.7000000000000028	0.262000000000000011
60728	SA	138.5	0.435999999999999999
60728	RHO1	19.6000000000000014	0.0229999999999999996
60728	Q1	30.6999999999999993	0.115000000000000005
60728	T2	136.199999999999989	0.0129999999999999994
60728	R2	239.099999999999994	0.00300000000000000006
60728	2Q1	34.2000000000000028	0.0160000000000000003
60728	P1	52.3999999999999986	0.147999999999999993
60728	2SM2	206.199999999999989	0.00300000000000000006
60728	M3	264.100000000000023	0.00300000000000000006
60728	L2	159.599999999999994	0.0129999999999999994
60728	2MK3	164.300000000000011	0.0129999999999999994
60728	K2	191.599999999999994	0.0330000000000000016
60728	MS4	191.5	0.00700000000000000015
60729	M2	205.699999999999989	0.0980000000000000038
60729	S2	216.099999999999994	0.0850000000000000061
60729	N2	238.400000000000006	0.0229999999999999996
60729	K1	58.5	0.554000000000000048
60729	M4	223.699999999999989	0.0229999999999999996
60729	O1	48.7999999999999972	0.505000000000000004
60729	M6	43	0.00300000000000000006
60729	MK3	209.400000000000006	0.0229999999999999996
60729	S4	343.600000000000023	0.00700000000000000015
60729	MN4	165.900000000000006	0.0129999999999999994
60729	NU2	308.699999999999989	0.00300000000000000006
60729	MU2	153.699999999999989	0.00300000000000000006
60729	2N2	246.199999999999989	0.0100000000000000002
60729	OO1	55.6000000000000014	0.0389999999999999999
60729	LDA2	164.699999999999989	0.00300000000000000006
60729	S1	137	0.0459999999999999992
60729	M1	105.700000000000003	0.0200000000000000004
60729	J1	82.5999999999999943	0.0299999999999999989
60729	SSA	40.7000000000000028	0.262000000000000011
60729	SA	138.5	0.435999999999999999
60729	RHO1	28.6000000000000014	0.0229999999999999996
60729	Q1	37.6000000000000014	0.104999999999999996
60729	T2	111.200000000000003	0.0100000000000000002
60729	R2	241.199999999999989	0.00700000000000000015
60729	2Q1	8.90000000000000036	0.0200000000000000004
60729	P1	60.7999999999999972	0.138000000000000012
60729	2SM2	57.1000000000000014	0.00300000000000000006
60729	M3	2	0.00300000000000000006
60729	L2	206.099999999999994	0.00700000000000000015
60729	2MK3	193.199999999999989	0.0229999999999999996
60729	K2	202.300000000000011	0.0389999999999999999
60729	MS4	275.399999999999977	0.00700000000000000015
60730	M2	210.699999999999989	0.112000000000000002
60730	S2	222.099999999999994	0.0919999999999999984
60730	N2	228	0.0299999999999999989
60730	K1	59.5	0.622999999999999998
60730	M4	202.5	0.0160000000000000003
60730	O1	48.2999999999999972	0.576999999999999957
60730	MK3	209.800000000000011	0.0200000000000000004
60730	S4	348.800000000000011	0.0100000000000000002
60730	MN4	173	0.0100000000000000002
60730	NU2	225.699999999999989	0.00700000000000000015
60730	MU2	195.400000000000006	0.0129999999999999994
60730	2N2	230.900000000000006	0.0129999999999999994
60730	OO1	50.1000000000000014	0.0519999999999999976
60730	S1	128.300000000000011	0.0719999999999999946
60730	M1	53.8999999999999986	0.0389999999999999999
60730	J1	65.2000000000000028	0.0459999999999999992
60730	SSA	57	0.194000000000000006
60730	SA	139.300000000000011	0.259000000000000008
60730	RHO1	33.8999999999999986	0.0330000000000000016
60730	Q1	30.3999999999999986	0.138000000000000012
60730	T2	221.599999999999994	0.00700000000000000015
60730	2Q1	13.0999999999999996	0.0229999999999999996
60730	P1	63	0.161000000000000004
60730	L2	193.400000000000006	0.00700000000000000015
60730	2MK3	177.800000000000011	0.0160000000000000003
60730	K2	196.099999999999994	0.0459999999999999992
60731	M2	121.099999999999994	0.0619999999999999996
60731	S2	116.400000000000006	0.0359999999999999973
60731	N2	141.400000000000006	0.0160000000000000003
60731	K1	22	0.429999999999999993
60731	M4	337.100000000000023	0.0100000000000000002
60731	O1	13.5999999999999996	0.409999999999999976
60731	M6	9.09999999999999964	0.00300000000000000006
60731	S4	104.099999999999994	0.00300000000000000006
60731	MN4	308.699999999999989	0.00700000000000000015
60731	NU2	214.699999999999989	0.00300000000000000006
60731	MU2	124	0.00300000000000000006
60731	2N2	124.099999999999994	0.00700000000000000015
60731	OO1	34.6000000000000014	0.0129999999999999994
60731	LDA2	358.800000000000011	0.00300000000000000006
60731	S1	347.600000000000023	0.0229999999999999996
60731	M1	355.300000000000011	0.0229999999999999996
60731	J1	40	0.0259999999999999988
60731	MM	245.800000000000011	0.0490000000000000019
60731	SSA	32.3999999999999986	0.307999999999999996
60731	SA	163.900000000000006	0.394000000000000017
60731	MSF	340.100000000000023	0.0749999999999999972
60731	MF	354.800000000000011	0.0690000000000000058
60731	RHO1	351.899999999999977	0.0200000000000000004
60731	Q1	9.5	0.0919999999999999984
60731	T2	82.5999999999999943	0.00300000000000000006
60731	R2	276.899999999999977	0.00300000000000000006
60731	2Q1	354.300000000000011	0.0200000000000000004
60731	P1	16.3000000000000007	0.131000000000000005
60731	2SM2	329.899999999999977	0.00300000000000000006
60731	K2	91.7999999999999972	0.00700000000000000015
60731	MS4	342.399999999999977	0.00700000000000000015
60732	M2	116.299999999999997	0.0589999999999999969
60732	S2	108.299999999999997	0.0359999999999999973
60732	N2	137.599999999999994	0.0160000000000000003
60732	K1	18	0.456000000000000016
60732	O1	10.9000000000000004	0.443000000000000005
60732	NU2	134.699999999999989	0.00300000000000000006
60732	2N2	159	0.00300000000000000006
60732	OO1	32.8999999999999986	0.0160000000000000003
60732	S1	24.1000000000000014	0.0160000000000000003
60732	M1	28.3999999999999986	0.0160000000000000003
60732	J1	33.7999999999999972	0.0299999999999999989
60732	SSA	58	0.262000000000000011
60732	SA	159.300000000000011	0.312
60732	RHO1	0	0.0229999999999999996
60732	Q1	358.600000000000023	0.0980000000000000038
60732	T2	108.5	0.00300000000000000006
60732	2Q1	338.399999999999977	0.0160000000000000003
60732	P1	18.1000000000000014	0.131000000000000005
60732	L2	94.7999999999999972	0.00300000000000000006
60732	K2	107.599999999999994	0.0100000000000000002
60733	M2	201.400000000000006	0.0980000000000000038
60733	S2	210.099999999999994	0.0490000000000000019
60733	N2	224.800000000000011	0.0100000000000000002
60733	K1	50.2000000000000028	0.52200000000000002
60733	M4	196.300000000000011	0.0129999999999999994
60733	O1	43.5	0.48899999999999999
60733	M6	271.600000000000023	0.00300000000000000006
60733	S4	174.599999999999994	0.00300000000000000006
60733	NU2	221.599999999999994	0.00300000000000000006
60733	MU2	192.699999999999989	0.00300000000000000006
60733	OO1	57	0.0200000000000000004
60733	M1	46.8999999999999986	0.0359999999999999973
60733	J1	53.6000000000000014	0.0389999999999999999
60733	SSA	40.7000000000000028	0.262000000000000011
60733	SA	138.5	0.435999999999999999
60733	RHO1	40.6000000000000014	0.0200000000000000004
60733	Q1	40.1000000000000014	0.0950000000000000011
60733	T2	209.800000000000011	0.00300000000000000006
60733	2Q1	36.7000000000000028	0.0129999999999999994
60733	P1	49.7000000000000028	0.173999999999999988
60733	L2	178	0.00300000000000000006
60733	K2	210.800000000000011	0.0129999999999999994
60734	M2	163.699999999999989	0.0359999999999999973
60734	S2	148.800000000000011	0.0259999999999999988
60734	N2	216	0.0100000000000000002
60734	K1	49.2000000000000028	0.409999999999999976
60734	M4	35.1000000000000014	0.00700000000000000015
60734	O1	39	0.36399999999999999
60734	M6	130.300000000000011	0.00300000000000000006
60734	S4	72.4000000000000057	0.00300000000000000006
60734	NU2	217.900000000000006	0.00300000000000000006
60734	S6	50.5	0.00300000000000000006
60734	2N2	227.900000000000006	0.00300000000000000006
60734	OO1	57.2000000000000028	0.0160000000000000003
60734	M1	46.1000000000000014	0.0200000000000000004
60734	J1	57.2000000000000028	0.0259999999999999988
60734	RHO1	22.8999999999999986	0.0129999999999999994
60734	Q1	32.1000000000000014	0.0749999999999999972
60734	T2	166.300000000000011	0.00300000000000000006
60734	2Q1	29.6000000000000014	0.0100000000000000002
60734	P1	51.3999999999999986	0.135000000000000009
60734	K2	163.800000000000011	0.0100000000000000002
60735	M2	180.400000000000006	0.0229999999999999996
60735	S2	176	0.0129999999999999994
60735	N2	218.199999999999989	0.00700000000000000015
60735	K1	61.2000000000000028	0.245999999999999996
60735	M4	70.4000000000000057	0.00300000000000000006
60735	O1	45.7999999999999972	0.245999999999999996
60735	MU2	133	0.00300000000000000006
60735	2N2	182.199999999999989	0.00700000000000000015
60735	OO1	59.3999999999999986	0.00700000000000000015
60735	LDA2	313.800000000000011	0.00300000000000000006
60735	S1	334.899999999999977	0.0389999999999999999
60735	M1	109.200000000000003	0.0100000000000000002
60735	J1	39.2000000000000028	0.0100000000000000002
60735	RHO1	30.1999999999999993	0.0200000000000000004
60735	Q1	34.7999999999999972	0.0619999999999999996
60735	T2	259.300000000000011	0.00300000000000000006
60735	R2	263.399999999999977	0.00300000000000000006
60735	2Q1	36.5	0.0129999999999999994
60735	P1	51.2000000000000028	0.0589999999999999969
60735	L2	104.400000000000006	0.00300000000000000006
60735	2MK3	83.5999999999999943	0.00300000000000000006
60735	K2	191	0.0100000000000000002
60735	MS4	77	0.00300000000000000006
60736	M2	210.900000000000006	0.0660000000000000031
60736	S2	199.800000000000011	0.0389999999999999999
60736	N2	240.599999999999994	0.0160000000000000003
60736	K1	56	0.446000000000000008
60736	M4	97.2999999999999972	0.00300000000000000006
60736	O1	44.2999999999999972	0.422999999999999987
60736	M6	97.2000000000000028	0.00300000000000000006
60736	MK3	197.699999999999989	0.00300000000000000006
60736	S4	207.800000000000011	0.00300000000000000006
60736	MN4	78.5999999999999943	0.00300000000000000006
60736	MU2	244.400000000000006	0.00700000000000000015
60736	2N2	289.5	0.00700000000000000015
60736	OO1	57.7000000000000028	0.0229999999999999996
60736	LDA2	173.699999999999989	0.00300000000000000006
60736	S1	14.3000000000000007	0.0359999999999999973
60736	M1	24.3999999999999986	0.0160000000000000003
60736	J1	96.0999999999999943	0.0299999999999999989
60736	RHO1	1	0.0200000000000000004
60736	Q1	42.6000000000000014	0.0980000000000000038
60736	T2	85.4000000000000057	0.00700000000000000015
60736	R2	345.300000000000011	0.00700000000000000015
60736	2Q1	66.5	0.0299999999999999989
60736	P1	43.2000000000000028	0.143999999999999989
60736	M3	29.6000000000000014	0.00300000000000000006
60736	L2	215.199999999999989	0.00300000000000000006
60736	2MK3	36.6000000000000014	0.00300000000000000006
60736	K2	189.5	0.0129999999999999994
60736	MS4	328	0.00300000000000000006
60737	M2	125.599999999999994	0.0519999999999999976
60737	S2	99.9000000000000057	0.0389999999999999999
60737	N2	145.199999999999989	0.0160000000000000003
60737	K1	19.8999999999999986	0.429999999999999993
60737	M4	322.300000000000011	0.0100000000000000002
60737	O1	12.6999999999999993	0.422999999999999987
60737	M6	341.600000000000023	0.00300000000000000006
60737	S4	85.5999999999999943	0.00300000000000000006
60737	MN4	289.399999999999977	0.00300000000000000006
60737	NU2	158.699999999999989	0.00300000000000000006
60737	MU2	105	0.00300000000000000006
60737	2N2	145.5	0.00300000000000000006
60737	OO1	38.3999999999999986	0.0129999999999999994
60737	S1	335.899999999999977	0.0330000000000000016
60737	M1	34.5	0.0200000000000000004
60737	J1	22.6000000000000014	0.0229999999999999996
60737	SSA	52.2000000000000028	0.153999999999999998
60737	SA	145.599999999999994	0.266000000000000014
60737	RHO1	354.899999999999977	0.0160000000000000003
60737	Q1	359.5	0.0950000000000000011
60737	T2	75	0.00300000000000000006
60737	R2	161.599999999999994	0.00300000000000000006
60737	2Q1	352.800000000000011	0.0129999999999999994
60737	P1	19.1000000000000014	0.138000000000000012
60737	K2	94.4000000000000057	0.00700000000000000015
60737	MS4	329.100000000000023	0.00300000000000000006
60738	M2	123	0.0560000000000000012
60738	S2	105.5	0.0429999999999999966
60738	N2	141.800000000000011	0.0160000000000000003
60738	K1	20.6000000000000014	0.435999999999999999
60738	M4	319.600000000000023	0.00700000000000000015
60738	O1	12	0.432999999999999996
60738	M6	340.300000000000011	0.00300000000000000006
60738	S4	137	0.00300000000000000006
60738	MN4	289.699999999999989	0.00300000000000000006
60738	NU2	160.599999999999994	0.00300000000000000006
60738	S6	215.599999999999994	0.00300000000000000006
60738	MU2	97	0.00700000000000000015
60738	2N2	142.300000000000011	0.00300000000000000006
60738	OO1	35.3999999999999986	0.0200000000000000004
60738	S1	6	0.0359999999999999973
60738	M1	48.8999999999999986	0.0129999999999999994
60738	J1	12.9000000000000004	0.0200000000000000004
60738	SSA	58.2999999999999972	0.183999999999999997
60738	SA	155.199999999999989	0.262000000000000011
60738	RHO1	5.20000000000000018	0.0129999999999999994
60738	Q1	357.600000000000023	0.107999999999999999
60738	2Q1	319.699999999999989	0.0129999999999999994
60738	P1	20.6999999999999993	0.140999999999999986
60738	L2	348.399999999999977	0.00300000000000000006
60738	2MK3	342.399999999999977	0.00300000000000000006
60738	K2	90.5999999999999943	0.0100000000000000002
60738	MS4	309.300000000000011	0.00300000000000000006
60739	M2	293.100000000000023	0.0820000000000000034
60739	S2	315	0.0519999999999999976
60739	N2	325.699999999999989	0.0200000000000000004
60739	K1	96.5	0.463000000000000023
60739	M4	354.699999999999989	0.0100000000000000002
60739	O1	83.2999999999999972	0.426999999999999991
60739	MK3	11.5	0.0200000000000000004
60739	S4	166	0.00300000000000000006
60739	MN4	313.699999999999989	0.00700000000000000015
60739	NU2	336.699999999999989	0.00300000000000000006
60739	S6	238.300000000000011	0.00300000000000000006
60739	MU2	143.400000000000006	0.00300000000000000006
60739	2N2	214.900000000000006	0.00300000000000000006
60739	OO1	97.4000000000000057	0.0459999999999999992
60739	LDA2	271.899999999999977	0.00700000000000000015
60739	S1	72.4000000000000057	0.0389999999999999999
60739	M1	147.5	0.0160000000000000003
60739	J1	103.400000000000006	0.0200000000000000004
60739	MM	340.899999999999977	0.0389999999999999999
60739	SSA	63.3999999999999986	0.284999999999999976
60739	SA	167.5	0.325000000000000011
60739	MSF	32.6000000000000014	0.0299999999999999989
60739	MF	277.199999999999989	0.0259999999999999988
60739	RHO1	66.5	0.0229999999999999996
60739	Q1	67.9000000000000057	0.0889999999999999958
60739	R2	268.300000000000011	0.0100000000000000002
60739	2Q1	34	0.00700000000000000015
60739	P1	96.9000000000000057	0.135000000000000009
60739	2SM2	137.5	0.00700000000000000015
60739	L2	305.600000000000023	0.00700000000000000015
60739	2MK3	355.699999999999989	0.0200000000000000004
60739	K2	298.800000000000011	0.0519999999999999976
60740	M2	312.300000000000011	0.0950000000000000011
60740	S2	291.600000000000023	0.0459999999999999992
60740	N2	323.899999999999977	0.0200000000000000004
60740	K1	107	0.347999999999999976
60740	M4	33	0.00700000000000000015
60740	O1	80	0.33500000000000002
60740	M6	1.69999999999999996	0.00300000000000000006
60740	S4	43.5	0.00700000000000000015
60740	NU2	322.300000000000011	0.00300000000000000006
60740	S6	58.6000000000000014	0.00700000000000000015
60740	MU2	332.899999999999977	0.00300000000000000006
60740	2N2	335.600000000000023	0.00300000000000000006
60740	OO1	134	0.0129999999999999994
60740	M1	93.5999999999999943	0.0229999999999999996
60740	J1	120.400000000000006	0.0259999999999999988
60740	SSA	60.5	0.190000000000000002
60740	SA	146.699999999999989	0.404000000000000026
60740	RHO1	68.4000000000000057	0.0129999999999999994
60740	Q1	66.5999999999999943	0.0660000000000000031
60740	T2	292.5	0.00300000000000000006
60740	2Q1	53.2000000000000028	0.0100000000000000002
60740	P1	105	0.115000000000000005
60740	L2	300.600000000000023	0.00300000000000000006
60740	K2	290	0.0129999999999999994
60741	M2	314.399999999999977	0.0589999999999999969
60741	S2	280.699999999999989	0.0299999999999999989
60741	N2	335.300000000000011	0.0160000000000000003
60741	K1	108.299999999999997	0.20699999999999999
60741	M4	14.1999999999999993	0.00300000000000000006
60741	O1	85.5	0.23899999999999999
60741	M6	126.400000000000006	0.00700000000000000015
60741	S4	22.6999999999999993	0.0100000000000000002
60741	NU2	332.5	0.00300000000000000006
60741	S6	90.5	0.00700000000000000015
60741	2N2	356.199999999999989	0.00300000000000000006
60741	OO1	131.199999999999989	0.0100000000000000002
60741	M1	97	0.0160000000000000003
60741	J1	119.700000000000003	0.0200000000000000004
60741	SSA	44.8999999999999986	0.248999999999999999
60741	SA	147.400000000000006	0.331000000000000016
60741	RHO1	75.5999999999999943	0.0100000000000000002
60741	Q1	74.0999999999999943	0.0459999999999999992
60741	T2	282	0.00300000000000000006
60741	2Q1	62.7999999999999972	0.00700000000000000015
60741	P1	106.599999999999994	0.0690000000000000058
60741	L2	293.600000000000023	0.00300000000000000006
60741	K2	278	0.00700000000000000015
60742	M2	229	0.0359999999999999973
60742	S2	12	0.0690000000000000058
60742	N2	147.5	0.0229999999999999996
60742	K1	103.900000000000006	0.366999999999999993
60742	M4	8.90000000000000036	0.0160000000000000003
60742	O1	95	0.409999999999999976
60742	M6	293.800000000000011	0.00700000000000000015
60742	S4	144.400000000000006	0.00300000000000000006
60742	NU2	158.400000000000006	0.00300000000000000006
60742	S6	27.3000000000000007	0.00300000000000000006
60742	2N2	66	0.00300000000000000006
60742	OO1	112.700000000000003	0.0160000000000000003
60742	M1	99.5	0.0299999999999999989
60742	J1	108.200000000000003	0.0330000000000000016
60742	RHO1	91.2999999999999972	0.0160000000000000003
60742	Q1	90.7000000000000028	0.0790000000000000008
60742	T2	6.29999999999999982	0.00300000000000000006
60742	2Q1	86.2999999999999972	0.0100000000000000002
60742	P1	103.200000000000003	0.120999999999999996
60742	K2	23.6000000000000014	0.0200000000000000004
60742	M8	320.899999999999977	0.00300000000000000006
60743	M2	169.400000000000006	0.0429999999999999966
60743	K1	47	0.381000000000000005
60743	O1	40.2999999999999972	0.373999999999999999
60743	OO1	53.7000000000000028	0.0160000000000000003
60743	M1	43.7000000000000028	0.0259999999999999988
60743	J1	50.3999999999999986	0.0299999999999999989
60743	SSA	34.8999999999999986	0.245999999999999996
60743	SA	152.400000000000006	0.256000000000000005
60743	RHO1	37.3999999999999986	0.0129999999999999994
60743	Q1	29.6999999999999993	0.0790000000000000008
60743	P1	48.7999999999999972	0.112000000000000002
60744	M2	163	0.0429999999999999966
60744	S2	154.599999999999994	0.0229999999999999996
60744	N2	176.099999999999994	0.0160000000000000003
60744	K1	37.3999999999999986	0.373999999999999999
60744	O1	30.8000000000000007	0.373999999999999999
60744	NU2	174.199999999999989	0.00300000000000000006
60744	2N2	189.099999999999994	0.00300000000000000006
60744	OO1	33.5	0.0200000000000000004
60744	S1	4.59999999999999964	0.0160000000000000003
60744	M1	42.1000000000000014	0.0160000000000000003
60744	J1	41.2000000000000028	0.0200000000000000004
60744	SSA	49.7000000000000028	0.197000000000000008
60744	SA	149.699999999999989	0.284999999999999976
60744	RHO1	17.3000000000000007	0.0160000000000000003
60744	Q1	19.1999999999999993	0.0820000000000000034
60744	2Q1	3.60000000000000009	0.0100000000000000002
60744	P1	37.2000000000000028	0.117999999999999994
60744	L2	149.800000000000011	0.00300000000000000006
60744	K2	153.800000000000011	0.00700000000000000015
60745	M2	197.900000000000006	0.0200000000000000004
60745	S2	172.199999999999989	0.0160000000000000003
60745	N2	213.900000000000006	0.00700000000000000015
60745	K1	52.8999999999999986	0.33500000000000002
60745	M4	52.7000000000000028	0.00700000000000000015
60745	O1	45.7000000000000028	0.318000000000000005
60745	MK3	193.300000000000011	0.0100000000000000002
60745	S4	178.599999999999994	0.00300000000000000006
60745	MN4	17.8999999999999986	0.00300000000000000006
60745	MU2	166.400000000000006	0.00300000000000000006
60745	2N2	266	0.0100000000000000002
60745	OO1	62.1000000000000014	0.0200000000000000004
60745	S1	357.100000000000023	0.0160000000000000003
60745	M1	88.5	0.0200000000000000004
60745	J1	39	0.0129999999999999994
60745	SSA	49.7000000000000028	0.197000000000000008
60745	SA	149.699999999999989	0.284999999999999976
60745	RHO1	11.5	0.0160000000000000003
60745	Q1	28.3000000000000007	0.0719999999999999946
60745	R2	248.199999999999989	0.00300000000000000006
60745	2Q1	72.2999999999999972	0.0129999999999999994
60745	P1	50.6000000000000014	0.0980000000000000038
60745	2SM2	203.599999999999994	0.00300000000000000006
60745	M3	76.0999999999999943	0.00300000000000000006
60745	L2	331.699999999999989	0.00300000000000000006
60745	2MK3	186.199999999999989	0.0100000000000000002
60745	K2	190	0.0100000000000000002
60745	MS4	30.5	0.00300000000000000006
60746	M2	233	0.0100000000000000002
60746	S2	187.599999999999994	0.0129999999999999994
60746	N2	259.300000000000011	0.00700000000000000015
60746	K1	65.2999999999999972	0.298999999999999988
60746	M4	102.200000000000003	0.00700000000000000015
60746	O1	56.2999999999999972	0.288999999999999979
60746	M6	197.099999999999994	0.00300000000000000006
60746	MK3	244	0.0160000000000000003
60746	MN4	57.2000000000000028	0.00300000000000000006
60746	NU2	336.5	0.00300000000000000006
60746	2N2	42	0.0129999999999999994
60746	OO1	54.2999999999999972	0.0200000000000000004
60746	S1	239.300000000000011	0.00300000000000000006
60746	M1	235.900000000000006	0.00300000000000000006
60746	J1	69.0999999999999943	0.00700000000000000015
60746	MM	320.399999999999977	0.117999999999999994
60746	SSA	95.5	0.117999999999999994
60746	SA	151.300000000000011	0.187
60746	MSF	9.59999999999999964	0.0259999999999999988
60746	MF	302.699999999999989	0.0229999999999999996
60746	RHO1	25.1000000000000014	0.0100000000000000002
60746	Q1	39.2999999999999972	0.0690000000000000058
60746	T2	25	0.00300000000000000006
60746	R2	107	0.00300000000000000006
60746	2Q1	313.199999999999989	0.00700000000000000015
60746	P1	69.9000000000000057	0.0820000000000000034
60746	2SM2	189.599999999999994	0.00300000000000000006
60746	L2	240.199999999999989	0.00300000000000000006
60746	2MK3	224.5	0.0160000000000000003
60746	K2	206.099999999999994	0.0129999999999999994
60747	M2	159.599999999999994	0.0459999999999999992
60747	S2	148.599999999999994	0.0259999999999999988
60747	N2	161.099999999999994	0.0129999999999999994
60747	K1	42.1000000000000014	0.343999999999999972
60747	M4	338.699999999999989	0.00700000000000000015
60747	O1	34.6000000000000014	0.338000000000000023
60747	M6	31.1999999999999993	0.00300000000000000006
60747	MK3	180.900000000000006	0.00700000000000000015
60747	S4	116.900000000000006	0.00300000000000000006
60747	MN4	332.399999999999977	0.00300000000000000006
60747	MU2	147.800000000000011	0.00300000000000000006
60747	2N2	155.800000000000011	0.00700000000000000015
60747	OO1	38.7999999999999972	0.0200000000000000004
60747	S1	32.5	0.00700000000000000015
60747	M1	61.1000000000000014	0.0100000000000000002
60747	J1	33.7000000000000028	0.0160000000000000003
60747	SSA	49.7000000000000028	0.197000000000000008
60747	SA	149.699999999999989	0.284999999999999976
60747	RHO1	2.39999999999999991	0.0100000000000000002
60747	Q1	16.1999999999999993	0.0820000000000000034
60747	R2	48.2000000000000028	0.00300000000000000006
60747	2Q1	301.899999999999977	0.00700000000000000015
60747	P1	41.6000000000000014	0.104999999999999996
60747	2SM2	270.5	0.00300000000000000006
60747	L2	171.699999999999989	0.00300000000000000006
60747	2MK3	187.900000000000006	0.00700000000000000015
60747	K2	266.199999999999989	0.00300000000000000006
60747	MS4	332.5	0.00300000000000000006
60748	M2	281.699999999999989	0.00300000000000000006
60748	S2	288.699999999999989	0.00700000000000000015
60748	K1	146.900000000000006	0.0690000000000000058
60748	O1	135.800000000000011	0.0719999999999999946
60748	MK3	111.799999999999997	0.00300000000000000006
60748	2N2	87.2999999999999972	0.00700000000000000015
60748	OO1	138	0.00700000000000000015
60748	S1	229.699999999999989	0.00700000000000000015
60748	M1	275.300000000000011	0.00300000000000000006
60748	J1	180.900000000000006	0.00300000000000000006
60748	SSA	49.7000000000000028	0.197000000000000008
60748	SA	149.699999999999989	0.284999999999999976
60748	RHO1	106	0.00300000000000000006
60748	Q1	132.699999999999989	0.0160000000000000003
60748	2Q1	217.900000000000006	0.00700000000000000015
60748	P1	140.599999999999994	0.0229999999999999996
60748	L2	159.300000000000011	0.00300000000000000006
60748	2MK3	115.700000000000003	0.00300000000000000006
60748	K2	354.300000000000011	0.00300000000000000006
60749	M2	49.6000000000000014	0.0100000000000000002
60749	S2	327.100000000000023	0.00700000000000000015
60749	K1	190.5	0.120999999999999996
60749	O1	176.400000000000006	0.117999999999999994
60749	MK3	219.199999999999989	0.00300000000000000006
60749	S4	207.199999999999989	0.00300000000000000006
60749	OO1	199.699999999999989	0.0129999999999999994
60749	S1	147.800000000000011	0.0160000000000000003
60749	M1	263.100000000000023	0.00700000000000000015
60749	SSA	44.8999999999999986	0.248999999999999999
60749	SA	147.400000000000006	0.331000000000000016
60749	RHO1	135.400000000000006	0.00700000000000000015
60749	Q1	156.900000000000006	0.0229999999999999996
60749	T2	260.399999999999977	0.00300000000000000006
60749	P1	190.599999999999994	0.0259999999999999988
60749	K2	72.0999999999999943	0.00700000000000000015
60750	M2	174.599999999999994	0.0589999999999999969
60750	S2	170.5	0.0259999999999999988
60750	N2	178.300000000000011	0.0200000000000000004
60750	K1	30.3000000000000007	0.432999999999999996
60750	M4	7.09999999999999964	0.0100000000000000002
60750	O1	22.6999999999999993	0.422999999999999987
60750	M6	50.2000000000000028	0.00300000000000000006
60750	MK3	131.699999999999989	0.00300000000000000006
60750	S4	108.5	0.00300000000000000006
60750	MN4	331.199999999999989	0.00700000000000000015
60750	NU2	196.900000000000006	0.00700000000000000015
60750	S6	15	0.00300000000000000006
60750	MU2	141.099999999999994	0.00700000000000000015
60750	2N2	122.700000000000003	0.00700000000000000015
60750	OO1	36.3999999999999986	0.0229999999999999996
60750	LDA2	6.70000000000000018	0.00300000000000000006
60750	S1	342.800000000000011	0.0160000000000000003
60750	M1	41.7999999999999972	0.0259999999999999988
60750	J1	32.2000000000000028	0.0299999999999999989
60750	MM	191.5	0.0719999999999999946
60750	SSA	45.2000000000000028	0.173999999999999988
60750	SA	174.5	0.343999999999999972
60750	MSF	152.699999999999989	0.0100000000000000002
60750	MF	354.100000000000023	0.0100000000000000002
60750	RHO1	15.5999999999999996	0.0259999999999999988
60750	Q1	1.60000000000000009	0.0889999999999999958
60750	T2	127	0.00300000000000000006
60750	R2	345.800000000000011	0.00300000000000000006
60750	2Q1	341.399999999999977	0.00700000000000000015
60750	P1	30	0.135000000000000009
60750	2MK3	122.299999999999997	0.00300000000000000006
60750	K2	122.799999999999997	0.00300000000000000006
60750	MS4	351.899999999999977	0.00300000000000000006
60751	M2	284	0.0389999999999999999
60751	S2	283.800000000000011	0.0160000000000000003
60751	N2	303.199999999999989	0.0100000000000000002
60751	K1	80.7000000000000028	0.269000000000000017
60751	M4	162.400000000000006	0.00300000000000000006
60751	O1	72.2999999999999972	0.269000000000000017
60751	MK3	274.100000000000023	0.0129999999999999994
60751	MN4	172.300000000000011	0.00300000000000000006
60751	MU2	97.7000000000000028	0.00300000000000000006
60751	2N2	322.300000000000011	0.0100000000000000002
60751	OO1	61.1000000000000014	0.0229999999999999996
60751	LDA2	335.899999999999977	0.00300000000000000006
60751	S1	320.300000000000011	0.0129999999999999994
60751	M1	169.300000000000011	0.0160000000000000003
60751	J1	118.400000000000006	0.0129999999999999994
60751	SSA	49.7000000000000028	0.197000000000000008
60751	SA	149.699999999999989	0.284999999999999976
60751	RHO1	60.2999999999999972	0.0100000000000000002
60751	Q1	68.5999999999999943	0.0519999999999999976
60751	T2	169.800000000000011	0.00300000000000000006
60751	R2	221.400000000000006	0.00300000000000000006
60751	2Q1	100.099999999999994	0.0160000000000000003
60751	P1	85	0.0850000000000000061
60751	2SM2	213.5	0.00300000000000000006
60751	M3	311.100000000000023	0.00300000000000000006
60751	L2	263.699999999999989	0.00300000000000000006
60751	2MK3	263.100000000000023	0.0129999999999999994
60751	K2	270.399999999999977	0.0100000000000000002
60751	MS4	145	0.00300000000000000006
60752	M2	49.7000000000000028	0.0129999999999999994
60752	S2	357.300000000000011	0.0100000000000000002
60752	N2	33.8999999999999986	0.00300000000000000006
60752	K1	132.800000000000011	0.164000000000000007
60752	M4	345.199999999999989	0.00300000000000000006
60752	O1	121.099999999999994	0.147999999999999993
60752	MK3	53.8999999999999986	0.0100000000000000002
60752	NU2	56.5	0.00300000000000000006
60752	MU2	175.599999999999994	0.00300000000000000006
60752	2N2	157.5	0.0100000000000000002
60752	OO1	124.799999999999997	0.0160000000000000003
60752	LDA2	229.400000000000006	0.00300000000000000006
60752	S1	276.100000000000023	0.0429999999999999966
60752	M1	339	0.0129999999999999994
60752	J1	295.899999999999977	0.00700000000000000015
60752	RHO1	114.200000000000003	0.0100000000000000002
60752	Q1	105.599999999999994	0.0299999999999999989
60752	T2	139.199999999999989	0.00300000000000000006
60752	R2	271.5	0.00300000000000000006
60752	2Q1	303.199999999999989	0.0129999999999999994
60752	P1	140.599999999999994	0.0259999999999999988
60752	2SM2	332.399999999999977	0.00300000000000000006
60752	L2	29.1000000000000014	0.00300000000000000006
60752	2MK3	41.6000000000000014	0.0129999999999999994
60752	K2	338.5	0.0100000000000000002
60753	M2	251.5	0.0389999999999999999
60753	S2	238.199999999999989	0.00700000000000000015
60753	N2	252.199999999999989	0.0200000000000000004
60753	K1	46.7999999999999972	0.456000000000000016
60753	M4	129.599999999999994	0.00300000000000000006
60753	O1	35.6000000000000014	0.429999999999999993
60753	M6	37.3999999999999986	0.00300000000000000006
60753	MK3	197.699999999999989	0.0100000000000000002
60753	MN4	55.3999999999999986	0.00300000000000000006
60753	NU2	267.5	0.00700000000000000015
60753	MU2	79.2000000000000028	0.00700000000000000015
60753	2N2	24.5	0.0129999999999999994
60753	OO1	44	0.0259999999999999988
60753	LDA2	195.099999999999994	0.00700000000000000015
60753	S1	299.899999999999977	0.0459999999999999992
60753	M1	108.799999999999997	0.00700000000000000015
60753	J1	50.7999999999999972	0.0129999999999999994
60753	SSA	49.7000000000000028	0.197000000000000008
60753	SA	149.699999999999989	0.284999999999999976
60753	RHO1	23.6999999999999993	0.0200000000000000004
60753	Q1	23.3000000000000007	0.0980000000000000038
60753	T2	127.099999999999994	0.00300000000000000006
60753	R2	90.7000000000000028	0.00700000000000000015
60753	2Q1	343.199999999999989	0.00300000000000000006
60753	P1	43.7999999999999972	0.125
60753	2SM2	23	0.00300000000000000006
60753	M3	34.2000000000000028	0.00700000000000000015
60753	L2	216.5	0.00300000000000000006
60753	2MK3	180.5	0.00700000000000000015
60753	K2	196.099999999999994	0.0200000000000000004
60753	M8	176.699999999999989	0.00300000000000000006
60753	MS4	161.199999999999989	0.00300000000000000006
60754	M2	42.2000000000000028	0.00700000000000000015
60754	S2	45	0.0100000000000000002
60754	K1	195.400000000000006	0.115000000000000005
60754	M4	141.900000000000006	0.00300000000000000006
60754	O1	178.900000000000006	0.104999999999999996
60754	MK3	221.699999999999989	0.00300000000000000006
60754	NU2	257.5	0.00300000000000000006
60754	2N2	93.7999999999999972	0.00300000000000000006
60754	OO1	198.5	0.0129999999999999994
60754	S1	280.699999999999989	0.0100000000000000002
60754	J1	246.300000000000011	0.00300000000000000006
60754	SSA	60.5	0.190000000000000002
60754	SA	146.699999999999989	0.404000000000000026
60754	RHO1	139.400000000000006	0.00300000000000000006
60754	Q1	157.599999999999994	0.0200000000000000004
60754	T2	11.0999999999999996	0.00300000000000000006
60754	2Q1	187.300000000000011	0.00300000000000000006
60754	P1	188	0.0299999999999999989
60754	2MK3	223.5	0.00300000000000000006
60754	K2	66.9000000000000057	0.00700000000000000015
60755	M2	192.400000000000006	0.00300000000000000006
60755	S2	3.10000000000000009	0.0129999999999999994
60755	N2	223.699999999999989	0.00300000000000000006
60755	K1	186.800000000000011	0.153999999999999998
60755	M4	47.3999999999999986	0.0129999999999999994
60755	O1	176.199999999999989	0.150999999999999995
60755	M6	195.699999999999989	0.00700000000000000015
60755	S4	140.400000000000006	0.00300000000000000006
60755	S6	105.700000000000003	0.0129999999999999994
60755	OO1	197.300000000000011	0.00700000000000000015
60755	M1	181.5	0.0100000000000000002
60755	J1	192	0.0129999999999999994
60755	SSA	44.8999999999999986	0.248999999999999999
60755	SA	147.400000000000006	0.331000000000000016
60755	RHO1	171.699999999999989	0.00700000000000000015
60755	Q1	171	0.0299999999999999989
60755	2Q1	165.800000000000011	0.00300000000000000006
60755	P1	186	0.0519999999999999976
60755	K2	16.8999999999999986	0.00300000000000000006
60755	M8	44.1000000000000014	0.0100000000000000002
60756	M2	194.699999999999989	0.0790000000000000008
60756	S2	159.400000000000006	0.0330000000000000016
60756	N2	183.699999999999989	0.0330000000000000016
60756	K1	24.1999999999999993	0.463000000000000023
60756	M4	35.6000000000000014	0.0100000000000000002
60756	O1	17.5	0.416999999999999982
60756	M6	82	0.0100000000000000002
60756	S4	245.5	0.00300000000000000006
60756	NU2	185.599999999999994	0.00700000000000000015
60756	S6	135.800000000000011	0.00300000000000000006
60756	MU2	219.800000000000011	0.00300000000000000006
60756	2N2	174.900000000000006	0.00300000000000000006
60756	OO1	30.3999999999999986	0.0200000000000000004
60756	M1	20.8000000000000007	0.0299999999999999989
60756	J1	27.3999999999999986	0.0330000000000000016
60756	SSA	45.2000000000000028	0.173999999999999988
60756	SA	174.5	0.343999999999999972
60756	RHO1	14.5999999999999996	0.0160000000000000003
60756	Q1	14.1999999999999993	0.0820000000000000034
60756	T2	161.800000000000011	0.00300000000000000006
60756	2Q1	10.9000000000000004	0.0100000000000000002
60756	P1	23.6000000000000014	0.153999999999999998
60756	L2	205	0.00300000000000000006
60756	K2	157.699999999999989	0.0100000000000000002
60756	M8	228.199999999999989	0.00300000000000000006
60757	M2	252	0.0619999999999999996
60757	S2	238.5	0.0259999999999999988
60757	N2	241.800000000000011	0.0200000000000000004
60757	K1	54.7000000000000028	0.360999999999999988
60757	O1	49.2999999999999972	0.360999999999999988
60757	OO1	48.7999999999999972	0.0389999999999999999
60757	S1	298.100000000000023	0.0129999999999999994
60757	SSA	49.7000000000000028	0.197000000000000008
60757	SA	149.699999999999989	0.284999999999999976
60757	MF	339.300000000000011	0.0359999999999999973
60757	Q1	23.6000000000000014	0.0690000000000000058
60757	P1	52	0.101999999999999993
60757	K2	229.5	0.0160000000000000003
60758	M2	222.400000000000006	0.173999999999999988
60758	S2	215.800000000000011	0.0690000000000000058
60758	N2	214	0.0589999999999999969
60758	K1	26.3000000000000007	0.498999999999999999
60758	M4	126.200000000000003	0.0229999999999999996
60758	O1	21.6999999999999993	0.466000000000000025
60758	M6	256.399999999999977	0.00700000000000000015
60758	MK3	310.600000000000023	0.00700000000000000015
60758	S4	198.900000000000006	0.00700000000000000015
60758	MN4	108.5	0.0100000000000000002
60758	NU2	246.900000000000006	0.00700000000000000015
60758	2N2	198.199999999999989	0.0129999999999999994
60758	OO1	71.0999999999999943	0.0330000000000000016
60758	LDA2	327.600000000000023	0.00700000000000000015
60758	S1	215.699999999999989	0.0129999999999999994
60758	M1	55.7000000000000028	0.0229999999999999996
60758	J1	30.8000000000000007	0.0330000000000000016
60758	RHO1	297.600000000000023	0.0229999999999999996
60758	Q1	12.4000000000000004	0.0889999999999999958
60758	R2	30.8999999999999986	0.0100000000000000002
60758	2Q1	355.399999999999977	0.0259999999999999988
60758	P1	23.8000000000000007	0.157000000000000001
60758	M3	195	0.0129999999999999994
60758	2MK3	279.899999999999977	0.00700000000000000015
60758	K2	244.400000000000006	0.0129999999999999994
60758	MS4	158.400000000000006	0.00700000000000000015
60759	M2	16.3000000000000007	0.115000000000000005
60759	S2	15	0.0359999999999999973
60759	N2	353.300000000000011	0.0330000000000000016
60759	K1	82.9000000000000057	0.164000000000000007
60759	M4	4.59999999999999964	0.0100000000000000002
60759	O1	74.4000000000000057	0.164000000000000007
60759	M6	295.399999999999977	0.00300000000000000006
60759	MK3	35.3999999999999986	0.0200000000000000004
60759	S4	138	0.00300000000000000006
60759	MN4	333.600000000000023	0.00700000000000000015
60759	NU2	308.100000000000023	0.00700000000000000015
60759	MU2	232.300000000000011	0.0100000000000000002
60759	2N2	277.399999999999977	0.0200000000000000004
60759	OO1	88.7000000000000028	0.0129999999999999994
60759	LDA2	358.600000000000023	0.00700000000000000015
60759	S1	36.8999999999999986	0.0690000000000000058
60759	M1	81.9000000000000057	0.0100000000000000002
60759	J1	349.600000000000023	0.00700000000000000015
60759	RHO1	65.4000000000000057	0.0100000000000000002
60759	Q1	59.1000000000000014	0.0389999999999999999
60759	T2	152.699999999999989	0.0160000000000000003
60759	R2	39.7000000000000028	0.0160000000000000003
60759	2Q1	286.5	0.00700000000000000015
60759	P1	76.5	0.0359999999999999973
60759	2SM2	64.2999999999999972	0.00300000000000000006
60759	M3	78.0999999999999943	0.00700000000000000015
60759	L2	95.5999999999999943	0.0129999999999999994
60759	2MK3	26.3000000000000007	0.0259999999999999988
60759	K2	321.800000000000011	0.0100000000000000002
60759	MS4	8.5	0.00700000000000000015
60760	M2	356.899999999999977	0.0850000000000000061
60760	S2	348.399999999999977	0.0330000000000000016
60760	N2	335.699999999999989	0.0259999999999999988
60760	K1	75.7999999999999972	0.138000000000000012
60760	M4	325	0.00700000000000000015
60760	O1	68.2000000000000028	0.128000000000000003
60760	MK3	11.5999999999999996	0.0129999999999999994
60760	MN4	279.899999999999977	0.00300000000000000006
60760	NU2	353	0.0100000000000000002
60760	MU2	238.199999999999989	0.00300000000000000006
60760	2N2	334	0.00700000000000000015
60760	OO1	94.5999999999999943	0.00300000000000000006
60760	S1	296.399999999999977	0.0330000000000000016
60760	M1	116.799999999999997	0.00700000000000000015
60760	J1	85.7999999999999972	0.00700000000000000015
60760	SSA	108.799999999999997	0.284999999999999976
60760	SA	36.7999999999999972	1.02000000000000002
60760	RHO1	38.8999999999999986	0.00700000000000000015
60760	Q1	53.7000000000000028	0.0229999999999999996
60760	T2	82.9000000000000057	0.0100000000000000002
60760	R2	54.7000000000000028	0.0129999999999999994
60760	2Q1	75.5999999999999943	0.00300000000000000006
60760	P1	76.7000000000000028	0.0359999999999999973
60760	2SM2	134.900000000000006	0.00300000000000000006
60760	M3	335.699999999999989	0.00300000000000000006
60760	L2	32.1000000000000014	0.00300000000000000006
60760	2MK3	3.60000000000000009	0.0129999999999999994
60760	K2	311.800000000000011	0.0129999999999999994
60760	MS4	311.5	0.00300000000000000006
60761	M2	285.199999999999989	0.284999999999999976
60761	S2	282.100000000000023	0.101999999999999993
60761	N2	265.399999999999977	0.0790000000000000008
60761	K1	39.5	0.432999999999999996
60761	M4	209.800000000000011	0.0129999999999999994
60761	O1	33.7000000000000028	0.377000000000000002
60761	M6	36.8999999999999986	0.00300000000000000006
60761	MK3	271.399999999999977	0.0200000000000000004
60761	S4	15.0999999999999996	0.00700000000000000015
60761	MN4	160.800000000000011	0.00700000000000000015
60761	NU2	270.800000000000011	0.0160000000000000003
60761	MU2	175.800000000000011	0.0129999999999999994
60761	2N2	268.699999999999989	0.0129999999999999994
60761	OO1	73.2000000000000028	0.0160000000000000003
60761	LDA2	244.599999999999994	0.00300000000000000006
60761	S1	270.899999999999977	0.0299999999999999989
60761	M1	87.7999999999999972	0.0200000000000000004
60761	J1	42.5	0.0200000000000000004
60761	SSA	60.5	0.115000000000000005
60761	SA	103.400000000000006	0.381000000000000005
60761	RHO1	359.100000000000023	0.0129999999999999994
60761	Q1	19.1999999999999993	0.0719999999999999946
60761	R2	26.3000000000000007	0.0160000000000000003
60761	2Q1	15.6999999999999993	0.0160000000000000003
60761	P1	30.3000000000000007	0.128000000000000003
60761	2SM2	76.9000000000000057	0.00700000000000000015
60761	M3	255.5	0.0129999999999999994
60761	L2	328.899999999999977	0.0100000000000000002
60761	2MK3	267.100000000000023	0.0259999999999999988
60761	K2	254.099999999999994	0.0229999999999999996
60761	MS4	200.400000000000006	0.00300000000000000006
60762	M2	256.800000000000011	0.33500000000000002
60762	S2	254.199999999999989	0.117999999999999994
60762	N2	209.199999999999989	0.117999999999999994
60762	K1	28.5	0.515000000000000013
60762	M4	189.599999999999994	0.0330000000000000016
60762	O1	20.3000000000000007	0.485999999999999988
60762	M6	312.399999999999977	0.00700000000000000015
60762	S4	159.099999999999994	0.0100000000000000002
60762	NU2	215.599999999999994	0.0229999999999999996
60762	S6	233.599999999999994	0.00700000000000000015
60762	MU2	76.5	0.0100000000000000002
60762	2N2	161.699999999999989	0.0160000000000000003
60762	OO1	36.7999999999999972	0.0200000000000000004
60762	LDA2	255.599999999999994	0.00300000000000000006
60762	M1	24.5	0.0359999999999999973
60762	J1	32.6000000000000014	0.0389999999999999999
60762	RHO1	16.8000000000000007	0.0200000000000000004
60762	Q1	16.1999999999999993	0.0950000000000000011
60762	T2	254.300000000000011	0.00700000000000000015
60762	2Q1	12.0999999999999996	0.0129999999999999994
60762	P1	27.8999999999999986	0.171000000000000013
60762	L2	304.300000000000011	0.0100000000000000002
60762	K2	254	0.0330000000000000016
60762	M8	205.599999999999994	0.00300000000000000006
60763	M2	253.699999999999989	0.343999999999999972
60763	S2	252.099999999999994	0.131000000000000005
60763	N2	226.800000000000011	0.0850000000000000061
60763	K1	22.6000000000000014	0.494999999999999996
60763	M4	197.099999999999994	0.0330000000000000016
60763	O1	21.8999999999999986	0.429999999999999993
60763	M6	260.5	0.00300000000000000006
60763	S4	359.399999999999977	0.00700000000000000015
60763	NU2	230.300000000000011	0.0160000000000000003
60763	S6	196.800000000000011	0.00300000000000000006
60763	MU2	256.199999999999989	0.00700000000000000015
60763	2N2	200	0.0100000000000000002
60763	OO1	23.5	0.0200000000000000004
60763	LDA2	252.699999999999989	0.00300000000000000006
60763	M1	22.3000000000000007	0.0299999999999999989
60763	J1	23.1000000000000014	0.0330000000000000016
60763	SSA	60.5	0.115000000000000005
60763	SA	103.400000000000006	0.381000000000000005
60763	RHO1	21.3000000000000007	0.0160000000000000003
60763	Q1	21.5	0.0850000000000000061
60763	T2	253.199999999999989	0.00700000000000000015
60763	2Q1	21.1999999999999993	0.0100000000000000002
60763	P1	22.5	0.164000000000000007
60763	L2	281.199999999999989	0.0100000000000000002
60763	K2	251.800000000000011	0.0359999999999999973
60763	M8	213.900000000000006	0.00300000000000000006
60764	M2	1.39999999999999991	0.248999999999999999
60764	S2	18.3999999999999986	0.0790000000000000008
60764	N2	6.09999999999999964	0.0820000000000000034
60764	K1	87.4000000000000057	0.531000000000000028
60764	M4	218.400000000000006	0.0160000000000000003
60764	O1	84	0.419999999999999984
60764	NU2	5.5	0.0160000000000000003
60764	S6	205	0.0100000000000000002
60764	2N2	10.8000000000000007	0.0100000000000000002
60764	OO1	90.7000000000000028	0.0160000000000000003
60764	M1	85.7000000000000028	0.0299999999999999989
60764	J1	89	0.0330000000000000016
60764	SSA	298.399999999999977	0.0950000000000000011
60764	SA	102.099999999999994	0.435999999999999999
60764	RHO1	82.5	0.0160000000000000003
60764	Q1	82.2999999999999972	0.0820000000000000034
60764	2Q1	80.5999999999999943	0.0100000000000000002
60764	P1	87.0999999999999943	0.176999999999999991
60764	K2	19.8000000000000007	0.0200000000000000004
60764	M8	36	0.0100000000000000002
60765	M2	351.699999999999989	0.23000000000000001
60765	S2	358.600000000000023	0.0950000000000000011
60765	N2	343.600000000000023	0.0389999999999999999
60765	K1	78	0.412999999999999978
60765	M4	189.199999999999989	0.0100000000000000002
60765	O1	69.2999999999999972	0.419999999999999984
60765	M6	33.7000000000000028	0.00300000000000000006
60765	S4	143.900000000000006	0.00300000000000000006
60765	NU2	344.600000000000023	0.00700000000000000015
60765	MU2	161	0.00700000000000000015
60765	2N2	335.5	0.00700000000000000015
60765	OO1	86.7000000000000028	0.0200000000000000004
60765	LDA2	354.899999999999977	0.00300000000000000006
60765	M1	73.7000000000000028	0.0299999999999999989
60765	J1	82.2999999999999972	0.0330000000000000016
60765	RHO1	65.5999999999999943	0.0160000000000000003
60765	Q1	65	0.0820000000000000034
60765	T2	358.300000000000011	0.00700000000000000015
60765	2Q1	60.7000000000000028	0.0100000000000000002
60765	P1	77.2999999999999972	0.138000000000000012
60765	L2	359.800000000000011	0.00700000000000000015
60765	K2	359.100000000000023	0.0259999999999999988
60765	M8	277.899999999999977	0.00300000000000000006
60766	M2	245.900000000000006	0.429999999999999993
60766	S2	236.400000000000006	0.143999999999999989
60766	N2	223.199999999999989	0.117999999999999994
60766	K1	22.6999999999999993	0.54500000000000004
60766	M4	34.5	0.0160000000000000003
60766	O1	15.9000000000000004	0.491999999999999993
60766	M6	300.899999999999977	0.00700000000000000015
60766	S4	223.099999999999994	0.00700000000000000015
60766	MN4	356.800000000000011	0.0100000000000000002
60766	NU2	238.400000000000006	0.0259999999999999988
60766	S6	264.5	0.00300000000000000006
60766	MU2	177.900000000000006	0.0160000000000000003
60766	2N2	208.5	0.0200000000000000004
60766	OO1	43.6000000000000014	0.0200000000000000004
60766	LDA2	25.6999999999999993	0.0100000000000000002
60766	S1	266	0.0129999999999999994
60766	M1	50.5	0.0259999999999999988
60766	J1	26.3000000000000007	0.0359999999999999973
60766	SSA	54.7000000000000028	0.20699999999999999
60766	SA	148.300000000000011	0.328000000000000014
60766	RHO1	6.59999999999999964	0.0160000000000000003
60766	Q1	1.10000000000000009	0.104999999999999996
60766	T2	253.199999999999989	0.0129999999999999994
60766	R2	355	0.0100000000000000002
60766	2Q1	352.300000000000011	0.0129999999999999994
60766	P1	14	0.16700000000000001
60766	2SM2	299.300000000000011	0.00700000000000000015
60766	M3	190.099999999999994	0.0129999999999999994
60766	L2	312.800000000000011	0.00700000000000000015
60766	2MK3	159.099999999999994	0.0100000000000000002
60766	K2	261.5	0.0129999999999999994
60766	M8	108	0.00300000000000000006
60766	MS4	11.1999999999999993	0.00300000000000000006
60767	M2	50.7000000000000028	0.294999999999999984
60767	S2	33.2000000000000028	0.0790000000000000008
60767	N2	23.6999999999999993	0.0690000000000000058
60767	K1	107.5	0.360999999999999988
60767	M4	3.89999999999999991	0.0160000000000000003
60767	O1	96.5	0.325000000000000011
60767	M6	283.199999999999989	0.00300000000000000006
60767	MK3	75.5	0.0200000000000000004
60767	S4	22.6999999999999993	0.00300000000000000006
60767	MN4	340.600000000000023	0.00700000000000000015
60767	NU2	34.1000000000000014	0.0160000000000000003
60767	MU2	274.5	0.0160000000000000003
60767	2N2	14.8000000000000007	0.0100000000000000002
60767	OO1	121.200000000000003	0.0200000000000000004
60767	LDA2	69.9000000000000057	0.00700000000000000015
60767	S1	138.199999999999989	0.0299999999999999989
60767	M1	171	0.0100000000000000002
60767	J1	99.4000000000000057	0.00700000000000000015
60767	SSA	57.8999999999999986	0.200000000000000011
60767	SA	123.900000000000006	0.312
60767	RHO1	81.7000000000000028	0.0129999999999999994
60767	Q1	80.5	0.0589999999999999969
60767	T2	146.599999999999994	0.0100000000000000002
60767	R2	19.1999999999999993	0.0100000000000000002
60767	2Q1	77.5999999999999943	0.0129999999999999994
60767	P1	105.799999999999997	0.0919999999999999984
60767	2SM2	216.699999999999989	0.00300000000000000006
60767	M3	28.8999999999999986	0.00700000000000000015
60767	L2	85.2999999999999972	0.0160000000000000003
60767	2MK3	72.7000000000000028	0.0160000000000000003
60767	K2	63.1000000000000014	0.0359999999999999973
60767	MS4	5.40000000000000036	0.0100000000000000002
60768	M2	48.6000000000000014	0.226000000000000006
60768	S2	21.8999999999999986	0.0749999999999999972
60768	N2	17.1000000000000014	0.0519999999999999976
60768	K1	109.599999999999994	0.39700000000000002
60768	M4	343.699999999999989	0.0200000000000000004
60768	O1	93.0999999999999943	0.304999999999999993
60768	M6	234.699999999999989	0.00700000000000000015
60768	S4	14.0999999999999996	0.00700000000000000015
60768	NU2	21.3000000000000007	0.0100000000000000002
60768	S6	188.300000000000011	0.00300000000000000006
60768	MU2	248.699999999999989	0.00700000000000000015
60768	2N2	345.5	0.00700000000000000015
60768	OO1	126.099999999999994	0.0129999999999999994
60768	LDA2	36.2000000000000028	0.00300000000000000006
60768	M1	101.400000000000006	0.0229999999999999996
60768	J1	117.700000000000003	0.0229999999999999996
60768	RHO1	86	0.0129999999999999994
60768	Q1	84.9000000000000057	0.0589999999999999969
60768	T2	23	0.00300000000000000006
60768	2Q1	76.7999999999999972	0.00700000000000000015
60768	P1	108.299999999999997	0.131000000000000005
60768	L2	80.2000000000000028	0.00700000000000000015
60768	K2	19.8000000000000007	0.0200000000000000004
60768	M8	116.099999999999994	0.00300000000000000006
60769	M2	254.400000000000006	0.446000000000000008
60769	S2	249.699999999999989	0.131000000000000005
60769	N2	233.800000000000011	0.117999999999999994
60769	K1	31.6000000000000014	0.475999999999999979
60769	M4	343.100000000000023	0.0299999999999999989
60769	O1	26.3999999999999986	0.432999999999999996
60769	M6	259.800000000000011	0.00700000000000000015
60769	MK3	96.2999999999999972	0.0299999999999999989
60769	S4	65.2999999999999972	0.00300000000000000006
60769	MN4	319.600000000000023	0.0129999999999999994
60769	NU2	243.599999999999994	0.0229999999999999996
60769	S6	272.600000000000023	0.00300000000000000006
60769	MU2	201	0.0160000000000000003
60769	2N2	198.599999999999994	0.0160000000000000003
60769	OO1	57.6000000000000014	0.0229999999999999996
60769	LDA2	31.5	0.00700000000000000015
60769	S1	281.199999999999989	0.0200000000000000004
60769	M1	52.7000000000000028	0.0229999999999999996
60769	J1	39.8999999999999986	0.0259999999999999988
60769	SSA	67.5	0.242999999999999994
60769	SA	143.900000000000006	0.360999999999999988
60769	RHO1	12.4000000000000004	0.0129999999999999994
60769	Q1	7.79999999999999982	0.0950000000000000011
60769	T2	291.800000000000011	0.0100000000000000002
60769	R2	325.199999999999989	0.00300000000000000006
60769	2Q1	12	0.0160000000000000003
60769	P1	25.6000000000000014	0.140999999999999986
60769	2SM2	317.899999999999977	0.00700000000000000015
60769	M3	209.5	0.0100000000000000002
60769	L2	310.600000000000023	0.0100000000000000002
60769	2MK3	102.700000000000003	0.0299999999999999989
60769	K2	313.399999999999977	0.0259999999999999988
60769	MS4	351	0.0129999999999999994
60770	M2	322.5	0.171000000000000013
60770	S2	312	0.0560000000000000012
60770	N2	299.800000000000011	0.0459999999999999992
60770	K1	74.9000000000000057	0.301999999999999991
60770	M4	275.300000000000011	0.00300000000000000006
60770	O1	66	0.284999999999999976
60770	M6	118.299999999999997	0.00300000000000000006
60770	MK3	161.400000000000006	0.00700000000000000015
60770	S4	156.099999999999994	0.00300000000000000006
60770	NU2	308.300000000000011	0.00700000000000000015
60770	MU2	216.5	0.0129999999999999994
60770	2N2	172.800000000000011	0.0100000000000000002
60770	OO1	87.0999999999999943	0.0330000000000000016
60770	LDA2	54.1000000000000014	0.00300000000000000006
60770	S1	316.5	0.0160000000000000003
60770	M1	199.5	0.0100000000000000002
60770	J1	74.7000000000000028	0.0100000000000000002
60770	SSA	52	0.253000000000000003
60770	SA	135.699999999999989	0.212999999999999995
60770	RHO1	37.2000000000000028	0.00700000000000000015
60770	Q1	35.5	0.0459999999999999992
60770	T2	306.199999999999989	0.00300000000000000006
60770	R2	67.5	0.00700000000000000015
60770	2Q1	263.5	0.00700000000000000015
60770	P1	69.2000000000000028	0.0919999999999999984
60770	2SM2	358.5	0.00300000000000000006
60770	M3	217.900000000000006	0.00300000000000000006
60770	L2	68.5	0.00700000000000000015
60770	2MK3	145.699999999999989	0.00700000000000000015
60770	K2	26	0.0259999999999999988
60770	MS4	270.699999999999989	0.00300000000000000006
60771	M2	29.3999999999999986	0.16700000000000001
60771	S2	12	0.0459999999999999992
60771	N2	6	0.0429999999999999966
60771	K1	102.200000000000003	0.301999999999999991
60771	M4	339.199999999999989	0.00300000000000000006
60771	O1	90.5999999999999943	0.276000000000000023
60771	MK3	68.5	0.00700000000000000015
60771	S4	201.099999999999994	0.00300000000000000006
60771	MN4	307.899999999999977	0.00300000000000000006
60771	NU2	7	0.00700000000000000015
60771	MU2	216	0.00700000000000000015
60771	OO1	116.900000000000006	0.0259999999999999988
60771	LDA2	62.8999999999999986	0.00700000000000000015
60771	S1	312.699999999999989	0.00700000000000000015
60771	M1	231.300000000000011	0.0160000000000000003
60771	J1	25.6000000000000014	0.00700000000000000015
60771	SSA	52	0.253000000000000003
60771	SA	135.699999999999989	0.212999999999999995
60771	RHO1	304.199999999999989	0.00300000000000000006
60771	Q1	66.2000000000000028	0.0429999999999999966
60771	T2	42.6000000000000014	0.00700000000000000015
60771	R2	109.299999999999997	0.00700000000000000015
60771	2Q1	205.199999999999989	0.00300000000000000006
60771	P1	93.2999999999999972	0.0889999999999999958
60771	M3	59.2000000000000028	0.00300000000000000006
60771	L2	68.7000000000000028	0.0100000000000000002
60771	2MK3	32.6000000000000014	0.00700000000000000015
60771	K2	36.2999999999999972	0.0259999999999999988
60771	MS4	336.899999999999977	0.00300000000000000006
60772	M2	290.699999999999989	0.253000000000000003
60772	S2	284.699999999999989	0.0749999999999999972
60772	N2	268.300000000000011	0.0589999999999999969
60772	K1	58.7000000000000028	0.322000000000000008
60772	M4	334.899999999999977	0.0100000000000000002
60772	O1	50.7000000000000028	0.315000000000000002
60772	M6	194.199999999999989	0.00300000000000000006
60772	NU2	305.800000000000011	0.0160000000000000003
60772	MU2	263.800000000000011	0.00300000000000000006
60772	2N2	212.699999999999989	0.0229999999999999996
60772	OO1	63	0.0129999999999999994
60772	LDA2	340.600000000000023	0.00300000000000000006
60772	S1	321.399999999999977	0.0229999999999999996
60772	M1	320.699999999999989	0.0129999999999999994
60772	J1	77.7000000000000028	0.00700000000000000015
60772	SSA	67	0.341000000000000025
60772	SA	125.700000000000003	0.233000000000000013
60772	RHO1	20.3999999999999986	0.0229999999999999996
60772	Q1	41.2999999999999972	0.0660000000000000031
60772	T2	283.300000000000011	0.0100000000000000002
60772	R2	130.099999999999994	0.00300000000000000006
60772	2Q1	205.900000000000006	0.00700000000000000015
60772	P1	43.6000000000000014	0.0950000000000000011
60772	L2	10.1999999999999993	0.0100000000000000002
60772	K2	341.399999999999977	0.0299999999999999989
60773	M2	51	0.16700000000000001
60773	S2	35.1000000000000014	0.0359999999999999973
60773	N2	36.1000000000000014	0.0299999999999999989
60773	K1	111.700000000000003	0.353999999999999981
60773	M4	343.399999999999977	0.0160000000000000003
60773	O1	97.4000000000000057	0.338000000000000023
60773	M6	275.600000000000023	0.00300000000000000006
60773	NU2	43.3999999999999986	0.0160000000000000003
60773	MU2	258.199999999999989	0.0160000000000000003
60773	2N2	155.199999999999989	0.00700000000000000015
60773	OO1	95.2000000000000028	0.0330000000000000016
60773	LDA2	119.200000000000003	0.00700000000000000015
60773	S1	315.699999999999989	0.0259999999999999988
60773	M1	166.5	0.0160000000000000003
60773	J1	150.599999999999994	0.0100000000000000002
60773	SSA	28.1000000000000014	0.200000000000000011
60773	SA	159.800000000000011	0.307999999999999996
60773	RHO1	97.4000000000000057	0.0229999999999999996
60773	Q1	89.7000000000000028	0.0589999999999999969
60773	T2	109.200000000000003	0.0160000000000000003
60773	R2	107.700000000000003	0.0100000000000000002
60773	2Q1	136.099999999999994	0.0129999999999999994
60773	P1	94.7999999999999972	0.104999999999999996
60773	L2	101.5	0.00300000000000000006
60773	K2	60.2000000000000028	0.0200000000000000004
60773	M8	114.099999999999994	0.00300000000000000006
60774	M2	275.5	0.404000000000000026
60774	S2	271.5	0.128000000000000003
60774	N2	254.400000000000006	0.107999999999999999
60774	K1	40.7000000000000028	0.432999999999999996
60774	M4	318.899999999999977	0.0160000000000000003
60774	O1	34.6000000000000014	0.404000000000000026
60774	MK3	141.199999999999989	0.0229999999999999996
60774	NU2	269.5	0.0229999999999999996
60774	MU2	210.300000000000011	0.0160000000000000003
60774	2N2	220.400000000000006	0.0160000000000000003
60774	OO1	61.3999999999999986	0.0200000000000000004
60774	LDA2	273.600000000000023	0.00300000000000000006
60774	S1	306.300000000000011	0.0389999999999999999
60774	M1	36.8999999999999986	0.0200000000000000004
60774	J1	47.1000000000000014	0.0229999999999999996
60774	SSA	52	0.253000000000000003
60774	SA	135.699999999999989	0.212999999999999995
60774	RHO1	23.8000000000000007	0.0200000000000000004
60774	Q1	21.8000000000000007	0.0850000000000000061
60774	T2	271.699999999999989	0.00700000000000000015
60774	2Q1	28.5	0.0100000000000000002
60774	P1	33.1000000000000014	0.131000000000000005
60774	L2	5.09999999999999964	0.0129999999999999994
60774	2MK3	132.800000000000011	0.0200000000000000004
60774	K2	338.5	0.0259999999999999988
60775	M2	47.6000000000000014	0.153999999999999998
60775	S2	15.8000000000000007	0.0490000000000000019
60775	N2	87.5999999999999943	0.0229999999999999996
60775	K1	111.599999999999994	0.226000000000000006
60775	M4	330.800000000000011	0.0100000000000000002
60775	O1	102.099999999999994	0.216999999999999998
60775	M6	1.80000000000000004	0.00300000000000000006
60775	S4	269.899999999999977	0.00300000000000000006
60775	NU2	82.2999999999999972	0.00300000000000000006
60775	S6	88.7000000000000028	0.00300000000000000006
60775	MU2	251.900000000000006	0.00300000000000000006
60775	2N2	127.700000000000003	0.00300000000000000006
60775	OO1	121.200000000000003	0.0100000000000000002
60775	M1	106.900000000000006	0.0160000000000000003
60775	J1	116.400000000000006	0.0160000000000000003
60775	RHO1	98	0.0100000000000000002
60775	Q1	97.2999999999999972	0.0429999999999999966
60775	T2	17.1000000000000014	0.00300000000000000006
60775	2Q1	92.5999999999999943	0.00700000000000000015
60775	P1	110.900000000000006	0.0749999999999999972
60775	L2	7.5	0.00300000000000000006
60775	K2	13.3000000000000007	0.0129999999999999994
60775	M8	149.5	0.00300000000000000006
60776	M2	65	0.194000000000000006
60776	S2	49.6000000000000014	0.0429999999999999966
60776	N2	37.8999999999999986	0.0459999999999999992
60776	K1	111.200000000000003	0.429999999999999993
60776	M4	350.699999999999989	0.00300000000000000006
60776	O1	98.5999999999999943	0.416999999999999982
60776	M6	186.800000000000011	0.00300000000000000006
60776	MK3	67.7999999999999972	0.00300000000000000006
60776	S4	313.300000000000011	0.00300000000000000006
60776	MN4	318.800000000000011	0.00300000000000000006
60776	NU2	47.6000000000000014	0.0100000000000000002
60776	S6	68.9000000000000057	0.00300000000000000006
60776	MU2	297.399999999999977	0.0100000000000000002
60776	2N2	26.8000000000000007	0.00300000000000000006
60776	OO1	131.099999999999994	0.0459999999999999992
60776	LDA2	99.0999999999999943	0.00700000000000000015
60776	S1	128.300000000000011	0.0129999999999999994
60776	M1	202.099999999999994	0.0129999999999999994
60776	J1	78.5	0.00700000000000000015
60776	SSA	71.2999999999999972	0.328000000000000014
60776	SA	133	0.33500000000000002
60776	RHO1	101.700000000000003	0.0160000000000000003
60776	Q1	82.4000000000000057	0.0820000000000000034
60776	T2	97.0999999999999943	0.00300000000000000006
60776	R2	17.8000000000000007	0.00700000000000000015
60776	2Q1	50.2000000000000028	0.0100000000000000002
60776	P1	114.599999999999994	0.112000000000000002
60776	L2	96	0.0100000000000000002
60776	2MK3	54.2000000000000028	0.00300000000000000006
60776	K2	87.0999999999999943	0.0330000000000000016
60776	M8	66.0999999999999943	0.00300000000000000006
60777	M2	59.1000000000000014	0.171000000000000013
60777	S2	45.7999999999999972	0.0389999999999999999
60777	N2	32.7999999999999972	0.0389999999999999999
60777	K1	110.400000000000006	0.370999999999999996
60777	M4	338.199999999999989	0.0100000000000000002
60777	O1	103.5	0.370999999999999996
60777	M6	237.900000000000006	0.00300000000000000006
60777	MK3	26	0.00700000000000000015
60777	MN4	316.899999999999977	0.00300000000000000006
60777	NU2	50.2999999999999972	0.0100000000000000002
60777	MU2	257.300000000000011	0.0129999999999999994
60777	2N2	288.300000000000011	0.0160000000000000003
60777	OO1	119.299999999999997	0.0490000000000000019
60777	LDA2	93.5999999999999943	0.00300000000000000006
60777	S1	277.699999999999989	0.0359999999999999973
60777	M1	227.5	0.0229999999999999996
60777	J1	121.5	0.00700000000000000015
60777	SSA	48.8999999999999986	0.373999999999999999
60777	SA	146.400000000000006	0.288999999999999979
60777	RHO1	143.5	0.0129999999999999994
60777	Q1	71.5	0.0790000000000000008
60777	T2	112.900000000000006	0.0100000000000000002
60777	R2	90.5999999999999943	0.00700000000000000015
60777	2Q1	290.600000000000023	0.0129999999999999994
60777	P1	113	0.0889999999999999958
60777	2SM2	70.9000000000000057	0.00700000000000000015
60777	M3	238.699999999999989	0.00300000000000000006
60777	L2	93.5999999999999943	0.0100000000000000002
60777	K2	72.4000000000000057	0.0330000000000000016
60777	MS4	342.399999999999977	0.00700000000000000015
60778	M2	84.2000000000000028	0.245999999999999996
60778	S2	75.5999999999999943	0.0619999999999999996
60778	N2	62.5	0.0560000000000000012
60778	K1	121.299999999999997	0.426999999999999991
60778	M4	90.4000000000000057	0.00300000000000000006
60778	O1	106	0.394000000000000017
60778	M6	215.300000000000011	0.00300000000000000006
60778	MK3	119.700000000000003	0.0129999999999999994
60778	S4	190.300000000000011	0.00300000000000000006
60778	MN4	48.3999999999999986	0.00300000000000000006
60778	NU2	88.9000000000000057	0.0129999999999999994
60778	S6	185.199999999999989	0.00300000000000000006
60778	MU2	286.100000000000023	0.0129999999999999994
60778	2N2	27	0.0200000000000000004
60778	OO1	131.900000000000006	0.0330000000000000016
60778	LDA2	135.199999999999989	0.00700000000000000015
60778	S1	140.400000000000006	0.0100000000000000002
60778	M1	119.900000000000006	0.0160000000000000003
60778	J1	78.7999999999999972	0.00700000000000000015
60778	SSA	57	0.331000000000000016
60778	SA	121.5	0.325000000000000011
60778	RHO1	81.2000000000000028	0.0299999999999999989
60778	Q1	102	0.0719999999999999946
60778	T2	136.800000000000011	0.0100000000000000002
60778	R2	344.300000000000011	0.00300000000000000006
60778	2Q1	40	0.0160000000000000003
60778	P1	131.400000000000006	0.117999999999999994
60778	2SM2	321.399999999999977	0.00300000000000000006
60778	M3	14	0.00700000000000000015
60778	L2	154.699999999999989	0.0200000000000000004
60778	2MK3	92.2000000000000028	0.0100000000000000002
60778	K2	103	0.0359999999999999973
60778	M8	183.5	0.00300000000000000006
60778	MS4	131.5	0.00300000000000000006
60779	M2	84.5	0.23899999999999999
60779	S2	78.4000000000000057	0.0719999999999999946
60779	N2	63	0.0560000000000000012
60779	K1	120.400000000000006	0.426999999999999991
60779	M4	53.8999999999999986	0.00700000000000000015
60779	O1	107.799999999999997	0.387000000000000011
60779	M6	255.900000000000006	0.00300000000000000006
60779	NU2	61	0.0200000000000000004
60779	MU2	4.79999999999999982	0.00700000000000000015
60779	2N2	131.599999999999994	0.0200000000000000004
60779	OO1	125	0.0389999999999999999
60779	LDA2	175.099999999999994	0.00700000000000000015
60779	S1	88.9000000000000057	0.0160000000000000003
60779	M1	156.599999999999994	0.0229999999999999996
60779	J1	201.300000000000011	0.0129999999999999994
60779	SSA	35.3999999999999986	0.341000000000000025
60779	SA	141.800000000000011	0.426999999999999991
60779	RHO1	50	0.0259999999999999988
60779	Q1	93.4000000000000057	0.0660000000000000031
60779	T2	133.400000000000006	0.0200000000000000004
60779	R2	72.5999999999999943	0.00700000000000000015
60779	2Q1	107.799999999999997	0.0160000000000000003
60779	P1	130.300000000000011	0.104999999999999996
60779	L2	140.5	0.0259999999999999988
60779	K2	99.7000000000000028	0.0330000000000000016
60780	M2	80.2999999999999972	0.307999999999999996
60780	S2	68.2000000000000028	0.0749999999999999972
60780	N2	56	0.0749999999999999972
60780	K1	115.700000000000003	0.502000000000000002
60780	M4	95.2999999999999972	0.0129999999999999994
60780	O1	102.299999999999997	0.468999999999999972
60780	M6	283.199999999999989	0.00300000000000000006
60780	MK3	88.2000000000000028	0.0160000000000000003
60780	S4	3.20000000000000018	0.00300000000000000006
60780	MN4	68.7000000000000028	0.00300000000000000006
60780	NU2	76.7000000000000028	0.0129999999999999994
60780	MU2	297.100000000000023	0.0160000000000000003
60780	2N2	175.199999999999989	0.0160000000000000003
60780	OO1	124.299999999999997	0.0749999999999999972
60780	LDA2	115	0.0100000000000000002
60780	S1	128.199999999999989	0.0160000000000000003
60780	M1	211.300000000000011	0.0259999999999999988
60780	J1	134.599999999999994	0.0160000000000000003
60780	SSA	71.2999999999999972	0.328000000000000014
60780	SA	133	0.33500000000000002
60780	RHO1	97.2000000000000028	0.0100000000000000002
60780	Q1	77.2999999999999972	0.0820000000000000034
60780	T2	97.7999999999999972	0.0160000000000000003
60780	R2	220.199999999999989	0.00300000000000000006
60780	2Q1	159.300000000000011	0.0160000000000000003
60780	P1	122.299999999999997	0.143999999999999989
60780	2SM2	331.699999999999989	0.00300000000000000006
60780	M3	192.599999999999994	0.00300000000000000006
60780	L2	148.300000000000011	0.0129999999999999994
60780	2MK3	37.7999999999999972	0.0100000000000000002
60780	K2	110.099999999999994	0.0490000000000000019
60780	M8	251	0.00300000000000000006
60780	MS4	86.0999999999999943	0.00700000000000000015
60781	M2	33.7999999999999972	0.209999999999999992
60781	S2	36.1000000000000014	0.0619999999999999996
60781	N2	8.69999999999999929	0.0560000000000000012
60781	K1	98.2999999999999972	0.412999999999999978
60781	M4	17.5	0.0200000000000000004
60781	O1	90.7000000000000028	0.394000000000000017
60781	M6	293.5	0.00300000000000000006
60781	MK3	344	0.0129999999999999994
60781	S4	253.199999999999989	0.00700000000000000015
60781	MN4	352.300000000000011	0.0100000000000000002
60781	NU2	359.5	0.0129999999999999994
60781	S6	208.099999999999994	0.00300000000000000006
60781	MU2	252.199999999999989	0.0129999999999999994
60781	2N2	205.300000000000011	0.00300000000000000006
60781	OO1	131.400000000000006	0.0560000000000000012
60781	LDA2	67.0999999999999943	0.00300000000000000006
60781	S1	13.0999999999999996	0.0519999999999999976
60781	M1	182.099999999999994	0.0200000000000000004
60781	J1	130.800000000000011	0.0229999999999999996
60781	SSA	55.6000000000000014	0.281999999999999973
60781	SA	155.699999999999989	0.216999999999999998
60781	RHO1	358.300000000000011	0.0200000000000000004
60781	Q1	61.5	0.0560000000000000012
60781	T2	241.300000000000011	0.00700000000000000015
60781	R2	104.700000000000003	0.00700000000000000015
60781	2Q1	104.900000000000006	0.00300000000000000006
60781	P1	91.4000000000000057	0.115000000000000005
60781	2SM2	35.2000000000000028	0.00300000000000000006
60781	M3	137.699999999999989	0.00300000000000000006
60781	L2	126.700000000000003	0.00300000000000000006
60781	2MK3	353.899999999999977	0.0160000000000000003
60781	K2	71	0.0429999999999999966
60781	MS4	15.5	0.0100000000000000002
60782	M2	266.399999999999977	0.435999999999999999
60782	S2	270.399999999999977	0.125
60782	N2	246.699999999999989	0.107999999999999999
60782	K1	35	0.468999999999999972
60782	M4	326.600000000000023	0.0160000000000000003
60782	O1	28.3000000000000007	0.422999999999999987
60782	M6	300.199999999999989	0.00300000000000000006
60782	MK3	121.700000000000003	0.0229999999999999996
60782	S4	193.900000000000006	0.00300000000000000006
60782	MN4	306	0.00700000000000000015
60782	NU2	233.699999999999989	0.0229999999999999996
60782	S6	191.099999999999994	0.00300000000000000006
60782	MU2	178.400000000000006	0.0229999999999999996
60782	2N2	183	0.0229999999999999996
60782	OO1	44.5	0.0330000000000000016
60782	LDA2	319.600000000000023	0.00300000000000000006
60782	S1	231	0.0129999999999999994
60782	M1	68.2999999999999972	0.0129999999999999994
60782	J1	34.1000000000000014	0.0299999999999999989
60782	SSA	52	0.253000000000000003
60782	SA	135.699999999999989	0.212999999999999995
60782	RHO1	16.8000000000000007	0.0100000000000000002
60782	Q1	10	0.0749999999999999972
60782	T2	256.5	0.0330000000000000016
60782	R2	69.7000000000000028	0.0330000000000000016
60782	2Q1	255.5	0.00300000000000000006
60782	P1	30.6000000000000014	0.157000000000000001
60782	2SM2	2.89999999999999991	0.00300000000000000006
60782	M3	194.900000000000006	0.0129999999999999994
60782	L2	76	0.0129999999999999994
60782	2MK3	129.900000000000006	0.0259999999999999988
60782	K2	317.300000000000011	0.0490000000000000019
60782	M8	182.300000000000011	0.00300000000000000006
60782	MS4	334.100000000000023	0.0129999999999999994
60783	M2	94.7000000000000028	0.120999999999999996
60783	S2	81.2999999999999972	0.0259999999999999988
60783	N2	96.4000000000000057	0.0330000000000000016
60783	K1	133	0.343999999999999972
60783	M4	313.899999999999977	0.0100000000000000002
60783	O1	118.200000000000003	0.343999999999999972
60783	M6	282.399999999999977	0.00300000000000000006
60783	NU2	155.199999999999989	0.0100000000000000002
60783	MU2	305.399999999999977	0.00700000000000000015
60783	2N2	260	0.0200000000000000004
60783	OO1	136.400000000000006	0.0459999999999999992
60783	LDA2	239.800000000000011	0.0129999999999999994
60783	S1	36.2000000000000028	0.0129999999999999994
60783	M1	282.100000000000023	0.00700000000000000015
60783	J1	166.599999999999994	0.0100000000000000002
60783	SSA	68.0999999999999943	0.377000000000000002
60783	SA	126.400000000000006	0.220000000000000001
60783	RHO1	117.700000000000003	0.0229999999999999996
60783	Q1	115.200000000000003	0.0820000000000000034
60783	T2	193.699999999999989	0.00700000000000000015
60783	R2	51.1000000000000014	0.00300000000000000006
60783	2Q1	256.699999999999989	0.0200000000000000004
60783	P1	140.099999999999994	0.0889999999999999958
60783	K2	110.5	0.0330000000000000016
60783	M8	160.5	0.00300000000000000006
60784	M2	24.6999999999999993	0.190000000000000002
60784	S2	17.3999999999999986	0.0589999999999999969
60784	N2	14.5	0.0429999999999999966
60784	K1	96.9000000000000057	0.373999999999999999
60784	M4	334.899999999999977	0.0200000000000000004
60784	O1	88.5	0.370999999999999996
60784	M6	227.400000000000006	0.00300000000000000006
60784	NU2	40.2999999999999972	0.0129999999999999994
60784	MU2	119.099999999999994	0.00300000000000000006
60784	2N2	256.100000000000023	0.0129999999999999994
60784	OO1	104	0.0299999999999999989
60784	LDA2	3.60000000000000009	0.00300000000000000006
60784	S1	326.899999999999977	0.0719999999999999946
60784	M1	325.800000000000011	0.0200000000000000004
60784	J1	94	0.0160000000000000003
60784	SSA	76	0.262000000000000011
60784	SA	124.299999999999997	0.242999999999999994
60784	RHO1	77.0999999999999943	0.00700000000000000015
60784	Q1	69.0999999999999943	0.0790000000000000008
60784	T2	234	0.00700000000000000015
60784	R2	184.400000000000006	0.00300000000000000006
60784	2Q1	259.899999999999977	0.0100000000000000002
60784	P1	88.5	0.104999999999999996
60784	L2	71.9000000000000057	0.0100000000000000002
60784	K2	38	0.0389999999999999999
60785	M2	19.6999999999999993	0.112000000000000002
60785	S2	15	0.0389999999999999999
60785	N2	351.5	0.0299999999999999989
60785	K1	100.400000000000006	0.384000000000000008
60785	O1	89.5	0.373999999999999999
60785	NU2	355.300000000000011	0.00700000000000000015
60785	2N2	323.300000000000011	0.00300000000000000006
60785	OO1	110.799999999999997	0.0330000000000000016
60785	S1	13.3000000000000007	0.0259999999999999988
60785	M1	94.7999999999999972	0.0259999999999999988
60785	J1	105.799999999999997	0.0299999999999999989
60785	SSA	48.8999999999999986	0.373999999999999999
60785	SA	146.400000000000006	0.288999999999999979
60785	RHO1	68.0999999999999943	0.0200000000000000004
60785	Q1	75.4000000000000057	0.0719999999999999946
60785	T2	15.1999999999999993	0.00300000000000000006
60785	2Q1	78.7000000000000028	0.0100000000000000002
60785	P1	104.400000000000006	0.0980000000000000038
60785	L2	47.8999999999999986	0.00300000000000000006
60785	K2	71.5999999999999943	0.0229999999999999996
60786	M2	262.600000000000023	0.554000000000000048
60786	S2	254.199999999999989	0.173999999999999988
60786	N2	236.900000000000006	0.150999999999999995
60786	K1	23.3000000000000007	0.567999999999999949
60786	M4	284.5	0.0160000000000000003
60786	O1	16.3000000000000007	0.528000000000000025
60786	MK3	257.899999999999977	0.00700000000000000015
60786	MN4	245.900000000000006	0.00700000000000000015
60786	NU2	249.5	0.0259999999999999988
60786	S6	242.400000000000006	0.00300000000000000006
60786	MU2	181.300000000000011	0.0200000000000000004
60786	2N2	216	0.0259999999999999988
60786	OO1	50.5	0.0200000000000000004
60786	S1	324.600000000000023	0.0200000000000000004
60786	M1	48.1000000000000014	0.0129999999999999994
60786	J1	27.1999999999999993	0.0259999999999999988
60786	SSA	52	0.253000000000000003
60786	SA	135.699999999999989	0.212999999999999995
60786	RHO1	5.40000000000000036	0.0229999999999999996
60786	Q1	2.10000000000000009	0.120999999999999996
60786	T2	315.600000000000023	0.0129999999999999994
60786	R2	311.300000000000011	0.0129999999999999994
60786	2Q1	333	0.0100000000000000002
60786	P1	19.3000000000000007	0.173999999999999988
60786	M3	209.5	0.0100000000000000002
60786	2MK3	270.800000000000011	0.00700000000000000015
60786	K2	275.699999999999989	0.0359999999999999973
60786	MS4	281.100000000000023	0.0100000000000000002
60787	M2	290.699999999999989	0.259000000000000008
60787	S2	286.899999999999977	0.0790000000000000008
60787	N2	265.300000000000011	0.0719999999999999946
60787	K1	60.3999999999999986	0.463000000000000023
60787	O1	54.2999999999999972	0.459000000000000019
60787	MK3	128.099999999999994	0.0459999999999999992
60787	NU2	254.699999999999989	0.0160000000000000003
60787	MU2	249.099999999999994	0.0100000000000000002
60787	2N2	256	0.0129999999999999994
60787	OO1	105.799999999999997	0.0459999999999999992
60787	LDA2	288.800000000000011	0.00300000000000000006
60787	S1	345.100000000000023	0.0459999999999999992
60787	M1	97.5999999999999943	0.0259999999999999988
60787	J1	58.8999999999999986	0.0129999999999999994
60787	SSA	48.8999999999999986	0.412999999999999978
60787	SA	155.5	0.253000000000000003
60787	RHO1	38.8999999999999986	0.0229999999999999996
60787	Q1	34	0.101999999999999993
60787	T2	340.600000000000023	0.0129999999999999994
60787	2Q1	345.199999999999989	0.0129999999999999994
60787	P1	54.7000000000000028	0.128000000000000003
60787	L2	315.899999999999977	0.0100000000000000002
60787	2MK3	117.099999999999994	0.0359999999999999973
60787	K2	10.1999999999999993	0.0519999999999999976
60788	M2	281.5	0.360999999999999988
60788	S2	289	0.0980000000000000038
60788	N2	257.399999999999977	0.0919999999999999984
60788	K1	40.7999999999999972	0.481999999999999984
60788	M4	232.699999999999989	0.0100000000000000002
60788	O1	33.1000000000000014	0.456000000000000016
60788	M6	278.899999999999977	0.00700000000000000015
60788	MK3	107.400000000000006	0.0129999999999999994
60788	S4	210.199999999999989	0.00700000000000000015
60788	MN4	193.099999999999994	0.00700000000000000015
60788	NU2	271.300000000000011	0.0200000000000000004
60788	S6	264.399999999999977	0.00300000000000000006
60788	MU2	218.400000000000006	0.0129999999999999994
60788	2N2	244.099999999999994	0.0129999999999999994
60788	OO1	85.0999999999999943	0.0160000000000000003
60788	LDA2	3.5	0.00300000000000000006
60788	S1	320.199999999999989	0.0359999999999999973
60788	M1	67.2999999999999972	0.0200000000000000004
60788	J1	30.6999999999999993	0.0299999999999999989
60788	SSA	76	0.27200000000000002
60788	SA	154.900000000000006	0.245999999999999996
60788	RHO1	21.6999999999999993	0.0200000000000000004
60788	Q1	14.5999999999999996	0.0980000000000000038
60788	T2	269.199999999999989	0.0129999999999999994
60788	R2	133.400000000000006	0.00700000000000000015
60788	2Q1	3.20000000000000018	0.0160000000000000003
60788	P1	35.7999999999999972	0.138000000000000012
60788	2SM2	348.199999999999989	0.00700000000000000015
60788	L2	330.600000000000023	0.0100000000000000002
60788	2MK3	96.2999999999999972	0.0100000000000000002
60788	K2	344.199999999999989	0.0200000000000000004
60788	MS4	267.199999999999989	0.00300000000000000006
60789	M2	295.699999999999989	0.291999999999999982
60789	S2	293.100000000000023	0.0919999999999999984
60789	N2	274	0.0790000000000000008
60789	K1	53.2999999999999972	0.432999999999999996
60789	M4	255.400000000000006	0.0160000000000000003
60789	O1	45.5	0.412999999999999978
60789	NU2	292.100000000000023	0.0160000000000000003
60789	MU2	227.699999999999989	0.0129999999999999994
60789	2N2	239.300000000000011	0.0160000000000000003
60789	OO1	82.2999999999999972	0.0259999999999999988
60789	LDA2	294.5	0.00300000000000000006
60789	S1	352.199999999999989	0.0299999999999999989
60789	M1	44.3999999999999986	0.0160000000000000003
60789	J1	51	0.0229999999999999996
60789	SSA	55.6000000000000014	0.281999999999999973
60789	SA	155.699999999999989	0.216999999999999998
60789	RHO1	30.5	0.0229999999999999996
60789	Q1	29.3999999999999986	0.0889999999999999958
60789	T2	293.199999999999989	0.00700000000000000015
60789	2Q1	37.8999999999999986	0.0100000000000000002
60789	P1	46.6000000000000014	0.128000000000000003
60789	L2	317.199999999999989	0.0129999999999999994
60789	K2	19.3000000000000007	0.0129999999999999994
60790	M2	315	0.209999999999999992
60790	S2	313.800000000000011	0.0749999999999999972
60790	N2	293.600000000000023	0.0560000000000000012
60790	K1	69.2000000000000028	0.394000000000000017
60790	M4	259.800000000000011	0.0100000000000000002
60790	O1	60.2000000000000028	0.384000000000000008
60790	M6	311.100000000000023	0.00300000000000000006
60790	MK3	154.300000000000011	0.0100000000000000002
60790	S4	19.5	0.00300000000000000006
60790	MN4	163.199999999999989	0.00700000000000000015
60790	NU2	290.699999999999989	0.0129999999999999994
60790	MU2	236.099999999999994	0.0100000000000000002
60790	2N2	197.199999999999989	0.0129999999999999994
60790	OO1	100.799999999999997	0.0490000000000000019
60790	S1	324.5	0.0299999999999999989
60790	M1	194.800000000000011	0.0100000000000000002
60790	J1	88.2000000000000028	0.0200000000000000004
60790	SSA	55.6000000000000014	0.281999999999999973
60790	SA	155.699999999999989	0.216999999999999998
60790	RHO1	24.6999999999999993	0.0160000000000000003
60790	Q1	31.6000000000000014	0.0790000000000000008
60790	T2	310.800000000000011	0.0100000000000000002
60790	R2	150.199999999999989	0.00700000000000000015
60790	2Q1	22.1000000000000014	0.00300000000000000006
60790	P1	65.5999999999999943	0.115000000000000005
60790	2SM2	310.699999999999989	0.00300000000000000006
60790	M3	252.400000000000006	0.00300000000000000006
60790	L2	97.4000000000000057	0.00700000000000000015
60790	2MK3	149.099999999999994	0.00700000000000000015
60790	K2	33.1000000000000014	0.0259999999999999988
60790	MS4	282.300000000000011	0.00700000000000000015
60791	M2	276.100000000000023	0.456000000000000016
60791	S2	267.899999999999977	0.112000000000000002
60791	N2	254.599999999999994	0.117999999999999994
60791	K1	28	0.561000000000000054
60791	M4	203.300000000000011	0.0200000000000000004
60791	O1	20.3000000000000007	0.528000000000000025
60791	NU2	270.899999999999977	0.0259999999999999988
60791	MU2	197.099999999999994	0.0160000000000000003
60791	2N2	228.800000000000011	0.0200000000000000004
60791	OO1	46.2000000000000028	0.0200000000000000004
60791	LDA2	272.199999999999989	0.00300000000000000006
60791	S1	327	0.0459999999999999992
60791	M1	24.1999999999999993	0.0259999999999999988
60791	J1	34.5	0.0330000000000000016
60791	SSA	55.2000000000000028	0.294999999999999984
60791	SA	157.400000000000006	0.253000000000000003
60791	RHO1	4	0.0229999999999999996
60791	Q1	7	0.117999999999999994
60791	T2	268.100000000000023	0.00700000000000000015
60791	2Q1	349.5	0.0129999999999999994
60791	P1	24.3000000000000007	0.16700000000000001
60791	L2	352.100000000000023	0.0129999999999999994
60791	K2	275.600000000000023	0.0200000000000000004
60791	MS4	224.699999999999989	0.0129999999999999994
60792	M2	287.5	0.203000000000000014
60792	S2	283.300000000000011	0.0560000000000000012
60792	N2	265.199999999999989	0.0519999999999999976
60792	K1	44.8999999999999986	0.353999999999999981
60792	M4	168.900000000000006	0.0100000000000000002
60792	O1	37.5	0.343999999999999972
60792	M6	303.399999999999977	0.00300000000000000006
60792	MK3	94.2000000000000028	0.0100000000000000002
60792	S4	294.600000000000023	0.00300000000000000006
60792	MN4	115.700000000000003	0.00700000000000000015
60792	NU2	276.300000000000011	0.0100000000000000002
60792	MU2	215.400000000000006	0.0100000000000000002
60792	2N2	184.699999999999989	0.0100000000000000002
60792	OO1	90.2999999999999972	0.0229999999999999996
60792	LDA2	342.399999999999977	0.00300000000000000006
60792	S1	0.900000000000000022	0.0160000000000000003
60792	M1	27.1999999999999993	0.00300000000000000006
60792	J1	48.5	0.0229999999999999996
60792	SSA	55.6000000000000014	0.281999999999999973
60792	SA	155.699999999999989	0.216999999999999998
60792	RHO1	18.1999999999999993	0.0100000000000000002
60792	Q1	17.6000000000000014	0.0749999999999999972
60792	T2	305.800000000000011	0.0100000000000000002
60792	R2	107.299999999999997	0.00300000000000000006
60792	2Q1	277.899999999999977	0.00300000000000000006
60792	P1	40.7000000000000028	0.107999999999999999
60792	2SM2	334.5	0.00300000000000000006
60792	M3	61.5	0.00300000000000000006
60792	L2	66.5999999999999943	0.00300000000000000006
60792	2MK3	95	0.0100000000000000002
60792	K2	338.5	0.0129999999999999994
60792	MS4	179.699999999999989	0.00300000000000000006
60793	M2	275.399999999999977	0.315000000000000002
60793	S2	274.600000000000023	0.0889999999999999958
60793	N2	253.400000000000006	0.0790000000000000008
60793	K1	26.6000000000000014	0.498999999999999999
60793	M4	165.800000000000011	0.0160000000000000003
60793	O1	18.6999999999999993	0.481999999999999984
60793	NU2	253.900000000000006	0.0160000000000000003
60793	2N2	242.5	0.0129999999999999994
60793	OO1	36.7000000000000028	0.0200000000000000004
60793	LDA2	275	0.00300000000000000006
60793	S1	332.199999999999989	0.0229999999999999996
60793	M1	69.2000000000000028	0.0200000000000000004
60793	J1	28.5	0.0259999999999999988
60793	SSA	64.2999999999999972	0.242999999999999994
60793	SA	173.5	0.187
60793	RHO1	358.300000000000011	0.0259999999999999988
60793	Q1	0.599999999999999978	0.115000000000000005
60793	T2	274.600000000000023	0.00700000000000000015
60793	2Q1	341.399999999999977	0.0129999999999999994
60793	P1	23.5	0.147999999999999993
60793	L2	335.5	0.0100000000000000002
60793	K2	279.600000000000023	0.0229999999999999996
60794	M2	275.199999999999989	0.312
60794	S2	275.899999999999977	0.0850000000000000061
60794	N2	252.5	0.0790000000000000008
60794	K1	26.1000000000000014	0.498999999999999999
60794	M4	160.5	0.0160000000000000003
60794	O1	19.1999999999999993	0.481999999999999984
60794	M6	306.600000000000023	0.00300000000000000006
60794	MK3	13.8000000000000007	0.00300000000000000006
60794	S4	246.099999999999994	0.00300000000000000006
60794	MN4	133.900000000000006	0.00700000000000000015
60794	NU2	258.800000000000011	0.0160000000000000003
60794	S6	310.199999999999989	0.00300000000000000006
60794	MU2	199.900000000000006	0.0100000000000000002
60794	2N2	247.699999999999989	0.0129999999999999994
60794	OO1	39.8999999999999986	0.0160000000000000003
60794	LDA2	359.399999999999977	0.00300000000000000006
60794	S1	308.899999999999977	0.0259999999999999988
60794	M1	50.3999999999999986	0.0229999999999999996
60794	J1	28.8000000000000007	0.0299999999999999989
60794	SSA	69.2999999999999972	0.242999999999999994
60794	SA	155.900000000000006	0.276000000000000023
60794	RHO1	9.40000000000000036	0.0200000000000000004
60794	Q1	2.10000000000000009	0.104999999999999996
60794	T2	295.100000000000023	0.0100000000000000002
60794	R2	262.300000000000011	0.00300000000000000006
60794	2Q1	341.100000000000023	0.0129999999999999994
60794	P1	23.3999999999999986	0.147999999999999993
60794	M3	37	0.00700000000000000015
60794	L2	328.5	0.0100000000000000002
60794	2MK3	1.10000000000000009	0.00300000000000000006
60794	K2	281.199999999999989	0.0160000000000000003
60794	MS4	180.699999999999989	0.00700000000000000015
60795	M2	274.100000000000023	0.301999999999999991
60795	S2	274.5	0.0820000000000000034
60795	N2	253.099999999999994	0.0790000000000000008
60795	K1	26	0.48899999999999999
60795	M4	160.800000000000011	0.0160000000000000003
60795	O1	19.1000000000000014	0.475999999999999979
60795	M6	309.699999999999989	0.00300000000000000006
60795	MK3	25	0.00700000000000000015
60795	S4	296.199999999999989	0.00700000000000000015
60795	MN4	119.400000000000006	0.0100000000000000002
60795	NU2	251.800000000000011	0.0160000000000000003
60795	MU2	204.099999999999994	0.0100000000000000002
60795	2N2	216.699999999999989	0.0160000000000000003
60795	OO1	49.5	0.0229999999999999996
60795	LDA2	299.800000000000011	0.00300000000000000006
60795	S1	319.100000000000023	0.0330000000000000016
60795	M1	36.2000000000000028	0.0100000000000000002
60795	J1	37.1000000000000014	0.0330000000000000016
60795	SSA	69.2999999999999972	0.242999999999999994
60795	SA	155.900000000000006	0.276000000000000023
60795	RHO1	341.800000000000011	0.0200000000000000004
60795	Q1	0.100000000000000006	0.107999999999999999
60795	T2	292.800000000000011	0.0100000000000000002
60795	2Q1	319.199999999999989	0.0129999999999999994
60795	P1	27.8999999999999986	0.157000000000000001
60795	2SM2	323.5	0.00300000000000000006
60795	M3	31.1999999999999993	0.0100000000000000002
60795	L2	18.5	0.00300000000000000006
60795	2MK3	26.8000000000000007	0.00700000000000000015
60795	K2	278.399999999999977	0.0200000000000000004
60795	M8	193	0.00300000000000000006
60795	MS4	158.300000000000011	0.00700000000000000015
60796	M2	287.600000000000023	0.0790000000000000008
60796	S2	295.399999999999977	0.0299999999999999989
60796	N2	262.899999999999977	0.0200000000000000004
60796	K1	52	0.183999999999999997
60796	M4	137.400000000000006	0.0129999999999999994
60796	O1	46.2999999999999972	0.176999999999999991
60796	MK3	174.400000000000006	0.00300000000000000006
60796	S4	271.899999999999977	0.00700000000000000015
60796	MN4	111.900000000000006	0.00300000000000000006
60796	NU2	322.300000000000011	0.00300000000000000006
60796	S6	265.300000000000011	0.00300000000000000006
60796	MU2	170.900000000000006	0.00300000000000000006
60796	2N2	259.699999999999989	0.00300000000000000006
60796	OO1	77.7999999999999972	0.0160000000000000003
60796	LDA2	330	0.00300000000000000006
60796	S1	63.5	0.00700000000000000015
60796	M1	130.599999999999994	0.00700000000000000015
60796	J1	68.7000000000000028	0.0100000000000000002
60796	SSA	74.2999999999999972	0.288999999999999979
60796	SA	179.900000000000006	0.294999999999999984
60796	RHO1	284.100000000000023	0.00300000000000000006
60796	Q1	26.8000000000000007	0.0359999999999999973
60796	T2	208.099999999999994	0.0100000000000000002
60796	R2	295	0.0100000000000000002
60796	2Q1	235.5	0.00300000000000000006
60796	P1	44.7999999999999972	0.0560000000000000012
60796	2SM2	182.699999999999989	0.00300000000000000006
60796	M3	63.2999999999999972	0.00300000000000000006
60796	L2	336.100000000000023	0.00300000000000000006
60796	2MK3	173.599999999999994	0.00300000000000000006
60796	K2	276	0.0100000000000000002
60796	MS4	132.599999999999994	0.00700000000000000015
60797	M2	49.8999999999999986	0.00700000000000000015
60797	S2	308.899999999999977	0.00300000000000000006
60797	K1	196.5	0.0429999999999999966
60797	O1	161.5	0.0690000000000000058
60797	M6	113	0.00300000000000000006
60797	MK3	124.799999999999997	0.00300000000000000006
60797	S4	189.599999999999994	0.00300000000000000006
60797	NU2	330.899999999999977	0.00300000000000000006
60797	S6	129.900000000000006	0.00300000000000000006
60797	MU2	181.099999999999994	0.00300000000000000006
60797	2N2	135.900000000000006	0.00300000000000000006
60797	OO1	144.900000000000006	0.0129999999999999994
60797	LDA2	182	0.00300000000000000006
60797	S1	228	0.0429999999999999966
60797	M1	326.699999999999989	0.0100000000000000002
60797	J1	138.599999999999994	0.00300000000000000006
60797	RHO1	186.300000000000011	0.00300000000000000006
60797	Q1	161.5	0.0129999999999999994
60797	T2	7.5	0.0129999999999999994
60797	R2	113	0.0259999999999999988
60797	2Q1	247	0.00700000000000000015
60797	P1	213.300000000000011	0.0229999999999999996
60797	2SM2	154.099999999999994	0.00700000000000000015
60797	M3	49.2000000000000028	0.00300000000000000006
60797	L2	205.400000000000006	0.00300000000000000006
60797	2MK3	243.199999999999989	0.00300000000000000006
60797	K2	146.800000000000011	0.0129999999999999994
60797	M8	300.300000000000011	0.00300000000000000006
60797	MS4	49.6000000000000014	0.00300000000000000006
60798	M2	319.399999999999977	0.0459999999999999992
60798	S2	308.199999999999989	0.0200000000000000004
60798	N2	307.899999999999977	0.0129999999999999994
60798	K1	73.0999999999999943	0.117999999999999994
60798	M4	188.900000000000006	0.00700000000000000015
60798	O1	70.5999999999999943	0.117999999999999994
60798	MK3	245.599999999999994	0.00700000000000000015
60798	S4	232.199999999999989	0.00300000000000000006
60798	MN4	144.800000000000011	0.00300000000000000006
60798	MU2	197.900000000000006	0.00300000000000000006
60798	OO1	91.9000000000000057	0.0129999999999999994
60798	LDA2	0	0.00300000000000000006
60798	S1	159.599999999999994	0.0160000000000000003
60798	M1	283	0.00300000000000000006
60798	J1	114.5	0.00700000000000000015
60798	RHO1	205.400000000000006	0.00700000000000000015
60798	Q1	44.7999999999999972	0.0259999999999999988
60798	T2	186.900000000000006	0.00300000000000000006
60798	R2	1	0.00300000000000000006
60798	2Q1	179.699999999999989	0.00700000000000000015
60798	P1	85.9000000000000057	0.0359999999999999973
60798	M3	109	0.00300000000000000006
60798	2MK3	232.300000000000011	0.00700000000000000015
60798	K2	348.699999999999989	0.00700000000000000015
60798	MS4	164.699999999999989	0.00300000000000000006
60799	M2	51.1000000000000014	0.0889999999999999958
60799	S2	36.6000000000000014	0.0200000000000000004
60799	N2	33.2000000000000028	0.0200000000000000004
60799	K1	108.400000000000006	0.294999999999999984
60799	M4	295.399999999999977	0.00700000000000000015
60799	O1	97	0.304999999999999993
60799	MK3	14.9000000000000004	0.00300000000000000006
60799	MN4	278.800000000000011	0.00300000000000000006
60799	NU2	269.600000000000023	0.00300000000000000006
60799	MU2	239.400000000000006	0.00700000000000000015
60799	2N2	155.400000000000006	0.0129999999999999994
60799	OO1	97.5	0.0459999999999999992
60799	LDA2	205.199999999999989	0.00300000000000000006
60799	S1	200.900000000000006	0.0429999999999999966
60799	M1	234.199999999999989	0.0200000000000000004
60799	J1	134.5	0.0160000000000000003
60799	RHO1	132.5	0.0100000000000000002
60799	Q1	77.7999999999999972	0.0690000000000000058
60799	T2	95.7999999999999972	0.00300000000000000006
60799	R2	79.2999999999999972	0.00700000000000000015
60799	2Q1	182.300000000000011	0.0160000000000000003
60799	P1	131.099999999999994	0.0889999999999999958
60799	2SM2	247.199999999999989	0.00300000000000000006
60799	M3	108.799999999999997	0.00300000000000000006
60799	L2	87.2999999999999972	0.00700000000000000015
60799	2MK3	325.100000000000023	0.00300000000000000006
60799	K2	51.5	0.0259999999999999988
60799	MS4	320	0.00300000000000000006
60800	M2	336.100000000000023	0.0490000000000000019
60800	S2	354.899999999999977	0.0229999999999999996
60800	N2	303.5	0.0129999999999999994
60800	K1	80.5999999999999943	0.256000000000000005
60800	M4	141.099999999999994	0.00700000000000000015
60800	O1	70	0.253000000000000003
60800	MK3	284.199999999999989	0.00300000000000000006
60800	S4	207.400000000000006	0.00300000000000000006
60800	MN4	104.599999999999994	0.00300000000000000006
60800	NU2	345.699999999999989	0.00300000000000000006
60800	MU2	211.400000000000006	0.00300000000000000006
60800	2N2	98.2999999999999972	0.00300000000000000006
60800	OO1	73.2999999999999972	0.0229999999999999996
60800	S1	344.899999999999977	0.0200000000000000004
60800	M1	156.099999999999994	0.00700000000000000015
60800	J1	124.099999999999994	0.00700000000000000015
60800	RHO1	35.2999999999999972	0.0100000000000000002
60800	Q1	50.3999999999999986	0.0589999999999999969
60800	2Q1	132	0.0100000000000000002
60800	P1	85.4000000000000057	0.0820000000000000034
60800	L2	12.8000000000000007	0.00300000000000000006
60800	2MK3	263.100000000000023	0.00300000000000000006
60800	K2	349.600000000000023	0.0129999999999999994
60800	MS4	120.400000000000006	0.00300000000000000006
60801	M2	245.400000000000006	0.140999999999999986
60801	S2	251.599999999999994	0.0459999999999999992
60801	N2	229.5	0.0389999999999999999
60801	K1	45.2000000000000028	0.373999999999999999
60801	M4	42.3999999999999986	0.0160000000000000003
60801	O1	38.7999999999999972	0.366999999999999993
60801	M6	202.699999999999989	0.00700000000000000015
60801	MK3	86	0.0389999999999999999
60801	S4	263.199999999999989	0.00300000000000000006
60801	MN4	39.7999999999999972	0.0100000000000000002
60801	NU2	218.199999999999989	0.00700000000000000015
60801	MU2	170.599999999999994	0.0129999999999999994
60801	2N2	96.5999999999999943	0.0229999999999999996
60801	OO1	83.5999999999999943	0.0359999999999999973
60801	LDA2	247.800000000000011	0.00300000000000000006
60801	S1	325	0.0160000000000000003
60801	M1	94.0999999999999943	0.00700000000000000015
60801	J1	71.0999999999999943	0.0259999999999999988
60801	RHO1	45	0.0229999999999999996
60801	Q1	20.6000000000000014	0.0950000000000000011
60801	T2	228.900000000000006	0.00300000000000000006
60801	R2	25.8999999999999986	0.00300000000000000006
60801	2Q1	27.6000000000000014	0.00700000000000000015
60801	P1	45.8999999999999986	0.117999999999999994
60801	2SM2	323.300000000000011	0.00300000000000000006
60801	M3	96.7000000000000028	0.0100000000000000002
60801	L2	82.7000000000000028	0.00300000000000000006
60801	2MK3	74.0999999999999943	0.0389999999999999999
60801	K2	344.199999999999989	0.0490000000000000019
60801	M8	50.8999999999999986	0.00300000000000000006
60801	MS4	48.1000000000000014	0.0100000000000000002
60802	M2	124.099999999999994	0.00300000000000000006
60802	S2	17	0.0100000000000000002
60802	K1	178.300000000000011	0.0690000000000000058
60802	O1	164.699999999999989	0.0719999999999999946
60802	MK3	359.600000000000023	0.00300000000000000006
60802	S4	319.300000000000011	0.00300000000000000006
60802	NU2	116.599999999999994	0.00300000000000000006
60802	S6	299.699999999999989	0.00300000000000000006
60802	OO1	196	0.0129999999999999994
60802	LDA2	4.90000000000000036	0.00300000000000000006
60802	S1	155.400000000000006	0.00700000000000000015
60802	M1	296.300000000000011	0.00300000000000000006
60802	J1	216.400000000000006	0.00700000000000000015
60802	RHO1	92.0999999999999943	0.00700000000000000015
60802	Q1	128.900000000000006	0.0160000000000000003
60802	T2	169.300000000000011	0.00300000000000000006
60802	R2	341.899999999999977	0.00700000000000000015
60802	2Q1	203.900000000000006	0.00700000000000000015
60802	P1	181.199999999999989	0.0259999999999999988
60802	M3	234.400000000000006	0.00300000000000000006
60802	L2	352.300000000000011	0.00300000000000000006
60802	K2	49.7000000000000028	0.00300000000000000006
60803	M2	16.8999999999999986	0.0259999999999999988
60803	S2	47.2999999999999972	0.00300000000000000006
60803	N2	358.5	0.00700000000000000015
60803	K1	117.299999999999997	0.112000000000000002
60803	M4	261.199999999999989	0.00300000000000000006
60803	O1	112	0.120999999999999996
60803	MK3	82.0999999999999943	0.00300000000000000006
60803	S4	13.1999999999999993	0.00300000000000000006
60803	NU2	181	0.00300000000000000006
60803	2N2	228.599999999999994	0.00300000000000000006
60803	OO1	124.599999999999994	0.0229999999999999996
60803	S1	313.399999999999977	0.0129999999999999994
60803	M1	266.100000000000023	0.00700000000000000015
60803	J1	138.199999999999989	0.00300000000000000006
60803	RHO1	183	0.00300000000000000006
60803	Q1	88.5999999999999943	0.0299999999999999989
60803	R2	336.699999999999989	0.00300000000000000006
60803	2Q1	146.900000000000006	0.00300000000000000006
60803	P1	118.400000000000006	0.0259999999999999988
60803	2SM2	335.399999999999977	0.00300000000000000006
60803	L2	84.9000000000000057	0.00300000000000000006
60803	2MK3	109.599999999999994	0.00300000000000000006
60803	K2	76.5999999999999943	0.00700000000000000015
60803	MS4	268.399999999999977	0.00300000000000000006
60804	M2	332	0.0259999999999999988
60804	K1	104.700000000000003	0.0980000000000000038
60804	O1	99.2999999999999972	0.0980000000000000038
60804	OO1	123.599999999999994	0.0100000000000000002
60804	S1	350.399999999999977	0.0129999999999999994
60804	M1	102	0.00700000000000000015
60804	J1	107.400000000000006	0.00700000000000000015
60804	SSA	69.9000000000000057	0.294999999999999984
60804	SA	161	0.200000000000000011
60804	RHO1	97	0.00300000000000000006
60804	Q1	76.4000000000000057	0.0200000000000000004
60804	2Q1	93.9000000000000057	0.00300000000000000006
60804	P1	103.599999999999994	0.0259999999999999988
60805	M2	75.7999999999999972	0.0359999999999999973
60805	S2	1.80000000000000004	0.0100000000000000002
60805	N2	24.8000000000000007	0.00700000000000000015
60805	K1	144.099999999999994	0.179999999999999993
60805	M4	335.399999999999977	0.00700000000000000015
60805	O1	120.599999999999994	0.183999999999999997
60805	NU2	345.300000000000011	0.00300000000000000006
60805	MU2	306.800000000000011	0.00700000000000000015
60805	2N2	248.400000000000006	0.00300000000000000006
60805	OO1	150.199999999999989	0.0229999999999999996
60805	LDA2	316.199999999999989	0.00700000000000000015
60805	S1	194.199999999999989	0.0950000000000000011
60805	M1	44.8999999999999986	0.00700000000000000015
60805	J1	226.599999999999994	0.00700000000000000015
60805	SSA	52.7999999999999972	0.456000000000000016
60805	SA	138.5	0.307999999999999996
60805	RHO1	271.5	0.00700000000000000015
60805	Q1	112.200000000000003	0.0259999999999999988
60805	T2	108.599999999999994	0.0100000000000000002
60805	R2	30.3999999999999986	0.00700000000000000015
60805	2Q1	257.199999999999989	0.00300000000000000006
60805	P1	166.599999999999994	0.0980000000000000038
60805	L2	59.8999999999999986	0.00300000000000000006
60805	K2	63.6000000000000014	0.0160000000000000003
60806	M2	258.5	0.161000000000000004
60806	S2	262.199999999999989	0.0490000000000000019
60806	N2	237.699999999999989	0.0429999999999999966
60806	K1	40.2000000000000028	0.301999999999999991
60806	M4	104.299999999999997	0.0129999999999999994
60806	O1	33.6000000000000014	0.315000000000000002
60806	M6	258.699999999999989	0.00300000000000000006
60806	MK3	137.599999999999994	0.0100000000000000002
60806	S4	229.099999999999994	0.00700000000000000015
60806	MN4	84.2999999999999972	0.00700000000000000015
60806	NU2	248.800000000000011	0.00700000000000000015
60806	MU2	188.300000000000011	0.00300000000000000006
60806	2N2	165.800000000000011	0.0160000000000000003
60806	OO1	88.7999999999999972	0.0129999999999999994
60806	LDA2	101.200000000000003	0.00300000000000000006
60806	S1	47.2999999999999972	0.0100000000000000002
60806	M1	13.3000000000000007	0.00300000000000000006
60806	J1	52.2999999999999972	0.0160000000000000003
60806	RHO1	51.7999999999999972	0.0200000000000000004
60806	Q1	12.0999999999999996	0.0719999999999999946
60806	T2	244.099999999999994	0.00700000000000000015
60806	2Q1	297.699999999999989	0.00300000000000000006
60806	P1	43.8999999999999986	0.0889999999999999958
60806	2SM2	157.599999999999994	0.00300000000000000006
60806	M3	68.2000000000000028	0.00700000000000000015
60806	L2	274.699999999999989	0.00700000000000000015
60806	2MK3	90.2000000000000028	0.0129999999999999994
60806	K2	356.300000000000011	0.0129999999999999994
60806	M8	232.300000000000011	0.00300000000000000006
60806	MS4	90.0999999999999943	0.0100000000000000002
60807	M2	254.800000000000011	0.235999999999999988
60807	S2	259.300000000000011	0.0690000000000000058
60807	N2	234.800000000000011	0.0560000000000000012
60807	K1	29.1000000000000014	0.404000000000000026
60807	M4	103.799999999999997	0.0160000000000000003
60807	O1	21.6000000000000014	0.422999999999999987
60807	M6	222.800000000000011	0.00300000000000000006
60807	MK3	129.599999999999994	0.0160000000000000003
60807	S4	237.800000000000011	0.00700000000000000015
60807	MN4	72	0.0100000000000000002
60807	NU2	235.699999999999989	0.0129999999999999994
60807	S6	120.599999999999994	0.00300000000000000006
60807	MU2	174	0.00700000000000000015
60807	2N2	180.099999999999994	0.0229999999999999996
60807	OO1	64	0.0100000000000000002
60807	LDA2	302.300000000000011	0.00300000000000000006
60807	S1	351.600000000000023	0.0129999999999999994
60807	M1	26.8999999999999986	0.00300000000000000006
60807	J1	65.5	0.0229999999999999996
60807	SSA	58.2000000000000028	0.328000000000000014
60807	SA	146	0.0889999999999999958
60807	RHO1	14.1999999999999993	0.0229999999999999996
60807	Q1	2.29999999999999982	0.0950000000000000011
60807	T2	259	0.00700000000000000015
60807	R2	323	0.00700000000000000015
60807	2Q1	299.800000000000011	0.0100000000000000002
60807	P1	32.2000000000000028	0.128000000000000003
60807	2SM2	33.7999999999999972	0.00300000000000000006
60807	M3	56.2999999999999972	0.0100000000000000002
60807	L2	255.599999999999994	0.00300000000000000006
60807	2MK3	94.5999999999999943	0.0160000000000000003
60807	K2	323.600000000000023	0.0129999999999999994
60807	MS4	94.2000000000000028	0.0100000000000000002
60808	M2	65.5	0.0490000000000000019
60808	S2	5.90000000000000036	0.0100000000000000002
60808	N2	38.6000000000000014	0.0100000000000000002
60808	K1	137.199999999999989	0.20699999999999999
60808	M4	345.300000000000011	0.00300000000000000006
60808	O1	116.599999999999994	0.216999999999999998
60808	M6	282.199999999999989	0.00300000000000000006
60808	MK3	79.2999999999999972	0.00700000000000000015
60808	S4	175.599999999999994	0.00300000000000000006
60808	MN4	316.800000000000011	0.00300000000000000006
60808	NU2	31.8000000000000007	0.00300000000000000006
60808	MU2	293.5	0.00300000000000000006
60808	2N2	127.700000000000003	0.0100000000000000002
60808	OO1	150.300000000000011	0.0299999999999999989
60808	LDA2	188.599999999999994	0.00300000000000000006
60808	S1	181.900000000000006	0.0749999999999999972
60808	M1	190.900000000000006	0.0160000000000000003
60808	J1	103	0.00700000000000000015
60808	SSA	61.5	0.20699999999999999
60808	SA	110.200000000000003	0.301999999999999991
60808	RHO1	97.2999999999999972	0.00700000000000000015
60808	Q1	96.9000000000000057	0.0359999999999999973
60808	T2	69.5	0.00300000000000000006
60808	R2	335.899999999999977	0.00300000000000000006
60808	2Q1	185.599999999999994	0.0129999999999999994
60808	P1	139.300000000000011	0.0850000000000000061
60808	2SM2	76.0999999999999943	0.00300000000000000006
60808	M3	298	0.00300000000000000006
60808	L2	113.799999999999997	0.00700000000000000015
60808	2MK3	71.9000000000000057	0.00700000000000000015
60808	K2	56.1000000000000014	0.0200000000000000004
60809	M2	262.300000000000011	0.284999999999999976
60809	S2	264.5	0.0790000000000000008
60809	N2	241.199999999999989	0.0660000000000000031
60809	K1	26.3000000000000007	0.567999999999999949
60809	O1	20	0.554000000000000048
60809	NU2	243.900000000000006	0.0129999999999999994
60809	OO1	32.6000000000000014	0.0229999999999999996
60809	M1	36.5	0.0459999999999999992
60809	J1	29.5	0.0429999999999999966
60809	MM	353.300000000000011	0.0560000000000000012
60809	SSA	53.8999999999999986	0.373999999999999999
60809	SA	173.900000000000006	0.384000000000000008
60809	MF	118.099999999999994	0.131000000000000005
60809	RHO1	17.3000000000000007	0.0200000000000000004
60809	Q1	1	0.112000000000000002
60809	2Q1	13.6999999999999993	0.0160000000000000003
60809	P1	26	0.176999999999999991
60809	K2	264.5	0.0200000000000000004
60810	M2	352.699999999999989	0.0459999999999999992
60810	S2	347.899999999999977	0.0100000000000000002
60810	N2	339.899999999999977	0.0100000000000000002
60810	K1	98.4000000000000057	0.194000000000000006
60810	M4	215.300000000000011	0.00700000000000000015
60810	O1	87.7999999999999972	0.209999999999999992
60810	NU2	335.600000000000023	0.00300000000000000006
60810	MU2	240.400000000000006	0.00300000000000000006
60810	2N2	225.400000000000006	0.00300000000000000006
60810	OO1	107.5	0.0229999999999999996
60810	S1	279.699999999999989	0.0100000000000000002
60810	M1	343.800000000000011	0.00700000000000000015
60810	J1	111.200000000000003	0.00700000000000000015
60810	SSA	58.2000000000000028	0.328000000000000014
60810	SA	146	0.0889999999999999958
60810	RHO1	60.6000000000000014	0.0100000000000000002
60810	Q1	76	0.0459999999999999992
60810	T2	44.2000000000000028	0.00300000000000000006
60810	R2	308.899999999999977	0.00300000000000000006
60810	2Q1	251.800000000000011	0.0100000000000000002
60810	P1	101.099999999999994	0.0519999999999999976
60810	L2	25.3999999999999986	0.00300000000000000006
60810	K2	43	0.0100000000000000002
60811	M2	17.6000000000000014	0.0560000000000000012
60811	S2	335.5	0.0200000000000000004
60811	N2	357.199999999999989	0.0160000000000000003
60811	K1	107.799999999999997	0.209999999999999992
60811	M4	274.699999999999989	0.00300000000000000006
60811	O1	93.7000000000000028	0.212999999999999995
60811	MK3	18.5	0.00700000000000000015
60811	S4	337.800000000000011	0.00300000000000000006
60811	MN4	250.900000000000006	0.00300000000000000006
60811	2N2	170.400000000000006	0.00300000000000000006
60811	OO1	111.599999999999994	0.0330000000000000016
60811	S1	170.800000000000011	0.0389999999999999999
60811	M1	252.400000000000006	0.0129999999999999994
60811	J1	179.400000000000006	0.00700000000000000015
60811	RHO1	78	0.0100000000000000002
60811	Q1	77.4000000000000057	0.0459999999999999992
60811	T2	332.5	0.00300000000000000006
60811	R2	340.300000000000011	0.00700000000000000015
60811	2Q1	137.599999999999994	0.0100000000000000002
60811	P1	115.599999999999994	0.0660000000000000031
60811	L2	50.3999999999999986	0.00700000000000000015
60811	2MK3	341.199999999999989	0.00300000000000000006
60811	K2	43.2000000000000028	0.0100000000000000002
60811	MS4	271.100000000000023	0.00300000000000000006
60812	M2	20.3000000000000007	0.0519999999999999976
60812	S2	14.3000000000000007	0.0229999999999999996
60812	N2	5.40000000000000036	0.0129999999999999994
60812	K1	107.900000000000006	0.203000000000000014
60812	M4	270.600000000000023	0.00300000000000000006
60812	O1	95.2000000000000028	0.212999999999999995
60812	NU2	12.5	0.00300000000000000006
60812	MU2	216.300000000000011	0.00300000000000000006
60812	2N2	244.800000000000011	0.00300000000000000006
60812	OO1	120.900000000000006	0.0259999999999999988
60812	LDA2	111	0.00300000000000000006
60812	S1	326.5	0.0100000000000000002
60812	M1	323.100000000000023	0.00700000000000000015
60812	J1	104.799999999999997	0.00700000000000000015
60812	SSA	58.1000000000000014	0.338000000000000023
60812	SA	178.900000000000006	0.0820000000000000034
60812	RHO1	85.5999999999999943	0.0100000000000000002
60812	Q1	84.2999999999999972	0.0490000000000000019
60812	R2	307.399999999999977	0.00300000000000000006
60812	2Q1	250.699999999999989	0.00700000000000000015
60812	P1	114.900000000000006	0.0619999999999999996
60812	L2	0.299999999999999989	0.00300000000000000006
60812	K2	36.2000000000000028	0.0100000000000000002
60813	M2	22.8999999999999986	0.0160000000000000003
60813	S2	6.29999999999999982	0.00700000000000000015
60813	N2	19	0.00300000000000000006
60813	K1	116	0.120999999999999996
60813	M4	101.900000000000006	0.00300000000000000006
60813	O1	107.599999999999994	0.131000000000000005
60813	MK3	187.599999999999994	0.00300000000000000006
60813	S4	206	0.00300000000000000006
60813	2N2	270.300000000000011	0.00300000000000000006
60813	OO1	124.5	0.0129999999999999994
60813	S1	16.1999999999999993	0.0229999999999999996
60813	M1	340.699999999999989	0.00300000000000000006
60813	J1	148.900000000000006	0.00700000000000000015
60813	SSA	37.5	0.39700000000000002
60813	SA	205.599999999999994	0.284999999999999976
60813	RHO1	78.7999999999999972	0.00700000000000000015
60813	Q1	90.2000000000000028	0.0259999999999999988
60813	T2	68.7000000000000028	0.00300000000000000006
60813	R2	231.599999999999994	0.00300000000000000006
60813	2Q1	241.199999999999989	0.00300000000000000006
60813	P1	114.5	0.0359999999999999973
60813	L2	38.1000000000000014	0.00300000000000000006
60813	2MK3	156.599999999999994	0.00300000000000000006
60813	K2	51.6000000000000014	0.00700000000000000015
60814	M2	260.100000000000023	0.27200000000000002
60814	S2	269.300000000000011	0.0719999999999999946
60814	N2	240.699999999999989	0.0660000000000000031
60814	K1	24.5	0.525000000000000022
60814	M4	115.400000000000006	0.0160000000000000003
60814	O1	16.8000000000000007	0.531000000000000028
60814	NU2	240.599999999999994	0.0160000000000000003
60814	2N2	221.300000000000011	0.0100000000000000002
60814	OO1	45.1000000000000014	0.0160000000000000003
60814	LDA2	264.399999999999977	0.00300000000000000006
60814	S1	291.899999999999977	0.0100000000000000002
60814	M1	64.7999999999999972	0.0229999999999999996
60814	J1	25.1999999999999993	0.0299999999999999989
60814	SSA	58.2999999999999972	0.315000000000000002
60814	SA	180.199999999999989	0.203000000000000014
60814	RHO1	1.30000000000000004	0.0259999999999999988
60814	Q1	0.699999999999999956	0.120999999999999996
60814	T2	268.899999999999977	0.00300000000000000006
60814	2Q1	337	0.0160000000000000003
60814	P1	28.5	0.161000000000000004
60814	L2	279.5	0.0100000000000000002
60814	K2	266.899999999999977	0.0200000000000000004
60815	M2	53.3999999999999986	0.0330000000000000016
60815	S2	81.7999999999999972	0.00700000000000000015
60815	N2	24.1999999999999993	0.00700000000000000015
60815	K1	123.799999999999997	0.179999999999999993
60815	M4	309.800000000000011	0.00300000000000000006
60815	O1	112.900000000000006	0.164000000000000007
60815	MK3	61.1000000000000014	0.00300000000000000006
60815	S4	191.699999999999989	0.00300000000000000006
60815	NU2	50.7999999999999972	0.00300000000000000006
60815	MU2	232.699999999999989	0.00300000000000000006
60815	2N2	198.900000000000006	0.00700000000000000015
60815	OO1	174.199999999999989	0.0129999999999999994
60815	S1	147.699999999999989	0.0200000000000000004
60815	M1	207.800000000000011	0.0100000000000000002
60815	J1	160.199999999999989	0.0100000000000000002
60815	SSA	58.7999999999999972	0.226000000000000006
60815	SA	196.099999999999994	0.179999999999999993
60815	RHO1	92.2000000000000028	0.0129999999999999994
60815	Q1	92.2000000000000028	0.0359999999999999973
60815	T2	257.600000000000023	0.00700000000000000015
60815	R2	148.900000000000006	0.00300000000000000006
60815	2Q1	287.600000000000023	0.0129999999999999994
60815	P1	116.799999999999997	0.0429999999999999966
60815	M3	217.599999999999994	0.00300000000000000006
60815	L2	39.3999999999999986	0.00300000000000000006
60815	2MK3	37.7999999999999972	0.00700000000000000015
60815	K2	50	0.0160000000000000003
60816	M2	266.699999999999989	0.187
60816	S2	273.300000000000011	0.0459999999999999992
60816	N2	247	0.0490000000000000019
60816	K1	34.7999999999999972	0.422999999999999987
60816	M4	106.599999999999994	0.00300000000000000006
60816	O1	28.8000000000000007	0.432999999999999996
60816	MK3	77.5999999999999943	0.0100000000000000002
60816	S4	243.400000000000006	0.00300000000000000006
60816	MN4	61.5	0.00300000000000000006
60816	NU2	249.800000000000011	0.0100000000000000002
60816	MU2	186.599999999999994	0.00700000000000000015
60816	2N2	153	0.00300000000000000006
60816	OO1	55.7999999999999972	0.0229999999999999996
60816	S1	322.800000000000011	0.0200000000000000004
60816	M1	99.2999999999999972	0.00700000000000000015
60816	J1	55.2999999999999972	0.0229999999999999996
60816	SSA	49.6000000000000014	0.262000000000000011
60816	SA	186.099999999999994	0.216999999999999998
60816	RHO1	25.8000000000000007	0.0259999999999999988
60816	Q1	12.1999999999999993	0.104999999999999996
60816	T2	279.399999999999977	0.00700000000000000015
60816	R2	240.400000000000006	0.00300000000000000006
60816	2Q1	0.699999999999999956	0.0129999999999999994
60816	P1	37.2999999999999972	0.128000000000000003
60816	M3	74.0999999999999943	0.00700000000000000015
60816	L2	316.899999999999977	0.00300000000000000006
60816	2MK3	69.5999999999999943	0.0129999999999999994
60816	K2	320.300000000000011	0.0229999999999999996
60816	MS4	107.099999999999994	0.00300000000000000006
60817	M2	260	0.20699999999999999
60817	S2	267.899999999999977	0.0560000000000000012
60817	N2	241.199999999999989	0.0519999999999999976
60817	K1	30.6999999999999993	0.446000000000000008
60817	M4	101	0.00300000000000000006
60817	O1	23.5	0.459000000000000019
60817	MK3	67.7999999999999972	0.0100000000000000002
60817	S4	258.300000000000011	0.00300000000000000006
60817	MN4	50	0.00300000000000000006
60817	NU2	251.5	0.0129999999999999994
60817	MU2	191.099999999999994	0.00700000000000000015
60817	2N2	183	0.0100000000000000002
60817	OO1	36.8999999999999986	0.0200000000000000004
60817	LDA2	306	0.00300000000000000006
60817	S1	337.699999999999989	0.0160000000000000003
60817	M1	40.8999999999999986	0.00300000000000000006
60817	J1	52.8999999999999986	0.0259999999999999988
60817	SSA	46.6000000000000014	0.262000000000000011
60817	SA	186.099999999999994	0.216999999999999998
60817	RHO1	26.6000000000000014	0.0229999999999999996
60817	Q1	10.0999999999999996	0.104999999999999996
60817	T2	283.699999999999989	0.00700000000000000015
60817	R2	290.5	0.00300000000000000006
60817	2Q1	344	0.0129999999999999994
60817	P1	33.1000000000000014	0.138000000000000012
60817	2SM2	33.2000000000000028	0.00300000000000000006
60817	M3	68.2000000000000028	0.00700000000000000015
60817	L2	307.300000000000011	0.00300000000000000006
60817	2MK3	58.1000000000000014	0.0129999999999999994
60817	K2	302.100000000000023	0.0229999999999999996
60817	MS4	98.7000000000000028	0.00300000000000000006
60818	M2	258.399999999999977	0.242999999999999994
60818	S2	265.100000000000023	0.0660000000000000031
60818	N2	234	0.0619999999999999996
60818	K1	28	0.518000000000000016
60818	O1	21.5	0.515000000000000013
60818	NU2	237.199999999999989	0.0129999999999999994
60818	OO1	34.5	0.0229999999999999996
60818	M1	24.6999999999999993	0.0359999999999999973
60818	J1	31.1999999999999993	0.0389999999999999999
60818	MM	202	0.0560000000000000012
60818	SSA	56.2000000000000028	0.279000000000000026
60818	SA	206.599999999999994	0.266000000000000014
60818	MSF	219.599999999999994	0.0330000000000000016
60818	MF	321.5	0.0950000000000000011
60818	RHO1	18.6999999999999993	0.0200000000000000004
60818	Q1	3.39999999999999991	0.131000000000000005
60818	2Q1	15	0.0129999999999999994
60818	P1	32.7000000000000028	0.173999999999999988
60818	K2	265.100000000000023	0.0160000000000000003
60819	M2	274.300000000000011	0.209999999999999992
60819	S2	285.800000000000011	0.0560000000000000012
60819	N2	256.800000000000011	0.0519999999999999976
60819	K1	36.5	0.432999999999999996
60819	M4	142.5	0.00300000000000000006
60819	O1	29	0.432999999999999996
60819	M6	130.099999999999994	0.00300000000000000006
60819	MK3	110.400000000000006	0.00700000000000000015
60819	S4	262.399999999999977	0.00300000000000000006
60819	MN4	92.4000000000000057	0.00300000000000000006
60819	NU2	260.300000000000011	0.0129999999999999994
60819	S6	100.599999999999994	0.00300000000000000006
60819	MU2	205.5	0.00700000000000000015
60819	2N2	216.300000000000011	0.00700000000000000015
60819	OO1	57.6000000000000014	0.0160000000000000003
60819	LDA2	328.600000000000023	0.00300000000000000006
60819	S1	8.69999999999999929	0.0129999999999999994
60819	M1	58.5	0.0160000000000000003
60819	J1	39.6000000000000014	0.0259999999999999988
60819	SSA	49.6000000000000014	0.262000000000000011
60819	SA	186.099999999999994	0.216999999999999998
60819	RHO1	15.1999999999999993	0.0200000000000000004
60819	Q1	12.5999999999999996	0.0919999999999999984
60819	T2	287.199999999999989	0.00700000000000000015
60819	R2	198.099999999999994	0.00300000000000000006
60819	2Q1	4.59999999999999964	0.0129999999999999994
60819	P1	36.2999999999999972	0.128000000000000003
60819	M3	78.7000000000000028	0.00700000000000000015
60819	L2	339.399999999999977	0.00700000000000000015
60819	2MK3	96.0999999999999943	0.00700000000000000015
60819	K2	312.399999999999977	0.0129999999999999994
60819	MS4	140.199999999999989	0.00300000000000000006
60820	M2	144.400000000000006	1.58800000000000008
60820	S2	138.400000000000006	0.640000000000000013
60820	N2	122.700000000000003	0.373999999999999999
60820	K1	210.800000000000011	1.1419999999999999
60820	M4	269.899999999999977	0.00700000000000000015
60820	O1	194.199999999999989	0.70499999999999996
60820	M6	164.199999999999989	0.00300000000000000006
60820	S4	241.599999999999994	0.0100000000000000002
60820	NU2	125.599999999999994	0.0719999999999999946
60820	MU2	150.400000000000006	0.0389999999999999999
60820	2N2	101	0.0490000000000000019
60820	OO1	227.5	0.0299999999999999989
60820	LDA2	141.599999999999994	0.0100000000000000002
60820	M1	202.599999999999994	0.0490000000000000019
60820	J1	219.199999999999989	0.0560000000000000012
60820	SSA	261	0.0519999999999999976
60820	SA	175.699999999999989	0.259000000000000008
60820	RHO1	187	0.0259999999999999988
60820	Q1	185.900000000000006	0.138000000000000012
60820	T2	138.599999999999994	0.0389999999999999999
60820	R2	138.099999999999994	0.00700000000000000015
60820	2Q1	177.699999999999989	0.0200000000000000004
60820	P1	209.599999999999994	0.377000000000000002
60820	L2	166.099999999999994	0.0459999999999999992
60820	K2	137.900000000000006	0.173999999999999988
60820	M8	175.400000000000006	0.00300000000000000006
60821	M2	143.599999999999994	1.627
60821	S2	139.599999999999994	0.663000000000000034
60821	N2	122.599999999999994	0.377000000000000002
60821	K1	208.900000000000006	1.16100000000000003
60821	M4	313.199999999999989	0.0100000000000000002
60821	O1	192.199999999999989	0.691999999999999948
60821	M6	266.300000000000011	0.00300000000000000006
60821	S4	230.5	0.00700000000000000015
60821	NU2	125.400000000000006	0.0719999999999999946
60821	MU2	147.5	0.0389999999999999999
60821	2N2	101.599999999999994	0.0490000000000000019
60821	OO1	225.699999999999989	0.0299999999999999989
60821	LDA2	141.699999999999989	0.0100000000000000002
60821	M1	200.599999999999994	0.0490000000000000019
60821	J1	217.300000000000011	0.0560000000000000012
60821	SSA	261	0.0519999999999999976
60821	SA	175.699999999999989	0.259000000000000008
60821	RHO1	185	0.0259999999999999988
60821	Q1	183.800000000000011	0.135000000000000009
60821	T2	139.800000000000011	0.0389999999999999999
60821	R2	139.5	0.00700000000000000015
60821	2Q1	175.400000000000006	0.0160000000000000003
60821	P1	207.699999999999989	0.384000000000000008
60821	L2	164.5	0.0459999999999999992
60821	K2	139.300000000000011	0.179999999999999993
60821	M8	273.5	0.00300000000000000006
60822	M2	144.699999999999989	1.85000000000000009
60822	S2	142.599999999999994	0.78400000000000003
60822	N2	125.099999999999994	0.432999999999999996
60822	K1	209.300000000000011	1.15799999999999992
60822	M4	251.699999999999989	0.00700000000000000015
60822	O1	192.699999999999989	0.70499999999999996
60822	M6	52.1000000000000014	0.0200000000000000004
60822	S4	213.599999999999994	0.0100000000000000002
60822	NU2	127.799999999999997	0.0850000000000000061
60822	S6	139.099999999999994	0.00300000000000000006
60822	MU2	146.800000000000011	0.0459999999999999992
60822	2N2	105.5	0.0589999999999999969
60822	OO1	225.900000000000006	0.0299999999999999989
60822	LDA2	143.699999999999989	0.0129999999999999994
60822	M1	201	0.0490000000000000019
60822	J1	217.5	0.0560000000000000012
60822	SA	179.300000000000011	0.226000000000000006
60822	RHO1	185.5	0.0259999999999999988
60822	Q1	184.400000000000006	0.138000000000000012
60822	T2	142.699999999999989	0.0459999999999999992
60822	R2	142.5	0.00700000000000000015
60822	2Q1	176.199999999999989	0.0200000000000000004
60822	P1	208	0.384000000000000008
60822	L2	164.300000000000011	0.0519999999999999976
60822	K2	142.400000000000006	0.212999999999999995
60822	M8	111.700000000000003	0.00300000000000000006
60823	M2	142.300000000000011	1.67599999999999993
60823	S2	137.900000000000006	0.708999999999999964
60823	N2	123.700000000000003	0.39700000000000002
60823	K1	207.099999999999994	1.11499999999999999
60823	M4	273.300000000000011	0.0160000000000000003
60823	O1	191.599999999999994	0.695999999999999952
60823	NU2	126.200000000000003	0.0749999999999999972
60823	MU2	146.900000000000006	0.0389999999999999999
60823	2N2	105	0.0519999999999999976
60823	OO1	222.400000000000006	0.0299999999999999989
60823	LDA2	140.300000000000011	0.0129999999999999994
60823	M1	199.400000000000006	0.0490000000000000019
60823	J1	214.699999999999989	0.0560000000000000012
60823	SA	184.300000000000011	0.226000000000000006
60823	RHO1	185.099999999999994	0.0259999999999999988
60823	Q1	184	0.135000000000000009
60823	T2	138	0.0429999999999999966
60823	2Q1	176.300000000000011	0.0160000000000000003
60823	P1	205.900000000000006	0.370999999999999996
60823	L2	161	0.0459999999999999992
60823	K2	137.5	0.194000000000000006
60823	M8	343	0.00300000000000000006
60824	M2	143.199999999999989	1.82400000000000007
60824	S2	140.199999999999989	0.751000000000000001
60824	N2	123.799999999999997	0.426999999999999991
60824	K1	208	1.1379999999999999
60824	O1	192.400000000000006	0.721999999999999975
60824	M6	61.3999999999999986	0.0129999999999999994
60824	NU2	128.800000000000011	0.0820000000000000034
60824	MU2	93	0.0519999999999999976
60824	2N2	97.5	0.0519999999999999976
60824	OO1	241.099999999999994	0.0359999999999999973
60824	LDA2	128.800000000000011	0.0100000000000000002
60824	S1	338.800000000000011	0.0129999999999999994
60824	M1	220.400000000000006	0.0429999999999999966
60824	J1	220.599999999999994	0.0660000000000000031
60824	SA	179.300000000000011	0.226000000000000006
60824	RHO1	184.300000000000011	0.0299999999999999989
60824	Q1	184.699999999999989	0.135000000000000009
60824	T2	127.299999999999997	0.0459999999999999992
60824	R2	140.099999999999994	0.00700000000000000015
60824	2Q1	182.099999999999994	0.0129999999999999994
60824	P1	205.5	0.357999999999999985
60824	M3	346.100000000000023	0.0100000000000000002
60824	L2	144	0.0490000000000000019
60824	K2	134.300000000000011	0.220000000000000001
60825	M2	144	1.68300000000000005
60825	S2	141.199999999999989	0.695999999999999952
60825	N2	123.700000000000003	0.394000000000000017
60825	K1	208.800000000000011	1.125
60825	M4	232.199999999999989	0.00300000000000000006
60825	O1	192.300000000000011	0.688999999999999946
60825	M6	343.100000000000023	0.00700000000000000015
60825	S4	218.800000000000011	0.00700000000000000015
60825	NU2	126.400000000000006	0.0749999999999999972
60825	MU2	146.699999999999989	0.0389999999999999999
60825	2N2	103.5	0.0519999999999999976
60825	OO1	225.300000000000011	0.0299999999999999989
60825	LDA2	142.699999999999989	0.0129999999999999994
60825	M1	200.599999999999994	0.0490000000000000019
60825	J1	217	0.0560000000000000012
60825	SSA	261	0.0519999999999999976
60825	SA	175.699999999999989	0.259000000000000008
60825	RHO1	185.199999999999989	0.0259999999999999988
60825	Q1	184.099999999999994	0.135000000000000009
60825	T2	141.300000000000011	0.0429999999999999966
60825	R2	141.099999999999994	0.00700000000000000015
60825	2Q1	175.800000000000011	0.0160000000000000003
60825	P1	207.599999999999994	0.373999999999999999
60825	L2	164.199999999999989	0.0459999999999999992
60825	K2	141	0.190000000000000002
60825	M8	339.300000000000011	0.00300000000000000006
60826	M2	142	1.6399999999999999
60826	S2	138.599999999999994	0.669000000000000039
60826	N2	121.700000000000003	0.384000000000000008
60826	K1	207	1.08899999999999997
60826	O1	191.800000000000011	0.698999999999999955
60826	NU2	126.5	0.0749999999999999972
60826	MU2	85.4000000000000057	0.0560000000000000012
60826	2N2	94.2000000000000028	0.0490000000000000019
60826	OO1	244.199999999999989	0.0330000000000000016
60826	LDA2	141.5	0.0100000000000000002
60826	M1	221	0.0359999999999999973
60826	J1	221	0.0660000000000000031
60826	SSA	261	0.0519999999999999976
60826	SA	175.699999999999989	0.259000000000000008
60826	RHO1	180.599999999999994	0.0229999999999999996
60826	Q1	184.400000000000006	0.125
60826	T2	131.900000000000006	0.0359999999999999973
60826	R2	77.4000000000000057	0.0100000000000000002
60826	2Q1	177.199999999999989	0.0160000000000000003
60826	P1	203.099999999999994	0.343999999999999972
60826	M3	346.800000000000011	0.0100000000000000002
60826	L2	132	0.0330000000000000016
60826	K2	130.400000000000006	0.190000000000000002
60827	M2	144.400000000000006	1.65999999999999992
60827	S2	140.199999999999989	0.669000000000000039
60827	N2	124.099999999999994	0.390000000000000013
60827	K1	208	1.10200000000000009
60827	M4	282.399999999999977	0.0100000000000000002
60827	O1	192.699999999999989	0.70499999999999996
60827	NU2	126.200000000000003	0.0719999999999999946
60827	MU2	84.2000000000000028	0.0519999999999999976
60827	2N2	97.2999999999999972	0.0519999999999999976
60827	OO1	239.5	0.0359999999999999973
60827	LDA2	142.400000000000006	0.0129999999999999994
60827	S1	312.800000000000011	0.0200000000000000004
60827	M1	218	0.0389999999999999999
60827	J1	218.400000000000006	0.0660000000000000031
60827	SSA	280.199999999999989	0.0459999999999999992
60827	SA	183.400000000000006	0.20699999999999999
60827	RHO1	186.199999999999989	0.0259999999999999988
60827	Q1	184.400000000000006	0.128000000000000003
60827	T2	128.800000000000011	0.0389999999999999999
60827	R2	140.099999999999994	0.00700000000000000015
60827	2Q1	177.5	0.0160000000000000003
60827	P1	203.300000000000011	0.347999999999999976
60827	M3	354.199999999999989	0.0100000000000000002
60827	L2	148	0.0490000000000000019
60827	K2	133.099999999999994	0.197000000000000008
60828	M2	145.5	1.68999999999999995
60828	S2	141.099999999999994	0.666000000000000036
60828	N2	123.700000000000003	0.39700000000000002
60828	K1	207.699999999999989	1.125
60828	O1	192.300000000000011	0.714999999999999969
60828	NU2	130.199999999999989	0.0749999999999999972
60828	MU2	88.0999999999999943	0.0560000000000000012
60828	2N2	95.0999999999999943	0.0490000000000000019
60828	OO1	236.900000000000006	0.0359999999999999973
60828	LDA2	166.400000000000006	0.0100000000000000002
60828	S1	314.100000000000023	0.0100000000000000002
60828	M1	222.599999999999994	0.0389999999999999999
60828	J1	219.099999999999994	0.0660000000000000031
60828	SA	184.400000000000006	0.216999999999999998
60828	RHO1	182.099999999999994	0.0259999999999999988
60828	Q1	185	0.128000000000000003
60828	T2	129.699999999999989	0.0389999999999999999
60828	R2	167.5	0.0100000000000000002
60828	2Q1	186.099999999999994	0.0129999999999999994
60828	P1	204.599999999999994	0.350999999999999979
60828	M3	350.100000000000023	0.0100000000000000002
60828	L2	134.199999999999989	0.0259999999999999988
60828	K2	135.5	0.197000000000000008
60829	M2	145.599999999999994	1.72599999999999998
60829	S2	140.800000000000011	0.682000000000000051
60829	N2	124	0.409999999999999976
60829	K1	207.699999999999989	1.14500000000000002
60829	O1	192.400000000000006	0.724999999999999978
60829	NU2	131	0.0790000000000000008
60829	MU2	88.7000000000000028	0.0589999999999999969
60829	2N2	96.7000000000000028	0.0519999999999999976
60829	OO1	238.099999999999994	0.0359999999999999973
60829	LDA2	143.300000000000011	0.0129999999999999994
60829	S1	329.399999999999977	0.0129999999999999994
60829	M1	220.099999999999994	0.0389999999999999999
60829	J1	220	0.0660000000000000031
60829	SSA	282	0.0560000000000000012
60829	SA	181.599999999999994	0.187
60829	MF	135.800000000000011	0.0200000000000000004
60829	RHO1	185.800000000000011	0.0299999999999999989
60829	Q1	184	0.135000000000000009
60829	T2	129	0.0429999999999999966
60829	R2	140.699999999999989	0.00700000000000000015
60829	2Q1	177.099999999999994	0.0200000000000000004
60829	P1	204.099999999999994	0.360999999999999988
60829	M3	352.800000000000011	0.0100000000000000002
60829	L2	167.199999999999989	0.0490000000000000019
60829	K2	134.699999999999989	0.200000000000000011
60830	M2	146.800000000000011	1.66700000000000004
60830	S2	143.099999999999994	0.663000000000000034
60830	N2	125.299999999999997	0.394000000000000017
60830	K1	208.900000000000006	1.12200000000000011
60830	M4	284.300000000000011	0.00700000000000000015
60830	O1	193.5	0.714999999999999969
60830	S4	270.199999999999989	0.00700000000000000015
60830	MN4	226.599999999999994	0.00300000000000000006
60830	NU2	132.199999999999989	0.0749999999999999972
60830	S6	30.6000000000000014	0.00300000000000000006
60830	MU2	88.9000000000000057	0.0560000000000000012
60830	2N2	97.9000000000000057	0.0490000000000000019
60830	OO1	236.599999999999994	0.0359999999999999973
60830	LDA2	154.599999999999994	0.0100000000000000002
60830	S1	290.699999999999989	0.0129999999999999994
60830	M1	219	0.0389999999999999999
60830	J1	221.300000000000011	0.0660000000000000031
60830	SSA	265.5	0.0389999999999999999
60830	SA	177.900000000000006	0.245999999999999996
60830	RHO1	186	0.0259999999999999988
60830	Q1	185.599999999999994	0.128000000000000003
60830	T2	129.400000000000006	0.0429999999999999966
60830	R2	120.400000000000006	0.00300000000000000006
60830	2Q1	182.099999999999994	0.0160000000000000003
60830	P1	205.300000000000011	0.350999999999999979
60830	2SM2	347.5	0.00700000000000000015
60830	M3	349.699999999999989	0.0100000000000000002
60830	L2	155.300000000000011	0.0259999999999999988
60830	2MK3	133	0.00300000000000000006
60830	K2	135.300000000000011	0.187
60830	MS4	218.5	0.00300000000000000006
60831	M2	154.800000000000011	1.64700000000000002
60831	S2	149.099999999999994	0.596999999999999975
60831	N2	133	0.394000000000000017
60831	K1	211.699999999999989	1.16500000000000004
60831	M4	282.5	0.0100000000000000002
60831	O1	196.699999999999989	0.72799999999999998
60831	MK3	137.300000000000011	0.00300000000000000006
60831	S4	269.699999999999989	0.00300000000000000006
60831	MN4	236.5	0.00300000000000000006
60831	NU2	137.199999999999989	0.0749999999999999972
60831	S6	53.3999999999999986	0.00300000000000000006
60831	MU2	93.2999999999999972	0.0519999999999999976
60831	2N2	105.5	0.0490000000000000019
60831	OO1	246.699999999999989	0.0389999999999999999
60831	LDA2	155.099999999999994	0.0100000000000000002
60831	S1	323.600000000000023	0.0229999999999999996
60831	M1	222.5	0.0429999999999999966
60831	J1	222.099999999999994	0.0719999999999999946
60831	SA	176	0.23899999999999999
60831	RHO1	186	0.0259999999999999988
60831	Q1	187.599999999999994	0.135000000000000009
60831	T2	138.699999999999989	0.0330000000000000016
60831	R2	113.900000000000006	0.00700000000000000015
60831	2Q1	188.099999999999994	0.0129999999999999994
60831	P1	207.800000000000011	0.366999999999999993
60831	2SM2	332.399999999999977	0.00700000000000000015
60831	M3	357.399999999999977	0.0100000000000000002
60831	L2	169	0.0589999999999999969
60831	2MK3	69.0999999999999943	0.00300000000000000006
60831	K2	141.400000000000006	0.173999999999999988
60831	M8	15.0999999999999996	0.00300000000000000006
60832	M2	156.400000000000006	1.6339999999999999
60832	S2	150.800000000000011	0.580999999999999961
60832	N2	133.199999999999989	0.384000000000000008
60832	K1	212.400000000000006	1.16100000000000003
60832	M4	288.800000000000011	0.00700000000000000015
60832	O1	197.199999999999989	0.734999999999999987
60832	MK3	246.199999999999989	0.00300000000000000006
60832	S4	286.199999999999989	0.00300000000000000006
60832	MN4	239.900000000000006	0.00300000000000000006
60832	NU2	140.099999999999994	0.0719999999999999946
60832	S6	73.5	0.00300000000000000006
60832	MU2	94.7999999999999972	0.0490000000000000019
60832	2N2	104.200000000000003	0.0490000000000000019
60832	OO1	241.199999999999989	0.0359999999999999973
60832	LDA2	177.699999999999989	0.00700000000000000015
60832	S1	307.899999999999977	0.0229999999999999996
60832	M1	220.699999999999989	0.0389999999999999999
60832	J1	226.199999999999989	0.0690000000000000058
60832	SA	176	0.23899999999999999
60832	MF	158.400000000000006	0.0200000000000000004
60832	RHO1	189.099999999999994	0.0259999999999999988
60832	Q1	189.400000000000006	0.135000000000000009
60832	T2	139.5	0.0330000000000000016
60832	R2	113.299999999999997	0.00700000000000000015
60832	2Q1	185.599999999999994	0.0129999999999999994
60832	P1	207.5	0.366999999999999993
60832	2SM2	336.300000000000011	0.00700000000000000015
60832	M3	1.80000000000000004	0.0100000000000000002
60832	L2	167.199999999999989	0.0200000000000000004
60832	2MK3	146.800000000000011	0.00300000000000000006
60832	K2	143.099999999999994	0.16700000000000001
60832	M8	295	0.00300000000000000006
60832	MS4	292	0.00300000000000000006
60833	M2	158.300000000000011	1.59800000000000009
60833	S2	151.300000000000011	0.558000000000000052
60833	N2	133.199999999999989	0.373999999999999999
60833	K1	211.400000000000006	1.16100000000000003
60833	M4	275.600000000000023	0.0100000000000000002
60833	O1	198.400000000000006	0.717999999999999972
60833	M6	349.399999999999977	0.00300000000000000006
60833	S4	311.100000000000023	0.00700000000000000015
60833	NU2	136.5	0.0719999999999999946
60833	S6	99.9000000000000057	0.00300000000000000006
60833	MU2	165.300000000000011	0.0389999999999999999
60833	2N2	108.099999999999994	0.0490000000000000019
60833	OO1	224.5	0.0299999999999999989
60833	LDA2	155	0.0100000000000000002
60833	M1	204.900000000000006	0.0519999999999999976
60833	J1	217.900000000000006	0.0560000000000000012
60833	SA	156.800000000000011	0.259000000000000008
60833	RHO1	192.800000000000011	0.0259999999999999988
60833	Q1	191.900000000000006	0.140999999999999986
60833	T2	151.599999999999994	0.0330000000000000016
60833	R2	151	0.00300000000000000006
60833	2Q1	185.5	0.0200000000000000004
60833	P1	210.5	0.384000000000000008
60833	L2	183.400000000000006	0.0459999999999999992
60833	K2	150.699999999999989	0.150999999999999995
60833	M8	37.5	0.00300000000000000006
60834	M2	162.599999999999994	1.61099999999999999
60834	S2	156.699999999999989	0.531000000000000028
60834	N2	138.699999999999989	0.384000000000000008
60834	K1	214.800000000000011	1.18799999999999994
60834	M4	305.800000000000011	0.0160000000000000003
60834	O1	200.199999999999989	0.751000000000000001
60834	MK3	29.1999999999999993	0.0200000000000000004
60834	NU2	147.5	0.0749999999999999972
60834	MU2	92.5999999999999943	0.0490000000000000019
60834	2N2	106.900000000000006	0.0359999999999999973
60834	OO1	245.5	0.0389999999999999999
60834	LDA2	186.5	0.0160000000000000003
60834	S1	323.600000000000023	0.0459999999999999992
60834	M1	223.400000000000006	0.0459999999999999992
60834	J1	224.800000000000011	0.0690000000000000058
60834	SSA	280.100000000000023	0.0560000000000000012
60834	SA	195.599999999999994	0.16700000000000001
60834	RHO1	168.5	0.0229999999999999996
60834	Q1	192.199999999999989	0.131000000000000005
60834	T2	153.599999999999994	0.0259999999999999988
60834	2Q1	170.5	0.0200000000000000004
60834	P1	211.699999999999989	0.387000000000000011
60834	L2	199.400000000000006	0.0389999999999999999
60834	K2	150.099999999999994	0.143999999999999989
60835	M2	168.099999999999994	1.64399999999999991
60835	S2	163.699999999999989	0.491999999999999993
60835	N2	144	0.384000000000000008
60835	K1	214.699999999999989	1.18799999999999994
60835	O1	198.800000000000011	0.744999999999999996
60835	NU2	150.199999999999989	0.0719999999999999946
60835	MU2	103.099999999999994	0.0490000000000000019
60835	2N2	114.599999999999994	0.0459999999999999992
60835	OO1	242.199999999999989	0.0389999999999999999
60835	LDA2	188.099999999999994	0.0100000000000000002
60835	S1	315.5	0.0200000000000000004
60835	M1	222.199999999999989	0.0459999999999999992
60835	J1	225.599999999999994	0.0719999999999999946
60835	SSA	279.100000000000023	0.104999999999999996
60835	SA	191.900000000000006	0.183999999999999997
60835	MF	123.700000000000003	0.0200000000000000004
60835	RHO1	194.800000000000011	0.0299999999999999989
60835	Q1	190.699999999999989	0.135000000000000009
60835	T2	151.699999999999989	0.0299999999999999989
60835	R2	163.599999999999994	0.00300000000000000006
60835	2Q1	186.5	0.0129999999999999994
60835	P1	211.900000000000006	0.377000000000000002
60835	L2	187.199999999999989	0.0389999999999999999
60835	K2	156.099999999999994	0.143999999999999989
60836	M2	174.800000000000011	1.60099999999999998
60836	S2	173.699999999999989	0.446000000000000008
60836	N2	147.900000000000006	0.347999999999999976
60836	K1	218.699999999999989	1.14500000000000002
60836	M4	321.600000000000023	0.0100000000000000002
60836	O1	202.300000000000011	0.711999999999999966
60836	M6	262.300000000000011	0.00700000000000000015
60836	S4	256.399999999999977	0.00700000000000000015
60836	NU2	151.5	0.0690000000000000058
60836	S6	167.800000000000011	0.00700000000000000015
60836	MU2	175.800000000000011	0.0389999999999999999
60836	2N2	121.099999999999994	0.0459999999999999992
60836	OO1	235.099999999999994	0.0299999999999999989
60836	LDA2	174.300000000000011	0.0100000000000000002
60836	M1	210.5	0.0490000000000000019
60836	J1	226.800000000000011	0.0560000000000000012
60836	SSA	279.100000000000023	0.104999999999999996
60836	SA	191.900000000000006	0.183999999999999997
60836	RHO1	195.199999999999989	0.0259999999999999988
60836	Q1	194.099999999999994	0.138000000000000012
60836	T2	173.800000000000011	0.0259999999999999988
60836	R2	173.599999999999994	0.00300000000000000006
60836	2Q1	186	0.0200000000000000004
60836	P1	217.5	0.381000000000000005
60836	L2	201.400000000000006	0.0459999999999999992
60836	K2	173.599999999999994	0.120999999999999996
60836	M8	118.400000000000006	0.00300000000000000006
60837	M2	181.300000000000011	1.61099999999999999
60837	S2	180.099999999999994	0.426999999999999991
60837	N2	155	0.366999999999999993
60837	K1	219.599999999999994	1.20100000000000007
60837	M4	272.699999999999989	0.00300000000000000006
60837	O1	203.5	0.751000000000000001
60837	S4	343.5	0.00300000000000000006
60837	MN4	233.400000000000006	0.00300000000000000006
60837	NU2	160.900000000000006	0.0719999999999999946
60837	MU2	114.700000000000003	0.0429999999999999966
60837	2N2	125.400000000000006	0.0459999999999999992
60837	OO1	246.400000000000006	0.0359999999999999973
60837	LDA2	213.599999999999994	0.0100000000000000002
60837	S1	317.100000000000023	0.0259999999999999988
60837	M1	224.900000000000006	0.0429999999999999966
60837	J1	232.300000000000011	0.0719999999999999946
60837	SSA	264.600000000000023	0.0660000000000000031
60837	SA	198.5	0.203000000000000014
60837	MF	138.099999999999994	0.0359999999999999973
60837	RHO1	197	0.0229999999999999996
60837	Q1	194.800000000000011	0.135000000000000009
60837	T2	165.300000000000011	0.0229999999999999996
60837	R2	163.199999999999989	0.00300000000000000006
60837	2Q1	191.699999999999989	0.0160000000000000003
60837	P1	215.800000000000011	0.377000000000000002
60837	2SM2	348.100000000000023	0.00300000000000000006
60837	M3	7	0.0100000000000000002
60837	L2	213.400000000000006	0.0359999999999999973
60837	2MK3	126.799999999999997	0.00300000000000000006
60837	K2	170.599999999999994	0.120999999999999996
60837	MS4	264	0.00300000000000000006
60838	M2	189.900000000000006	1.64999999999999991
60838	S2	197.800000000000011	0.404000000000000026
60838	N2	168.900000000000006	0.357999999999999985
60838	K1	228.400000000000006	1.16799999999999993
60838	M4	113.200000000000003	0.0589999999999999969
60838	O1	212.099999999999994	0.717999999999999972
60838	M6	116.900000000000006	0.0160000000000000003
60838	MK3	198.5	0.0429999999999999966
60838	S4	79.5999999999999943	0.00300000000000000006
60838	MN4	93.9000000000000057	0.0229999999999999996
60838	NU2	166.5	0.0660000000000000031
60838	S6	166	0.00300000000000000006
60838	MU2	220.300000000000011	0.00700000000000000015
60838	2N2	147.5	0.0490000000000000019
60838	OO1	253.900000000000006	0.0429999999999999966
60838	LDA2	149.300000000000011	0.0299999999999999989
60838	S1	7.40000000000000036	0.0490000000000000019
60838	M1	239.699999999999989	0.0459999999999999992
60838	J1	245.699999999999989	0.0589999999999999969
60838	RHO1	178.800000000000011	0.0160000000000000003
60838	Q1	208.199999999999989	0.125
60838	T2	230.199999999999989	0.0229999999999999996
60838	R2	173.5	0.0429999999999999966
60838	2Q1	179.599999999999994	0.0129999999999999994
60838	P1	220.199999999999989	0.33500000000000002
60838	2SM2	338.199999999999989	0.0100000000000000002
60838	M3	312.899999999999977	0.0100000000000000002
60838	L2	167.099999999999994	0.0660000000000000031
60838	2MK3	206	0.0389999999999999999
60838	K2	175.400000000000006	0.138000000000000012
60838	M8	74.0999999999999943	0.00700000000000000015
60838	MS4	122.400000000000006	0.0330000000000000016
60839	M2	194.400000000000006	1.61099999999999999
60839	S2	196.5	0.466000000000000025
60839	N2	173.099999999999994	0.366999999999999993
60839	K1	228.699999999999989	1.15799999999999992
60839	M4	144	0.0820000000000000034
60839	O1	213.900000000000006	0.717999999999999972
60839	M6	147.099999999999994	0.0389999999999999999
60839	S4	290.800000000000011	0.00300000000000000006
60839	NU2	176	0.0719999999999999946
60839	MU2	309	0.0389999999999999999
60839	2N2	151.900000000000006	0.0490000000000000019
60839	OO1	243.5	0.0299999999999999989
60839	LDA2	195.300000000000011	0.0100000000000000002
60839	M1	221.400000000000006	0.0519999999999999976
60839	J1	236	0.0560000000000000012
60839	RHO1	207.599999999999994	0.0259999999999999988
60839	Q1	206.599999999999994	0.138000000000000012
60839	T2	196.400000000000006	0.0259999999999999988
60839	R2	196.599999999999994	0.00300000000000000006
60839	2Q1	199.199999999999989	0.0200000000000000004
60839	P1	227.599999999999994	0.384000000000000008
60839	L2	215.699999999999989	0.0459999999999999992
60839	K2	196.699999999999989	0.128000000000000003
60839	M8	101.400000000000006	0.0100000000000000002
60840	M2	195	1.65999999999999992
60840	S2	200.599999999999994	0.475999999999999979
60840	N2	174	0.373999999999999999
60840	K1	229.5	1.15500000000000003
60840	M4	146.599999999999994	0.0889999999999999958
60840	O1	214.199999999999989	0.724999999999999978
60840	M6	148.900000000000006	0.0459999999999999992
60840	S4	254.800000000000011	0.00300000000000000006
60840	NU2	176.800000000000011	0.0719999999999999946
60840	MU2	248.199999999999989	0.0229999999999999996
60840	2N2	153.099999999999994	0.0490000000000000019
60840	OO1	244.800000000000011	0.0330000000000000016
60840	LDA2	197.400000000000006	0.0129999999999999994
60840	M1	221.900000000000006	0.0519999999999999976
60840	J1	237.099999999999994	0.0560000000000000012
60840	SSA	264.600000000000023	0.0660000000000000031
60840	SA	198.5	0.203000000000000014
60840	MF	138.099999999999994	0.0359999999999999973
60840	RHO1	207.5	0.0259999999999999988
60840	Q1	206.599999999999994	0.140999999999999986
60840	T2	200.300000000000011	0.0299999999999999989
60840	R2	200.800000000000011	0.00300000000000000006
60840	2Q1	199	0.0200000000000000004
60840	P1	228.400000000000006	0.384000000000000008
60840	L2	215.900000000000006	0.0459999999999999992
60840	K2	201.099999999999994	0.128000000000000003
60840	M8	108	0.0129999999999999994
60841	M2	193	1.68999999999999995
60841	S2	199.099999999999994	0.468999999999999972
60841	N2	171.300000000000011	0.400000000000000022
60841	K1	228.699999999999989	1.16500000000000004
60841	M4	139.099999999999994	0.0719999999999999946
60841	O1	214.900000000000006	0.731999999999999984
60841	M6	141	0.0330000000000000016
60841	S4	202.199999999999989	0.00700000000000000015
60841	NU2	174.199999999999989	0.0749999999999999972
60841	S6	181.300000000000011	0.00300000000000000006
60841	MU2	186.599999999999994	0.0389999999999999999
60841	2N2	149.699999999999989	0.0519999999999999976
60841	OO1	242.400000000000006	0.0299999999999999989
60841	LDA2	195.800000000000011	0.0129999999999999994
60841	M1	221.800000000000011	0.0519999999999999976
60841	J1	235.5	0.0560000000000000012
60841	RHO1	209	0.0259999999999999988
60841	Q1	208.099999999999994	0.140999999999999986
60841	T2	198.900000000000006	0.0259999999999999988
60841	R2	199.400000000000006	0.00300000000000000006
60841	2Q1	201.300000000000011	0.0200000000000000004
60841	P1	227.599999999999994	0.384000000000000008
60841	L2	214.5	0.0459999999999999992
60841	K2	199.599999999999994	0.128000000000000003
60841	M8	78.2999999999999972	0.0100000000000000002
60842	M2	184.099999999999994	1.78099999999999992
60842	S2	189.599999999999994	0.471999999999999975
60842	N2	158.400000000000006	0.390000000000000013
60842	K1	217.300000000000011	1.15199999999999991
60842	M4	283	0.00700000000000000015
60842	O1	203.300000000000011	0.737999999999999989
60842	M6	351.300000000000011	0.00300000000000000006
60842	S4	253.900000000000006	0.00300000000000000006
60842	NU2	161.900000000000006	0.0749999999999999972
60842	S6	107.799999999999997	0.00700000000000000015
60842	MU2	178.699999999999989	0.0429999999999999966
60842	2N2	132.599999999999994	0.0519999999999999976
60842	OO1	231.400000000000006	0.0330000000000000016
60842	LDA2	186.699999999999989	0.0129999999999999994
60842	M1	210.400000000000006	0.0519999999999999976
60842	J1	224.300000000000011	0.0589999999999999969
60842	SSA	286.899999999999977	0.128000000000000003
60842	SA	221.400000000000006	0.125
60842	RHO1	197.199999999999989	0.0299999999999999989
60842	Q1	196.300000000000011	0.143999999999999989
60842	T2	189.300000000000011	0.0299999999999999989
60842	R2	189.800000000000011	0.00300000000000000006
60842	2Q1	189.300000000000011	0.0200000000000000004
60842	P1	216.300000000000011	0.381000000000000005
60842	L2	209.800000000000011	0.0490000000000000019
60842	K2	190	0.128000000000000003
60842	M8	323.699999999999989	0.00300000000000000006
60843	M2	208.199999999999989	1.8899999999999999
60843	S2	216.199999999999989	0.44900000000000001
60843	N2	183.199999999999989	0.400000000000000022
60843	K1	225.400000000000006	1.21399999999999997
60843	M4	136.800000000000011	0.0719999999999999946
60843	O1	208.400000000000006	0.755000000000000004
60843	M6	7.29999999999999982	0.00700000000000000015
60843	MK3	124.099999999999994	0.0589999999999999969
60843	MN4	112	0.0259999999999999988
60843	NU2	189.900000000000006	0.0850000000000000061
60843	MU2	100.200000000000003	0.0229999999999999996
60843	2N2	153.300000000000011	0.0429999999999999966
60843	OO1	260	0.0389999999999999999
60843	LDA2	214.300000000000011	0.0229999999999999996
60843	S1	282.600000000000023	0.0229999999999999996
60843	M1	237.5	0.0359999999999999973
60843	J1	244.300000000000011	0.0619999999999999996
60843	SSA	272.300000000000011	0.0980000000000000038
60843	SA	200.199999999999989	0.143999999999999989
60843	MF	153.099999999999994	0.0490000000000000019
60843	RHO1	200	0.0299999999999999989
60843	Q1	202.400000000000006	0.135000000000000009
60843	T2	204.599999999999994	0.0299999999999999989
60843	R2	126.799999999999997	0.00300000000000000006
60843	2Q1	208.599999999999994	0.0200000000000000004
60843	P1	222.099999999999994	0.373999999999999999
60843	2SM2	37.2999999999999972	0.0100000000000000002
60843	M3	37.6000000000000014	0.0100000000000000002
60843	L2	229.599999999999994	0.0589999999999999969
60843	2MK3	92.2000000000000028	0.0459999999999999992
60843	K2	206	0.131000000000000005
60843	M8	108.5	0.00300000000000000006
60843	MS4	149	0.0330000000000000016
60844	M2	213.300000000000011	1.9910000000000001
60844	S2	220.699999999999989	0.463000000000000023
60844	N2	187	0.422999999999999987
60844	K1	226.800000000000011	1.23399999999999999
60844	M4	135.900000000000006	0.0950000000000000011
60844	O1	209.699999999999989	0.758000000000000007
60844	MK3	124	0.0850000000000000061
60844	MN4	108.599999999999994	0.0359999999999999973
60844	NU2	191.599999999999994	0.0889999999999999958
60844	MU2	88.0999999999999943	0.0229999999999999996
60844	2N2	154.099999999999994	0.0459999999999999992
60844	OO1	262.699999999999989	0.0429999999999999966
60844	LDA2	215	0.0259999999999999988
60844	S1	276.5	0.0229999999999999996
60844	M1	248.5	0.0429999999999999966
60844	J1	248.5	0.0619999999999999996
60844	SSA	286.899999999999977	0.128000000000000003
60844	SA	221.400000000000006	0.125
60844	RHO1	198.400000000000006	0.0330000000000000016
60844	Q1	202.699999999999989	0.131000000000000005
60844	T2	201.800000000000011	0.0259999999999999988
60844	R2	221	0.00300000000000000006
60844	2Q1	186.300000000000011	0.0160000000000000003
60844	P1	223.800000000000011	0.390000000000000013
60844	M3	29.8000000000000007	0.0299999999999999989
60844	L2	225.5	0.0619999999999999996
60844	2MK3	91.5	0.0619999999999999996
60844	K2	211.5	0.135000000000000009
60844	MS4	147.099999999999994	0.0389999999999999999
60845	M2	218.900000000000006	2.11299999999999999
60845	S2	227.199999999999989	0.468999999999999972
60845	N2	193.5	0.435999999999999999
60845	K1	229.5	1.25
60845	M4	135.199999999999989	0.0790000000000000008
60845	O1	212.800000000000011	0.758000000000000007
60845	M6	70.7000000000000028	0.0160000000000000003
60845	MK3	118.799999999999997	0.0820000000000000034
60845	MN4	110	0.0299999999999999989
60845	NU2	199	0.0850000000000000061
60845	MU2	76.7000000000000028	0.0229999999999999996
60845	2N2	160.099999999999994	0.0459999999999999992
60845	OO1	263.600000000000023	0.0459999999999999992
60845	LDA2	204.900000000000006	0.0259999999999999988
60845	S1	273.199999999999989	0.0229999999999999996
60845	M1	254.400000000000006	0.0429999999999999966
60845	J1	255.599999999999994	0.0589999999999999969
60845	SSA	286.899999999999977	0.128000000000000003
60845	SA	221.400000000000006	0.125
60845	RHO1	202.5	0.0299999999999999989
60845	Q1	207.300000000000011	0.131000000000000005
60845	T2	217.900000000000006	0.0299999999999999989
60845	R2	227.5	0.00300000000000000006
60845	2Q1	182.599999999999994	0.0129999999999999994
60845	P1	227.099999999999994	0.394000000000000017
60845	2SM2	48.3999999999999986	0.0160000000000000003
60845	M3	37.6000000000000014	0.0259999999999999988
60845	L2	226.400000000000006	0.0790000000000000008
60845	2MK3	86.0999999999999943	0.0719999999999999946
60845	K2	217.300000000000011	0.147999999999999993
60845	MS4	150.5	0.0299999999999999989
60846	M2	223.599999999999994	2.31599999999999984
60846	S2	236.5	0.535000000000000031
60846	N2	199.5	0.481999999999999984
60846	K1	232.099999999999994	1.29299999999999993
60846	M4	141	0.0619999999999999996
60846	O1	214.800000000000011	0.768000000000000016
60846	M6	59.7000000000000028	0.0229999999999999996
60846	MK3	113.299999999999997	0.0749999999999999972
60846	MN4	112.900000000000006	0.0200000000000000004
60846	NU2	198.400000000000006	0.104999999999999996
60846	MU2	41.2999999999999972	0.0200000000000000004
60846	2N2	172.900000000000006	0.0459999999999999992
60846	OO1	275	0.0429999999999999966
60846	LDA2	217.5	0.0429999999999999966
60846	S1	271.5	0.0389999999999999999
60846	M1	254	0.0490000000000000019
60846	J1	265.5	0.0660000000000000031
60846	SSA	286.899999999999977	0.128000000000000003
60846	SA	221.400000000000006	0.125
60846	RHO1	177.099999999999994	0.0429999999999999966
60846	Q1	215.699999999999989	0.143999999999999989
60846	T2	181.5	0.0330000000000000016
60846	R2	250.800000000000011	0.0200000000000000004
60846	2Q1	242.199999999999989	0.0200000000000000004
60846	P1	231.099999999999994	0.406999999999999973
60846	2SM2	69.0999999999999943	0.0160000000000000003
60846	M3	43.2999999999999972	0.0259999999999999988
60846	L2	224.900000000000006	0.101999999999999993
60846	2MK3	81.5	0.0790000000000000008
60846	K2	216.199999999999989	0.147999999999999993
60846	MS4	173.599999999999994	0.0229999999999999996
60847	M2	235.5	2.4700000000000002
60847	S2	246.599999999999994	0.54500000000000004
60847	N2	213.400000000000006	0.512000000000000011
60847	K1	238.300000000000011	1.31200000000000006
60847	M4	179	0.0330000000000000016
60847	O1	221.699999999999989	0.787000000000000033
60847	M6	79.2999999999999972	0.0200000000000000004
60847	MK3	115.200000000000003	0.0690000000000000058
60847	MN4	149.300000000000011	0.0100000000000000002
60847	NU2	193.300000000000011	0.112000000000000002
60847	MU2	45.1000000000000014	0.0299999999999999989
60847	2N2	194.099999999999994	0.0490000000000000019
60847	OO1	290.600000000000023	0.0389999999999999999
60847	LDA2	187.400000000000006	0.0129999999999999994
60847	S1	280.600000000000023	0.0589999999999999969
60847	M1	267	0.0490000000000000019
60847	J1	271.899999999999977	0.0589999999999999969
60847	SSA	286.899999999999977	0.128000000000000003
60847	SA	221.400000000000006	0.125
60847	RHO1	195	0.0359999999999999973
60847	Q1	219.900000000000006	0.140999999999999986
60847	T2	196.699999999999989	0.0389999999999999999
60847	R2	23.8999999999999986	0.0389999999999999999
60847	2Q1	229	0.0200000000000000004
60847	P1	237.5	0.404000000000000026
60847	2SM2	31.3000000000000007	0.0229999999999999996
60847	M3	42.7000000000000028	0.0259999999999999988
60847	L2	233.900000000000006	0.131000000000000005
60847	2MK3	86.5	0.0850000000000000061
60847	K2	228.599999999999994	0.171000000000000013
60848	M2	238	2.70999999999999996
60848	S2	253.300000000000011	0.596999999999999975
60848	N2	216	0.54500000000000004
60848	K1	239.5	1.31600000000000006
60848	M4	340.399999999999977	0.0389999999999999999
60848	O1	223.900000000000006	0.791000000000000036
60848	M6	48.2000000000000028	0.0299999999999999989
60848	MK3	83	0.0690000000000000058
60848	MN4	318.300000000000011	0.0200000000000000004
60848	NU2	216.5	0.128000000000000003
60848	MU2	9	0.0560000000000000012
60848	2N2	199.099999999999994	0.0560000000000000012
60848	OO1	281.699999999999989	0.0490000000000000019
60848	LDA2	218.599999999999994	0.0560000000000000012
60848	S1	229	0.0359999999999999973
60848	M1	274.399999999999977	0.0459999999999999992
60848	J1	275.399999999999977	0.0660000000000000031
60848	SSA	286.899999999999977	0.128000000000000003
60848	SA	221.400000000000006	0.125
60848	MF	139.599999999999994	0.0429999999999999966
60848	RHO1	217.300000000000011	0.0299999999999999989
60848	Q1	221.400000000000006	0.140999999999999986
60848	T2	225.900000000000006	0.0330000000000000016
60848	R2	47.5	0.0129999999999999994
60848	2Q1	236.099999999999994	0.0160000000000000003
60848	P1	238.800000000000011	0.412999999999999978
60848	2SM2	56.2000000000000028	0.0259999999999999988
60848	L2	233.199999999999989	0.125
60848	2MK3	65.7000000000000028	0.115000000000000005
60848	K2	238.900000000000006	0.203000000000000014
60848	MS4	3	0.0259999999999999988
60849	M2	241.699999999999989	2.8580000000000001
60849	S2	259.800000000000011	0.627000000000000002
60849	N2	219.800000000000011	0.586999999999999966
60849	K1	240.900000000000006	1.3620000000000001
60849	M4	2.10000000000000009	0.0359999999999999973
60849	O1	225.099999999999994	0.813999999999999946
60849	M6	55.2999999999999972	0.0359999999999999973
60849	MK3	93	0.0950000000000000011
60849	MN4	13	0.0160000000000000003
60849	NU2	227.5	0.125
60849	MU2	11	0.0690000000000000058
60849	2N2	208.199999999999989	0.0429999999999999966
60849	OO1	279.199999999999989	0.0429999999999999966
60849	LDA2	216	0.0619999999999999996
60849	S1	222.599999999999994	0.0459999999999999992
60849	M1	268.300000000000011	0.0490000000000000019
60849	J1	282.5	0.0589999999999999969
60849	SSA	286.899999999999977	0.128000000000000003
60849	SA	221.400000000000006	0.125
60849	RHO1	195.300000000000011	0.0330000000000000016
60849	Q1	225.900000000000006	0.150999999999999995
60849	T2	234	0.0389999999999999999
60849	R2	260.600000000000023	0.00700000000000000015
60849	2Q1	214.800000000000011	0.0160000000000000003
60849	P1	237.400000000000006	0.419999999999999984
60849	2SM2	47.3999999999999986	0.0299999999999999989
60849	M3	3.79999999999999982	0.0299999999999999989
60849	L2	229.5	0.176999999999999991
60849	2MK3	77.5	0.128000000000000003
60849	K2	238.099999999999994	0.197000000000000008
60849	M8	119.200000000000003	0.0129999999999999994
60849	MS4	7.09999999999999964	0.0299999999999999989
60850	M2	246.699999999999989	3.03799999999999981
60850	S2	264.199999999999989	0.650000000000000022
60850	N2	225.599999999999994	0.59099999999999997
60850	K1	244	1.37799999999999989
60850	M4	10.1999999999999993	0.0589999999999999969
60850	O1	228.900000000000006	0.810000000000000053
60850	M6	49.8999999999999986	0.0560000000000000012
60850	MK3	95.5999999999999943	0.104999999999999996
60850	MN4	356.699999999999989	0.0299999999999999989
60850	NU2	226.800000000000011	0.138000000000000012
60850	MU2	25.6999999999999993	0.0690000000000000058
60850	2N2	199.599999999999994	0.0690000000000000058
60850	OO1	283.199999999999989	0.0389999999999999999
60850	LDA2	212.199999999999989	0.0389999999999999999
60850	S1	218.300000000000011	0.0719999999999999946
60850	M1	272.399999999999977	0.0459999999999999992
60850	J1	281.899999999999977	0.0560000000000000012
60850	SSA	286.899999999999977	0.128000000000000003
60850	SA	221.400000000000006	0.125
60850	RHO1	215.5	0.0389999999999999999
60850	Q1	228.099999999999994	0.147999999999999993
60850	T2	249.300000000000011	0.0330000000000000016
60850	R2	264.899999999999977	0.00700000000000000015
60850	2Q1	215.900000000000006	0.0299999999999999989
60850	P1	240.800000000000011	0.44900000000000001
60850	2SM2	75	0.0259999999999999988
60850	M3	354.399999999999977	0.0229999999999999996
60850	L2	237.099999999999994	0.190000000000000002
60850	2MK3	80.5999999999999943	0.150999999999999995
60850	K2	244.599999999999994	0.235999999999999988
60850	M8	105.799999999999997	0.0100000000000000002
60850	MS4	23.3000000000000007	0.0429999999999999966
60851	M2	240.699999999999989	2.89999999999999991
60851	S2	258.600000000000023	0.630000000000000004
60851	N2	219.199999999999989	0.576999999999999957
60851	K1	240.800000000000011	1.3680000000000001
60851	M4	335.899999999999977	0.0359999999999999973
60851	O1	225.5	0.804000000000000048
60851	M6	43.1000000000000014	0.0389999999999999999
60851	MK3	89.7999999999999972	0.0889999999999999958
60851	MN4	331.300000000000011	0.0160000000000000003
60851	NU2	221.300000000000011	0.131000000000000005
60851	MU2	1.39999999999999991	0.0690000000000000058
60851	2N2	201.599999999999994	0.0490000000000000019
60851	OO1	289.399999999999977	0.0459999999999999992
60851	LDA2	214.300000000000011	0.0589999999999999969
60851	S1	217.699999999999989	0.0519999999999999976
60851	M1	269.5	0.0459999999999999992
60851	J1	280.600000000000023	0.0589999999999999969
60851	SSA	286.899999999999977	0.128000000000000003
60851	SA	221.400000000000006	0.125
60851	RHO1	206.099999999999994	0.0389999999999999999
60851	Q1	224.599999999999994	0.143999999999999989
60851	T2	223.300000000000011	0.0299999999999999989
60851	R2	64.9000000000000057	0.0160000000000000003
60851	2Q1	230.400000000000006	0.0200000000000000004
60851	P1	237.900000000000006	0.426999999999999991
60851	2SM2	61.7999999999999972	0.0299999999999999989
60851	M3	1.60000000000000009	0.0200000000000000004
60851	L2	230.199999999999989	0.176999999999999991
60851	2MK3	71.7000000000000028	0.128000000000000003
60851	K2	240.300000000000011	0.203000000000000014
60851	MS4	358.300000000000011	0.0299999999999999989
60852	M2	250.099999999999994	3.12699999999999978
60852	S2	273.800000000000011	0.698999999999999955
60852	N2	232.699999999999989	0.627000000000000002
60852	K1	246.900000000000006	1.30200000000000005
60852	M4	1.60000000000000009	0.161000000000000004
60852	O1	232.800000000000011	0.737999999999999989
60852	M6	44.1000000000000014	0.0690000000000000058
60852	MK3	66.7999999999999972	0.0950000000000000011
60852	S4	96.4000000000000057	0.0100000000000000002
60852	MN4	342.800000000000011	0.0719999999999999946
60852	NU2	227.099999999999994	0.150999999999999995
60852	S6	322.600000000000023	0.00300000000000000006
60852	MU2	357.199999999999989	0.128000000000000003
60852	2N2	220.199999999999989	0.0589999999999999969
60852	OO1	307.699999999999989	0.0359999999999999973
60852	LDA2	224.199999999999989	0.0820000000000000034
60852	S1	214.900000000000006	0.101999999999999993
60852	M1	283.5	0.0589999999999999969
60852	J1	300.300000000000011	0.0589999999999999969
60852	SSA	272.300000000000011	0.0980000000000000038
60852	SA	200.199999999999989	0.143999999999999989
60852	RHO1	227	0.0259999999999999988
60852	Q1	235.099999999999994	0.135000000000000009
60852	T2	229	0.0389999999999999999
60852	R2	43.8999999999999986	0.0299999999999999989
60852	2Q1	246.5	0.0129999999999999994
60852	P1	246.099999999999994	0.400000000000000022
60852	2SM2	68.9000000000000057	0.0359999999999999973
60852	M3	146.699999999999989	0.0359999999999999973
60852	L2	241.199999999999989	0.216999999999999998
60852	2MK3	68	0.161000000000000004
60852	K2	254.300000000000011	0.220000000000000001
60852	M8	96.2000000000000028	0.0200000000000000004
60852	MS4	24.3000000000000007	0.0919999999999999984
60853	M2	239.599999999999994	2.5259999999999998
60853	S2	254.900000000000006	0.528000000000000025
60853	N2	217.5	0.525000000000000022
60853	K1	242.099999999999994	1.30899999999999994
60853	M4	81.2000000000000028	0.0129999999999999994
60853	O1	226.5	0.771000000000000019
60853	M6	71.0999999999999943	0.0129999999999999994
60853	MK3	95.4000000000000057	0.0850000000000000061
60853	S4	75.2000000000000028	0.00300000000000000006
60853	MN4	39.8999999999999986	0.0100000000000000002
60853	NU2	223.699999999999989	0.143999999999999989
60853	MU2	357.5	0.0299999999999999989
60853	2N2	175	0.0820000000000000034
60853	OO1	271.399999999999977	0.0490000000000000019
60853	LDA2	252.5	0.0790000000000000008
60853	S1	325.5	0.0490000000000000019
60853	M1	269.699999999999989	0.0619999999999999996
60853	J1	274.199999999999989	0.0690000000000000058
60853	SSA	288.300000000000011	0.120999999999999996
60853	SA	227.800000000000011	0.104999999999999996
60853	MF	147.5	0.0429999999999999966
60853	RHO1	236.099999999999994	0.0259999999999999988
60853	Q1	223.300000000000011	0.140999999999999986
60853	T2	250.699999999999989	0.0820000000000000034
60853	R2	12.1999999999999993	0.0359999999999999973
60853	2Q1	175.099999999999994	0.0160000000000000003
60853	P1	240.099999999999994	0.366999999999999993
60853	2SM2	61.2000000000000028	0.0259999999999999988
60853	M3	112.099999999999994	0.0129999999999999994
60853	L2	229.699999999999989	0.125
60853	2MK3	66.5	0.104999999999999996
60853	K2	233.400000000000006	0.194000000000000006
60853	MS4	50.7999999999999972	0.0129999999999999994
60854	M2	221.5	2.19200000000000017
60854	S2	234.599999999999994	0.54500000000000004
60854	N2	196.400000000000006	0.440000000000000002
60854	K1	229.900000000000006	1.2430000000000001
60854	M4	114.5	0.0749999999999999972
60854	O1	215.699999999999989	0.758000000000000007
60854	M6	64.2000000000000028	0.0100000000000000002
60854	S4	206.400000000000006	0.00300000000000000006
60854	NU2	199.800000000000011	0.0850000000000000061
60854	S6	225.5	0.00300000000000000006
60854	MU2	208.199999999999989	0.0519999999999999976
60854	2N2	171.5	0.0589999999999999969
60854	OO1	244.099999999999994	0.0330000000000000016
60854	LDA2	227.599999999999994	0.0160000000000000003
60854	M1	222.900000000000006	0.0560000000000000012
60854	J1	236.900000000000006	0.0589999999999999969
60854	SSA	288.300000000000011	0.120999999999999996
60854	SA	227.800000000000011	0.104999999999999996
60854	MF	147.5	0.0429999999999999966
60854	RHO1	209.599999999999994	0.0299999999999999989
60854	Q1	208.699999999999989	0.147999999999999993
60854	T2	234	0.0330000000000000016
60854	R2	235.199999999999989	0.00300000000000000006
60854	2Q1	201.599999999999994	0.0200000000000000004
60854	P1	228.800000000000011	0.412999999999999978
60854	L2	246.5	0.0619999999999999996
60854	K2	235.699999999999989	0.147999999999999993
60854	M8	224.800000000000011	0.00300000000000000006
60855	M2	223.300000000000011	2.23099999999999987
60855	S2	234.400000000000006	0.502000000000000002
60855	N2	199.5	0.459000000000000019
60855	K1	232.699999999999989	1.2430000000000001
60855	M4	138.199999999999989	0.0459999999999999992
60855	O1	216.199999999999989	0.758000000000000007
60855	M6	32	0.0229999999999999996
60855	MK3	105.299999999999997	0.0589999999999999969
60855	MN4	119.5	0.0160000000000000003
60855	NU2	205.199999999999989	0.104999999999999996
60855	MU2	36.1000000000000014	0.0259999999999999988
60855	2N2	173.900000000000006	0.0490000000000000019
60855	OO1	276.399999999999977	0.0359999999999999973
60855	LDA2	217.400000000000006	0.0330000000000000016
60855	S1	282.399999999999977	0.0359999999999999973
60855	M1	256.899999999999977	0.0389999999999999999
60855	J1	258.300000000000011	0.0619999999999999996
60855	SSA	272.5	0.0950000000000000011
60855	SA	187.800000000000011	0.131000000000000005
60855	MF	153.199999999999989	0.0589999999999999969
60855	RHO1	209.800000000000011	0.0299999999999999989
60855	Q1	211.300000000000011	0.135000000000000009
60855	T2	219.699999999999989	0.0330000000000000016
60855	R2	68.2999999999999972	0.00700000000000000015
60855	2Q1	215.199999999999989	0.0160000000000000003
60855	P1	230.099999999999994	0.384000000000000008
60855	2SM2	42.7999999999999972	0.0160000000000000003
60855	M3	121.900000000000006	0.0100000000000000002
60855	L2	236.699999999999989	0.0950000000000000011
60855	2MK3	72.4000000000000057	0.0690000000000000058
60855	K2	222.199999999999989	0.153999999999999998
60855	MS4	161.300000000000011	0.0160000000000000003
60856	M2	221	2.08000000000000007
60856	S2	228.900000000000006	0.528000000000000025
60856	N2	197.199999999999989	0.453000000000000014
60856	K1	231.199999999999989	1.25299999999999989
60856	M4	130	0.0749999999999999972
60856	O1	215.400000000000006	0.721999999999999975
60856	M6	79.9000000000000057	0.0160000000000000003
60856	S4	265.199999999999989	0.00300000000000000006
60856	NU2	200.400000000000006	0.0889999999999999958
60856	S6	297.600000000000023	0.00300000000000000006
60856	MU2	213.099999999999994	0.0490000000000000019
60856	2N2	173.400000000000006	0.0589999999999999969
60856	OO1	246.900000000000006	0.0299999999999999989
60856	LDA2	224.699999999999989	0.0129999999999999994
60856	M1	223.300000000000011	0.0490000000000000019
60856	J1	239	0.0560000000000000012
60856	SSA	288.300000000000011	0.120999999999999996
60856	SA	227.800000000000011	0.104999999999999996
60856	MF	147.5	0.0429999999999999966
60856	RHO1	208.5	0.0259999999999999988
60856	Q1	207.5	0.140999999999999986
60856	T2	228.599999999999994	0.0330000000000000016
60856	R2	229.300000000000011	0.00300000000000000006
60856	2Q1	199.699999999999989	0.0200000000000000004
60856	P1	230	0.416999999999999982
60856	L2	244.599999999999994	0.0589999999999999969
60856	K2	229.599999999999994	0.143999999999999989
60857	M2	222.400000000000006	2.15899999999999981
60857	S2	231.5	0.505000000000000004
60857	N2	199.099999999999994	0.404000000000000026
60857	K1	231.300000000000011	1.2629999999999999
60857	M4	155.099999999999994	0.0490000000000000019
60857	O1	216.599999999999994	0.758000000000000007
60857	M6	39	0.0259999999999999988
60857	S4	282.699999999999989	0.0100000000000000002
60857	NU2	202.199999999999989	0.0790000000000000008
60857	MU2	213.400000000000006	0.0519999999999999976
60857	2N2	175.699999999999989	0.0519999999999999976
60857	OO1	246	0.0330000000000000016
60857	LDA2	226.599999999999994	0.0160000000000000003
60857	M1	224	0.0519999999999999976
60857	J1	238.599999999999994	0.0589999999999999969
60857	SSA	288.300000000000011	0.120999999999999996
60857	SA	227.800000000000011	0.104999999999999996
60857	MF	147.5	0.0429999999999999966
60857	RHO1	210.300000000000011	0.0299999999999999989
60857	Q1	209.300000000000011	0.147999999999999993
60857	T2	231.099999999999994	0.0299999999999999989
60857	R2	231.800000000000011	0.00300000000000000006
60857	2Q1	202	0.0200000000000000004
60857	P1	230.199999999999989	0.416999999999999982
60857	L2	245.800000000000011	0.0589999999999999969
60857	K2	232.199999999999989	0.138000000000000012
60857	M8	182.400000000000006	0.00700000000000000015
60858	M2	214.800000000000011	1.80099999999999993
60858	S2	222	0.422999999999999987
60858	N2	189.199999999999989	0.400000000000000022
60858	K1	229.400000000000006	1.19100000000000006
60858	M4	166.5	0.0619999999999999996
60858	O1	212.599999999999994	0.740999999999999992
60858	M6	29.8000000000000007	0.00700000000000000015
60858	MK3	143.800000000000011	0.0490000000000000019
60858	MN4	150.300000000000011	0.0229999999999999996
60858	NU2	198.599999999999994	0.0790000000000000008
60858	S6	71.2999999999999972	0.00300000000000000006
60858	MU2	108.299999999999997	0.0200000000000000004
60858	2N2	160.099999999999994	0.0389999999999999999
60858	OO1	249.900000000000006	0.0330000000000000016
60858	LDA2	224.599999999999994	0.0259999999999999988
60858	S1	219.699999999999989	0.0160000000000000003
60858	M1	235.300000000000011	0.0359999999999999973
60858	J1	246.199999999999989	0.0660000000000000031
60858	SSA	272.300000000000011	0.0980000000000000038
60858	SA	200.199999999999989	0.143999999999999989
60858	MF	153.099999999999994	0.0490000000000000019
60858	RHO1	221.699999999999989	0.0229999999999999996
60858	Q1	207.300000000000011	0.128000000000000003
60858	T2	203.300000000000011	0.0259999999999999988
60858	2Q1	208	0.0160000000000000003
60858	P1	227.199999999999989	0.377000000000000002
60858	2SM2	45.2999999999999972	0.00700000000000000015
60858	L2	243.300000000000011	0.0560000000000000012
60858	2MK3	104.700000000000003	0.0359999999999999973
60858	K2	214.099999999999994	0.120999999999999996
60858	MS4	177.699999999999989	0.0299999999999999989
60859	M2	300.399999999999977	1.96199999999999997
60859	S2	301.199999999999989	0.373999999999999999
60859	N2	274.100000000000023	0.419999999999999984
60859	K1	281.199999999999989	1.03699999999999992
60859	M4	161.5	0.125
60859	O1	255.800000000000011	0.52200000000000002
60859	M6	337.600000000000023	0.0719999999999999946
60859	S4	347.5	0.00700000000000000015
60859	NU2	277.699999999999989	0.0820000000000000034
60859	S6	186.5	0.00300000000000000006
60859	MU2	55.7999999999999972	0.0459999999999999992
60859	2N2	247.900000000000006	0.0560000000000000012
60859	OO1	306.699999999999989	0.0229999999999999996
60859	LDA2	300.800000000000011	0.0129999999999999994
60859	M1	268.600000000000023	0.0359999999999999973
60859	J1	293.899999999999977	0.0429999999999999966
60859	RHO1	244.900000000000006	0.0200000000000000004
60859	Q1	243.099999999999994	0.101999999999999993
60859	T2	301.199999999999989	0.0229999999999999996
60859	R2	301.300000000000011	0.00300000000000000006
60859	2Q1	230.5	0.0129999999999999994
60859	P1	279.300000000000011	0.343999999999999972
60859	L2	326.699999999999989	0.0560000000000000012
60859	K2	301.300000000000011	0.101999999999999993
60859	M8	183.300000000000011	0.0100000000000000002
60860	M2	219.699999999999989	2.01100000000000012
60860	S2	229.099999999999994	0.468999999999999972
60860	N2	195.300000000000011	0.440000000000000002
60860	K1	229.900000000000006	1.2430000000000001
60860	M4	186.400000000000006	0.0429999999999999966
60860	O1	214.199999999999989	0.737999999999999989
60860	M6	119.900000000000006	0.0129999999999999994
60860	S4	293.800000000000011	0.00700000000000000015
60860	NU2	198.5	0.0850000000000000061
60860	MU2	210.199999999999989	0.0490000000000000019
60860	2N2	170.800000000000011	0.0589999999999999969
60860	OO1	245.599999999999994	0.0330000000000000016
60860	LDA2	224.099999999999994	0.0129999999999999994
60860	M1	222.099999999999994	0.0519999999999999976
60860	J1	237.699999999999989	0.0589999999999999969
60860	SSA	272.300000000000011	0.0980000000000000038
60860	SA	200.199999999999989	0.143999999999999989
60860	MF	153.099999999999994	0.0490000000000000019
60860	RHO1	207.300000000000011	0.0299999999999999989
60860	Q1	206.300000000000011	0.143999999999999989
60860	T2	228.699999999999989	0.0259999999999999988
60860	R2	229.5	0.00300000000000000006
60860	2Q1	198.599999999999994	0.0200000000000000004
60860	P1	228.699999999999989	0.409999999999999976
60860	L2	244.099999999999994	0.0560000000000000012
60860	K2	229.900000000000006	0.128000000000000003
60860	M8	221	0.00300000000000000006
60861	M2	215.5	1.85000000000000009
60861	S2	222.400000000000006	0.429999999999999993
60861	N2	190	0.394000000000000017
60861	K1	230.599999999999994	1.19399999999999995
60861	M4	181	0.0560000000000000012
60861	O1	212.900000000000006	0.734999999999999987
60861	M6	36.5	0.0129999999999999994
60861	MK3	139.900000000000006	0.0359999999999999973
60861	S4	247.5	0.00300000000000000006
60861	MN4	161.5	0.0200000000000000004
60861	NU2	199.800000000000011	0.0690000000000000058
60861	MU2	112.400000000000006	0.0229999999999999996
60861	2N2	160.400000000000006	0.0359999999999999973
60861	OO1	242.199999999999989	0.0389999999999999999
60861	LDA2	215.900000000000006	0.0299999999999999989
60861	S1	272.199999999999989	0.0259999999999999988
60861	M1	239.900000000000006	0.0429999999999999966
60861	J1	245.699999999999989	0.0660000000000000031
60861	SSA	272.300000000000011	0.0980000000000000038
60861	SA	200.199999999999989	0.143999999999999989
60861	MF	153.099999999999994	0.0490000000000000019
60861	RHO1	222.300000000000011	0.0229999999999999996
60861	Q1	207.400000000000006	0.120999999999999996
60861	T2	237.900000000000006	0.0200000000000000004
60861	2Q1	238.099999999999994	0.00700000000000000015
60861	P1	228.5	0.384000000000000008
60861	2SM2	40.7000000000000028	0.0129999999999999994
60861	L2	245.099999999999994	0.0619999999999999996
60861	2MK3	95.2999999999999972	0.0389999999999999999
60861	K2	213.099999999999994	0.138000000000000012
60861	MS4	192	0.0259999999999999988
60862	M2	223.099999999999994	2.02099999999999991
60862	S2	233.599999999999994	0.468999999999999972
60862	N2	197.099999999999994	0.426999999999999991
60862	K1	233.099999999999994	1.22700000000000009
60862	M4	207.800000000000011	0.0359999999999999973
60862	O1	216.900000000000006	0.747999999999999998
60862	M6	92.4000000000000057	0.0160000000000000003
60862	MK3	149.199999999999989	0.0389999999999999999
60862	MN4	187.099999999999994	0.0160000000000000003
60862	NU2	200.599999999999994	0.0889999999999999958
60862	MU2	99.2000000000000028	0.0200000000000000004
60862	2N2	171.599999999999994	0.0429999999999999966
60862	OO1	261.199999999999989	0.0299999999999999989
60862	LDA2	225.099999999999994	0.0299999999999999989
60862	S1	250.699999999999989	0.0330000000000000016
60862	M1	249.800000000000011	0.0259999999999999988
60862	J1	254.900000000000006	0.0619999999999999996
60862	SSA	259.800000000000011	0.0950000000000000011
60862	SA	223.900000000000006	0.157000000000000001
60862	RHO1	220.5	0.0299999999999999989
60862	Q1	210.5	0.128000000000000003
60862	T2	200.199999999999989	0.0359999999999999973
60862	R2	234	0.00300000000000000006
60862	2Q1	216.300000000000011	0.0100000000000000002
60862	P1	229.800000000000011	0.390000000000000013
60862	2SM2	62.6000000000000014	0.0100000000000000002
60862	L2	246.300000000000011	0.0660000000000000031
60862	2MK3	96.0999999999999943	0.0389999999999999999
60862	K2	225.900000000000006	0.135000000000000009
60862	MS4	216.800000000000011	0.0160000000000000003
60863	M2	215.199999999999989	1.31899999999999995
60863	S2	228.400000000000006	0.284999999999999976
60863	N2	190.599999999999994	0.248999999999999999
60863	K1	240.400000000000006	0.944999999999999951
60863	M4	355.399999999999977	0.0719999999999999946
60863	O1	228.599999999999994	0.518000000000000016
60863	M6	30.1999999999999993	0.0229999999999999996
60863	MK3	353.300000000000011	0.0749999999999999972
60863	S4	28.6999999999999993	0.00700000000000000015
60863	MN4	347	0.0259999999999999988
60863	NU2	183.199999999999989	0.0619999999999999996
60863	MU2	31	0.0519999999999999976
60863	2N2	129.800000000000011	0.0490000000000000019
60863	OO1	288.300000000000011	0.0299999999999999989
60863	LDA2	177.099999999999994	0.0229999999999999996
60863	S1	30.6000000000000014	0.0129999999999999994
60863	M1	256.800000000000011	0.0100000000000000002
60863	J1	288.399999999999977	0.0299999999999999989
60863	SSA	285.300000000000011	0.101999999999999993
60863	SA	217.699999999999989	0.200000000000000011
60863	RHO1	218.800000000000011	0.0330000000000000016
60863	Q1	241.5	0.0889999999999999958
60863	T2	234.400000000000006	0.0259999999999999988
60863	R2	262	0.0160000000000000003
60863	2Q1	251.699999999999989	0.0259999999999999988
60863	P1	239.900000000000006	0.262000000000000011
60863	2SM2	31.8999999999999986	0.0100000000000000002
60863	M3	304.300000000000011	0.0200000000000000004
60863	L2	216.400000000000006	0.0619999999999999996
60863	2MK3	350.899999999999977	0.0790000000000000008
60863	K2	202.099999999999994	0.120999999999999996
60863	M8	137.099999999999994	0.00700000000000000015
60863	MS4	17.5	0.0429999999999999966
60864	M2	190.400000000000006	1.80400000000000005
60864	S2	196.300000000000011	0.44900000000000001
60864	N2	164.099999999999994	0.39700000000000002
60864	K1	219.900000000000006	1.2569999999999999
60864	M4	259.100000000000023	0.00300000000000000006
60864	O1	204.099999999999994	0.771000000000000019
60864	MK3	200.400000000000006	0.00300000000000000006
60864	S4	0.800000000000000044	0.00300000000000000006
60864	MN4	236.699999999999989	0.00300000000000000006
60864	NU2	170	0.0790000000000000008
60864	S6	66.7999999999999972	0.00300000000000000006
60864	MU2	124.5	0.0429999999999999966
60864	2N2	135.300000000000011	0.0459999999999999992
60864	OO1	249.800000000000011	0.0389999999999999999
60864	LDA2	221.099999999999994	0.0100000000000000002
60864	S1	316.300000000000011	0.0519999999999999976
60864	M1	227.199999999999989	0.0429999999999999966
60864	J1	233.800000000000011	0.0749999999999999972
60864	SSA	263.300000000000011	0.115000000000000005
60864	SA	213.300000000000011	0.194000000000000006
60864	RHO1	198.400000000000006	0.0259999999999999988
60864	Q1	196.699999999999989	0.138000000000000012
60864	T2	189.400000000000006	0.0229999999999999996
60864	R2	287.800000000000011	0.00300000000000000006
60864	2Q1	197.900000000000006	0.0160000000000000003
60864	P1	215	0.387000000000000011
60864	2SM2	347.699999999999989	0.00300000000000000006
60864	M3	10.8000000000000007	0.00700000000000000015
60864	L2	219.699999999999989	0.0299999999999999989
60864	2MK3	165.5	0.00300000000000000006
60864	K2	187	0.125
60865	M2	29.8000000000000007	1.11899999999999999
60865	S2	50.8999999999999986	0.212999999999999995
60865	N2	10.8000000000000007	0.200000000000000011
60865	K1	330.699999999999989	0.646000000000000019
60865	M4	326.600000000000023	0.0490000000000000019
60865	O1	326	0.440000000000000002
60865	M6	155.400000000000006	0.0459999999999999992
60865	S4	45.1000000000000014	0.00700000000000000015
60865	NU2	13.3000000000000007	0.0389999999999999999
60865	MU2	8.19999999999999929	0.0259999999999999988
60865	2N2	351.800000000000011	0.0259999999999999988
60865	OO1	335.300000000000011	0.0200000000000000004
60865	LDA2	39.7000000000000028	0.00700000000000000015
60865	M1	328.300000000000011	0.0330000000000000016
60865	J1	332.899999999999977	0.0359999999999999973
60865	RHO1	324.399999999999977	0.0160000000000000003
60865	Q1	323.800000000000011	0.0850000000000000061
60865	T2	50.5	0.0129999999999999994
60865	R2	47.3999999999999986	0.00300000000000000006
60865	2Q1	320.800000000000011	0.0129999999999999994
60865	P1	330.300000000000011	0.212999999999999995
60865	L2	48.6000000000000014	0.0330000000000000016
60865	K2	52.7000000000000028	0.0560000000000000012
60865	M8	133.099999999999994	0.00300000000000000006
60866	M2	239.400000000000006	2.09600000000000009
60866	S2	253.199999999999989	0.505000000000000004
60866	N2	213.599999999999994	0.416999999999999982
60866	K1	239.300000000000011	1.20100000000000007
60866	M4	36.2000000000000028	0.0100000000000000002
60866	O1	225.599999999999994	0.734999999999999987
60866	M6	97.5	0.0259999999999999988
60866	S4	5.40000000000000036	0.00700000000000000015
60866	NU2	217	0.0820000000000000034
60866	S6	227.400000000000006	0.00300000000000000006
60866	MU2	225.400000000000006	0.0490000000000000019
60866	2N2	187.699999999999989	0.0560000000000000012
60866	OO1	252.900000000000006	0.0330000000000000016
60866	LDA2	245.800000000000011	0.0129999999999999994
60866	M1	232.5	0.0519999999999999976
60866	J1	246	0.0589999999999999969
60866	SSA	286.899999999999977	0.128000000000000003
60866	SA	221.400000000000006	0.125
60866	RHO1	219.699999999999989	0.0299999999999999989
60866	Q1	218.900000000000006	0.143999999999999989
60866	T2	252.599999999999994	0.0299999999999999989
60866	R2	254	0.00300000000000000006
60866	2Q1	212.099999999999994	0.0200000000000000004
60866	P1	238.199999999999989	0.39700000000000002
60866	L2	265.100000000000023	0.0589999999999999969
60866	K2	254.300000000000011	0.138000000000000012
60866	M8	320.399999999999977	0.00300000000000000006
60867	M2	318.100000000000023	1.31200000000000006
60867	S2	325.100000000000023	0.223000000000000004
60867	N2	293.600000000000023	0.23899999999999999
60867	K1	298.100000000000023	0.758000000000000007
60867	M4	166.300000000000011	0.0589999999999999969
60867	O1	278.5	0.419999999999999984
60867	M6	328	0.0490000000000000019
60867	MK3	170	0.0950000000000000011
60867	MN4	143.300000000000011	0.0200000000000000004
60867	NU2	297.300000000000011	0.0660000000000000031
60867	MU2	129.800000000000011	0.0690000000000000058
60867	2N2	246.400000000000006	0.0200000000000000004
60867	OO1	342.800000000000011	0.0200000000000000004
60867	LDA2	300.5	0.0259999999999999988
60867	S1	118.200000000000003	0.0330000000000000016
60867	J1	37.2999999999999972	0.0100000000000000002
60867	SSA	285	0.197000000000000008
60867	RHO1	280.5	0.0359999999999999973
60867	Q1	290.300000000000011	0.0690000000000000058
60867	2Q1	316.399999999999977	0.0129999999999999994
60867	P1	283.800000000000011	0.223000000000000004
60867	2SM2	154	0.0160000000000000003
60867	M3	258.800000000000011	0.0299999999999999989
60867	L2	350.5	0.0980000000000000038
60867	2MK3	159.199999999999989	0.107999999999999999
60867	K2	311	0.0950000000000000011
60867	MS4	193	0.0330000000000000016
60868	M2	270.199999999999989	1.74900000000000011
60868	S2	287.699999999999989	0.315000000000000002
60868	N2	249.300000000000011	0.318000000000000005
60868	K1	261.699999999999989	0.970999999999999974
60868	M4	54.8999999999999986	0.0330000000000000016
60868	O1	245.699999999999989	0.535000000000000031
60868	M6	194.199999999999989	0.0200000000000000004
60868	S4	195	0.00300000000000000006
60868	NU2	252.199999999999989	0.0619999999999999996
60868	S6	266.199999999999989	0.00300000000000000006
60868	MU2	252.800000000000011	0.0429999999999999966
60868	2N2	228.5	0.0429999999999999966
60868	OO1	277.699999999999989	0.0229999999999999996
60868	LDA2	278.399999999999977	0.0129999999999999994
60868	M1	253.699999999999989	0.0389999999999999999
60868	J1	269.699999999999989	0.0429999999999999966
60868	SSA	285.699999999999989	0.197000000000000008
60868	RHO1	238.800000000000011	0.0200000000000000004
60868	Q1	237.699999999999989	0.101999999999999993
60868	T2	287	0.0200000000000000004
60868	R2	288.399999999999977	0.00300000000000000006
60868	2Q1	229.800000000000011	0.0129999999999999994
60868	P1	260.5	0.322000000000000008
60868	L2	291.100000000000023	0.0490000000000000019
60868	K2	289.100000000000023	0.0850000000000000061
60868	M8	284.399999999999977	0.00300000000000000006
60869	M2	26.1999999999999993	1.03000000000000003
60869	S2	47.1000000000000014	0.190000000000000002
60869	N2	8.19999999999999929	0.187
60869	K1	328.899999999999977	0.646000000000000019
60869	M4	312.199999999999989	0.0330000000000000016
60869	O1	324	0.429999999999999993
60869	M6	117.599999999999994	0.0229999999999999996
60869	S4	17.6000000000000014	0.00700000000000000015
60869	NU2	10.5999999999999996	0.0359999999999999973
60869	S6	27.5	0.00300000000000000006
60869	MU2	5.29999999999999982	0.0259999999999999988
60869	2N2	350.100000000000023	0.0259999999999999988
60869	OO1	333.899999999999977	0.0200000000000000004
60869	LDA2	36.1000000000000014	0.00700000000000000015
60869	M1	326.600000000000023	0.0299999999999999989
60869	J1	331.300000000000011	0.0359999999999999973
60869	SSA	285.699999999999989	0.197000000000000008
60869	RHO1	322.100000000000023	0.0160000000000000003
60869	Q1	321.600000000000023	0.0820000000000000034
60869	T2	46	0.0129999999999999994
60869	2Q1	320.399999999999977	0.0100000000000000002
60869	P1	328.600000000000023	0.212999999999999995
60869	L2	44.2999999999999972	0.0299999999999999989
60869	K2	48.7000000000000028	0.0519999999999999976
60870	M2	302.199999999999989	1.42700000000000005
60870	S2	317.399999999999977	0.276000000000000023
60870	N2	277.100000000000023	0.27200000000000002
60870	K1	282.800000000000011	0.849999999999999978
60870	M4	142.5	0.0459999999999999992
60870	O1	267.199999999999989	0.509000000000000008
60870	M6	279.699999999999989	0.0330000000000000016
60870	MK3	156.400000000000006	0.0919999999999999984
60870	MN4	132	0.0129999999999999994
60870	NU2	288.399999999999977	0.0719999999999999946
60870	MU2	104.900000000000006	0.0690000000000000058
60870	OO1	354.300000000000011	0.0259999999999999988
60870	LDA2	285	0.0389999999999999999
60870	S1	306.300000000000011	0.0359999999999999973
60870	M1	8	0.0589999999999999969
60870	SSA	285.699999999999989	0.197000000000000008
60870	RHO1	263.300000000000011	0.0200000000000000004
60870	Q1	277.600000000000023	0.0820000000000000034
60870	T2	298	0.0160000000000000003
60870	2Q1	215.800000000000011	0.0160000000000000003
60870	P1	283	0.226000000000000006
60870	2SM2	117.200000000000003	0.0160000000000000003
60870	M3	216.400000000000006	0.0129999999999999994
60870	L2	300.399999999999977	0.0889999999999999958
60870	2MK3	142.900000000000006	0.140999999999999986
60870	K2	306.699999999999989	0.135000000000000009
60870	MS4	158.300000000000011	0.0259999999999999988
60871	M2	257.5	1.96799999999999997
60871	S2	271.300000000000011	0.412999999999999978
60871	N2	232.5	0.373999999999999999
60871	K1	251.800000000000011	1.09600000000000009
60871	M4	346.699999999999989	0.0560000000000000012
60871	O1	234.400000000000006	0.663000000000000034
60871	M6	135.099999999999994	0.0389999999999999999
60871	MK3	101.700000000000003	0.0459999999999999992
60871	MN4	328.399999999999977	0.0200000000000000004
60871	NU2	243.199999999999989	0.0919999999999999984
60871	MU2	63.3999999999999986	0.0589999999999999969
60871	2N2	206	0.0490000000000000019
60871	OO1	308.100000000000023	0.0259999999999999988
60871	LDA2	247.699999999999989	0.0490000000000000019
60871	S1	261.199999999999989	0.0560000000000000012
60871	M1	271.100000000000023	0.0389999999999999999
60871	J1	287.399999999999977	0.0259999999999999988
60871	SSA	259.800000000000011	0.0950000000000000011
60871	SA	223.900000000000006	0.157000000000000001
60871	RHO1	233.099999999999994	0.0299999999999999989
60871	Q1	239	0.104999999999999996
60871	T2	241.300000000000011	0.0330000000000000016
60871	R2	182.300000000000011	0.0229999999999999996
60871	2Q1	280.300000000000011	0.0100000000000000002
60871	P1	254.699999999999989	0.288999999999999979
60871	2SM2	97.0999999999999943	0.0160000000000000003
60871	M3	174.199999999999989	0.0299999999999999989
60871	L2	280.600000000000023	0.138000000000000012
60871	2MK3	90.2000000000000028	0.0980000000000000038
60871	K2	257.899999999999977	0.157000000000000001
60871	MS4	27.1000000000000014	0.0229999999999999996
60872	M2	283.199999999999989	1.627
60872	S2	298.100000000000023	0.318000000000000005
60872	N2	258.800000000000011	0.304999999999999993
60872	K1	271	0.902000000000000024
60872	M4	125	0.0359999999999999973
60872	O1	255.400000000000006	0.518000000000000016
60872	M6	250.400000000000006	0.0359999999999999973
60872	MK3	128.800000000000011	0.104999999999999996
60872	S4	189.699999999999989	0.00300000000000000006
60872	MN4	104	0.0129999999999999994
60872	NU2	268.300000000000011	0.0790000000000000008
60872	MU2	90.5	0.0690000000000000058
60872	2N2	236.599999999999994	0.0259999999999999988
60872	OO1	328.5	0.0229999999999999996
60872	LDA2	279.199999999999989	0.0429999999999999966
60872	S1	298.300000000000011	0.0429999999999999966
60872	M1	350.5	0.0259999999999999988
60872	J1	349.899999999999977	0.0129999999999999994
60872	MM	34.3999999999999986	0.0519999999999999976
60872	SSA	264.800000000000011	0.138000000000000012
60872	SA	144.599999999999994	0.0889999999999999958
60872	MSF	18.1000000000000014	0.0980000000000000038
60872	MF	184.300000000000011	0.135000000000000009
60872	RHO1	247.699999999999989	0.0259999999999999988
60872	Q1	263.399999999999977	0.0820000000000000034
60872	T2	265.100000000000023	0.0200000000000000004
60872	R2	172.699999999999989	0.0100000000000000002
60872	2Q1	264.899999999999977	0.0100000000000000002
60872	P1	269.899999999999977	0.259000000000000008
60872	2SM2	123	0.0160000000000000003
60872	M3	210.099999999999994	0.0229999999999999996
60872	L2	298.899999999999977	0.107999999999999999
60872	2MK3	118.599999999999994	0.138000000000000012
60872	K2	287.800000000000011	0.150999999999999995
60872	M8	57.2999999999999972	0.00300000000000000006
60872	MS4	150.800000000000011	0.0259999999999999988
60873	M2	358.300000000000011	0.932000000000000051
60873	S2	22.6999999999999993	0.187
60873	N2	338.5	0.161000000000000004
60873	K1	319.800000000000011	0.688999999999999946
60873	M4	231.300000000000011	0.0389999999999999999
60873	O1	309.600000000000023	0.446000000000000008
60873	M6	2.10000000000000009	0.0330000000000000016
60873	S4	311.800000000000011	0.0100000000000000002
60873	NU2	341.199999999999989	0.0299999999999999989
60873	S6	239.199999999999989	0.00300000000000000006
60873	MU2	333.899999999999977	0.0229999999999999996
60873	2N2	318.600000000000023	0.0200000000000000004
60873	OO1	329.699999999999989	0.0200000000000000004
60873	LDA2	9.69999999999999929	0.00700000000000000015
60873	M1	314.699999999999989	0.0299999999999999989
60873	J1	324.899999999999977	0.0330000000000000016
60873	SSA	285.699999999999989	0.197000000000000008
60873	RHO1	305.5	0.0160000000000000003
60873	Q1	304.600000000000023	0.0850000000000000061
60873	T2	21.8000000000000007	0.0100000000000000002
60873	2Q1	298.199999999999989	0.0100000000000000002
60873	P1	319	0.226000000000000006
60873	L2	18.1999999999999993	0.0259999999999999988
60873	K2	24.5	0.0490000000000000019
60873	M8	328.300000000000011	0.00300000000000000006
60874	M2	260.600000000000023	1.95900000000000007
60874	S2	273.5	0.422999999999999987
60874	N2	233.800000000000011	0.390000000000000013
60874	K1	253.699999999999989	1.10200000000000009
60874	M4	30.8000000000000007	0.0389999999999999999
60874	O1	237.199999999999989	0.656000000000000028
60874	M6	147.300000000000011	0.0330000000000000016
60874	MK3	117.200000000000003	0.0619999999999999996
60874	MN4	347.100000000000023	0.0129999999999999994
60874	NU2	237	0.0820000000000000034
60874	MU2	66.7000000000000028	0.0519999999999999976
60874	2N2	206.800000000000011	0.0519999999999999976
60874	OO1	296.399999999999977	0.0389999999999999999
60874	LDA2	264.399999999999977	0.0429999999999999966
60874	S1	228.900000000000006	0.0519999999999999976
60874	M1	327.600000000000023	0.0490000000000000019
60874	J1	288	0.0459999999999999992
60874	SSA	259.800000000000011	0.0950000000000000011
60874	SA	223.900000000000006	0.157000000000000001
60874	RHO1	230.099999999999994	0.0259999999999999988
60874	Q1	234.300000000000011	0.104999999999999996
60874	T2	273.399999999999977	0.0259999999999999988
60874	R2	273.5	0.00300000000000000006
60874	2Q1	220.699999999999989	0.0160000000000000003
60874	P1	258.199999999999989	0.325000000000000011
60874	2SM2	93.5999999999999943	0.0129999999999999994
60874	M3	162	0.0160000000000000003
60874	L2	271.199999999999989	0.0749999999999999972
60874	2MK3	92.7000000000000028	0.104999999999999996
60874	K2	265.600000000000023	0.16700000000000001
60874	MS4	65.7000000000000028	0.0259999999999999988
60875	M2	15	0.947999999999999954
60875	S2	31.8999999999999986	0.173999999999999988
60875	N2	356.699999999999989	0.171000000000000013
60875	K1	323.5	0.633000000000000007
60875	M4	267.899999999999977	0.0229999999999999996
60875	O1	317.800000000000011	0.419999999999999984
60875	M6	52.2000000000000028	0.0259999999999999988
60875	S4	354.399999999999977	0.00300000000000000006
60875	NU2	359.100000000000023	0.0330000000000000016
60875	MU2	357.699999999999989	0.0229999999999999996
60875	2N2	338.399999999999977	0.0229999999999999996
60875	OO1	329.199999999999989	0.0200000000000000004
60875	LDA2	23	0.00700000000000000015
60875	M1	320.800000000000011	0.0299999999999999989
60875	J1	326.100000000000023	0.0330000000000000016
60875	SSA	285.699999999999989	0.197000000000000008
60875	RHO1	315.5	0.0160000000000000003
60875	Q1	315.100000000000023	0.0820000000000000034
60875	T2	31.5	0.0100000000000000002
60875	2Q1	313.399999999999977	0.0100000000000000002
60875	P1	323	0.209999999999999992
60875	L2	33.2999999999999972	0.0259999999999999988
60875	K2	33.2000000000000028	0.0459999999999999992
60875	M8	337.600000000000023	0.00300000000000000006
60876	M2	257.699999999999989	2.03399999999999981
60876	S2	273.199999999999989	0.394000000000000017
60876	N2	235.800000000000011	0.350999999999999979
60876	K1	256.800000000000011	1.129
60876	M4	73.5	0.131000000000000005
60876	O1	237.900000000000006	0.656000000000000028
60876	M6	179.400000000000006	0.0330000000000000016
60876	S4	358.300000000000011	0.00300000000000000006
60876	NU2	238.699999999999989	0.0690000000000000058
60876	S6	302.199999999999989	0.00700000000000000015
60876	MU2	241.800000000000011	0.0490000000000000019
60876	2N2	213.900000000000006	0.0459999999999999992
60876	OO1	275.600000000000023	0.0259999999999999988
60876	LDA2	265.100000000000023	0.0129999999999999994
60876	M1	247.400000000000006	0.0459999999999999992
60876	J1	266.100000000000023	0.0519999999999999976
60876	SSA	259.800000000000011	0.0950000000000000011
60876	SA	223.900000000000006	0.157000000000000001
60876	RHO1	229.699999999999989	0.0229999999999999996
60876	Q1	228.5	0.128000000000000003
60876	T2	272.600000000000023	0.0229999999999999996
60876	R2	274.199999999999989	0.00300000000000000006
60876	2Q1	218.800000000000011	0.0160000000000000003
60876	P1	255.400000000000006	0.373999999999999999
60876	L2	279.800000000000011	0.0560000000000000012
60876	K2	274.300000000000011	0.107999999999999999
60876	M8	53.2999999999999972	0.00700000000000000015
60877	M2	289.399999999999977	1.65999999999999992
60877	S2	303	0.318000000000000005
60877	N2	264.100000000000023	0.304999999999999993
60877	K1	273.699999999999989	0.980999999999999983
60877	M4	140.199999999999989	0.0790000000000000008
60877	O1	257.5	0.551000000000000045
60877	M6	246.699999999999989	0.0330000000000000016
60877	MK3	135.5	0.117999999999999994
60877	MN4	113.700000000000003	0.0259999999999999988
60877	NU2	267.5	0.0749999999999999972
60877	MU2	85.7999999999999972	0.0690000000000000058
60877	2N2	262.100000000000023	0.0589999999999999969
60877	OO1	321.300000000000011	0.0330000000000000016
60877	LDA2	285.300000000000011	0.0490000000000000019
60877	M1	307.5	0.0429999999999999966
60877	SSA	339.300000000000011	0.200000000000000011
60877	RHO1	239.900000000000006	0.0200000000000000004
60877	Q1	259.800000000000011	0.0889999999999999958
60877	P1	282.800000000000011	0.259000000000000008
60877	2SM2	129.300000000000011	0.0200000000000000004
60877	M3	203.5	0.0519999999999999976
60877	L2	285	0.157000000000000001
60877	2MK3	125.400000000000006	0.161000000000000004
60877	K2	290.199999999999989	0.173999999999999988
60877	MS4	155.900000000000006	0.0389999999999999999
60878	M2	338.5	1.21100000000000008
60878	S2	355.899999999999977	0.216999999999999998
60878	N2	304.300000000000011	0.223000000000000004
60878	K1	302.5	0.724999999999999978
60878	M4	213	0.0850000000000000061
60878	O1	294.199999999999989	0.36399999999999999
60878	M6	17.3000000000000007	0.0299999999999999989
60878	MK3	199.800000000000011	0.104999999999999996
60878	S4	238.599999999999994	0.00700000000000000015
60878	MN4	191.800000000000011	0.0330000000000000016
60878	NU2	333.199999999999989	0.0299999999999999989
60878	MU2	151.5	0.0660000000000000031
60878	2N2	311.699999999999989	0.0330000000000000016
60878	OO1	62.5	0.0100000000000000002
60878	LDA2	326.5	0.0459999999999999992
60878	S1	267.699999999999989	0.0749999999999999972
60878	M1	209.400000000000006	0.0129999999999999994
60878	J1	43.6000000000000014	0.0299999999999999989
60878	SSA	285.699999999999989	0.197000000000000008
60878	RHO1	287	0.0160000000000000003
60878	Q1	295.699999999999989	0.0519999999999999976
60878	T2	352.399999999999977	0.0229999999999999996
60878	R2	65.5999999999999943	0.0229999999999999996
60878	2Q1	315.899999999999977	0.0160000000000000003
60878	P1	308.100000000000023	0.269000000000000017
60878	2SM2	171.199999999999989	0.0129999999999999994
60878	M3	280.699999999999989	0.0330000000000000016
60878	L2	355.600000000000023	0.101999999999999993
60878	2MK3	191.300000000000011	0.0950000000000000011
60878	K2	337	0.0950000000000000011
60878	M8	251.599999999999994	0.00700000000000000015
60878	MS4	240.5	0.0389999999999999999
60879	M2	256.600000000000023	1.77800000000000002
60879	S2	277.800000000000011	0.291999999999999982
60879	N2	230.900000000000006	0.318000000000000005
60879	K1	256.5	0.944999999999999951
60879	M4	100.900000000000006	0.164000000000000007
60879	O1	253.599999999999994	0.563999999999999946
60879	M6	227	0.0229999999999999996
60879	S4	210.400000000000006	0.0100000000000000002
60879	NU2	234.300000000000011	0.0619999999999999996
60879	S6	179.099999999999994	0.00300000000000000006
60879	MU2	236.300000000000011	0.0429999999999999966
60879	2N2	205.599999999999994	0.0429999999999999966
60879	OO1	259	0.0229999999999999996
60879	LDA2	265.899999999999977	0.0129999999999999994
60879	M1	255	0.0389999999999999999
60879	J1	257.899999999999977	0.0429999999999999966
60879	SSA	286.899999999999977	0.128000000000000003
60879	SA	221.400000000000006	0.125
60879	RHO1	252.199999999999989	0.0200000000000000004
60879	Q1	252.199999999999989	0.107999999999999999
60879	T2	276.800000000000011	0.0160000000000000003
60879	R2	277.5	0.00300000000000000006
60879	2Q1	250.300000000000011	0.0129999999999999994
60879	P1	256.199999999999989	0.312
60879	L2	282.600000000000023	0.0490000000000000019
60879	K2	279.600000000000023	0.0790000000000000008
60879	M8	68.2999999999999972	0.0129999999999999994
60880	M2	265.100000000000023	2.27700000000000014
60880	S2	284.699999999999989	0.466000000000000025
60880	N2	248.599999999999994	0.390000000000000013
60880	K1	263.100000000000023	1.15199999999999991
60880	M4	97.7999999999999972	0.0889999999999999958
60880	O1	244.800000000000011	0.63600000000000001
60880	M6	201.300000000000011	0.0490000000000000019
60880	S4	311.600000000000023	0.00300000000000000006
60880	NU2	250.800000000000011	0.0749999999999999972
60880	S6	30.1000000000000014	0.00700000000000000015
60880	MU2	245.599999999999994	0.0560000000000000012
60880	2N2	232	0.0519999999999999976
60880	OO1	281.399999999999977	0.0259999999999999988
60880	LDA2	274.199999999999989	0.0160000000000000003
60880	M1	253.900000000000006	0.0459999999999999992
60880	J1	272.199999999999989	0.0519999999999999976
60880	SSA	259.800000000000011	0.0950000000000000011
60880	SA	223.900000000000006	0.157000000000000001
60880	RHO1	236.800000000000011	0.0229999999999999996
60880	Q1	235.800000000000011	0.120999999999999996
60880	T2	284	0.0299999999999999989
60880	R2	285.5	0.00300000000000000006
60880	2Q1	227.5	0.0160000000000000003
60880	P1	261.699999999999989	0.384000000000000008
60880	L2	281.899999999999977	0.0619999999999999996
60880	K2	286.300000000000011	0.128000000000000003
60880	M8	97.9000000000000057	0.00300000000000000006
60881	M2	273.300000000000011	2.33899999999999997
60881	S2	299.300000000000011	0.554000000000000048
60881	N2	258.199999999999989	0.443000000000000005
60881	K1	264.199999999999989	1.21700000000000008
60881	M4	72.0999999999999943	0.0690000000000000058
60881	O1	253.5	0.711999999999999966
60881	M6	226.599999999999994	0.0690000000000000058
60881	S4	151.099999999999994	0.0100000000000000002
60881	NU2	260.199999999999989	0.0850000000000000061
60881	MU2	247.5	0.0560000000000000012
60881	2N2	243.199999999999989	0.0589999999999999969
60881	OO1	273.800000000000011	0.0299999999999999989
60881	LDA2	285.199999999999989	0.0160000000000000003
60881	M1	258.699999999999989	0.0490000000000000019
60881	J1	268.899999999999977	0.0560000000000000012
60881	SSA	259.800000000000011	0.0950000000000000011
60881	SA	223.900000000000006	0.157000000000000001
60881	RHO1	249.300000000000011	0.0259999999999999988
60881	Q1	248.5	0.138000000000000012
60881	T2	298.199999999999989	0.0330000000000000016
60881	R2	301.5	0.00300000000000000006
60881	2Q1	243.699999999999989	0.0200000000000000004
60881	P1	263.399999999999977	0.404000000000000026
60881	L2	288.300000000000011	0.0660000000000000031
60881	K2	301.300000000000011	0.150999999999999995
60881	M8	263.5	0.00700000000000000015
60882	M2	193.5	1.67999999999999994
60882	S2	203.699999999999989	0.404000000000000026
60882	N2	165.300000000000011	0.373999999999999999
60882	K1	223.199999999999989	1.11899999999999999
60882	M4	28.6999999999999993	0.0299999999999999989
60882	O1	212.599999999999994	0.695999999999999952
60882	M6	110.099999999999994	0.00300000000000000006
60882	S4	41.3999999999999986	0.00700000000000000015
60882	NU2	169.099999999999994	0.0719999999999999946
60882	S6	65.7000000000000028	0.00300000000000000006
60882	MU2	183.300000000000011	0.0389999999999999999
60882	2N2	136.900000000000006	0.0490000000000000019
60882	OO1	233.699999999999989	0.0299999999999999989
60882	LDA2	198.199999999999989	0.0129999999999999994
60882	M1	217.900000000000006	0.0490000000000000019
60882	J1	228.400000000000006	0.0560000000000000012
60882	SSA	272.5	0.190000000000000002
60882	SA	263	0.23899999999999999
60882	RHO1	208.099999999999994	0.0259999999999999988
60882	Q1	207.400000000000006	0.135000000000000009
60882	T2	203.199999999999989	0.0229999999999999996
60882	R2	204	0.00300000000000000006
60882	2Q1	202.199999999999989	0.0160000000000000003
60882	P1	222.400000000000006	0.370999999999999996
60882	L2	221.900000000000006	0.0459999999999999992
60882	K2	204.5	0.112000000000000002
60882	M8	141.800000000000011	0.00300000000000000006
60883	M2	195.300000000000011	1.87000000000000011
60883	S2	205.300000000000011	0.456000000000000016
60883	N2	169.400000000000006	0.409999999999999976
60883	K1	223.400000000000006	1.21700000000000008
60883	M4	248.599999999999994	0.00300000000000000006
60883	O1	208	0.764000000000000012
60883	S4	348.399999999999977	0.00300000000000000006
60883	MN4	219.099999999999994	0.00300000000000000006
60883	NU2	174.900000000000006	0.0820000000000000034
60883	MU2	133.099999999999994	0.0459999999999999992
60883	2N2	141.699999999999989	0.0459999999999999992
60883	OO1	250.5	0.0389999999999999999
60883	LDA2	228.699999999999989	0.0129999999999999994
60883	S1	327.899999999999977	0.0429999999999999966
60883	M1	228.699999999999989	0.0459999999999999992
60883	J1	236.300000000000011	0.0719999999999999946
60883	SSA	255.5	0.107999999999999999
60883	SA	227.400000000000006	0.233000000000000013
60883	RHO1	199.599999999999994	0.0259999999999999988
60883	Q1	197.900000000000006	0.138000000000000012
60883	T2	201.300000000000011	0.0229999999999999996
60883	R2	155.5	0.00700000000000000015
60883	2Q1	201.400000000000006	0.0160000000000000003
60883	P1	220.400000000000006	0.384000000000000008
60883	2SM2	346.100000000000023	0.00300000000000000006
60883	M3	357.800000000000011	0.00700000000000000015
60883	L2	226.199999999999989	0.0389999999999999999
60883	2MK3	148.5	0.00300000000000000006
60883	K2	195.599999999999994	0.128000000000000003
60883	MS4	261.399999999999977	0.00300000000000000006
60884	M2	196.599999999999994	1.98199999999999998
60884	S2	211.199999999999989	0.48899999999999999
60884	N2	170.900000000000006	0.419999999999999984
60884	K1	222.800000000000011	1.21700000000000008
60884	M4	301.800000000000011	0.00300000000000000006
60884	O1	207.099999999999994	0.774000000000000021
60884	M6	325.600000000000023	0.00300000000000000006
60884	S4	305	0.00700000000000000015
60884	NU2	174.300000000000011	0.0820000000000000034
60884	S6	32.7999999999999972	0.00300000000000000006
60884	MU2	181.800000000000011	0.0490000000000000019
60884	2N2	145.199999999999989	0.0560000000000000012
60884	OO1	238.599999999999994	0.0330000000000000016
60884	LDA2	203.400000000000006	0.0129999999999999994
60884	M1	215	0.0560000000000000012
60884	J1	230.699999999999989	0.0619999999999999996
60884	SSA	272.5	0.190000000000000002
60884	SA	263	0.23899999999999999
60884	RHO1	200.300000000000011	0.0299999999999999989
60884	Q1	199.300000000000011	0.150999999999999995
60884	T2	210.699999999999989	0.0299999999999999989
60884	R2	211.900000000000006	0.00300000000000000006
60884	2Q1	191.5	0.0200000000000000004
60884	P1	221.699999999999989	0.404000000000000026
60884	L2	222.300000000000011	0.0560000000000000012
60884	K2	212.400000000000006	0.131000000000000005
60885	M2	200.900000000000006	1.96799999999999997
60885	S2	218.300000000000011	0.48899999999999999
60885	N2	174.5	0.426999999999999991
60885	K1	225.599999999999994	1.19700000000000006
60885	M4	217.099999999999994	0.00300000000000000006
60885	O1	208.400000000000006	0.791000000000000036
60885	S4	270.5	0.0100000000000000002
60885	NU2	178.099999999999994	0.0820000000000000034
60885	S6	145.699999999999989	0.00300000000000000006
60885	MU2	183.400000000000006	0.0459999999999999992
60885	2N2	148.199999999999989	0.0560000000000000012
60885	OO1	242.800000000000011	0.0330000000000000016
60885	LDA2	208.900000000000006	0.0129999999999999994
60885	M1	217.099999999999994	0.0560000000000000012
60885	J1	234.099999999999994	0.0619999999999999996
60885	SSA	272.5	0.190000000000000002
60885	SA	263	0.23899999999999999
60885	RHO1	201.099999999999994	0.0299999999999999989
60885	Q1	199.900000000000006	0.153999999999999998
60885	T2	217.599999999999994	0.0299999999999999989
60885	R2	219	0.00300000000000000006
60885	2Q1	191.400000000000006	0.0200000000000000004
60885	P1	224.300000000000011	0.39700000000000002
60885	L2	227.199999999999989	0.0560000000000000012
60885	K2	219.699999999999989	0.135000000000000009
60886	M2	221.699999999999989	1.8859999999999999
60886	S2	230.5	0.377000000000000002
60886	N2	194.199999999999989	0.370999999999999996
60886	K1	248.300000000000011	1.22399999999999998
60886	M4	334.5	0.0429999999999999966
60886	O1	226.800000000000011	0.65900000000000003
60886	M6	292.300000000000011	0.0129999999999999994
60886	MK3	358.600000000000023	0.0749999999999999972
60886	S4	18.6999999999999993	0.00700000000000000015
60886	MN4	335.199999999999989	0.0160000000000000003
60886	NU2	208.099999999999994	0.0749999999999999972
60886	S6	117.200000000000003	0.00300000000000000006
60886	MU2	1.10000000000000009	0.0200000000000000004
60886	2N2	151.099999999999994	0.0299999999999999989
60886	OO1	236.300000000000011	0.0129999999999999994
60886	LDA2	222.300000000000011	0.0100000000000000002
60886	S1	107.599999999999994	0.176999999999999991
60886	M1	275.199999999999989	0.0459999999999999992
60886	J1	273.100000000000023	0.0790000000000000008
60886	SSA	264.100000000000023	0.125
60886	SA	255	0.212999999999999995
60886	MF	149	0.0459999999999999992
60886	RHO1	262.100000000000023	0.0229999999999999996
60886	Q1	229.800000000000011	0.0980000000000000038
60886	T2	81.5	0.0719999999999999946
60886	R2	302	0.140999999999999986
60886	2Q1	141.800000000000011	0.0100000000000000002
60886	P1	242.800000000000011	0.466000000000000025
60886	2SM2	59	0.00700000000000000015
60886	M3	33.8999999999999986	0.0229999999999999996
60886	L2	223.699999999999989	0.0459999999999999992
60886	2MK3	355.899999999999977	0.0589999999999999969
60886	K2	250.099999999999994	0.138000000000000012
60886	M8	48	0.00300000000000000006
60886	MS4	334.300000000000011	0.0160000000000000003
60887	M2	214.800000000000011	2.29000000000000004
60887	S2	236	0.609999999999999987
60887	N2	190.599999999999994	0.485999999999999988
60887	K1	232.199999999999989	1.34800000000000009
60887	M4	213	0.0389999999999999999
60887	O1	217.5	0.797000000000000042
60887	M6	246	0.0200000000000000004
60887	S4	55.2000000000000028	0.00700000000000000015
60887	NU2	193.800000000000011	0.0919999999999999984
60887	S6	161.099999999999994	0.00300000000000000006
60887	MU2	193.599999999999994	0.0560000000000000012
60887	2N2	166.300000000000011	0.0660000000000000031
60887	OO1	247	0.0330000000000000016
60887	LDA2	224.599999999999994	0.0160000000000000003
60887	M1	224.900000000000006	0.0560000000000000012
60887	J1	239.599999999999994	0.0619999999999999996
60887	SSA	264.100000000000023	0.125
60887	SA	255	0.212999999999999995
60887	MF	149	0.0459999999999999992
60887	RHO1	211.099999999999994	0.0299999999999999989
60887	Q1	210.099999999999994	0.153999999999999998
60887	T2	235.099999999999994	0.0359999999999999973
60887	R2	236.900000000000006	0.00300000000000000006
60887	2Q1	202.800000000000011	0.0200000000000000004
60887	P1	231.199999999999989	0.446000000000000008
60887	L2	239	0.0660000000000000031
60887	K2	237.699999999999989	0.16700000000000001
60887	M8	207.599999999999994	0.00300000000000000006
60888	M2	215.099999999999994	2.29700000000000015
60888	S2	236.599999999999994	0.573999999999999955
60888	N2	190.5	0.485999999999999988
60888	K1	233.400000000000006	1.31600000000000006
60888	M4	200.599999999999994	0.0389999999999999999
60888	O1	217.199999999999989	0.816999999999999948
60888	M6	284.699999999999989	0.0200000000000000004
60888	MK3	197.5	0.0200000000000000004
60888	MN4	177.400000000000006	0.0160000000000000003
60888	NU2	194.5	0.0950000000000000011
60888	MU2	173	0.0330000000000000016
60888	2N2	164.199999999999989	0.0560000000000000012
60888	OO1	265.899999999999977	0.0429999999999999966
60888	LDA2	215.800000000000011	0.0200000000000000004
60888	S1	35	0.0389999999999999999
60888	M1	252.400000000000006	0.0429999999999999966
60888	J1	248.300000000000011	0.0719999999999999946
60888	SSA	264.100000000000023	0.125
60888	SA	255	0.212999999999999995
60888	MF	149	0.0459999999999999992
60888	RHO1	210.300000000000011	0.0259999999999999988
60888	Q1	211.300000000000011	0.143999999999999989
60888	T2	235.800000000000011	0.0330000000000000016
60888	R2	237.5	0.00700000000000000015
60888	2Q1	216.400000000000006	0.0160000000000000003
60888	P1	231.199999999999989	0.412999999999999978
60888	L2	225.199999999999989	0.0519999999999999976
60888	K2	228.300000000000011	0.153999999999999998
60888	MS4	239.099999999999994	0.0200000000000000004
60889	M2	220.199999999999989	2.39500000000000002
60889	S2	243.699999999999989	0.627000000000000002
60889	N2	198.5	0.502000000000000002
60889	K1	235	1.34200000000000008
60889	M4	202.599999999999994	0.0919999999999999984
60889	O1	221	0.791000000000000036
60889	M6	294.199999999999989	0.0660000000000000031
60889	S4	31.8999999999999986	0.00700000000000000015
60889	NU2	201.300000000000011	0.0950000000000000011
60889	S6	181	0.00700000000000000015
60889	MU2	196.800000000000011	0.0560000000000000012
60889	2N2	176.599999999999994	0.0660000000000000031
60889	OO1	249.099999999999994	0.0330000000000000016
60889	LDA2	231.099999999999994	0.0160000000000000003
60889	M1	228.099999999999994	0.0560000000000000012
60889	J1	242	0.0619999999999999996
60889	SSA	264.100000000000023	0.125
60889	SA	255	0.212999999999999995
60889	MF	149	0.0459999999999999992
60889	RHO1	215	0.0299999999999999989
60889	Q1	214	0.153999999999999998
60889	T2	242.800000000000011	0.0359999999999999973
60889	R2	244.300000000000011	0.00700000000000000015
60889	2Q1	207.099999999999994	0.0200000000000000004
60889	P1	234	0.443000000000000005
60889	L2	242	0.0660000000000000031
60889	K2	245.599999999999994	0.171000000000000013
60889	M8	304.800000000000011	0.0129999999999999994
60890	M2	231.900000000000006	1.55200000000000005
60890	S2	265.399999999999977	0.349999999999999978
60890	N2	229.099999999999994	0.309999999999999998
60890	K1	249.599999999999994	0.82999999999999996
60890	M4	44.1000000000000014	0.119999999999999996
60890	O1	255.5	0.540000000000000036
60890	S4	188.400000000000006	0.0100000000000000002
60890	NU2	229.400000000000006	0.0599999999999999978
60890	MU2	199.900000000000006	0.0400000000000000008
60890	2N2	225.199999999999989	0.0400000000000000008
60890	OO1	245.099999999999994	0.0200000000000000004
60890	LDA2	247.099999999999994	0.0100000000000000002
60890	M1	252.5	0.0400000000000000008
60890	J1	247.800000000000011	0.0400000000000000008
60890	SSA	262.100000000000023	0.130000000000000004
60890	SA	261.399999999999977	0.23000000000000001
60890	MF	152	0.0500000000000000028
60890	RHO1	257.300000000000011	0.0200000000000000004
60890	Q1	257.899999999999977	0.100000000000000006
60890	T2	263.899999999999977	0.0200000000000000004
60890	2Q1	259.399999999999977	0.0100000000000000002
60890	P1	249.900000000000006	0.280000000000000027
60890	L2	236	0.0400000000000000008
60890	K2	268	0.100000000000000006
60891	M2	211	2.3490000000000002
60891	S2	231.699999999999989	0.599999999999999978
60891	N2	185.199999999999989	0.498999999999999999
60891	K1	227.800000000000011	1.28299999999999992
60891	O1	212.599999999999994	0.794000000000000039
60891	NU2	191.199999999999989	0.0980000000000000038
60891	MU2	154	0.0519999999999999976
60891	2N2	158.800000000000011	0.0560000000000000012
60891	OO1	255	0.0459999999999999992
60891	LDA2	230.900000000000006	0.0160000000000000003
60891	S1	4.29999999999999982	0.0259999999999999988
60891	M1	242.5	0.0389999999999999999
60891	J1	240	0.0719999999999999946
60891	SSA	262.100000000000023	0.135000000000000009
60891	SA	261.399999999999977	0.233000000000000013
60891	MF	152	0.0459999999999999992
60891	RHO1	206.699999999999989	0.0299999999999999989
60891	Q1	205.5	0.140999999999999986
60891	T2	225.800000000000011	0.0330000000000000016
60891	R2	232.400000000000006	0.00700000000000000015
60891	2Q1	204.900000000000006	0.0160000000000000003
60891	P1	225.199999999999989	0.404000000000000026
60891	L2	235.599999999999994	0.0429999999999999966
60891	K2	223.599999999999994	0.16700000000000001
60892	M2	216.199999999999989	2.18800000000000017
60892	S2	236.900000000000006	0.554000000000000048
60892	N2	190.599999999999994	0.466000000000000025
60892	K1	228.699999999999989	1.21399999999999997
60892	M4	157.5	0.00700000000000000015
60892	O1	217.400000000000006	0.734999999999999987
60892	M6	164.099999999999994	0.00700000000000000015
60892	S4	86.2999999999999972	0.0100000000000000002
60892	NU2	194.099999999999994	0.0919999999999999984
60892	S6	106.700000000000003	0.00300000000000000006
60892	MU2	195.599999999999994	0.0519999999999999976
60892	2N2	165.099999999999994	0.0619999999999999996
60892	OO1	239.900000000000006	0.0330000000000000016
60892	LDA2	225.800000000000011	0.0160000000000000003
60892	M1	223.099999999999994	0.0519999999999999976
60892	J1	234.300000000000011	0.0560000000000000012
60892	SSA	262.100000000000023	0.135000000000000009
60892	SA	261.399999999999977	0.233000000000000013
60892	RHO1	212.599999999999994	0.0299999999999999989
60892	Q1	211.800000000000011	0.140999999999999986
60892	T2	236.099999999999994	0.0330000000000000016
60892	R2	237.400000000000006	0.00300000000000000006
60892	2Q1	206.199999999999989	0.0200000000000000004
60892	P1	227.800000000000011	0.400000000000000022
60892	L2	241.300000000000011	0.0619999999999999996
60892	K2	238.699999999999989	0.150999999999999995
60892	M8	165.800000000000011	0.00700000000000000015
60893	M2	218.900000000000006	2.40200000000000014
60893	S2	241	0.646000000000000019
60893	N2	193.5	0.512000000000000011
60893	K1	230.099999999999994	1.31600000000000006
60893	M4	242.5	0.0200000000000000004
60893	O1	214.199999999999989	0.85299999999999998
60893	M6	205	0.00700000000000000015
60893	MK3	234.099999999999994	0.0200000000000000004
60893	S4	345.399999999999977	0.00700000000000000015
60893	MN4	211.099999999999994	0.00300000000000000006
60893	NU2	196.800000000000011	0.0950000000000000011
60893	S6	137.5	0.00300000000000000006
60893	MU2	158.599999999999994	0.0560000000000000012
60893	2N2	165.599999999999994	0.0589999999999999969
60893	OO1	230.800000000000011	0.0490000000000000019
60893	LDA2	247.599999999999994	0.0200000000000000004
60893	S1	225.400000000000006	0.0160000000000000003
60893	M1	206.300000000000011	0.0660000000000000031
60893	J1	245.400000000000006	0.0889999999999999958
60893	SSA	262.100000000000023	0.135000000000000009
60893	SA	261.399999999999977	0.233000000000000013
60893	MF	152	0.0459999999999999992
60893	RHO1	195.800000000000011	0.0359999999999999973
60893	Q1	204.699999999999989	0.150999999999999995
60893	T2	245.199999999999989	0.0429999999999999966
60893	R2	91.4000000000000057	0.0100000000000000002
60893	2Q1	175	0.0359999999999999973
60893	P1	224.800000000000011	0.400000000000000022
60893	2SM2	182.300000000000011	0.00300000000000000006
60893	M3	327.699999999999989	0.0100000000000000002
60893	L2	256.399999999999977	0.0490000000000000019
60893	2MK3	182.699999999999989	0.0129999999999999994
60893	K2	229.699999999999989	0.157000000000000001
60893	M8	72.9000000000000057	0.00300000000000000006
60893	MS4	264.300000000000011	0.00300000000000000006
60894	M2	216.5	2.44099999999999984
60894	S2	239	0.646000000000000019
60894	N2	190.699999999999989	0.512000000000000011
60894	K1	230.900000000000006	1.40399999999999991
60894	M4	215.5	0.00300000000000000006
60894	O1	214.599999999999994	0.862999999999999989
60894	M6	3.70000000000000018	0.00300000000000000006
60894	MK3	253.800000000000011	0.00300000000000000006
60894	S4	8.5	0.00300000000000000006
60894	MN4	166.300000000000011	0.00300000000000000006
60894	NU2	196	0.104999999999999996
60894	MU2	158.199999999999989	0.0519999999999999976
60894	2N2	165.900000000000006	0.0560000000000000012
60894	OO1	262.199999999999989	0.0490000000000000019
60894	LDA2	244.300000000000011	0.0200000000000000004
60894	S1	354.100000000000023	0.0330000000000000016
60894	M1	240.599999999999994	0.0519999999999999976
60894	J1	242.800000000000011	0.0850000000000000061
60894	SA	274	0.288999999999999979
60894	RHO1	200.800000000000011	0.0299999999999999989
60894	Q1	206.5	0.153999999999999998
60894	T2	231.5	0.0359999999999999973
60894	R2	305.699999999999989	0.00300000000000000006
60894	2Q1	201.900000000000006	0.0160000000000000003
60894	P1	227.400000000000006	0.432999999999999996
60894	M3	336.600000000000023	0.00300000000000000006
60894	L2	240.599999999999994	0.0560000000000000012
60894	K2	232.699999999999989	0.171000000000000013
60894	MS4	294.100000000000023	0.00300000000000000006
60895	M2	299.600000000000023	1.6339999999999999
60895	S2	339.600000000000023	0.347999999999999976
60895	N2	281	0.276000000000000023
60895	K1	295.800000000000011	0.906000000000000028
60895	M4	168	0.135000000000000009
60895	O1	288.699999999999989	0.616999999999999993
60895	M6	161.699999999999989	0.0359999999999999973
60895	S4	279.600000000000023	0.0160000000000000003
60895	NU2	283.5	0.0519999999999999976
60895	S6	136.199999999999989	0.00300000000000000006
60895	MU2	259.399999999999977	0.0389999999999999999
60895	2N2	262.199999999999989	0.0359999999999999973
60895	OO1	302.600000000000023	0.0259999999999999988
60895	LDA2	318.100000000000023	0.0100000000000000002
60895	M1	292.300000000000011	0.0429999999999999966
60895	J1	299.199999999999989	0.0490000000000000019
60895	RHO1	286	0.0229999999999999996
60895	Q1	285.100000000000023	0.117999999999999994
60895	T2	337.899999999999977	0.0200000000000000004
60895	R2	341.5	0.00300000000000000006
60895	2Q1	282	0.0160000000000000003
60895	P1	295.199999999999989	0.298999999999999988
60895	L2	318	0.0459999999999999992
60895	K2	342.800000000000011	0.0950000000000000011
60895	M8	36	0.00700000000000000015
60896	M2	225.300000000000011	2.68400000000000016
60896	S2	251.099999999999994	0.70499999999999996
60896	N2	200.699999999999989	0.554000000000000048
60896	K1	235.199999999999989	1.31600000000000006
60896	M4	200.699999999999989	0.0259999999999999988
60896	O1	220.5	0.810000000000000053
60896	M6	331.100000000000023	0.0129999999999999994
60896	MK3	191.900000000000006	0.0160000000000000003
60896	MN4	183.900000000000006	0.0100000000000000002
60896	NU2	203.599999999999994	0.112000000000000002
60896	MU2	182.099999999999994	0.0429999999999999966
60896	2N2	174.599999999999994	0.0660000000000000031
60896	OO1	266.300000000000011	0.0429999999999999966
60896	LDA2	224	0.0160000000000000003
60896	S1	46.7000000000000028	0.0129999999999999994
60896	M1	246.5	0.0490000000000000019
60896	J1	249.400000000000006	0.0790000000000000008
60896	SA	283.300000000000011	0.338000000000000023
60896	MF	155.699999999999989	0.0519999999999999976
60896	RHO1	213.300000000000011	0.0299999999999999989
60896	Q1	214.300000000000011	0.143999999999999989
60896	T2	244.400000000000006	0.0389999999999999999
60896	R2	252.099999999999994	0.00700000000000000015
60896	2Q1	213.300000000000011	0.0129999999999999994
60896	P1	233.300000000000011	0.412999999999999978
60896	L2	241.400000000000006	0.0719999999999999946
60896	K2	244.599999999999994	0.190000000000000002
60896	MS4	252.900000000000006	0.0129999999999999994
60897	M2	230.599999999999994	2.45100000000000007
60897	S2	258	0.673000000000000043
60897	N2	207	0.505000000000000004
60897	K1	238.699999999999989	1.2370000000000001
60897	M4	216.199999999999989	0.00300000000000000006
60897	O1	223.800000000000011	0.791000000000000036
60897	M6	329.800000000000011	0.0160000000000000003
60897	MK3	129.5	0.00300000000000000006
60897	S4	3.29999999999999982	0.00700000000000000015
60897	NU2	216	0.101999999999999993
60897	MU2	187.800000000000011	0.0299999999999999989
60897	2N2	186.099999999999994	0.0560000000000000012
60897	OO1	260.100000000000023	0.0459999999999999992
60897	LDA2	235.099999999999994	0.0299999999999999989
60897	S1	17.3000000000000007	0.0129999999999999994
60897	M1	210.199999999999989	0.0459999999999999992
60897	J1	259.699999999999989	0.0790000000000000008
60897	SA	283.300000000000011	0.338000000000000023
60897	MF	155.699999999999989	0.0519999999999999976
60897	RHO1	213.800000000000011	0.0299999999999999989
60897	Q1	216.300000000000011	0.138000000000000012
60897	T2	257.600000000000023	0.0459999999999999992
60897	R2	130.300000000000011	0.0429999999999999966
60897	2Q1	201.199999999999989	0.0299999999999999989
60897	P1	232.099999999999994	0.381000000000000005
60897	2SM2	82.2999999999999972	0.00300000000000000006
60897	M3	2.20000000000000018	0.00700000000000000015
60897	L2	253.800000000000011	0.0619999999999999996
60897	2MK3	79.2999999999999972	0.00300000000000000006
60897	K2	241.099999999999994	0.190000000000000002
60897	MS4	329.399999999999977	0.00700000000000000015
60898	M2	255.900000000000006	2.53600000000000003
60898	S2	289.300000000000011	0.609999999999999987
60898	N2	236	0.471999999999999975
60898	K1	255.199999999999989	1.18799999999999994
60898	M4	7.59999999999999964	0.0359999999999999973
60898	O1	241.099999999999994	0.717999999999999972
60898	M6	75.9000000000000057	0.0429999999999999966
60898	S4	100.5	0.00700000000000000015
60898	NU2	238.699999999999989	0.0919999999999999984
60898	S6	251.599999999999994	0.00300000000000000006
60898	MU2	222.400000000000006	0.0619999999999999996
60898	2N2	216.099999999999994	0.0619999999999999996
60898	OO1	269.199999999999989	0.0299999999999999989
60898	LDA2	271.399999999999977	0.0160000000000000003
60898	M1	248.199999999999989	0.0519999999999999976
60898	J1	262.100000000000023	0.0560000000000000012
60898	RHO1	235.099999999999994	0.0259999999999999988
60898	Q1	234.199999999999989	0.138000000000000012
60898	T2	288	0.0359999999999999973
60898	R2	290.199999999999989	0.00300000000000000006
60898	2Q1	227.300000000000011	0.0200000000000000004
60898	P1	254.199999999999989	0.394000000000000017
60898	L2	275.600000000000023	0.0719999999999999946
60898	K2	292	0.164000000000000007
60898	M8	216.199999999999989	0.00700000000000000015
60899	M2	250.5	2.56199999999999983
60899	S2	286.300000000000011	0.65900000000000003
60899	N2	227.900000000000006	0.453000000000000014
60899	K1	250.099999999999994	1.25299999999999989
60899	M4	33	0.0299999999999999989
60899	O1	243.099999999999994	0.755000000000000004
60899	M6	66.0999999999999943	0.0389999999999999999
60899	S4	133.099999999999994	0.0100000000000000002
60899	NU2	230.900000000000006	0.0889999999999999958
60899	MU2	214.900000000000006	0.0619999999999999996
60899	2N2	205	0.0589999999999999969
60899	OO1	257	0.0330000000000000016
60899	LDA2	266.899999999999977	0.0200000000000000004
60899	M1	246.599999999999994	0.0519999999999999976
60899	J1	253.5	0.0589999999999999969
60899	SSA	234	0.0889999999999999958
60899	SA	285.899999999999977	0.0389999999999999999
60899	MF	183	0.0820000000000000034
60899	RHO1	240	0.0299999999999999989
60899	Q1	239.599999999999994	0.143999999999999989
60899	T2	284.800000000000011	0.0389999999999999999
60899	R2	287.699999999999989	0.00700000000000000015
60899	2Q1	236.400000000000006	0.0200000000000000004
60899	P1	249.599999999999994	0.416999999999999982
60899	L2	273.100000000000023	0.0719999999999999946
60899	K2	289.199999999999989	0.179999999999999993
60899	M8	233.300000000000011	0.00300000000000000006
60900	M2	230.800000000000011	2.56899999999999995
60900	S2	261.300000000000011	0.691999999999999948
60900	N2	207.300000000000011	0.535000000000000031
60900	K1	237.699999999999989	1.28899999999999992
60900	M4	278.899999999999977	0.0259999999999999988
60900	O1	223.300000000000011	0.791000000000000036
60900	M6	339.600000000000023	0.0129999999999999994
60900	MK3	287.199999999999989	0.0160000000000000003
60900	S4	37.6000000000000014	0.00700000000000000015
60900	MN4	268.399999999999977	0.0100000000000000002
60900	NU2	216.699999999999989	0.0980000000000000038
60900	MU2	207.599999999999994	0.0330000000000000016
60900	2N2	188.199999999999989	0.0560000000000000012
60900	OO1	254.400000000000006	0.0459999999999999992
60900	LDA2	237	0.0330000000000000016
60900	S1	339.100000000000023	0.0459999999999999992
60900	M1	222.199999999999989	0.0459999999999999992
60900	J1	260.699999999999989	0.0790000000000000008
60900	SSA	234	0.0889999999999999958
60900	SA	285.899999999999977	0.400000000000000022
60900	MF	183	0.0820000000000000034
60900	RHO1	217.199999999999989	0.0389999999999999999
60900	Q1	219.900000000000006	0.135000000000000009
60900	T2	269.399999999999977	0.0519999999999999976
60900	R2	161.900000000000006	0.0490000000000000019
60900	2Q1	211	0.0330000000000000016
60900	P1	227.300000000000011	0.377000000000000002
60900	2SM2	136.599999999999994	0.00700000000000000015
60900	M3	36.5	0.00300000000000000006
60900	L2	253.099999999999994	0.0719999999999999946
60900	2MK3	4.59999999999999964	0.00700000000000000015
60900	K2	241	0.209999999999999992
60900	MS4	324.300000000000011	0.0160000000000000003
60901	M2	245.5	2.47999999999999998
60901	S2	282.800000000000011	0.599999999999999978
60901	N2	224.400000000000006	0.498999999999999999
60901	K1	249.599999999999994	1.2370000000000001
60901	M4	355.5	0.0619999999999999996
60901	O1	236.199999999999989	0.747999999999999998
60901	M6	18.1999999999999993	0.0749999999999999972
60901	MK3	33.2999999999999972	0.0259999999999999988
60901	S4	68.0999999999999943	0.00300000000000000006
60901	MN4	332.899999999999977	0.0229999999999999996
60901	NU2	217	0.101999999999999993
60901	MU2	302	0.0299999999999999989
60901	2N2	196.900000000000006	0.0619999999999999996
60901	OO1	293.5	0.0589999999999999969
60901	LDA2	244.199999999999989	0.0330000000000000016
60901	S1	104.200000000000003	0.0100000000000000002
60901	M1	196.900000000000006	0.0200000000000000004
60901	J1	283.100000000000023	0.0589999999999999969
60901	SSA	234	0.0889999999999999958
60901	SA	285.899999999999977	0.400000000000000022
60901	MF	183	0.0820000000000000034
60901	RHO1	262.399999999999977	0.0359999999999999973
60901	Q1	236.5	0.112000000000000002
60901	T2	322.300000000000011	0.0560000000000000012
60901	R2	239.300000000000011	0.0560000000000000012
60901	2Q1	212.400000000000006	0.0359999999999999973
60901	P1	245.300000000000011	0.350999999999999979
60901	2SM2	95.5	0.0129999999999999994
60901	M3	156.800000000000011	0.00300000000000000006
60901	L2	258.199999999999989	0.0950000000000000011
60901	2MK3	32.8999999999999986	0.0389999999999999999
60901	K2	270	0.176999999999999991
60901	M8	112.299999999999997	0.0129999999999999994
60901	MS4	9.59999999999999964	0.0429999999999999966
60902	M2	235.5	2.98600000000000021
60902	S2	262.100000000000023	0.744999999999999996
60902	N2	214.400000000000006	0.666000000000000036
60902	K1	238	1.42100000000000004
60902	M4	234.699999999999989	0.0459999999999999992
60902	O1	224.800000000000011	0.845999999999999974
60902	M6	314.800000000000011	0.0330000000000000016
60902	S4	258.699999999999989	0.00700000000000000015
60902	NU2	217.199999999999989	0.128000000000000003
60902	S6	181.400000000000006	0.00300000000000000006
60902	MU2	208.900000000000006	0.0719999999999999946
60902	2N2	193.199999999999989	0.0889999999999999958
60902	OO1	251.300000000000011	0.0359999999999999973
60902	LDA2	247.900000000000006	0.0200000000000000004
60902	M1	231.5	0.0589999999999999969
60902	J1	244.599999999999994	0.0660000000000000031
60902	SSA	234	0.0889999999999999958
60902	SA	285.899999999999977	0.400000000000000022
60902	MF	183	0.0820000000000000034
60902	RHO1	219.099999999999994	0.0330000000000000016
60902	Q1	218.300000000000011	0.164000000000000007
60902	T2	261.100000000000023	0.0429999999999999966
60902	R2	263.199999999999989	0.00700000000000000015
60902	2Q1	211.699999999999989	0.0229999999999999996
60902	P1	237.099999999999994	0.468999999999999972
60902	L2	256.699999999999989	0.0820000000000000034
60902	K2	264.300000000000011	0.203000000000000014
60902	M8	236.599999999999994	0.0100000000000000002
60903	M2	231.199999999999989	2.91000000000000014
60903	S2	259.300000000000011	0.794000000000000039
60903	N2	207.5	0.603999999999999981
60903	K1	238.099999999999994	1.42399999999999993
60903	M4	198.800000000000011	0.0389999999999999999
60903	O1	221.400000000000006	0.862999999999999989
60903	M6	298.300000000000011	0.0259999999999999988
60903	MK3	196.900000000000006	0.0100000000000000002
60903	S4	349.699999999999989	0.00300000000000000006
60903	MN4	180.300000000000011	0.0160000000000000003
60903	NU2	210.400000000000006	0.120999999999999996
60903	S6	123.599999999999994	0.00300000000000000006
60903	MU2	203.900000000000006	0.0490000000000000019
60903	2N2	182.5	0.0690000000000000058
60903	OO1	274.399999999999977	0.0459999999999999992
60903	LDA2	223.199999999999989	0.0229999999999999996
60903	S1	5.40000000000000036	0.0389999999999999999
60903	M1	257.899999999999977	0.0490000000000000019
60903	J1	256	0.0790000000000000008
60903	SSA	234	0.0889999999999999958
60903	SA	285.899999999999977	0.400000000000000022
60903	MF	183	0.0820000000000000034
60903	RHO1	211.900000000000006	0.0299999999999999989
60903	Q1	214.199999999999989	0.150999999999999995
60903	T2	251.699999999999989	0.0490000000000000019
60903	R2	213.599999999999994	0.00700000000000000015
60903	2Q1	214.400000000000006	0.0160000000000000003
60903	P1	233.900000000000006	0.440000000000000002
60903	2SM2	54.2000000000000028	0.00700000000000000015
60903	L2	235.900000000000006	0.0719999999999999946
60903	2MK3	349	0.00700000000000000015
60903	K2	250.599999999999994	0.209999999999999992
60903	M8	260.399999999999977	0.00700000000000000015
60903	MS4	239.900000000000006	0.0229999999999999996
60904	M2	225	2.91999999999999993
60904	S2	250.599999999999994	0.801000000000000045
60904	N2	200.300000000000011	0.61399999999999999
60904	K1	235	1.43700000000000006
60904	O1	218.5	0.88600000000000001
60904	NU2	208.400000000000006	0.125
60904	MU2	171.300000000000011	0.0660000000000000031
60904	2N2	171.599999999999994	0.0719999999999999946
60904	OO1	266.699999999999989	0.0560000000000000012
60904	LDA2	269.600000000000023	0.0160000000000000003
60904	S1	37.2999999999999972	0.0160000000000000003
60904	M1	244.199999999999989	0.0560000000000000012
60904	J1	246.699999999999989	0.0850000000000000061
60904	MM	174.699999999999989	0.0889999999999999958
60904	SSA	258.699999999999989	0.0619999999999999996
60904	SA	281.600000000000023	0.404000000000000026
60904	MF	155	0.0619999999999999996
60904	RHO1	213.800000000000011	0.0299999999999999989
60904	Q1	212.599999999999994	0.157000000000000001
60904	T2	257.300000000000011	0.0519999999999999976
60904	R2	251.699999999999989	0.00700000000000000015
60904	2Q1	191.199999999999989	0.0200000000000000004
60904	P1	232.699999999999989	0.44900000000000001
60904	L2	251.300000000000011	0.0719999999999999946
60904	K2	240.699999999999989	0.212999999999999995
60905	M2	272	1.77499999999999991
60905	S2	309.300000000000011	0.412999999999999978
60905	N2	251.699999999999989	0.304999999999999993
60905	K1	273	0.919000000000000039
60905	M4	116.400000000000006	0.120999999999999996
60905	O1	273.699999999999989	0.563999999999999946
60905	M6	84.7000000000000028	0.0299999999999999989
60905	S4	218.099999999999994	0.0200000000000000004
60905	NU2	254.400000000000006	0.0589999999999999969
60905	MU2	234.5	0.0429999999999999966
60905	2N2	231.800000000000011	0.0389999999999999999
60905	OO1	271.800000000000011	0.0229999999999999996
60905	LDA2	289.399999999999977	0.0129999999999999994
60905	M1	273.300000000000011	0.0389999999999999999
60905	J1	272.300000000000011	0.0459999999999999992
60905	RHO1	274.300000000000011	0.0200000000000000004
60905	Q1	274.199999999999989	0.107999999999999999
60905	T2	307.800000000000011	0.0229999999999999996
60905	R2	310.800000000000011	0.00300000000000000006
60905	2Q1	275	0.0129999999999999994
60905	P1	273.100000000000023	0.304999999999999993
60905	L2	292	0.0490000000000000019
60905	K2	312.300000000000011	0.112000000000000002
60905	M8	299.100000000000023	0.0129999999999999994
60906	M2	229	2.52899999999999991
60906	S2	251.099999999999994	0.892000000000000015
60906	N2	205.800000000000011	0.509000000000000008
60906	K1	239.5	1.15500000000000003
60906	M4	64.7999999999999972	0.138000000000000012
60906	O1	231.900000000000006	0.744999999999999996
60906	M6	92.9000000000000057	0.0389999999999999999
60906	MK3	78.9000000000000057	0.128000000000000003
60906	S4	103.299999999999997	0.0160000000000000003
60906	MN4	46.3999999999999986	0.0619999999999999996
60906	NU2	198.300000000000011	0.112000000000000002
60906	S6	191.900000000000006	0.00300000000000000006
60906	MU2	90.7000000000000028	0.0259999999999999988
60906	2N2	169.900000000000006	0.0359999999999999973
60906	OO1	286.399999999999977	0.0560000000000000012
60906	LDA2	222	0.0359999999999999973
60906	S1	227	0.0660000000000000031
60906	M1	150	0.0200000000000000004
60906	J1	266.899999999999977	0.0589999999999999969
60906	SSA	234	0.0889999999999999958
60906	SA	285.899999999999977	0.400000000000000022
60906	MF	183	0.0820000000000000034
60906	RHO1	228.099999999999994	0.0259999999999999988
60906	Q1	234.699999999999989	0.117999999999999994
60906	T2	224.099999999999994	0.138000000000000012
60906	R2	75.4000000000000057	0.298999999999999988
60906	2Q1	233.900000000000006	0.0330000000000000016
60906	P1	243.099999999999994	0.318000000000000005
60906	2SM2	57.2999999999999972	0.0129999999999999994
60906	M3	238	0.0389999999999999999
60906	L2	252	0.0919999999999999984
60906	2MK3	35.1000000000000014	0.112000000000000002
60906	K2	202.5	0.212999999999999995
60906	M8	205.5	0.00300000000000000006
60906	MS4	82	0.0950000000000000011
60907	M2	261.100000000000023	2.32900000000000018
60907	S2	308.100000000000023	0.711999999999999966
60907	N2	239.900000000000006	0.459000000000000019
60907	K1	263.899999999999977	1.09899999999999998
60907	M4	115.700000000000003	0.245999999999999996
60907	O1	259.699999999999989	0.65900000000000003
60907	M6	39.7000000000000028	0.0429999999999999966
60907	MK3	115.799999999999997	0.259000000000000008
60907	S4	191	0.0160000000000000003
60907	MN4	94.7000000000000028	0.0980000000000000038
60907	NU2	238	0.0560000000000000012
60907	MU2	9.5	0.0850000000000000061
60907	2N2	191.900000000000006	0.0660000000000000031
60907	OO1	318.699999999999989	0.0560000000000000012
60907	LDA2	315.300000000000011	0.0359999999999999973
60907	S1	38.2000000000000028	0.0790000000000000008
60907	M1	48.6000000000000014	0.0459999999999999992
60907	J1	319.600000000000023	0.0519999999999999976
60907	SSA	198	0.0459999999999999992
60907	SA	286.199999999999989	0.36399999999999999
60907	MF	183.400000000000006	0.0850000000000000061
60907	RHO1	306.100000000000023	0.0389999999999999999
60907	Q1	258.800000000000011	0.0889999999999999958
60907	T2	307.399999999999977	0.0950000000000000011
60907	R2	165.599999999999994	0.183999999999999997
60907	2Q1	247.900000000000006	0.0589999999999999969
60907	P1	237.900000000000006	0.284999999999999976
60907	2SM2	105.799999999999997	0.0259999999999999988
60907	M3	271.899999999999977	0.0359999999999999973
60907	L2	272.5	0.147999999999999993
60907	2MK3	81.5	0.235999999999999988
60907	K2	272.699999999999989	0.279000000000000026
60907	M8	301.100000000000023	0.00700000000000000015
60907	MS4	152.199999999999989	0.135000000000000009
60908	M2	242.599999999999994	2.87699999999999978
60908	S2	273	0.771000000000000019
60908	N2	220	0.583999999999999964
60908	K1	245.800000000000011	1.371
60908	M4	250.400000000000006	0.0950000000000000011
60908	O1	229.099999999999994	0.82999999999999996
60908	M6	358.5	0.0519999999999999976
60908	MK3	247.599999999999994	0.0389999999999999999
60908	S4	354.399999999999977	0.00700000000000000015
60908	MN4	229.900000000000006	0.0389999999999999999
60908	NU2	221.800000000000011	0.120999999999999996
60908	MU2	252	0.0459999999999999992
60908	2N2	195.300000000000011	0.0619999999999999996
60908	OO1	285	0.0429999999999999966
60908	LDA2	223	0.0330000000000000016
60908	S1	7.70000000000000018	0.0389999999999999999
60908	M1	272.699999999999989	0.0459999999999999992
60908	J1	266.300000000000011	0.0690000000000000058
60908	SSA	198	0.0459999999999999992
60908	SA	286.199999999999989	0.36399999999999999
60908	MF	183.400000000000006	0.0850000000000000061
60908	RHO1	217.099999999999994	0.0299999999999999989
60908	Q1	223.599999999999994	0.140999999999999986
60908	T2	266.100000000000023	0.0490000000000000019
60908	R2	184.900000000000006	0.00700000000000000015
60908	2Q1	226.900000000000006	0.0160000000000000003
60908	P1	242.099999999999994	0.422999999999999987
60908	2SM2	72.4000000000000057	0.0129999999999999994
60908	M3	227.900000000000006	0.00700000000000000015
60908	L2	241.400000000000006	0.0850000000000000061
60908	2MK3	308.600000000000023	0.0129999999999999994
60908	K2	265.5	0.197000000000000008
60908	M8	15.9000000000000004	0.00700000000000000015
60908	MS4	286.600000000000023	0.0589999999999999969
60909	M2	230.599999999999994	2.83800000000000008
60909	S2	256.699999999999989	0.771000000000000019
60909	N2	205.5	0.580999999999999961
60909	K1	238.400000000000006	1.34800000000000009
60909	M4	180.199999999999989	0.0589999999999999969
60909	O1	219.699999999999989	0.865999999999999992
60909	M6	50.8999999999999986	0.0200000000000000004
60909	S4	318.100000000000023	0.00300000000000000006
60909	NU2	208.900000000000006	0.115000000000000005
60909	MU2	204.5	0.0690000000000000058
60909	2N2	180.400000000000006	0.0749999999999999972
60909	OO1	257.100000000000023	0.0359999999999999973
60909	LDA2	242.699999999999989	0.0200000000000000004
60909	M1	229.099999999999994	0.0619999999999999996
60909	J1	247.699999999999989	0.0690000000000000058
60909	SSA	198	0.0459999999999999992
60909	SA	286.199999999999989	0.36399999999999999
60909	MF	183.400000000000006	0.0850000000000000061
60909	RHO1	211.699999999999989	0.0330000000000000016
60909	Q1	210.400000000000006	0.16700000000000001
60909	T2	255.699999999999989	0.0459999999999999992
60909	R2	257.800000000000011	0.00700000000000000015
60909	2Q1	201.199999999999989	0.0229999999999999996
60909	P1	237	0.446000000000000008
60909	L2	255.699999999999989	0.0790000000000000008
60909	K2	258.800000000000011	0.209999999999999992
60909	M8	318.100000000000023	0.00700000000000000015
60910	M2	253.099999999999994	2.88099999999999978
60910	S2	290.800000000000011	0.787000000000000033
60910	N2	235.599999999999994	0.54500000000000004
60910	K1	254	1.3580000000000001
60910	M4	74.2000000000000028	0.131000000000000005
60910	O1	242.400000000000006	0.879000000000000004
60910	M6	30.1999999999999993	0.0690000000000000058
60910	S4	180.099999999999994	0.0299999999999999989
60910	NU2	237.900000000000006	0.104999999999999996
60910	S6	305.100000000000023	0.00700000000000000015
60910	MU2	215.300000000000011	0.0690000000000000058
60910	2N2	218.099999999999994	0.0719999999999999946
60910	OO1	265.5	0.0359999999999999973
60910	LDA2	270.699999999999989	0.0200000000000000004
60910	M1	248.199999999999989	0.0619999999999999996
60910	J1	259.800000000000011	0.0690000000000000058
60910	RHO1	237.400000000000006	0.0330000000000000016
60910	Q1	236.599999999999994	0.171000000000000013
60910	T2	289.399999999999977	0.0459999999999999992
60910	R2	292.5	0.00700000000000000015
60910	2Q1	230.900000000000006	0.0229999999999999996
60910	P1	253.199999999999989	0.44900000000000001
60910	L2	270.5	0.0820000000000000034
60910	K2	293.899999999999977	0.212999999999999995
60910	M8	201.599999999999994	0.0129999999999999994
60911	M2	260.899999999999977	3.26399999999999979
60911	S2	291.899999999999977	0.781000000000000028
60911	N2	239.900000000000006	0.630000000000000004
60911	K1	257.199999999999989	1.2629999999999999
60911	M4	29.8000000000000007	0.0429999999999999966
60911	O1	242.699999999999989	0.85299999999999998
60911	M6	31.1999999999999993	0.0560000000000000012
60911	MK3	106.299999999999997	0.0589999999999999969
60911	S4	142.400000000000006	0.0100000000000000002
60911	MN4	24.6000000000000014	0.0160000000000000003
60911	NU2	240.699999999999989	0.135000000000000009
60911	S6	357.300000000000011	0.00300000000000000006
60911	MU2	342.899999999999977	0.0429999999999999966
60911	2N2	212.800000000000011	0.0790000000000000008
60911	OO1	301.899999999999977	0.0560000000000000012
60911	LDA2	246.400000000000006	0.0490000000000000019
60911	S1	167.5	0.0820000000000000034
60911	M1	182.199999999999989	0.0100000000000000002
60911	J1	287.5	0.0619999999999999996
60911	SSA	183	0.147999999999999993
60911	SA	308.699999999999989	0.370999999999999996
60911	MF	187.900000000000006	0.0850000000000000061
60911	RHO1	248.5	0.0459999999999999992
60911	Q1	244.099999999999994	0.138000000000000012
60911	T2	298.199999999999989	0.0229999999999999996
60911	R2	345.699999999999989	0.0950000000000000011
60911	2Q1	233.699999999999989	0.0459999999999999992
60911	P1	253.800000000000011	0.404000000000000026
60911	2SM2	112.700000000000003	0.0299999999999999989
60911	M3	266.699999999999989	0.00300000000000000006
60911	L2	276.600000000000023	0.125
60911	2MK3	67.4000000000000057	0.0850000000000000061
60911	K2	298.300000000000011	0.216999999999999998
60911	M8	97.4000000000000057	0.0129999999999999994
60911	MS4	64.4000000000000057	0.0359999999999999973
60912	M2	250.599999999999994	3.04800000000000004
60912	S2	278.5	0.816999999999999948
60912	N2	226.800000000000011	0.616999999999999993
60912	K1	248.400000000000006	1.3620000000000001
60912	M4	245.900000000000006	0.0490000000000000019
60912	O1	232.5	0.85299999999999998
60912	M6	39.2000000000000028	0.0160000000000000003
60912	MK3	169.699999999999989	0.0160000000000000003
60912	S4	18.3000000000000007	0.00700000000000000015
60912	MN4	225.5	0.0129999999999999994
60912	NU2	230	0.104999999999999996
60912	MU2	233.300000000000011	0.0160000000000000003
60912	2N2	191.400000000000006	0.0749999999999999972
60912	OO1	287.100000000000023	0.0389999999999999999
60912	LDA2	266.100000000000023	0.0299999999999999989
60912	S1	15.6999999999999993	0.0299999999999999989
60912	M1	289	0.0429999999999999966
60912	J1	268	0.0719999999999999946
60912	SSA	184.099999999999994	0.171000000000000013
60912	SA	307.199999999999989	0.36399999999999999
60912	RHO1	239.800000000000011	0.0259999999999999988
60912	Q1	225	0.143999999999999989
60912	T2	257	0.0330000000000000016
60912	R2	268.600000000000023	0.00700000000000000015
60912	2Q1	212.199999999999989	0.0129999999999999994
60912	P1	246.800000000000011	0.406999999999999973
60912	2SM2	106.799999999999997	0.0200000000000000004
60912	M3	21.6000000000000014	0.00700000000000000015
60912	L2	267.5	0.0889999999999999958
60912	2MK3	102.599999999999994	0.0259999999999999988
60912	K2	271.199999999999989	0.23000000000000001
60912	MS4	296.899999999999977	0.0259999999999999988
60913	M2	261.600000000000023	3.16599999999999993
60913	S2	293.800000000000011	0.794000000000000039
60913	N2	239.5	0.603999999999999981
60913	K1	254.5	1.32200000000000006
60913	M4	109.099999999999994	0.0299999999999999989
60913	O1	239.599999999999994	0.801000000000000045
60913	M6	124.099999999999994	0.0389999999999999999
60913	MK3	113.299999999999997	0.0820000000000000034
60913	S4	160	0.0100000000000000002
60913	MN4	79.0999999999999943	0.0160000000000000003
60913	NU2	240.900000000000006	0.128000000000000003
60913	MU2	356.5	0.0619999999999999996
60913	2N2	214	0.0589999999999999969
60913	OO1	294.300000000000011	0.0389999999999999999
60913	LDA2	257.300000000000011	0.0719999999999999946
60913	S1	24.5	0.0359999999999999973
60913	M1	302.600000000000023	0.0459999999999999992
60913	J1	282.800000000000011	0.0490000000000000019
60913	SSA	183	0.147999999999999993
60913	SA	308.699999999999989	0.370999999999999996
60913	MF	187.900000000000006	0.0850000000000000061
60913	RHO1	239.900000000000006	0.0229999999999999996
60913	Q1	240	0.138000000000000012
60913	T2	296.399999999999977	0.0519999999999999976
60913	R2	356.399999999999977	0.00700000000000000015
60913	2Q1	253.699999999999989	0.0160000000000000003
60913	P1	251.400000000000006	0.366999999999999993
60913	2SM2	121.5	0.0330000000000000016
60913	M3	15.4000000000000004	0.0129999999999999994
60913	L2	267.399999999999977	0.150999999999999995
60913	2MK3	91.4000000000000057	0.101999999999999993
60913	K2	283.399999999999977	0.245999999999999996
60913	M8	231.400000000000006	0.00300000000000000006
60913	MS4	107.599999999999994	0.0200000000000000004
60914	M2	300.300000000000011	2.59200000000000008
60914	S2	335.199999999999989	0.603999999999999981
60914	N2	280	0.456000000000000016
60914	K1	280.699999999999989	0.973999999999999977
60914	M4	170.699999999999989	0.256000000000000005
60914	O1	268.800000000000011	0.548000000000000043
60914	M6	266.899999999999977	0.0359999999999999973
60914	MK3	149.199999999999989	0.216999999999999998
60914	S4	249.699999999999989	0.0100000000000000002
60914	MN4	154.599999999999994	0.0889999999999999958
60914	NU2	282.800000000000011	0.104999999999999996
60914	S6	52.8999999999999986	0.00300000000000000006
60914	MU2	58.7000000000000028	0.0980000000000000038
60914	2N2	233.099999999999994	0.0660000000000000031
60914	OO1	358	0.0229999999999999996
60914	LDA2	293.399999999999977	0.0690000000000000058
60914	S1	53.7999999999999972	0.0129999999999999994
60914	M1	13.1999999999999993	0.0459999999999999992
60914	J1	339	0.0429999999999999966
60914	RHO1	313.600000000000023	0.0160000000000000003
60914	Q1	276.5	0.0950000000000000011
60914	T2	332.399999999999977	0.0389999999999999999
60914	R2	353.399999999999977	0.0359999999999999973
60914	2Q1	232.099999999999994	0.0129999999999999994
60914	P1	281.800000000000011	0.245999999999999996
60914	2SM2	156.800000000000011	0.0359999999999999973
60914	M3	342.100000000000023	0.0299999999999999989
60914	L2	311.5	0.128000000000000003
60914	2MK3	135.800000000000011	0.220000000000000001
60914	K2	322.399999999999977	0.226000000000000006
60914	M8	117.5	0.0160000000000000003
60914	MS4	198.300000000000011	0.128000000000000003
60915	M2	52.2000000000000028	0.832999999999999963
60915	S2	84.2999999999999972	0.16700000000000001
60915	N2	33.6000000000000014	0.128000000000000003
60915	K1	12.4000000000000004	0.528000000000000025
60915	M4	22.3999999999999986	0.173999999999999988
60915	O1	19.8000000000000007	0.223000000000000004
60915	M6	10.3000000000000007	0.0200000000000000004
60915	MK3	327.199999999999989	0.153999999999999998
60915	S4	100.799999999999997	0.00300000000000000006
60915	MN4	2.70000000000000018	0.0519999999999999976
60915	NU2	57.3999999999999986	0.0259999999999999988
60915	MU2	162.300000000000011	0.0299999999999999989
60915	2N2	356.600000000000023	0.0389999999999999999
60915	OO1	81.2999999999999972	0.0160000000000000003
60915	LDA2	6.5	0.0129999999999999994
60915	S1	188.900000000000006	0.143999999999999989
60915	M1	58.3999999999999986	0.0389999999999999999
60915	J1	46.5	0.0330000000000000016
60915	RHO1	20.1999999999999993	0.00700000000000000015
60915	Q1	23.1000000000000014	0.0519999999999999976
60915	T2	123.5	0.0200000000000000004
60915	R2	151.800000000000011	0.0560000000000000012
60915	2Q1	343.800000000000011	0.0160000000000000003
60915	P1	309.5	0.183999999999999997
60915	2SM2	279.300000000000011	0.0100000000000000002
60915	M3	112.700000000000003	0.0160000000000000003
60915	L2	89.0999999999999943	0.0619999999999999996
60915	2MK3	314.699999999999989	0.115000000000000005
60915	K2	85.2999999999999972	0.0889999999999999958
60915	M8	77	0.00700000000000000015
60915	MS4	52.7999999999999972	0.0850000000000000061
60916	M2	20.1999999999999993	0.996999999999999997
60916	S2	64.7000000000000028	0.223000000000000004
60916	N2	355.5	0.173999999999999988
60916	K1	338.300000000000011	0.528000000000000025
60916	M4	306.5	0.179999999999999993
60916	O1	354	0.226000000000000006
60916	M6	249.400000000000006	0.0200000000000000004
60916	MK3	276	0.147999999999999993
60916	S4	67.5	0.0100000000000000002
60916	MN4	283.699999999999989	0.0619999999999999996
60916	NU2	358.199999999999989	0.0459999999999999992
60916	MU2	151.5	0.0519999999999999976
60916	2N2	247.800000000000011	0.0359999999999999973
60916	OO1	35.1000000000000014	0.00300000000000000006
60916	LDA2	54.7999999999999972	0.0330000000000000016
60916	S1	7	0.140999999999999986
60916	M1	21.8000000000000007	0.0259999999999999988
60916	J1	56.7999999999999972	0.0359999999999999973
60916	RHO1	36.8999999999999986	0.0160000000000000003
60916	Q1	348.300000000000011	0.0589999999999999969
60916	T2	54.3999999999999986	0.0359999999999999973
60916	R2	75.9000000000000057	0.0429999999999999966
60916	2Q1	70.7999999999999972	0.0100000000000000002
60916	P1	9.09999999999999964	0.0820000000000000034
60916	2SM2	232.5	0.0160000000000000003
60916	M3	146.400000000000006	0.0299999999999999989
60916	L2	0.200000000000000011	0.0459999999999999992
60916	2MK3	259.100000000000023	0.112000000000000002
60916	K2	54.5	0.0850000000000000061
60916	M8	29.8999999999999986	0.0100000000000000002
60916	MS4	341.699999999999989	0.0790000000000000008
60917	M2	31.1999999999999993	0.849999999999999978
60917	S2	59.8999999999999986	0.200000000000000011
60917	N2	11.4000000000000004	0.135000000000000009
60917	K1	357.899999999999977	0.443000000000000005
60917	M4	345.800000000000011	0.23000000000000001
60917	O1	6.70000000000000018	0.226000000000000006
60917	M6	333.300000000000011	0.0490000000000000019
60917	MK3	296.300000000000011	0.161000000000000004
60917	S4	74.7999999999999972	0.0129999999999999994
60917	MN4	326.300000000000011	0.0690000000000000058
60917	NU2	38.3999999999999986	0.0259999999999999988
60917	MU2	132.5	0.0299999999999999989
60917	2N2	337.100000000000023	0.0389999999999999999
60917	OO1	81.2999999999999972	0.0160000000000000003
60917	LDA2	343.600000000000023	0.0229999999999999996
60917	S1	255	0.107999999999999999
60917	M1	42.1000000000000014	0.0490000000000000019
60917	J1	35.1000000000000014	0.0330000000000000016
60917	Q1	12.0999999999999996	0.0519999999999999976
60917	T2	69.4000000000000057	0.0259999999999999988
60917	R2	136.300000000000011	0.0589999999999999969
60917	2Q1	333	0.0129999999999999994
60917	P1	342.399999999999977	0.0980000000000000038
60917	2SM2	258.100000000000023	0.00700000000000000015
60917	M3	115	0.0160000000000000003
60917	L2	62.7999999999999972	0.0519999999999999976
60917	2MK3	283.699999999999989	0.131000000000000005
60917	K2	61.8999999999999986	0.0950000000000000011
60917	M8	46.7000000000000028	0.00700000000000000015
60917	MS4	20.1000000000000014	0.131000000000000005
60918	M2	106.400000000000006	0.446000000000000008
60918	S2	145.800000000000011	0.101999999999999993
60918	N2	92.0999999999999943	0.0889999999999999958
60918	K1	45.8999999999999986	0.294999999999999984
60918	M4	112.799999999999997	0.0850000000000000061
60918	O1	62.7999999999999972	0.179999999999999993
60918	M6	121.5	0.0160000000000000003
60918	S4	289.199999999999989	0.0160000000000000003
60918	NU2	94	0.0200000000000000004
60918	S6	259.100000000000023	0.00300000000000000006
60918	MU2	78.5999999999999943	0.00700000000000000015
60918	2N2	76.9000000000000057	0.0100000000000000002
60918	OO1	33.6000000000000014	0.00300000000000000006
60918	LDA2	112.400000000000006	0.00300000000000000006
60918	M1	55.3999999999999986	0.0129999999999999994
60918	J1	44.1000000000000014	0.0100000000000000002
60918	RHO1	69	0.00700000000000000015
60918	Q1	67.4000000000000057	0.0330000000000000016
60918	T2	145.599999999999994	0.00700000000000000015
60918	2Q1	67.2999999999999972	0.00300000000000000006
60918	P1	47.2000000000000028	0.101999999999999993
60918	L2	116.400000000000006	0.0129999999999999994
60918	K2	149.400000000000006	0.0259999999999999988
60918	M8	210.5	0.00300000000000000006
60919	M2	153.400000000000006	0.394000000000000017
60919	S2	189.800000000000011	0.125
60919	N2	141	0.0660000000000000031
60919	K1	32.5	0.347999999999999976
60919	M4	205.400000000000006	0.0889999999999999958
60919	O1	61	0.190000000000000002
60919	M6	255.400000000000006	0.0259999999999999988
60919	S4	259.899999999999977	0.00700000000000000015
60919	NU2	143.300000000000011	0.0129999999999999994
60919	MU2	117.599999999999994	0.0100000000000000002
60919	2N2	128.800000000000011	0.0100000000000000002
60919	OO1	11.3000000000000007	0.0100000000000000002
60919	LDA2	170.300000000000011	0.00300000000000000006
60919	M1	47.1000000000000014	0.0160000000000000003
60919	J1	22.3999999999999986	0.0200000000000000004
60919	RHO1	77.5999999999999943	0.00700000000000000015
60919	Q1	76.4000000000000057	0.0299999999999999989
60919	T2	188.400000000000006	0.00700000000000000015
60919	2Q1	86.9000000000000057	0.00300000000000000006
60919	P1	34.1000000000000014	0.115000000000000005
60919	L2	163.099999999999994	0.0100000000000000002
60919	K2	192.699999999999989	0.0330000000000000016
60919	M8	317.800000000000011	0.00300000000000000006
60920	M2	58.6000000000000014	0.868999999999999995
60920	S2	104.099999999999994	0.197000000000000008
60920	N2	32.7999999999999972	0.157000000000000001
60920	K1	355.5	0.456000000000000016
60920	M4	39.5	0.176999999999999991
60920	O1	24.1999999999999993	0.223000000000000004
60920	M6	28.3000000000000007	0.0129999999999999994
60920	MK3	341.600000000000023	0.161000000000000004
60920	S4	152.5	0.00700000000000000015
60920	MN4	16.1000000000000014	0.0619999999999999996
60920	NU2	29.6000000000000014	0.0429999999999999966
60920	MU2	186.800000000000011	0.0429999999999999966
60920	2N2	279.800000000000011	0.0429999999999999966
60920	OO1	162.5	0.00700000000000000015
60920	LDA2	103.900000000000006	0.0359999999999999973
60920	S1	356.199999999999989	0.220000000000000001
60920	M1	32.6000000000000014	0.0229999999999999996
60920	J1	69.5	0.0429999999999999966
60920	RHO1	48.2000000000000028	0.0129999999999999994
60920	Q1	7.40000000000000036	0.0560000000000000012
60920	T2	106.200000000000003	0.0330000000000000016
60920	R2	111.799999999999997	0.0459999999999999992
60920	2Q1	38.1000000000000014	0.0100000000000000002
60920	P1	55	0.101999999999999993
60920	2SM2	270.199999999999989	0.0200000000000000004
60920	M3	204.300000000000011	0.0359999999999999973
60920	L2	38.2000000000000028	0.0330000000000000016
60920	2MK3	325.100000000000023	0.117999999999999994
60920	K2	98	0.0889999999999999958
60920	M8	115	0.00300000000000000006
60920	MS4	76.9000000000000057	0.0749999999999999972
60921	M2	42.3999999999999986	1.03699999999999992
60921	S2	76.5	0.216999999999999998
60921	N2	40.6000000000000014	0.147999999999999993
60921	K1	358.300000000000011	0.596999999999999975
60921	M4	4.5	0.16700000000000001
60921	O1	7.90000000000000036	0.276000000000000023
60921	M6	290.600000000000023	0.00700000000000000015
60921	S4	170.300000000000011	0.0100000000000000002
60921	NU2	40.6000000000000014	0.0299999999999999989
60921	S6	222.199999999999989	0.00300000000000000006
60921	MU2	8	0.0259999999999999988
60921	2N2	34.8999999999999986	0.0160000000000000003
60921	OO1	346.100000000000023	0.0100000000000000002
60921	LDA2	58.1000000000000014	0.00700000000000000015
60921	M1	2.79999999999999982	0.0200000000000000004
60921	J1	352.5	0.0229999999999999996
60921	RHO1	11.5	0.0100000000000000002
60921	Q1	12.9000000000000004	0.0519999999999999976
60921	T2	75.5999999999999943	0.0129999999999999994
60921	R2	80.9000000000000057	0.00300000000000000006
60921	2Q1	22.3999999999999986	0.00700000000000000015
60921	P1	358.899999999999977	0.197000000000000008
60921	L2	42.8999999999999986	0.0259999999999999988
60921	K2	79.2999999999999972	0.0589999999999999969
60921	M8	89.5999999999999943	0.0100000000000000002
60922	M2	358.100000000000023	1.23399999999999999
60922	S2	29.1999999999999993	0.276000000000000023
60922	N2	346.899999999999977	0.187
60922	K1	333.300000000000011	0.609999999999999987
60922	M4	267.199999999999989	0.279000000000000026
60922	O1	332.699999999999989	0.284999999999999976
60922	M6	200.599999999999994	0.0200000000000000004
60922	S4	55.1000000000000014	0.0200000000000000004
60922	NU2	348.300000000000011	0.0359999999999999973
60922	S6	239.699999999999989	0.00300000000000000006
60922	MU2	326.800000000000011	0.0299999999999999989
60922	2N2	335.300000000000011	0.0259999999999999988
60922	OO1	332.5	0.0129999999999999994
60922	LDA2	12.5999999999999996	0.0100000000000000002
60922	M1	332.800000000000011	0.0200000000000000004
60922	J1	333.399999999999977	0.0229999999999999996
60922	RHO1	332.699999999999989	0.0100000000000000002
60922	Q1	332.300000000000011	0.0519999999999999976
60922	T2	28.1000000000000014	0.0160000000000000003
60922	R2	30.6000000000000014	0.00300000000000000006
60922	2Q1	331.100000000000023	0.00700000000000000015
60922	P1	333.199999999999989	0.203000000000000014
60922	L2	8.80000000000000071	0.0330000000000000016
60922	K2	31.8000000000000007	0.0749999999999999972
60922	M8	347	0.0200000000000000004
60923	M2	340.600000000000023	1.39100000000000001
60923	S2	15.3000000000000007	0.33500000000000002
60923	N2	318.100000000000023	0.245999999999999996
60923	K1	314.300000000000011	0.570999999999999952
60923	M4	249	0.269000000000000017
60923	O1	314.800000000000011	0.298999999999999988
60923	M6	175.699999999999989	0.0160000000000000003
60923	MK3	214.900000000000006	0.194000000000000006
60923	S4	2.60000000000000009	0.0100000000000000002
60923	MN4	228	0.0919999999999999984
60923	NU2	314.300000000000011	0.0490000000000000019
60923	MU2	90.7000000000000028	0.0459999999999999992
60923	2N2	283.399999999999977	0.0229999999999999996
60923	OO1	29.1999999999999993	0.0100000000000000002
60923	LDA2	338	0.0459999999999999992
60923	S1	114.900000000000006	0.0330000000000000016
60923	M1	23.1999999999999993	0.0259999999999999988
60923	J1	7.90000000000000036	0.0200000000000000004
60923	RHO1	332	0.00300000000000000006
60923	Q1	324.800000000000011	0.0619999999999999996
60923	T2	31	0.0490000000000000019
60923	R2	74.2999999999999972	0.0160000000000000003
60923	2Q1	288.300000000000011	0.0100000000000000002
60923	P1	300.800000000000011	0.135000000000000009
60923	2SM2	204.599999999999994	0.0229999999999999996
60923	M3	135.800000000000011	0.0160000000000000003
60923	L2	348.300000000000011	0.0919999999999999984
60923	2MK3	203.900000000000006	0.157000000000000001
60923	K2	1.80000000000000004	0.140999999999999986
60923	M8	273.800000000000011	0.0100000000000000002
60923	MS4	284.300000000000011	0.135000000000000009
60924	M2	307.300000000000011	2.39500000000000002
60924	S2	340.199999999999989	0.567999999999999949
60924	N2	292.600000000000023	0.406999999999999973
60924	K1	287.800000000000011	0.919000000000000039
60924	M4	193.300000000000011	0.298999999999999988
60924	O1	277.199999999999989	0.502000000000000002
60924	M6	299.300000000000011	0.0519999999999999976
60924	S4	321.699999999999989	0.0160000000000000003
60924	NU2	294.600000000000023	0.0790000000000000008
60924	S6	98.7999999999999972	0.00700000000000000015
60924	MU2	274.300000000000011	0.0560000000000000012
60924	2N2	277.899999999999977	0.0560000000000000012
60924	OO1	297.699999999999989	0.0200000000000000004
60924	LDA2	322.5	0.0160000000000000003
60924	M1	282.399999999999977	0.0359999999999999973
60924	J1	292.699999999999989	0.0389999999999999999
60924	RHO1	272.399999999999977	0.0200000000000000004
60924	Q1	272.199999999999989	0.0950000000000000011
60924	T2	338.899999999999977	0.0330000000000000016
60924	R2	341.5	0.00300000000000000006
60924	2Q1	266.899999999999977	0.0129999999999999994
60924	P1	287	0.301999999999999991
60924	L2	322	0.0660000000000000031
60924	K2	342.899999999999977	0.153999999999999998
60924	M8	161.599999999999994	0.0229999999999999996
60925	M2	326.5	1.82099999999999995
60925	S2	358.899999999999977	0.426999999999999991
60925	N2	313.199999999999989	0.301999999999999991
60925	K1	306.600000000000023	0.724999999999999978
60925	M4	229.400000000000006	0.366999999999999993
60925	O1	298.5	0.377000000000000002
60925	M6	352.300000000000011	0.0200000000000000004
60925	S4	9.30000000000000071	0.0229999999999999996
60925	NU2	314.899999999999977	0.0589999999999999969
60925	S6	184.199999999999989	0.00300000000000000006
60925	MU2	294	0.0429999999999999966
60925	2N2	299.800000000000011	0.0389999999999999999
60925	OO1	314.100000000000023	0.0160000000000000003
60925	LDA2	341.5	0.0129999999999999994
60925	M1	302.5	0.0259999999999999988
60925	J1	310.300000000000011	0.0299999999999999989
60925	RHO1	295.600000000000023	0.0129999999999999994
60925	Q1	294.699999999999989	0.0719999999999999946
60925	T2	357.399999999999977	0.0259999999999999988
60925	R2	0.200000000000000011	0.00300000000000000006
60925	2Q1	290.800000000000011	0.0100000000000000002
60925	P1	305.899999999999977	0.23899999999999999
60925	L2	339.899999999999977	0.0490000000000000019
60925	K2	1.39999999999999991	0.115000000000000005
60925	M8	257.699999999999989	0.0259999999999999988
60926	M2	291.800000000000011	2.7759999999999998
60926	S2	325.5	0.65900000000000003
60926	N2	271.600000000000023	0.494999999999999996
60926	K1	274.800000000000011	1.06299999999999994
60926	M4	145.5	0.220000000000000001
60926	O1	261.5	0.619999999999999996
60926	M6	233.5	0.0359999999999999973
60926	MK3	133.5	0.197000000000000008
60926	S4	213.900000000000006	0.0100000000000000002
60926	MN4	130.699999999999989	0.0820000000000000034
60926	NU2	274.199999999999989	0.117999999999999994
60926	MU2	50.5	0.0980000000000000038
60926	2N2	229.199999999999989	0.0690000000000000058
60926	OO1	332.699999999999989	0.0229999999999999996
60926	LDA2	279	0.0749999999999999972
60926	S1	128.400000000000006	0.0129999999999999994
60926	M1	4.70000000000000018	0.0560000000000000012
60926	J1	325.100000000000023	0.0459999999999999992
60926	RHO1	301.199999999999989	0.0200000000000000004
60926	Q1	267.699999999999989	0.104999999999999996
60926	T2	314	0.0429999999999999966
60926	R2	14.8000000000000007	0.0229999999999999996
60926	2Q1	227.199999999999989	0.0160000000000000003
60926	P1	275.300000000000011	0.288999999999999979
60926	2SM2	148.699999999999989	0.0359999999999999973
60926	M3	330.800000000000011	0.0330000000000000016
60926	L2	302.399999999999977	0.128000000000000003
60926	2MK3	121.599999999999994	0.20699999999999999
60926	K2	312.300000000000011	0.233000000000000013
60926	M8	74	0.0129999999999999994
60926	MS4	171.900000000000006	0.112000000000000002
60927	M2	244	2.81800000000000006
60927	S2	270	0.781000000000000028
60927	N2	218.5	0.583999999999999964
60927	K1	245.099999999999994	1.35499999999999998
60927	M4	205.5	0.0889999999999999958
60927	O1	228.800000000000011	0.862999999999999989
60927	M6	297.800000000000011	0.0100000000000000002
60927	MK3	196.300000000000011	0.0389999999999999999
60927	S4	331.300000000000011	0.00300000000000000006
60927	MN4	180.099999999999994	0.0330000000000000016
60927	NU2	220.699999999999989	0.117999999999999994
60927	S6	149.599999999999994	0.00300000000000000006
60927	MU2	192.599999999999994	0.0560000000000000012
60927	2N2	184.300000000000011	0.0660000000000000031
60927	OO1	269	0.0389999999999999999
60927	LDA2	273.399999999999977	0.0200000000000000004
60927	S1	3.10000000000000009	0.0459999999999999992
60927	M1	253.599999999999994	0.0560000000000000012
60927	J1	254.199999999999989	0.0889999999999999958
60927	SSA	183	0.147999999999999993
60927	SA	308.699999999999989	0.370999999999999996
60927	MF	187.900000000000006	0.0850000000000000061
60927	RHO1	222.300000000000011	0.0229999999999999996
60927	Q1	216.400000000000006	0.150999999999999995
60927	T2	267.5	0.0459999999999999992
60927	R2	161.300000000000011	0.00300000000000000006
60927	2Q1	158.400000000000006	0.0100000000000000002
60927	P1	242.599999999999994	0.426999999999999991
60927	2SM2	118.400000000000006	0.00300000000000000006
60927	M3	267.300000000000011	0.0129999999999999994
60927	L2	266.100000000000023	0.0749999999999999972
60927	2MK3	200	0.0160000000000000003
60927	K2	265.300000000000011	0.216999999999999998
60927	M8	359.699999999999989	0.00300000000000000006
60927	MS4	244.599999999999994	0.0389999999999999999
60928	M2	281.899999999999977	3.81899999999999995
60928	S2	323.399999999999977	0.883000000000000007
60928	N2	260.699999999999989	0.633000000000000007
60928	K1	268.800000000000011	1.23399999999999999
60928	M4	20.5	0.242999999999999994
60928	O1	257.899999999999977	0.673000000000000043
60928	M6	117.599999999999994	0.197000000000000008
60928	S4	186.099999999999994	0.0160000000000000003
60928	NU2	263.5	0.120999999999999996
60928	S6	64.0999999999999943	0.00300000000000000006
60928	MU2	240.5	0.0919999999999999984
60928	2N2	239.5	0.0850000000000000061
60928	OO1	279.399999999999977	0.0299999999999999989
60928	LDA2	301.199999999999989	0.0259999999999999988
60928	M1	263.399999999999977	0.0490000000000000019
60928	J1	274.100000000000023	0.0519999999999999976
60928	SA	289.800000000000011	0.518000000000000016
60928	MF	161.800000000000011	0.0790000000000000008
60928	RHO1	253.199999999999989	0.0259999999999999988
60928	Q1	252.5	0.131000000000000005
60928	T2	321.699999999999989	0.0519999999999999976
60928	R2	325	0.00700000000000000015
60928	2Q1	247.300000000000011	0.0160000000000000003
60928	P1	267.899999999999977	0.406999999999999973
60928	L2	303.100000000000023	0.107999999999999999
60928	K2	326.800000000000011	0.23899999999999999
60928	M8	208.099999999999994	0.0330000000000000016
60929	M2	264.100000000000023	3.8620000000000001
60929	S2	299.600000000000023	0.967999999999999972
60929	N2	237.900000000000006	0.740999999999999992
60929	K1	257.100000000000023	1.42999999999999994
60929	M4	336.600000000000023	0.220000000000000001
60929	O1	242.599999999999994	0.865999999999999992
60929	M6	90.7999999999999972	0.115000000000000005
60929	S4	70.5	0.0359999999999999973
60929	NU2	241.5	0.143999999999999989
60929	2N2	211.699999999999989	0.0980000000000000038
60929	OO1	271.600000000000023	0.0389999999999999999
60929	LDA2	113.5	0.0259999999999999988
60929	M1	249.800000000000011	0.0619999999999999996
60929	J1	264.300000000000011	0.0690000000000000058
60929	RHO1	236.400000000000006	0.0330000000000000016
60929	Q1	235.300000000000011	0.16700000000000001
60929	T2	299.5	0.0560000000000000012
60929	R2	299.5	0.00700000000000000015
60929	2Q1	228.099999999999994	0.0229999999999999996
60929	P1	257.100000000000023	0.471999999999999975
60929	L2	290.300000000000011	0.107999999999999999
60929	K2	299.5	0.262000000000000011
60929	M8	170.699999999999989	0.0229999999999999996
60930	M2	259.699999999999989	3.68800000000000017
60930	S2	291.199999999999989	0.97799999999999998
60930	N2	233.599999999999994	0.768000000000000016
60930	K1	254.800000000000011	1.40399999999999991
60930	M4	317	0.197000000000000008
60930	O1	239.199999999999989	0.865999999999999992
60930	M6	62.8999999999999986	0.112000000000000002
60930	S4	57.2000000000000028	0.0330000000000000016
60930	NU2	237.099999999999994	0.147999999999999993
60930	2N2	207.300000000000011	0.101999999999999993
60930	OO1	270.399999999999977	0.0359999999999999973
60930	LDA2	274.399999999999977	0.0259999999999999988
60930	M1	246.900000000000006	0.0619999999999999996
60930	J1	262.5	0.0690000000000000058
60930	RHO1	232.400000000000006	0.0330000000000000016
60930	Q1	231.300000000000011	0.171000000000000013
60930	T2	291.100000000000023	0.0589999999999999969
60930	R2	291.199999999999989	0.00700000000000000015
60930	2Q1	223.599999999999994	0.0229999999999999996
60930	P1	254.699999999999989	0.463000000000000023
60930	L2	286	0.101999999999999993
60930	K2	291.100000000000023	0.266000000000000014
60930	M8	143.400000000000006	0.0129999999999999994
60931	M2	253.699999999999989	3.21799999999999997
60931	S2	284.399999999999977	0.855999999999999983
60931	N2	229.699999999999989	0.650000000000000022
60931	K1	251.099999999999994	1.42700000000000005
60931	M4	352.600000000000023	0.0459999999999999992
60931	O1	235.400000000000006	0.865999999999999992
60931	M6	45.2999999999999972	0.0299999999999999989
60931	MK3	10.9000000000000004	0.0129999999999999994
60931	MN4	335.600000000000023	0.0200000000000000004
60931	NU2	228.599999999999994	0.143999999999999989
60931	MU2	253.199999999999989	0.0259999999999999988
60931	2N2	204.599999999999994	0.0719999999999999946
60931	OO1	292.600000000000023	0.0519999999999999976
60931	LDA2	269.300000000000011	0.0299999999999999989
60931	S1	40.7000000000000028	0.0200000000000000004
60931	M1	270.300000000000011	0.0519999999999999976
60931	J1	267.600000000000023	0.0749999999999999972
60931	SA	289.800000000000011	0.518000000000000016
60931	MF	161.800000000000011	0.0790000000000000008
60931	RHO1	208.699999999999989	0.0359999999999999973
60931	Q1	230.199999999999989	0.153999999999999998
60931	T2	270.5	0.0560000000000000012
60931	R2	285.600000000000023	0.00700000000000000015
60931	2Q1	221	0.0200000000000000004
60931	P1	249.199999999999989	0.446000000000000008
60931	L2	266.300000000000011	0.107999999999999999
60931	2MK3	64.2999999999999972	0.0160000000000000003
60931	K2	279.600000000000023	0.233000000000000013
60931	MS4	30.5	0.0299999999999999989
60932	M2	240.699999999999989	3.23200000000000021
60932	S2	271.300000000000011	0.88600000000000001
60932	N2	217.900000000000006	0.666000000000000036
60932	K1	244	1.39399999999999991
60932	M4	210	0.0850000000000000061
60932	O1	228.400000000000006	0.849999999999999978
60932	M6	19.8999999999999986	0.0560000000000000012
60932	MK3	191.199999999999989	0.0330000000000000016
60932	S4	336.600000000000023	0.00300000000000000006
60932	MN4	195.199999999999989	0.0330000000000000016
60932	NU2	218.599999999999994	0.135000000000000009
60932	S6	144.5	0.00300000000000000006
60932	MU2	240.800000000000011	0.0519999999999999976
60932	2N2	193	0.0749999999999999972
60932	OO1	278	0.0459999999999999992
60932	LDA2	230	0.0299999999999999989
60932	S1	31.3000000000000007	0.0359999999999999973
60932	M1	268.199999999999989	0.0459999999999999992
60932	J1	259.899999999999977	0.0719999999999999946
60932	MM	171.199999999999989	0.0790000000000000008
60932	SA	289.600000000000023	0.412999999999999978
60932	MF	190.300000000000011	0.0889999999999999958
60932	RHO1	220.699999999999989	0.0259999999999999988
60932	Q1	222.400000000000006	0.147999999999999993
60932	T2	277.600000000000023	0.0459999999999999992
60932	R2	210.099999999999994	0.0160000000000000003
60932	2Q1	233.699999999999989	0.0160000000000000003
60932	P1	239.900000000000006	0.429999999999999993
60932	2SM2	80.7000000000000028	0.0160000000000000003
60932	M3	264.100000000000023	0.00300000000000000006
60932	L2	243.099999999999994	0.0980000000000000038
60932	2MK3	108.799999999999997	0.0129999999999999994
60932	K2	264.300000000000011	0.235999999999999988
60932	M8	11.3000000000000007	0.0129999999999999994
60932	MS4	254.699999999999989	0.0429999999999999966
60933	M2	253.599999999999994	3.65799999999999992
60933	S2	289	0.980999999999999983
60933	N2	234.400000000000006	0.724999999999999978
60933	K1	250.900000000000006	1.42100000000000004
60933	M4	305.199999999999989	0.200000000000000011
60933	O1	235.800000000000011	0.845999999999999974
60933	M6	41.5	0.131000000000000005
60933	MK3	314.899999999999977	0.0359999999999999973
60933	S4	54.7000000000000028	0.0129999999999999994
60933	MN4	287.600000000000023	0.0690000000000000058
60933	NU2	230	0.147999999999999993
60933	MU2	303.399999999999977	0.112000000000000002
60933	2N2	188	0.107999999999999999
60933	OO1	293.300000000000011	0.0429999999999999966
60933	LDA2	225.800000000000011	0.0619999999999999996
60933	S1	73	0.0160000000000000003
60933	M1	297.5	0.0429999999999999966
60933	J1	281	0.0820000000000000034
60933	MM	306.800000000000011	0.0519999999999999976
60933	SSA	203.900000000000006	0.0519999999999999976
60933	SA	277.800000000000011	0.284999999999999976
60933	MSF	21.5	0.0950000000000000011
60933	MF	164.599999999999994	0.0820000000000000034
60933	RHO1	234.300000000000011	0.0229999999999999996
60933	Q1	235.199999999999989	0.143999999999999989
60933	T2	296.399999999999977	0.0560000000000000012
60933	R2	265.899999999999977	0.0229999999999999996
60933	2Q1	210.5	0.0200000000000000004
60933	P1	248.699999999999989	0.422999999999999987
60933	2SM2	101	0.0299999999999999989
60933	M3	72.9000000000000057	0.0160000000000000003
60933	L2	254.5	0.117999999999999994
60933	2MK3	41	0.0459999999999999992
60933	K2	282.5	0.276000000000000023
60933	M8	105.599999999999994	0.0330000000000000016
60933	MS4	345.800000000000011	0.112000000000000002
60934	M2	248.300000000000011	1.98799999999999999
60934	S2	275.5	0.509000000000000008
60934	N2	224.599999999999994	0.39700000000000002
60934	K1	263.199999999999989	0.810000000000000053
60934	M4	98.7999999999999972	0.315000000000000002
60934	O1	266.800000000000011	0.463000000000000023
60934	M6	233.199999999999989	0.0389999999999999999
60934	S4	162.400000000000006	0.0160000000000000003
60934	NU2	227.800000000000011	0.0790000000000000008
60934	S6	279.399999999999977	0.00300000000000000006
60934	MU2	221.099999999999994	0.0490000000000000019
60934	2N2	200.599999999999994	0.0519999999999999976
60934	OO1	259.5	0.0200000000000000004
60934	LDA2	260.899999999999977	0.0129999999999999994
60934	M1	265	0.0330000000000000016
60934	J1	261.5	0.0359999999999999973
60934	MM	171.199999999999989	0.0790000000000000008
60934	SA	289.600000000000023	0.412999999999999978
60934	MF	190.300000000000011	0.0889999999999999958
60934	RHO1	268.899999999999977	0.0160000000000000003
60934	Q1	268.600000000000023	0.0889999999999999958
60934	T2	274.5	0.0299999999999999989
60934	R2	276.699999999999989	0.00300000000000000006
60934	2Q1	270.600000000000023	0.0129999999999999994
60934	P1	263.399999999999977	0.269000000000000017
60934	L2	271.300000000000011	0.0560000000000000012
60934	K2	277.800000000000011	0.138000000000000012
60934	M8	32.6000000000000014	0.0100000000000000002
60935	M2	234.900000000000006	3.06099999999999994
60935	S2	262	0.872999999999999998
60935	N2	210.199999999999989	0.640000000000000013
60935	K1	239.599999999999994	1.41100000000000003
60935	M4	95.5	0.00300000000000000006
60935	O1	223.800000000000011	0.859999999999999987
60935	M6	80.5	0.00300000000000000006
60935	MK3	20.8000000000000007	0.00300000000000000006
60935	S4	43.6000000000000014	0.00300000000000000006
60935	MN4	54.1000000000000014	0.00300000000000000006
60935	NU2	213.300000000000011	0.128000000000000003
60935	MU2	184.900000000000006	0.0690000000000000058
60935	2N2	183.400000000000006	0.0719999999999999946
60935	OO1	266.300000000000011	0.0490000000000000019
60935	LDA2	260.199999999999989	0.0160000000000000003
60935	S1	346.600000000000023	0.0229999999999999996
60935	M1	244.099999999999994	0.0519999999999999976
60935	J1	252.800000000000011	0.0889999999999999958
60935	SSA	125.799999999999997	0.0519999999999999976
60935	SA	286.5	0.561000000000000054
60935	RHO1	209.699999999999989	0.0259999999999999988
60935	Q1	216	0.150999999999999995
60935	T2	257.399999999999977	0.0490000000000000019
60935	R2	258.399999999999977	0.0100000000000000002
60935	2Q1	205.400000000000006	0.0160000000000000003
60935	P1	235.800000000000011	0.440000000000000002
60935	2SM2	66.9000000000000057	0.00300000000000000006
60935	M3	293	0.00300000000000000006
60935	L2	258.600000000000023	0.0660000000000000031
60935	K2	254.400000000000006	0.235999999999999988
60935	MS4	40.2000000000000028	0.00300000000000000006
60936	M2	238.099999999999994	3.07100000000000017
60936	S2	267	0.896000000000000019
60936	N2	211.099999999999994	0.622999999999999998
60936	K1	240.599999999999994	1.40399999999999991
60936	M4	110.400000000000006	0.00300000000000000006
60936	O1	224.599999999999994	0.899000000000000021
60936	M6	132.5	0.00700000000000000015
60936	S4	341.100000000000023	0.0100000000000000002
60936	NU2	214.699999999999989	0.120999999999999996
60936	S6	209.599999999999994	0.00700000000000000015
60936	MU2	209.300000000000011	0.0719999999999999946
60936	2N2	184.099999999999994	0.0820000000000000034
60936	OO1	256.800000000000011	0.0389999999999999999
60936	LDA2	251.5	0.0229999999999999996
60936	M1	232.699999999999989	0.0660000000000000031
60936	J1	248.699999999999989	0.0719999999999999946
60936	SA	289.899999999999977	0.412999999999999978
60936	MF	164.599999999999994	0.0589999999999999969
60936	RHO1	217.599999999999994	0.0359999999999999973
60936	Q1	216.599999999999994	0.173999999999999988
60936	T2	265.800000000000011	0.0519999999999999976
60936	R2	268.100000000000023	0.00700000000000000015
60936	2Q1	208.599999999999994	0.0229999999999999996
60936	P1	239.400000000000006	0.463000000000000023
60936	L2	265.199999999999989	0.0850000000000000061
60936	K2	269.300000000000011	0.242999999999999994
60937	M2	246.199999999999989	2.58899999999999997
60937	S2	272.5	0.758000000000000007
60937	N2	222.300000000000011	0.551000000000000045
60937	K1	248.5	1.627
60937	M4	58.7999999999999972	0.0359999999999999973
60937	O1	231.599999999999994	1.004
60937	M6	184.199999999999989	0.0229999999999999996
60937	MK3	325.300000000000011	0.0519999999999999976
60937	MN4	28	0.0160000000000000003
60937	NU2	226.5	0.104999999999999996
60937	MU2	202.5	0.0749999999999999972
60937	2N2	196.599999999999994	0.0660000000000000031
60937	OO1	283.5	0.0519999999999999976
60937	LDA2	270	0.0100000000000000002
60937	S1	29.3000000000000007	0.0429999999999999966
60937	M1	263.399999999999977	0.0560000000000000012
60937	J1	264.800000000000011	0.0889999999999999958
60937	SA	289.899999999999977	0.412999999999999978
60937	MF	164.599999999999994	0.0589999999999999969
60937	RHO1	219.599999999999994	0.0330000000000000016
60937	Q1	223.800000000000011	0.179999999999999993
60937	T2	267.199999999999989	0.0389999999999999999
60937	R2	288	0.0100000000000000002
60937	2Q1	227.400000000000006	0.0200000000000000004
60937	P1	246.800000000000011	0.509000000000000008
60937	L2	265.600000000000023	0.0389999999999999999
60937	2MK3	321.600000000000023	0.0330000000000000016
60937	K2	266.899999999999977	0.194000000000000006
60937	MS4	68.5999999999999943	0.0229999999999999996
60938	M2	258	2.19499999999999984
60938	S2	283.5	0.653000000000000025
60938	N2	233.900000000000006	0.481999999999999984
60938	K1	252.199999999999989	1.77800000000000002
60938	M4	66.0999999999999943	0.0299999999999999989
60938	O1	233.5	1.08299999999999996
60938	M6	187.199999999999989	0.0299999999999999989
60938	MK3	5	0.0429999999999999966
60938	S4	89.0999999999999943	0.00700000000000000015
60938	MN4	33.6000000000000014	0.0100000000000000002
60938	NU2	238.599999999999994	0.0950000000000000011
60938	MU2	216.900000000000006	0.0820000000000000034
60938	2N2	220.900000000000006	0.0660000000000000031
60938	OO1	283.899999999999977	0.0519999999999999976
60938	LDA2	260.100000000000023	0.0129999999999999994
60938	S1	45.6000000000000014	0.0719999999999999946
60938	M1	261.100000000000023	0.0619999999999999996
60938	J1	261.199999999999989	0.0889999999999999958
60938	SA	289.899999999999977	0.412999999999999978
60938	MF	164.599999999999994	0.0589999999999999969
60938	RHO1	232.5	0.0459999999999999992
60938	Q1	226	0.187
60938	T2	272.199999999999989	0.0429999999999999966
60938	R2	227.900000000000006	0.00700000000000000015
60938	2Q1	211.300000000000011	0.0330000000000000016
60938	P1	243.900000000000006	0.563999999999999946
60938	2SM2	295.100000000000023	0.0100000000000000002
60938	M3	313.100000000000023	0.0160000000000000003
60938	L2	277.399999999999977	0.0359999999999999973
60938	2MK3	8.09999999999999964	0.0459999999999999992
60938	K2	277.800000000000011	0.153999999999999998
60938	M8	230.900000000000006	0.00300000000000000006
60938	MS4	84.2000000000000028	0.0129999999999999994
60939	M2	266.800000000000011	2.00800000000000001
60939	S2	288.5	0.630000000000000004
60939	N2	243.5	0.440000000000000002
60939	K1	254.699999999999989	1.76800000000000002
60939	M4	85.5999999999999943	0.0299999999999999989
60939	O1	237.099999999999994	1.10200000000000009
60939	M6	195	0.0389999999999999999
60939	S4	356.399999999999977	0.00700000000000000015
60939	NU2	246.599999999999994	0.0850000000000000061
60939	S6	228	0.00300000000000000006
60939	MU2	245	0.0490000000000000019
60939	2N2	220.199999999999989	0.0589999999999999969
60939	OO1	272.5	0.0459999999999999992
60939	LDA2	276.800000000000011	0.0129999999999999994
60939	M1	246	0.0790000000000000008
60939	J1	263.600000000000023	0.0889999999999999958
60939	SA	289.899999999999977	0.412999999999999978
60939	MF	164.599999999999994	0.0589999999999999969
60939	RHO1	229.5	0.0429999999999999966
60939	Q1	228.400000000000006	0.212999999999999995
60939	T2	287.600000000000023	0.0359999999999999973
60939	R2	289.399999999999977	0.00700000000000000015
60939	2Q1	219.599999999999994	0.0299999999999999989
60939	P1	253.400000000000006	0.586999999999999966
60939	L2	290.100000000000023	0.0560000000000000012
60939	K2	290.300000000000011	0.171000000000000013
60939	M8	158.199999999999989	0.00300000000000000006
60940	M2	307.100000000000023	1.68599999999999994
60940	S2	326.399999999999977	0.478999999999999981
60940	N2	280.100000000000023	0.381000000000000005
60940	K1	261.800000000000011	2.18800000000000017
60940	M4	100.299999999999997	0.0490000000000000019
60940	O1	241.599999999999994	1.28299999999999992
60940	M6	196.199999999999989	0.0490000000000000019
60940	MK3	22.3999999999999986	0.0660000000000000031
60940	MN4	68.0999999999999943	0.0259999999999999988
60940	NU2	286.699999999999989	0.0690000000000000058
60940	MU2	234	0.0889999999999999958
60940	2N2	248.599999999999994	0.0490000000000000019
60940	OO1	301.600000000000023	0.0749999999999999972
60940	LDA2	51.7999999999999972	0.0200000000000000004
60940	S1	15.5999999999999996	0.0560000000000000012
60940	M1	273.800000000000011	0.0690000000000000058
60940	J1	286	0.128000000000000003
60940	MM	187.699999999999989	0.0749999999999999972
60940	SA	287.600000000000023	0.331000000000000016
60940	MF	146.800000000000011	0.0459999999999999992
60940	RHO1	233.199999999999989	0.0389999999999999999
60940	Q1	232.800000000000011	0.216999999999999998
60940	T2	335.5	0.0259999999999999988
60940	R2	327.199999999999989	0.00300000000000000006
60940	2Q1	221.800000000000011	0.0229999999999999996
60940	P1	259.399999999999977	0.679000000000000048
60940	M3	142.099999999999994	0.0100000000000000002
60940	L2	31.8999999999999986	0.0389999999999999999
60940	2MK3	19.3000000000000007	0.0660000000000000031
60940	K2	332.699999999999989	0.0889999999999999958
60940	MS4	118.5	0.0299999999999999989
60941	M2	349.699999999999989	2.24699999999999989
60941	S2	12.5999999999999996	0.558000000000000052
60941	N2	320	0.478999999999999981
60941	K1	270.699999999999989	2.5129999999999999
60941	M4	60.5	0.128000000000000003
60941	O1	249.800000000000011	1.46700000000000008
60941	M6	246.300000000000011	0.0330000000000000016
60941	MK3	332.800000000000011	0.0919999999999999984
60941	MN4	29.6999999999999993	0.0490000000000000019
60941	NU2	331.5	0.0919999999999999984
60941	MU2	239.599999999999994	0.0889999999999999958
60941	2N2	286.800000000000011	0.0589999999999999969
60941	OO1	317	0.0950000000000000011
60941	LDA2	44.2999999999999972	0.0359999999999999973
60941	S1	51.2000000000000028	0.0519999999999999976
60941	M1	303.199999999999989	0.0820000000000000034
60941	J1	302.399999999999977	0.128000000000000003
60941	MM	184.599999999999994	0.0719999999999999946
60941	SA	292	0.269000000000000017
60941	MF	144.300000000000011	0.0660000000000000031
60941	RHO1	240.400000000000006	0.0490000000000000019
60941	Q1	242.300000000000011	0.248999999999999999
60941	T2	14.0999999999999996	0.0359999999999999973
60941	R2	13.5999999999999996	0.00300000000000000006
60941	2Q1	242.400000000000006	0.0259999999999999988
60941	P1	269.5	0.791000000000000036
60941	2SM2	290.600000000000023	0.0129999999999999994
60941	M3	228.699999999999989	0.0100000000000000002
60941	L2	44.1000000000000014	0.0850000000000000061
60941	2MK3	341.100000000000023	0.0619999999999999996
60941	K2	16.8000000000000007	0.171000000000000013
60941	MS4	83.5	0.0690000000000000058
60942	M2	3.39999999999999991	2.8969999999999998
60942	S2	29.6000000000000014	0.714999999999999969
60942	N2	331.300000000000011	0.558000000000000052
60942	K1	275.899999999999977	2.50999999999999979
60942	M4	180.900000000000006	0.0560000000000000012
60942	O1	253.900000000000006	1.38100000000000001
60942	M6	296.399999999999977	0.0160000000000000003
60942	S4	140.300000000000011	0.00700000000000000015
60942	NU2	335.600000000000023	0.107999999999999999
60942	MU2	337.100000000000023	0.0690000000000000058
60942	2N2	299.199999999999989	0.0749999999999999972
60942	OO1	297.800000000000011	0.0589999999999999969
60942	LDA2	15.5999999999999996	0.0200000000000000004
60942	M1	265	0.0980000000000000038
60942	J1	286.699999999999989	0.107999999999999999
60942	SSA	231.099999999999994	0.107999999999999999
60942	SA	292.899999999999977	0.253000000000000003
60942	MF	140.5	0.0719999999999999946
60942	RHO1	244.5	0.0519999999999999976
60942	Q1	243.099999999999994	0.269000000000000017
60942	T2	28.6000000000000014	0.0429999999999999966
60942	R2	30.6999999999999993	0.00700000000000000015
60942	2Q1	232.199999999999989	0.0359999999999999973
60942	P1	274.199999999999989	0.82999999999999996
60942	L2	35.3999999999999986	0.0820000000000000034
60942	K2	31.8000000000000007	0.194000000000000006
60942	M8	275.5	0.00300000000000000006
60943	M2	4.09999999999999964	3.35999999999999988
60943	S2	29.5	0.842999999999999972
60943	N2	333.5	0.682000000000000051
60943	K1	274.800000000000011	2.73899999999999988
60943	M4	183.400000000000006	0.0889999999999999958
60943	O1	251.900000000000006	1.52899999999999991
60943	M6	85.0999999999999943	0.0299999999999999989
60943	MK3	73	0.0950000000000000011
60943	S4	211.5	0.0129999999999999994
60943	MN4	141	0.0359999999999999973
60943	NU2	345.100000000000023	0.143999999999999989
60943	MU2	237.199999999999989	0.115000000000000005
60943	2N2	318.199999999999989	0.0790000000000000008
60943	OO1	320.199999999999989	0.112000000000000002
60943	LDA2	37.8999999999999986	0.0660000000000000031
60943	S1	42.1000000000000014	0.0389999999999999999
60943	M1	308.600000000000023	0.0660000000000000031
60943	J1	307.899999999999977	0.112000000000000002
60943	MM	187.699999999999989	0.0749999999999999972
60943	SA	287.600000000000023	0.331000000000000016
60943	MF	146.800000000000011	0.0459999999999999992
60943	RHO1	247.099999999999994	0.0560000000000000012
60943	Q1	247.199999999999989	0.262000000000000011
60943	T2	33.6000000000000014	0.0459999999999999992
60943	R2	30.3999999999999986	0.00700000000000000015
60943	2Q1	236.199999999999989	0.0330000000000000016
60943	P1	273.899999999999977	0.85299999999999998
60943	2SM2	271.199999999999989	0.0229999999999999996
60943	M3	350.399999999999977	0.0299999999999999989
60943	L2	65.4000000000000057	0.131000000000000005
60943	2MK3	48.7999999999999972	0.107999999999999999
60943	K2	28.5	0.23899999999999999
60943	MS4	199.900000000000006	0.0519999999999999976
60944	M2	4.79999999999999982	3.49400000000000022
60944	S2	29.6000000000000014	0.889000000000000012
60944	N2	333.199999999999989	0.622999999999999998
60944	K1	273.100000000000023	2.95599999999999996
60944	M4	179	0.115000000000000005
60944	O1	249.400000000000006	1.56499999999999995
60944	M6	87.4000000000000057	0.0619999999999999996
60944	S4	277.199999999999989	0.00300000000000000006
60944	NU2	337.399999999999977	0.120999999999999996
60944	S6	95	0.00300000000000000006
60944	MU2	340	0.0850000000000000061
60944	2N2	301.5	0.0820000000000000034
60944	OO1	296.899999999999977	0.0690000000000000058
60944	LDA2	16.3000000000000007	0.0229999999999999996
60944	M1	261.399999999999977	0.112000000000000002
60944	J1	284.899999999999977	0.125
60944	MM	184.599999999999994	0.0719999999999999946
60944	SA	292	0.269000000000000017
60944	MF	144.300000000000011	0.0660000000000000031
60944	RHO1	239.199999999999989	0.0589999999999999969
60944	Q1	237.599999999999994	0.304999999999999993
60944	T2	28.6000000000000014	0.0519999999999999976
60944	R2	30.6000000000000014	0.00700000000000000015
60944	2Q1	225.900000000000006	0.0389999999999999999
60944	P1	271.399999999999977	0.97799999999999998
60944	L2	36.3999999999999986	0.0980000000000000038
60944	K2	31.6000000000000014	0.242999999999999994
60944	M8	154.599999999999994	0.00300000000000000006
60945	M2	15.1999999999999993	3.42799999999999994
60945	S2	52.5	0.947999999999999954
60945	N2	1.80000000000000004	0.721999999999999975
60945	K1	283.199999999999989	2.871
60945	M4	256.5	0.135000000000000009
60945	O1	254.699999999999989	1.3680000000000001
60945	M6	341.199999999999989	0.0790000000000000008
60945	S4	17.1000000000000014	0.0560000000000000012
60945	NU2	3.60000000000000009	0.140999999999999986
60945	S6	343.399999999999977	0.00700000000000000015
60945	MU2	92.5999999999999943	0.0820000000000000034
60945	2N2	348.399999999999977	0.0950000000000000011
60945	OO1	311.600000000000023	0.0589999999999999969
60945	LDA2	32.5	0.0229999999999999996
60945	M1	269	0.0980000000000000038
60945	J1	297.300000000000011	0.107999999999999999
60945	SSA	231.099999999999994	0.107999999999999999
60945	SA	292.899999999999977	0.253000000000000003
60945	MF	140.5	0.0719999999999999946
60945	RHO1	242.5	0.0519999999999999976
60945	Q1	240.599999999999994	0.266000000000000014
60945	T2	51	0.0560000000000000012
60945	R2	53.8999999999999986	0.00700000000000000015
60945	2Q1	226.5	0.0359999999999999973
60945	P1	281	0.950999999999999956
60945	L2	28.5	0.0950000000000000011
60945	K2	55.5	0.259000000000000008
60945	M8	245.599999999999994	0.00300000000000000006
60946	M2	27.6999999999999993	4.37000000000000011
60946	S2	57.6000000000000014	1.05600000000000005
60946	N2	4.20000000000000018	0.807000000000000051
60946	K1	287.5	2.91999999999999993
60946	M4	331.300000000000011	0.0889999999999999958
60946	O1	260.5	1.50600000000000001
60946	M6	117.299999999999997	0.0359999999999999973
60946	S4	11.5	0.00300000000000000006
60946	NU2	7.40000000000000036	0.157000000000000001
60946	S6	233.599999999999994	0.00300000000000000006
60946	MU2	358	0.104999999999999996
60946	2N2	340.699999999999989	0.104999999999999996
60946	OO1	314.5	0.0619999999999999996
60946	LDA2	41.6000000000000014	0.0299999999999999989
60946	M1	274.100000000000023	0.104999999999999996
60946	J1	300.899999999999977	0.117999999999999994
60946	SSA	231.099999999999994	0.107999999999999999
60946	SA	292.899999999999977	0.253000000000000003
60946	MF	140.5	0.0719999999999999946
60946	RHO1	248.900000000000006	0.0560000000000000012
60946	Q1	247.099999999999994	0.291999999999999982
60946	T2	56.3999999999999986	0.0619999999999999996
60946	R2	58.7999999999999972	0.0100000000000000002
60946	2Q1	233.699999999999989	0.0389999999999999999
60946	P1	285.5	0.964999999999999969
60946	L2	51.3999999999999986	0.120999999999999996
60946	K2	60.1000000000000014	0.284999999999999976
60946	M8	302.5	0.00700000000000000015
60947	M2	11.8000000000000007	3.7370000000000001
60947	S2	37.7999999999999972	0.925000000000000044
60947	N2	341.199999999999989	0.737999999999999989
60947	K1	277.899999999999977	2.74900000000000011
60947	M4	207.699999999999989	0.0619999999999999996
60947	O1	255.099999999999994	1.50600000000000001
60947	M6	292	0.0160000000000000003
60947	MK3	74.9000000000000057	0.117999999999999994
60947	S4	267.800000000000011	0.0100000000000000002
60947	MN4	184.099999999999994	0.0259999999999999988
60947	NU2	359.399999999999977	0.147999999999999993
60947	MU2	232.599999999999994	0.117999999999999994
60947	2N2	311.800000000000011	0.0589999999999999969
60947	OO1	338.600000000000023	0.117999999999999994
60947	LDA2	48.7999999999999972	0.0660000000000000031
60947	S1	35.2000000000000028	0.0660000000000000031
60947	M1	294.100000000000023	0.107999999999999999
60947	J1	319	0.143999999999999989
60947	SSA	214.599999999999994	0.0889999999999999958
60947	SA	289.399999999999977	0.242999999999999994
60947	RHO1	222.900000000000006	0.0519999999999999976
60947	Q1	250.599999999999994	0.248999999999999999
60947	T2	39.7999999999999972	0.0619999999999999996
60947	R2	38.8999999999999986	0.00700000000000000015
60947	2Q1	255.099999999999994	0.0229999999999999996
60947	P1	277.199999999999989	0.836999999999999966
60947	2SM2	293	0.0229999999999999996
60947	M3	152.400000000000006	0.0259999999999999988
60947	L2	53.2999999999999972	0.203000000000000014
60947	2MK3	44.6000000000000014	0.104999999999999996
60947	K2	39.6000000000000014	0.269000000000000017
60947	MS4	243.099999999999994	0.0359999999999999973
60948	M2	26.1999999999999993	4.40899999999999981
60948	S2	55.7999999999999972	1.06299999999999994
60948	N2	359.699999999999989	0.845999999999999974
60948	K1	285.699999999999989	2.76600000000000001
60948	M4	281.699999999999989	0.104999999999999996
60948	O1	263.399999999999977	1.52600000000000002
60948	M6	121.700000000000003	0.0490000000000000019
60948	MK3	126.900000000000006	0.0749999999999999972
60948	S4	267.300000000000011	0.00700000000000000015
60948	MN4	250.199999999999989	0.0429999999999999966
60948	NU2	6.09999999999999964	0.187
60948	S6	97.7999999999999972	0.00300000000000000006
60948	MU2	205.199999999999989	0.0850000000000000061
60948	2N2	339.600000000000023	0.101999999999999993
60948	OO1	19.1000000000000014	0.0950000000000000011
60948	LDA2	45.7999999999999972	0.0850000000000000061
60948	S1	328.300000000000011	0.0690000000000000058
60948	M1	309.699999999999989	0.0560000000000000012
60948	J1	331.800000000000011	0.157000000000000001
60948	SSA	231.099999999999994	0.107999999999999999
60948	SA	292.899999999999977	0.253000000000000003
60948	MF	140.5	0.0719999999999999946
60948	RHO1	268.600000000000023	0.0619999999999999996
60948	Q1	261.199999999999989	0.242999999999999994
60948	T2	43.5	0.0749999999999999972
60948	R2	173.900000000000006	0.0229999999999999996
60948	2Q1	219.699999999999989	0.0359999999999999973
60948	P1	286.699999999999989	0.797000000000000042
60948	2SM2	280.199999999999989	0.0429999999999999966
60948	M3	222.900000000000006	0.0129999999999999994
60948	L2	65.2000000000000028	0.200000000000000011
60948	2MK3	42.6000000000000014	0.0100000000000000002
60948	K2	51.6000000000000014	0.298999999999999988
60948	M8	352.100000000000023	0.00300000000000000006
60948	MS4	310.899999999999977	0.0589999999999999969
60949	M2	26.5	3.74299999999999988
60949	S2	57.2000000000000028	0.912000000000000033
60949	N2	1.5	0.714999999999999969
60949	K1	285.800000000000011	2.45699999999999985
60949	M4	282.600000000000023	0.0919999999999999984
60949	O1	261.100000000000023	1.31899999999999995
60949	M6	124.5	0.0429999999999999966
60949	S4	283.800000000000011	0.00700000000000000015
60949	NU2	4.90000000000000036	0.138000000000000012
60949	S6	205.800000000000011	0.00300000000000000006
60949	MU2	355.699999999999989	0.0889999999999999958
60949	2N2	336.5	0.0950000000000000011
60949	OO1	310.600000000000023	0.0589999999999999969
60949	LDA2	40.7000000000000028	0.0259999999999999988
60949	M1	273.600000000000023	0.0950000000000000011
60949	J1	298.100000000000023	0.104999999999999996
60949	SSA	231.099999999999994	0.107999999999999999
60949	SA	292.899999999999977	0.253000000000000003
60949	MF	140.5	0.0719999999999999946
60949	RHO1	250.5	0.0519999999999999976
60949	Q1	248.900000000000006	0.256000000000000005
60949	T2	56	0.0519999999999999976
60949	R2	58.3999999999999986	0.00700000000000000015
60949	2Q1	236.5	0.0330000000000000016
60949	P1	284	0.813999999999999946
60949	L2	51.5	0.104999999999999996
60949	K2	59.7000000000000028	0.248999999999999999
60949	M8	356.199999999999989	0.00300000000000000006
60950	M2	30.3000000000000007	4.78699999999999992
60950	S2	62	1.125
60950	N2	4.5	0.906000000000000028
60950	K1	289.600000000000023	2.87699999999999978
60950	M4	294.399999999999977	0.161000000000000004
60950	O1	266.399999999999977	1.54899999999999993
60950	M6	143.800000000000011	0.0950000000000000011
60950	MK3	145.800000000000011	0.0950000000000000011
60950	S4	334.800000000000011	0.0129999999999999994
60950	MN4	265.399999999999977	0.0660000000000000031
60950	NU2	10.5999999999999996	0.209999999999999992
60950	MU2	193	0.0820000000000000034
60950	2N2	345.199999999999989	0.115000000000000005
60950	OO1	5.59999999999999964	0.0850000000000000061
60950	LDA2	46.7999999999999972	0.0889999999999999958
60950	S1	63.5	0.0560000000000000012
60950	M1	309	0.0619999999999999996
60950	J1	331.399999999999977	0.16700000000000001
60950	SSA	231.099999999999994	0.107999999999999999
60950	SA	292.899999999999977	0.253000000000000003
60950	MF	140.5	0.0719999999999999946
60950	RHO1	269.800000000000011	0.0820000000000000034
60950	Q1	264.699999999999989	0.23000000000000001
60950	T2	69.9000000000000057	0.0490000000000000019
60950	R2	118.299999999999997	0.0389999999999999999
60950	2Q1	238.199999999999989	0.0259999999999999988
60950	P1	285.300000000000011	0.883000000000000007
60950	2SM2	273.399999999999977	0.0459999999999999992
60950	M3	254.800000000000011	0.0200000000000000004
60950	L2	64.4000000000000057	0.223000000000000004
60950	2MK3	267.300000000000011	0.0200000000000000004
60950	K2	58.7999999999999972	0.322000000000000008
60950	M8	18.8000000000000007	0.0100000000000000002
60950	MS4	313.699999999999989	0.0950000000000000011
60951	M2	10.5999999999999996	3.5169999999999999
60951	S2	37	0.879000000000000004
60951	N2	340.800000000000011	0.708999999999999964
60951	K1	277	2.73600000000000021
60951	M4	200.199999999999989	0.0690000000000000058
60951	O1	254.599999999999994	1.51200000000000001
60951	M6	313.600000000000023	0.0299999999999999989
60951	MK3	78.0999999999999943	0.112000000000000002
60951	MN4	174	0.0299999999999999989
60951	NU2	354.899999999999977	0.147999999999999993
60951	MU2	236.599999999999994	0.112000000000000002
60951	2N2	308.699999999999989	0.0790000000000000008
60951	OO1	328.899999999999977	0.104999999999999996
60951	LDA2	48.3999999999999986	0.0660000000000000031
60951	S1	44.2000000000000028	0.0519999999999999976
60951	M1	319.800000000000011	0.0889999999999999958
60951	J1	315.199999999999989	0.131000000000000005
60951	SSA	231.099999999999994	0.107999999999999999
60951	SA	292.899999999999977	0.253000000000000003
60951	MF	140.5	0.0719999999999999946
60951	RHO1	246.599999999999994	0.0490000000000000019
60951	Q1	249.900000000000006	0.245999999999999996
60951	T2	37.1000000000000014	0.0519999999999999976
60951	R2	38	0.00700000000000000015
60951	2Q1	251.5	0.0259999999999999988
60951	P1	276.600000000000023	0.845999999999999974
60951	2SM2	282.600000000000023	0.0259999999999999988
60951	M3	342.399999999999977	0.0160000000000000003
60951	L2	56.1000000000000014	0.147999999999999993
60951	2MK3	46.7000000000000028	0.112000000000000002
60951	K2	37.8999999999999986	0.259000000000000008
60951	MS4	229.900000000000006	0.0389999999999999999
60952	M2	11.5999999999999996	3.31000000000000005
60952	S2	37.1000000000000014	0.845999999999999974
60952	N2	345.300000000000011	0.61399999999999999
60952	K1	276.899999999999977	2.65399999999999991
60952	M4	181.5	0.0619999999999999996
60952	O1	258.300000000000011	1.53200000000000003
60952	M6	327.199999999999989	0.0389999999999999999
60952	S4	294.800000000000011	0.00300000000000000006
60952	NU2	348.800000000000011	0.117999999999999994
60952	S6	36.8999999999999986	0.00300000000000000006
60952	MU2	346.100000000000023	0.0790000000000000008
60952	2N2	319	0.0790000000000000008
60952	OO1	295.399999999999977	0.0660000000000000031
60952	LDA2	23.3999999999999986	0.0229999999999999996
60952	M1	267.699999999999989	0.107999999999999999
60952	J1	286.100000000000023	0.120999999999999996
60952	SSA	231.099999999999994	0.107999999999999999
60952	SA	292.899999999999977	0.253000000000000003
60952	MF	140.5	0.0719999999999999946
60952	RHO1	250.400000000000006	0.0589999999999999969
60952	Q1	249.099999999999994	0.294999999999999984
60952	T2	36.1000000000000014	0.0490000000000000019
60952	R2	38.1000000000000014	0.00700000000000000015
60952	2Q1	240	0.0389999999999999999
60952	P1	275.399999999999977	0.876000000000000001
60952	L2	38.1000000000000014	0.0919999999999999984
60952	K2	39.2000000000000028	0.23000000000000001
60952	M8	244.099999999999994	0.00300000000000000006
60953	M2	15.5	3.3660000000000001
60953	S2	43.3999999999999986	0.826999999999999957
60953	N2	346.300000000000011	0.666000000000000036
60953	K1	281.100000000000023	2.61500000000000021
60953	M4	267.199999999999989	0.0820000000000000034
60953	O1	259.899999999999977	1.51899999999999991
60953	M6	350.899999999999977	0.0330000000000000016
60953	S4	284.5	0.0160000000000000003
60953	NU2	350.199999999999989	0.128000000000000003
60953	S6	218.099999999999994	0.00300000000000000006
60953	MU2	347.600000000000023	0.0820000000000000034
60953	2N2	317.100000000000023	0.0889999999999999958
60953	OO1	302.100000000000023	0.0660000000000000031
60953	LDA2	28.3999999999999986	0.0229999999999999996
60953	M1	270.5	0.107999999999999999
60953	J1	291.5	0.117999999999999994
60953	SSA	231.099999999999994	0.107999999999999999
60953	SA	292.899999999999977	0.253000000000000003
60953	MF	140.5	0.0719999999999999946
60953	RHO1	250.800000000000011	0.0589999999999999969
60953	Q1	249.400000000000006	0.294999999999999984
60953	T2	42.2999999999999972	0.0490000000000000019
60953	R2	44.5	0.00700000000000000015
60953	2Q1	239	0.0389999999999999999
60953	P1	279.5	0.865999999999999992
60953	L2	44.7000000000000028	0.0950000000000000011
60953	K2	45.6000000000000014	0.226000000000000006
60953	M8	284.800000000000011	0.00700000000000000015
60954	M2	10.6999999999999993	3.41900000000000004
60954	S2	36.2000000000000028	0.82999999999999996
60954	N2	341.899999999999977	0.682000000000000051
60954	K1	278.300000000000011	2.70699999999999985
60954	M4	185.699999999999989	0.0690000000000000058
60954	O1	255.400000000000006	1.47999999999999998
60954	M6	324.699999999999989	0.0560000000000000012
60954	S4	274.100000000000023	0.00700000000000000015
60954	NU2	345.699999999999989	0.131000000000000005
60954	MU2	345.199999999999989	0.0820000000000000034
60954	2N2	313	0.0919999999999999984
60954	OO1	301.100000000000023	0.0619999999999999996
60954	LDA2	22.5	0.0229999999999999996
60954	M1	267	0.104999999999999996
60954	J1	289.600000000000023	0.117999999999999994
60954	SSA	231.099999999999994	0.107999999999999999
60954	SA	292.899999999999977	0.253000000000000003
60954	MF	140.5	0.0719999999999999946
60954	RHO1	245.599999999999994	0.0560000000000000012
60954	Q1	244.099999999999994	0.284999999999999976
60954	T2	35.2000000000000028	0.0490000000000000019
60954	R2	37.2000000000000028	0.00700000000000000015
60954	2Q1	232.800000000000011	0.0359999999999999973
60954	P1	276.600000000000023	0.896000000000000019
60954	L2	39.6000000000000014	0.0950000000000000011
60954	K2	38.2999999999999972	0.226000000000000006
60954	M8	190.199999999999989	0.00300000000000000006
60955	M2	12	3.52700000000000014
60955	S2	37.6000000000000014	0.865999999999999992
60955	N2	344.399999999999977	0.679000000000000048
60955	K1	278.100000000000023	2.76900000000000013
60955	M4	186.099999999999994	0.0660000000000000031
60955	O1	254.599999999999994	1.51200000000000001
60955	M6	328.699999999999989	0.0660000000000000031
60955	S4	244.099999999999994	0.0100000000000000002
60955	NU2	348.100000000000023	0.131000000000000005
60955	S6	228.099999999999994	0.0100000000000000002
60955	MU2	346.399999999999977	0.0850000000000000061
60955	2N2	316.699999999999989	0.0889999999999999958
60955	OO1	301.699999999999989	0.0660000000000000031
60955	LDA2	23.8999999999999986	0.0229999999999999996
60955	M1	266.5	0.107999999999999999
60955	J1	289.800000000000011	0.120999999999999996
60955	SSA	231.099999999999994	0.107999999999999999
60955	SA	292.899999999999977	0.253000000000000003
60955	MF	140.5	0.0719999999999999946
60955	RHO1	244.5	0.0589999999999999969
60955	Q1	242.900000000000006	0.291999999999999982
60955	T2	36.6000000000000014	0.0519999999999999976
60955	R2	38.6000000000000014	0.00700000000000000015
60955	2Q1	231.300000000000011	0.0389999999999999999
60955	P1	276.399999999999977	0.915000000000000036
60955	L2	39.6000000000000014	0.0980000000000000038
60955	K2	39.6000000000000014	0.235999999999999988
60955	M8	129.599999999999994	0.00300000000000000006
60956	M2	341.100000000000023	1.81099999999999994
60956	S2	357	0.485999999999999988
60956	N2	311.300000000000011	0.416999999999999982
60956	K1	270.199999999999989	2.22100000000000009
60956	M4	111.900000000000006	0.0459999999999999992
60956	O1	251.300000000000011	1.30899999999999994
60956	M6	199.599999999999994	0.0459999999999999992
60956	S4	38.3999999999999986	0.00700000000000000015
60956	NU2	315.399999999999977	0.0820000000000000034
60956	S6	356.699999999999989	0.00300000000000000006
60956	MU2	325.199999999999989	0.0429999999999999966
60956	2N2	281.600000000000023	0.0560000000000000012
60956	OO1	289	0.0560000000000000012
60956	LDA2	348.5	0.0129999999999999994
60956	M1	260.800000000000011	0.0919999999999999984
60956	J1	279.5	0.101999999999999993
60956	SSA	221	0.128000000000000003
60956	SA	280.399999999999977	0.279000000000000026
60956	RHO1	243.199999999999989	0.0490000000000000019
60956	Q1	242	0.253000000000000003
60956	T2	356.399999999999977	0.0299999999999999989
60956	R2	357.600000000000023	0.00300000000000000006
60956	2Q1	232.599999999999994	0.0330000000000000016
60956	P1	268.800000000000011	0.734999999999999987
60956	L2	10.9000000000000004	0.0519999999999999976
60956	K2	358.300000000000011	0.131000000000000005
60956	M8	227.699999999999989	0.00300000000000000006
60957	M2	10.8000000000000007	3.44799999999999995
60957	S2	35.2999999999999972	0.836999999999999966
60957	N2	342.100000000000023	0.701999999999999957
60957	K1	277.800000000000011	2.6080000000000001
60957	M4	183.800000000000011	0.0690000000000000058
60957	O1	257	1.53499999999999992
60957	M6	323	0.0560000000000000012
60957	S4	203.400000000000006	0.0160000000000000003
60957	NU2	346	0.138000000000000012
60957	MU2	346.300000000000011	0.0820000000000000034
60957	2N2	313.5	0.0919999999999999984
60957	OO1	298.800000000000011	0.0660000000000000031
60957	LDA2	22.1000000000000014	0.0229999999999999996
60957	M1	267.5	0.107999999999999999
60957	J1	288.199999999999989	0.120999999999999996
60957	SSA	231.099999999999994	0.107999999999999999
60957	SA	292.899999999999977	0.253000000000000003
60957	MF	140.5	0.0719999999999999946
60957	RHO1	248	0.0589999999999999969
60957	Q1	246.599999999999994	0.298999999999999988
60957	T2	34.2999999999999972	0.0490000000000000019
60957	R2	36.2000000000000028	0.00700000000000000015
60957	2Q1	236.199999999999989	0.0389999999999999999
60957	P1	276.300000000000011	0.862999999999999989
60957	L2	39.3999999999999986	0.0950000000000000011
60957	K2	37.2999999999999972	0.226000000000000006
60958	M2	9.69999999999999929	3.43800000000000017
60958	S2	35.5	0.842999999999999972
60958	N2	344.300000000000011	0.688999999999999946
60958	K1	277.300000000000011	2.59799999999999986
60958	M4	184.300000000000011	0.0690000000000000058
60958	O1	257.399999999999977	1.54499999999999993
60958	M6	325	0.0560000000000000012
60958	S4	222.400000000000006	0.00700000000000000015
60958	NU2	347.699999999999989	0.135000000000000009
60958	S6	203.699999999999989	0.00300000000000000006
60958	MU2	344	0.0820000000000000034
60958	2N2	318.800000000000011	0.0919999999999999984
60958	OO1	297.199999999999989	0.0660000000000000031
60958	LDA2	21.6000000000000014	0.0229999999999999996
60958	M1	267.5	0.107999999999999999
60958	J1	287.199999999999989	0.120999999999999996
60958	SSA	231.099999999999994	0.107999999999999999
60958	SA	292.899999999999977	0.253000000000000003
60958	MF	140.5	0.0719999999999999946
60958	RHO1	248.900000000000006	0.0589999999999999969
60958	Q1	247.599999999999994	0.298999999999999988
60958	T2	34.3999999999999986	0.0490000000000000019
60958	R2	36.5	0.00700000000000000015
60958	2Q1	237.800000000000011	0.0389999999999999999
60958	P1	275.800000000000011	0.859999999999999987
60958	L2	35.1000000000000014	0.0950000000000000011
60958	K2	37.6000000000000014	0.23000000000000001
60958	M8	211.300000000000011	0.00700000000000000015
60959	M2	18.3000000000000007	3.3660000000000001
60959	S2	42	0.85299999999999998
60959	N2	349.399999999999977	0.676000000000000045
60959	K1	282	2.57200000000000006
60959	M4	12	0.0129999999999999994
60959	O1	258	1.47300000000000009
60959	M6	134.800000000000011	0.0719999999999999946
60959	S4	211	0.00700000000000000015
60959	NU2	353.300000000000011	0.131000000000000005
60959	S6	273.699999999999989	0.00300000000000000006
60959	MU2	354.600000000000023	0.0790000000000000008
60959	2N2	320.5	0.0889999999999999958
60959	OO1	305.899999999999977	0.0619999999999999996
60959	LDA2	29.3000000000000007	0.0229999999999999996
60959	M1	270.100000000000023	0.104999999999999996
60959	J1	293.800000000000011	0.115000000000000005
60959	RHO1	247.800000000000011	0.0560000000000000012
60959	Q1	246.199999999999989	0.284999999999999976
60959	T2	41.1000000000000014	0.0490000000000000019
60959	R2	43	0.00700000000000000015
60959	2Q1	234.400000000000006	0.0389999999999999999
60959	P1	280.199999999999989	0.85299999999999998
60959	L2	47.1000000000000014	0.0950000000000000011
60959	K2	43.8999999999999986	0.233000000000000013
60959	M8	13	0.0160000000000000003
60960	M2	18.1000000000000014	3.17899999999999983
60960	S2	43.5	0.787000000000000033
60960	N2	346.199999999999989	0.646000000000000019
60960	K1	279.600000000000023	2.68400000000000016
60960	M4	58.1000000000000014	0.0229999999999999996
60960	O1	256.600000000000023	1.47999999999999998
60960	M6	149.099999999999994	0.0719999999999999946
60960	MK3	82.0999999999999943	0.0950000000000000011
60960	S4	19.5	0.00300000000000000006
60960	MN4	20	0.0100000000000000002
60960	NU2	355.800000000000011	0.120999999999999996
60960	MU2	259	0.115000000000000005
60960	2N2	326.399999999999977	0.0749999999999999972
60960	OO1	322	0.0950000000000000011
60960	LDA2	58.7999999999999972	0.0519999999999999976
60960	S1	25.6999999999999993	0.0950000000000000011
60960	M1	306.899999999999977	0.0519999999999999976
60960	J1	313	0.120999999999999996
60960	SSA	221	0.128000000000000003
60960	SA	280.399999999999977	0.279000000000000026
60960	RHO1	262.899999999999977	0.0749999999999999972
60960	Q1	252.599999999999994	0.23000000000000001
60960	T2	43.5	0.0589999999999999969
60960	R2	97.5	0.00700000000000000015
60960	2Q1	229.5	0.0429999999999999966
60960	P1	275.699999999999989	0.826999999999999957
60960	2SM2	315.699999999999989	0.0299999999999999989
60960	M3	1.60000000000000009	0.0429999999999999966
60960	L2	81.4000000000000057	0.104999999999999996
60960	2MK3	68.0999999999999943	0.138000000000000012
60960	K2	45.6000000000000014	0.23899999999999999
60960	M8	60	0.0160000000000000003
60960	MS4	46.8999999999999986	0.0160000000000000003
60961	M2	344.600000000000023	1.90599999999999992
60961	S2	4.70000000000000018	0.485999999999999988
60961	N2	313.699999999999989	0.426999999999999991
60961	K1	269.600000000000023	2.42099999999999982
60961	M4	135.5	0.0299999999999999989
60961	O1	247.5	1.375
60961	M6	215.699999999999989	0.0429999999999999966
60961	MK3	53.5	0.0619999999999999996
60961	S4	111.099999999999994	0.00700000000000000015
60961	MN4	101.400000000000006	0.0129999999999999994
60961	NU2	316.100000000000023	0.0790000000000000008
60961	MU2	250.400000000000006	0.104999999999999996
60961	2N2	309.100000000000023	0.0690000000000000058
60961	OO1	305.800000000000011	0.0889999999999999958
60961	LDA2	66.5999999999999943	0.0359999999999999973
60961	S1	21.6999999999999993	0.0790000000000000008
60961	M1	285	0.0619999999999999996
60961	J1	286.199999999999989	0.120999999999999996
60961	SSA	221	0.128000000000000003
60961	SA	280.399999999999977	0.279000000000000026
60961	RHO1	254.5	0.0619999999999999996
60961	Q1	239	0.223000000000000004
60961	T2	12.5999999999999996	0.0359999999999999973
60961	R2	301	0.00700000000000000015
60961	2Q1	217.300000000000011	0.0429999999999999966
60961	P1	264.399999999999977	0.764000000000000012
60961	2SM2	301.199999999999989	0.0160000000000000003
60961	M3	332.699999999999989	0.0229999999999999996
60961	L2	63.7999999999999972	0.0519999999999999976
60961	2MK3	38.8999999999999986	0.0790000000000000008
60961	K2	20.6000000000000014	0.101999999999999993
60961	MS4	130.5	0.0160000000000000003
60962	M2	16.6999999999999993	3.09699999999999998
60962	S2	42.8999999999999986	0.781000000000000028
60962	N2	347.399999999999977	0.630000000000000004
60962	K1	281.399999999999977	2.4740000000000002
60962	M4	77.0999999999999943	0.0459999999999999992
60962	O1	259	1.43399999999999994
60962	M6	154.300000000000011	0.0660000000000000031
60962	S4	205.800000000000011	0.0100000000000000002
60962	NU2	351.300000000000011	0.120999999999999996
60962	S6	149.900000000000006	0.00300000000000000006
60962	MU2	350.600000000000023	0.0749999999999999972
60962	2N2	318	0.0820000000000000034
60962	OO1	303.899999999999977	0.0619999999999999996
60962	LDA2	29	0.0229999999999999996
60962	M1	270.300000000000011	0.101999999999999993
60962	J1	292.600000000000023	0.112000000000000002
60962	MM	184.599999999999994	0.0719999999999999946
60962	SA	292	0.269000000000000017
60962	MF	144.300000000000011	0.0660000000000000031
60962	RHO1	249.400000000000006	0.0519999999999999976
60962	Q1	247.800000000000011	0.279000000000000026
60962	T2	41.8999999999999986	0.0459999999999999992
60962	R2	44	0.00700000000000000015
60962	2Q1	236.699999999999989	0.0359999999999999973
60962	P1	279.800000000000011	0.819999999999999951
60962	L2	46.1000000000000014	0.0850000000000000061
60962	K2	45.1000000000000014	0.212999999999999995
60962	M8	37.7999999999999972	0.0229999999999999996
60963	M2	18.1000000000000014	2.31300000000000017
60963	S2	44.6000000000000014	0.563999999999999946
60963	N2	349.100000000000023	0.478999999999999981
60963	K1	282.199999999999989	2.55600000000000005
60963	M4	236.300000000000011	0.0229999999999999996
60963	O1	259.399999999999977	1.41399999999999992
60963	M6	234.199999999999989	0.0429999999999999966
60963	MK3	172.199999999999989	0.0429999999999999966
60963	MN4	195.400000000000006	0.0100000000000000002
60963	NU2	357.699999999999989	0.0980000000000000038
60963	MU2	254.900000000000006	0.0660000000000000031
60963	2N2	316.699999999999989	0.0490000000000000019
60963	OO1	336.100000000000023	0.138000000000000012
60963	LDA2	54.2999999999999972	0.0389999999999999999
60963	S1	52	0.104999999999999996
60963	M1	296.699999999999989	0.104999999999999996
60963	J1	314	0.143999999999999989
60963	MM	141.5	0.0429999999999999966
60963	SSA	227.099999999999994	0.0919999999999999984
60963	SA	276.899999999999977	0.212999999999999995
60963	RHO1	227.5	0.0589999999999999969
60963	Q1	250.5	0.233000000000000013
60963	T2	44.5	0.0359999999999999973
60963	R2	300.5	0.0100000000000000002
60963	2Q1	276.300000000000011	0.0100000000000000002
60963	P1	281.100000000000023	0.787000000000000033
60963	2SM2	285.199999999999989	0.0100000000000000002
60963	M3	235	0.0129999999999999994
60963	L2	56.2000000000000028	0.104999999999999996
60963	2MK3	110.700000000000003	0.0229999999999999996
60963	K2	34	0.157000000000000001
60963	M8	113.599999999999994	0.0100000000000000002
60963	MS4	220.900000000000006	0.00700000000000000015
60964	M2	16.8999999999999986	2.23399999999999999
60964	S2	42.6000000000000014	0.548000000000000043
60964	N2	345.899999999999977	0.494999999999999996
60964	K1	279.699999999999989	2.78900000000000015
60964	M4	117.299999999999997	0.0229999999999999996
60964	O1	254.599999999999994	1.46700000000000008
60964	M6	274.5	0.00300000000000000006
60964	S4	163.5	0.00700000000000000015
60964	NU2	350	0.0950000000000000011
60964	S6	199.800000000000011	0.00300000000000000006
60964	MU2	351	0.0519999999999999976
60964	2N2	315	0.0660000000000000031
60964	OO1	304.699999999999989	0.0619999999999999996
60964	LDA2	28.8000000000000007	0.0160000000000000003
60964	M1	267.199999999999989	0.101999999999999993
60964	J1	292.100000000000023	0.115000000000000005
60964	SSA	236.5	0.0749999999999999972
60964	SA	280.100000000000023	0.164000000000000007
60964	MF	132.400000000000006	0.0790000000000000008
60964	RHO1	244	0.0560000000000000012
60964	Q1	242.199999999999989	0.284999999999999976
60964	T2	41.6000000000000014	0.0330000000000000016
60964	R2	43.7000000000000028	0.00300000000000000006
60964	2Q1	229.800000000000011	0.0359999999999999973
60964	P1	277.899999999999977	0.922000000000000042
60964	L2	47.7999999999999972	0.0619999999999999996
60964	K2	44.7000000000000028	0.147999999999999993
60965	M2	22.3999999999999986	2.375
60965	S2	50.2000000000000028	0.583999999999999964
60965	N2	354.699999999999989	0.498999999999999999
60965	K1	283.100000000000023	2.65399999999999991
60965	M4	158.5	0.0200000000000000004
60965	O1	260.5	1.4930000000000001
60965	M6	59.3999999999999986	0.0100000000000000002
60965	MK3	12.6999999999999993	0.00700000000000000015
60965	S4	162.5	0.00300000000000000006
60965	MN4	120	0.00700000000000000015
60965	NU2	2.20000000000000018	0.0980000000000000038
60965	MU2	268	0.0519999999999999976
60965	2N2	326.899999999999977	0.0619999999999999996
60965	OO1	325.699999999999989	0.101999999999999993
60965	LDA2	56.7000000000000028	0.0330000000000000016
60965	S1	24.8999999999999986	0.0950000000000000011
60965	M1	309.300000000000011	0.0690000000000000058
60965	J1	321.399999999999977	0.140999999999999986
60965	MM	141.5	0.0429999999999999966
60965	SSA	227.099999999999994	0.0919999999999999984
60965	SA	276.899999999999977	0.212999999999999995
60965	RHO1	253.699999999999989	0.0519999999999999976
60965	Q1	253.699999999999989	0.245999999999999996
60965	T2	42.3999999999999986	0.0389999999999999999
60965	R2	326.199999999999989	0.00300000000000000006
60965	2Q1	253.800000000000011	0.0299999999999999989
60965	P1	280.600000000000023	0.819999999999999951
60965	2SM2	278.199999999999989	0.0100000000000000002
60965	M3	76.0999999999999943	0.00300000000000000006
60965	L2	60.3999999999999986	0.0790000000000000008
60965	2MK3	334.399999999999977	0.0160000000000000003
60965	K2	50.7999999999999972	0.161000000000000004
60965	M8	80.2999999999999972	0.00300000000000000006
60965	MS4	164	0.0100000000000000002
60966	M2	27.1000000000000014	2.55200000000000005
60966	S2	54.3999999999999986	0.622999999999999998
60966	N2	359.699999999999989	0.528000000000000025
60966	K1	285.600000000000023	2.7719999999999998
60966	M4	174.599999999999994	0.0200000000000000004
60966	O1	261	1.53200000000000003
60966	M6	68.4000000000000057	0.0160000000000000003
60966	S4	199.300000000000011	0.00700000000000000015
60966	NU2	3.29999999999999982	0.101999999999999993
60966	S6	191.300000000000011	0.00300000000000000006
60966	MU2	359.800000000000011	0.0619999999999999996
60966	2N2	332.199999999999989	0.0690000000000000058
60966	OO1	310.100000000000023	0.0660000000000000031
60966	LDA2	39.7999999999999972	0.0160000000000000003
60966	M1	273.399999999999977	0.107999999999999999
60966	J1	297.800000000000011	0.120999999999999996
60966	MM	141.5	0.0429999999999999966
60966	SSA	227.099999999999994	0.0919999999999999984
60966	SA	276.899999999999977	0.212999999999999995
60966	RHO1	250.599999999999994	0.0589999999999999969
60966	Q1	248.800000000000011	0.294999999999999984
60966	T2	53.2999999999999972	0.0359999999999999973
60966	R2	55.5	0.00700000000000000015
60966	2Q1	236.800000000000011	0.0389999999999999999
60966	P1	283.699999999999989	0.919000000000000039
60966	L2	54.3999999999999986	0.0719999999999999946
60966	K2	56.6000000000000014	0.171000000000000013
60967	M2	24.8000000000000007	2.50300000000000011
60967	S2	53.2000000000000028	0.609999999999999987
60967	N2	355.800000000000011	0.54500000000000004
60967	K1	286.300000000000011	2.57200000000000006
60967	M4	126.400000000000006	0.00700000000000000015
60967	O1	262.300000000000011	1.43999999999999995
60967	M6	26	0.0129999999999999994
60967	NU2	359.600000000000023	0.104999999999999996
60967	S6	225	0.00300000000000000006
60967	MU2	356.399999999999977	0.0589999999999999969
60967	2N2	326.699999999999989	0.0719999999999999946
60967	OO1	310.300000000000011	0.0619999999999999996
60967	LDA2	38	0.0160000000000000003
60967	M1	274.300000000000011	0.101999999999999993
60967	J1	298.199999999999989	0.115000000000000005
60967	SSA	236.5	0.0749999999999999972
60967	SA	280.100000000000023	0.164000000000000007
60967	MF	132.400000000000006	0.0790000000000000008
60967	RHO1	252	0.0560000000000000012
60967	Q1	250.300000000000011	0.279000000000000026
60967	T2	52.1000000000000014	0.0359999999999999973
60967	R2	54.3999999999999986	0.00300000000000000006
60967	2Q1	238.400000000000006	0.0359999999999999973
60967	P1	284.5	0.85299999999999998
60967	L2	53.8999999999999986	0.0690000000000000058
60967	K2	55.6000000000000014	0.16700000000000001
60967	M8	277.800000000000011	0.00300000000000000006
60968	M2	15.4000000000000004	2.02800000000000002
60968	S2	41.2999999999999972	0.485999999999999988
60968	N2	348.699999999999989	0.422999999999999987
60968	K1	281.300000000000011	2.57900000000000018
60968	M4	139.400000000000006	0.0490000000000000019
60968	O1	259.100000000000023	1.44700000000000006
60968	M6	201.900000000000006	0.0129999999999999994
60968	S4	178.099999999999994	0.00700000000000000015
60968	NU2	352.300000000000011	0.0820000000000000034
60968	S6	191.400000000000006	0.00300000000000000006
60968	MU2	349.600000000000023	0.0490000000000000019
60968	2N2	321.899999999999977	0.0560000000000000012
60968	OO1	303.600000000000023	0.0619999999999999996
60968	LDA2	27.3999999999999986	0.0129999999999999994
60968	M1	270.300000000000011	0.101999999999999993
60968	J1	292.300000000000011	0.115000000000000005
60968	SSA	227.5	0.0719999999999999946
60968	SA	274.5	0.248999999999999999
60968	MF	156.400000000000006	0.0690000000000000058
60968	RHO1	249.5	0.0560000000000000012
60968	Q1	248	0.279000000000000026
60968	T2	40.2999999999999972	0.0299999999999999989
60968	R2	42.3999999999999986	0.00300000000000000006
60968	2Q1	236.900000000000006	0.0389999999999999999
60968	P1	279.600000000000023	0.85299999999999998
60968	L2	42	0.0560000000000000012
60968	K2	43.3999999999999986	0.131000000000000005
60968	M8	95.7000000000000028	0.00300000000000000006
60969	M2	4.70000000000000018	1.86699999999999999
60969	S2	28.3000000000000007	0.443000000000000005
60969	N2	337.899999999999977	0.384000000000000008
60969	K1	277.699999999999989	2.5
60969	M4	143.800000000000011	0.0519999999999999976
60969	O1	255	1.3879999999999999
60969	M6	195.400000000000006	0.0299999999999999989
60969	S4	169.300000000000011	0.0100000000000000002
60969	NU2	341.600000000000023	0.0749999999999999972
60969	S6	173.900000000000006	0.00700000000000000015
60969	MU2	341.199999999999989	0.0459999999999999992
60969	2N2	311.199999999999989	0.0519999999999999976
60969	OO1	300.399999999999977	0.0589999999999999969
60969	LDA2	15.5999999999999996	0.0129999999999999994
60969	M1	266.399999999999977	0.0980000000000000038
60969	J1	289	0.107999999999999999
60969	SSA	221	0.128000000000000003
60969	SA	280.399999999999977	0.279000000000000026
60969	RHO1	245.199999999999989	0.0519999999999999976
60969	Q1	243.699999999999989	0.269000000000000017
60969	T2	27.3000000000000007	0.0259999999999999988
60969	R2	29.1999999999999993	0.00300000000000000006
60969	2Q1	232.400000000000006	0.0359999999999999973
60969	P1	276	0.826999999999999957
60969	L2	31.3999999999999986	0.0519999999999999976
60969	K2	30.1000000000000014	0.120999999999999996
60969	M8	80.4000000000000057	0.00300000000000000006
60970	M2	357.199999999999989	1.73199999999999998
60970	S2	17.6999999999999993	0.412999999999999978
60970	N2	324.800000000000011	0.370999999999999996
60970	K1	275	2.46399999999999997
60970	M4	87.0999999999999943	0.0619999999999999996
60970	O1	253.300000000000011	1.43399999999999994
60970	M6	206.099999999999994	0.0299999999999999989
60970	MK3	1.39999999999999991	0.0619999999999999996
60970	S4	79.2999999999999972	0.00700000000000000015
60970	MN4	53.6000000000000014	0.0299999999999999989
60970	NU2	336.100000000000023	0.0660000000000000031
60970	MU2	245.400000000000006	0.0749999999999999972
60970	2N2	315.199999999999989	0.0589999999999999969
60970	OO1	316.199999999999989	0.0950000000000000011
60970	LDA2	53.7999999999999972	0.0389999999999999999
60970	S1	11.8000000000000007	0.0749999999999999972
60970	M1	293.199999999999989	0.0519999999999999976
60970	J1	302.899999999999977	0.107999999999999999
60970	SSA	221	0.128000000000000003
60970	SA	280.399999999999977	0.279000000000000026
60970	RHO1	257.800000000000011	0.0619999999999999996
60970	Q1	244.400000000000006	0.235999999999999988
60970	T2	20.5	0.0330000000000000016
60970	R2	281	0.00700000000000000015
60970	2Q1	205.5	0.0359999999999999973
60970	P1	270.899999999999977	0.737999999999999989
60970	2SM2	277.5	0.0129999999999999994
60970	M3	300	0.0259999999999999988
60970	L2	58.3999999999999986	0.0589999999999999969
60970	2MK3	11.8000000000000007	0.0589999999999999969
60970	K2	36	0.107999999999999999
60970	M8	213.599999999999994	0.00300000000000000006
60970	MS4	107.200000000000003	0.0359999999999999973
60971	M2	344.399999999999977	1.68999999999999995
60971	S2	4.20000000000000018	0.409999999999999976
60971	N2	316.600000000000023	0.353999999999999981
60971	K1	270.699999999999989	2.39800000000000013
60971	M4	141.900000000000006	0.0389999999999999999
60971	O1	249.199999999999989	1.33499999999999996
60971	M6	199.199999999999989	0.0389999999999999999
60971	S4	142	0.0100000000000000002
60971	NU2	320.300000000000011	0.0690000000000000058
60971	S6	97.7000000000000028	0.00300000000000000006
60971	MU2	324.600000000000023	0.0389999999999999999
60971	2N2	288.899999999999977	0.0459999999999999992
60971	OO1	292.199999999999989	0.0589999999999999969
60971	LDA2	353.600000000000023	0.0129999999999999994
60971	M1	260	0.0950000000000000011
60971	J1	281.300000000000011	0.104999999999999996
60971	SSA	221	0.128000000000000003
60971	SA	280.399999999999977	0.279000000000000026
60971	RHO1	240	0.0519999999999999976
60971	Q1	238.5	0.259000000000000008
60971	T2	3.39999999999999991	0.0229999999999999996
60971	R2	5	0.00300000000000000006
60971	2Q1	227.900000000000006	0.0359999999999999973
60971	P1	269.100000000000023	0.794000000000000039
60971	L2	12	0.0459999999999999992
60971	K2	5.79999999999999982	0.112000000000000002
60971	M8	70.2999999999999972	0.00300000000000000006
60972	M2	10.5999999999999996	1.82699999999999996
60972	S2	35.7000000000000028	0.432999999999999996
60972	N2	343	0.394000000000000017
60972	K1	280.399999999999977	2.49299999999999988
60972	M4	124.599999999999994	0.0519999999999999976
60972	O1	258.699999999999989	1.42399999999999993
60972	M6	237.199999999999989	0.0160000000000000003
60972	MK3	27.5	0.0389999999999999999
60972	S4	157	0.00700000000000000015
60972	MN4	92	0.0229999999999999996
60972	NU2	350.100000000000023	0.0790000000000000008
60972	S6	255.900000000000006	0.00300000000000000006
60972	MU2	266.600000000000023	0.0560000000000000012
60972	2N2	309.399999999999977	0.0429999999999999966
60972	OO1	325.699999999999989	0.0980000000000000038
60972	LDA2	60	0.0259999999999999988
60972	S1	26.8000000000000007	0.0790000000000000008
60972	M1	298	0.0820000000000000034
60972	J1	315.100000000000023	0.138000000000000012
60972	MM	168.800000000000011	0.0299999999999999989
60972	SSA	227.5	0.0719999999999999946
60972	SA	274.5	0.248999999999999999
60972	MSF	265.100000000000023	0.0229999999999999996
60972	MF	156.400000000000006	0.0690000000000000058
60972	RHO1	245.900000000000006	0.0429999999999999966
60972	Q1	250.699999999999989	0.23899999999999999
60972	T2	39.8999999999999986	0.0359999999999999973
60972	R2	313.600000000000023	0.00700000000000000015
60972	2Q1	253.5	0.0259999999999999988
60972	P1	278	0.771000000000000019
60972	2SM2	289.100000000000023	0.00700000000000000015
60972	M3	127.099999999999994	0.00300000000000000006
60972	L2	52.3999999999999986	0.0690000000000000058
60972	2MK3	19.5	0.0299999999999999989
60972	K2	44	0.115000000000000005
60972	M8	105.200000000000003	0.00300000000000000006
60972	MS4	134	0.0330000000000000016
60973	M2	4.29999999999999982	1.8600000000000001
60973	S2	27	0.44900000000000001
60973	N2	338	0.394000000000000017
60973	K1	277.5	2.47699999999999987
60973	M4	142.300000000000011	0.0519999999999999976
60973	O1	254.699999999999989	1.39799999999999991
60973	M6	203.199999999999989	0.0299999999999999989
60973	S4	139.599999999999994	0.0100000000000000002
60973	NU2	341.5	0.0749999999999999972
60973	S6	112.700000000000003	0.00300000000000000006
60973	MU2	341.600000000000023	0.0459999999999999992
60973	2N2	311.600000000000023	0.0519999999999999976
60973	OO1	300.300000000000011	0.0589999999999999969
60973	LDA2	14.8000000000000007	0.0129999999999999994
60973	M1	266.199999999999989	0.0980000000000000038
60973	J1	288.800000000000011	0.112000000000000002
60973	SSA	221	0.128000000000000003
60973	SA	280.399999999999977	0.279000000000000026
60973	RHO1	245	0.0519999999999999976
60973	Q1	243.5	0.27200000000000002
60973	T2	26	0.0259999999999999988
60973	R2	27.8000000000000007	0.00300000000000000006
60973	2Q1	232.099999999999994	0.0359999999999999973
60973	P1	275.800000000000011	0.819999999999999951
60973	L2	30.6999999999999993	0.0519999999999999976
60973	K2	28.8000000000000007	0.120999999999999996
60973	M8	105.599999999999994	0.00300000000000000006
60974	M2	0.5	1.87999999999999989
60974	S2	22	0.471999999999999975
60974	N2	330.5	0.409999999999999976
60974	K1	276.399999999999977	2.47999999999999998
60974	M4	121.900000000000006	0.0790000000000000008
60974	O1	255.699999999999989	1.42999999999999994
60974	M6	202.5	0.0330000000000000016
60974	MK3	24.6000000000000014	0.0950000000000000011
60974	S4	149.599999999999994	0.00700000000000000015
60974	MN4	89.2000000000000028	0.0359999999999999973
60974	NU2	340.100000000000023	0.0790000000000000008
60974	MU2	260.800000000000011	0.0889999999999999958
60974	2N2	279.600000000000023	0.0459999999999999992
60974	OO1	332.899999999999977	0.0980000000000000038
60974	LDA2	69.2999999999999972	0.0259999999999999988
60974	S1	57.1000000000000014	0.0619999999999999996
60974	M1	287.5	0.0980000000000000038
60974	J1	303.5	0.143999999999999989
60974	MM	187.699999999999989	0.0749999999999999972
60974	SA	287.600000000000023	0.331000000000000016
60974	MF	146.800000000000011	0.0459999999999999992
60974	RHO1	246	0.0490000000000000019
60974	Q1	245.900000000000006	0.245999999999999996
60974	T2	24.5	0.0330000000000000016
60974	R2	332.5	0.00300000000000000006
60974	2Q1	243.5	0.0229999999999999996
60974	P1	274.899999999999977	0.797000000000000042
60974	2SM2	317	0.0100000000000000002
60974	M3	44.6000000000000014	0.0160000000000000003
60974	L2	53.1000000000000014	0.0690000000000000058
60974	2MK3	15.6999999999999993	0.0719999999999999946
60974	K2	38.7000000000000028	0.131000000000000005
60974	M8	72.5	0.00300000000000000006
60974	MS4	142.400000000000006	0.0459999999999999992
60975	M2	340.100000000000023	1.71300000000000008
60975	S2	0.299999999999999989	0.443000000000000005
60975	N2	310.300000000000011	0.387000000000000011
60975	K1	270.899999999999977	2.33899999999999997
60975	M4	110	0.0299999999999999989
60975	O1	247.199999999999989	1.34499999999999997
60975	M6	199.5	0.0429999999999999966
60975	MK3	53.2999999999999972	0.0490000000000000019
60975	S4	134.599999999999994	0.00700000000000000015
60975	MN4	77.4000000000000057	0.0160000000000000003
60975	NU2	321.399999999999977	0.0660000000000000031
60975	MU2	249.800000000000011	0.0919999999999999984
60975	2N2	259	0.0429999999999999966
60975	OO1	314.5	0.0980000000000000038
60975	LDA2	77.7999999999999972	0.0229999999999999996
60975	S1	37	0.0820000000000000034
60975	M1	273.100000000000023	0.0820000000000000034
60975	J1	295.800000000000011	0.131000000000000005
60975	MM	187.699999999999989	0.0749999999999999972
60975	SA	287.600000000000023	0.331000000000000016
60975	MF	146.800000000000011	0.0459999999999999992
60975	RHO1	226.199999999999989	0.0429999999999999966
60975	Q1	237.199999999999989	0.233000000000000013
60975	T2	7.40000000000000036	0.0330000000000000016
60975	R2	284.300000000000011	0.00300000000000000006
60975	2Q1	234.400000000000006	0.0229999999999999996
60975	P1	267.399999999999977	0.731999999999999984
60975	2SM2	314.699999999999989	0.0129999999999999994
60975	M3	91.7000000000000028	0.0100000000000000002
60975	L2	50	0.0749999999999999972
60975	2MK3	35.6000000000000014	0.0690000000000000058
60975	K2	8.09999999999999964	0.0889999999999999958
60975	M8	133.400000000000006	0.00300000000000000006
60975	MS4	118.200000000000003	0.0200000000000000004
60976	M2	348.600000000000023	1.44399999999999995
60976	S2	10	0.353999999999999981
60976	N2	320.399999999999977	0.307999999999999996
60976	K1	273.199999999999989	2.01799999999999979
60976	M4	107.299999999999997	0.0589999999999999969
60976	O1	252.599999999999994	1.14799999999999991
60976	M6	195.400000000000006	0.0359999999999999973
60976	S4	142	0.00700000000000000015
60976	NU2	324.199999999999989	0.0589999999999999969
60976	S6	143	0.00300000000000000006
60976	MU2	327.199999999999989	0.0359999999999999973
60976	2N2	292	0.0389999999999999999
60976	OO1	293.899999999999977	0.0490000000000000019
60976	LDA2	358.600000000000023	0.0100000000000000002
60976	M1	263	0.0820000000000000034
60976	J1	283.5	0.0919999999999999984
60976	SSA	221	0.128000000000000003
60976	SA	280.399999999999977	0.279000000000000026
60976	RHO1	243.699999999999989	0.0429999999999999966
60976	Q1	242.300000000000011	0.223000000000000004
60976	T2	9.19999999999999929	0.0200000000000000004
60976	R2	10.9000000000000004	0.00300000000000000006
60976	2Q1	232	0.0299999999999999989
60976	P1	271.600000000000023	0.669000000000000039
60976	L2	16.6999999999999993	0.0389999999999999999
60976	K2	11.8000000000000007	0.0980000000000000038
60976	M8	86.5999999999999943	0.00300000000000000006
60977	M2	272.199999999999989	4.93400000000000016
60977	S2	305.800000000000011	1.60400000000000009
60977	N2	249.800000000000011	1.03299999999999992
60977	K1	262.600000000000023	1.50600000000000001
60977	M4	309.100000000000023	0.0330000000000000016
60977	O1	244.300000000000011	0.970999999999999974
60977	M6	122.700000000000003	0.0129999999999999994
60977	S4	250	0.0129999999999999994
60977	NU2	252.800000000000011	0.200000000000000011
60977	MU2	238.599999999999994	0.117999999999999994
60977	2N2	227.300000000000011	0.138000000000000012
60977	OO1	281	0.0429999999999999966
60977	LDA2	287.800000000000011	0.0359999999999999973
60977	M1	253.5	0.0690000000000000058
60977	J1	271.800000000000011	0.0749999999999999972
60977	SSA	161.099999999999994	0.101999999999999993
60977	SA	273.699999999999989	0.377000000000000002
60977	RHO1	236.400000000000006	0.0359999999999999973
60977	Q1	235.099999999999994	0.187
60977	T2	304.5	0.0950000000000000011
60977	R2	307.199999999999989	0.0129999999999999994
60977	2Q1	226	0.0259999999999999988
60977	P1	261.300000000000011	0.498999999999999999
60977	L2	294.699999999999989	0.138000000000000012
60977	K2	308.600000000000023	0.435999999999999999
60977	M8	212.599999999999994	0.00700000000000000015
60978	M2	272.300000000000011	4.94099999999999984
60978	S2	304.100000000000023	1.51600000000000001
60978	N2	251.900000000000006	0.990999999999999992
60978	K1	263.399999999999977	1.52600000000000002
60978	M4	297.199999999999989	0.0359999999999999973
60978	O1	244.099999999999994	0.97799999999999998
60978	M6	153.599999999999994	0.0129999999999999994
60978	S4	24.8999999999999986	0.0100000000000000002
60978	NU2	254.699999999999989	0.194000000000000006
60978	S6	43.8999999999999986	0.00700000000000000015
60978	MU2	240.599999999999994	0.117999999999999994
60978	2N2	231.599999999999994	0.131000000000000005
60978	OO1	282.600000000000023	0.0429999999999999966
60978	LDA2	287.100000000000023	0.0359999999999999973
60978	M1	253.800000000000011	0.0690000000000000058
60978	J1	272.899999999999977	0.0790000000000000008
60978	SSA	161.099999999999994	0.101999999999999993
60978	SA	273.699999999999989	0.377000000000000002
60978	RHO1	235.900000000000006	0.0359999999999999973
60978	Q1	234.599999999999994	0.190000000000000002
60978	T2	302.899999999999977	0.0889999999999999958
60978	R2	305.399999999999977	0.0129999999999999994
60978	2Q1	225	0.0259999999999999988
60978	P1	261.899999999999977	0.505000000000000004
60978	L2	292.699999999999989	0.138000000000000012
60978	K2	306.699999999999989	0.412999999999999978
60978	M8	215	0.0129999999999999994
60979	M2	268.699999999999989	6.03699999999999992
60979	S2	299.5	1.92300000000000004
60979	N2	242.300000000000011	1.15799999999999992
60979	K1	262.5	1.67599999999999993
60979	M4	289	0.0389999999999999999
60979	O1	244.5	1.00099999999999989
60979	M6	233.400000000000006	0.00700000000000000015
60979	S4	9.19999999999999929	0.0200000000000000004
60979	NU2	245.800000000000011	0.226000000000000006
60979	S6	46.7000000000000028	0.00300000000000000006
60979	MU2	335.300000000000011	0.143999999999999989
60979	2N2	215.900000000000006	0.153999999999999998
60979	OO1	280.600000000000023	0.0429999999999999966
60979	LDA2	283	0.0429999999999999966
60979	M1	253.599999999999994	0.0719999999999999946
60979	J1	271.5	0.0790000000000000008
60979	SSA	161.099999999999994	0.101999999999999993
60979	SA	273.699999999999989	0.377000000000000002
60979	MF	173	0.0889999999999999958
60979	RHO1	236.699999999999989	0.0389999999999999999
60979	Q1	235.5	0.194000000000000006
60979	T2	298.300000000000011	0.115000000000000005
60979	R2	300.800000000000011	0.0160000000000000003
60979	2Q1	226.5	0.0259999999999999988
60979	P1	261.199999999999989	0.554000000000000048
60979	L2	295	0.171000000000000013
60979	K2	302	0.52200000000000002
60979	M8	243.5	0.00300000000000000006
60980	M2	269.199999999999989	5.93499999999999961
60980	S2	304.5	1.89999999999999991
60980	N2	241.599999999999994	1.18100000000000005
60980	K1	257.600000000000023	1.65700000000000003
60980	M4	310.199999999999989	0.0330000000000000016
60980	O1	245.300000000000011	1.004
60980	M6	104.400000000000006	0.00300000000000000006
60980	S4	26.3000000000000007	0.0160000000000000003
60980	NU2	245.300000000000011	0.23000000000000001
60980	S6	27.8000000000000007	0.00300000000000000006
60980	MU2	330.699999999999989	0.140999999999999986
60980	2N2	214.099999999999994	0.157000000000000001
60980	OO1	270	0.0429999999999999966
60980	LDA2	285.600000000000023	0.0429999999999999966
60980	M1	251.5	0.0719999999999999946
60980	J1	263.800000000000011	0.0790000000000000008
60980	SSA	161.099999999999994	0.101999999999999993
60980	SA	273.699999999999989	0.377000000000000002
60980	RHO1	240	0.0389999999999999999
60980	Q1	239.099999999999994	0.194000000000000006
60980	T2	303.100000000000023	0.112000000000000002
60980	R2	305.899999999999977	0.0160000000000000003
60980	2Q1	233	0.0259999999999999988
60980	P1	256.699999999999989	0.548000000000000043
60980	L2	296.699999999999989	0.16700000000000001
60980	K2	307.399999999999977	0.518000000000000016
60980	M8	202.900000000000006	0.0100000000000000002
60981	M2	272.600000000000023	5.00300000000000011
60981	S2	304.199999999999989	1.53499999999999992
60981	N2	253.400000000000006	1.04299999999999993
60981	K1	261.699999999999989	1.58099999999999996
60981	M4	262.300000000000011	0.0359999999999999973
60981	O1	248.400000000000006	1.004
60981	M6	100.200000000000003	0.0160000000000000003
60981	S4	316.899999999999977	0.00700000000000000015
60981	NU2	255.900000000000006	0.203000000000000014
60981	MU2	241	0.120999999999999996
60981	2N2	234.099999999999994	0.138000000000000012
60981	OO1	275.100000000000023	0.0429999999999999966
60981	LDA2	287.300000000000011	0.0359999999999999973
60981	M1	255.099999999999994	0.0719999999999999946
60981	J1	268.399999999999977	0.0790000000000000008
60981	SSA	161.099999999999994	0.101999999999999993
60981	SA	273.100000000000023	0.377000000000000002
60981	MF	173	0.0889999999999999958
60981	RHO1	242.699999999999989	0.0389999999999999999
60981	Q1	241.800000000000011	0.194000000000000006
60981	T2	302.899999999999977	0.0919999999999999984
60981	R2	305.5	0.0129999999999999994
60981	2Q1	235.199999999999989	0.0259999999999999988
60981	P1	260.699999999999989	0.52200000000000002
60981	L2	291.899999999999977	0.140999999999999986
60981	K2	306.800000000000011	0.416999999999999982
60981	M8	224.5	0.00700000000000000015
60982	M2	270.100000000000023	6.17400000000000038
60982	S2	301.800000000000011	2.04700000000000015
60982	N2	245.599999999999994	1.25299999999999989
60982	K1	261.100000000000023	1.68300000000000005
60982	M4	291.600000000000023	0.0519999999999999976
60982	O1	244.900000000000006	1.02000000000000002
60982	MK3	9.80000000000000071	0.0160000000000000003
60982	S4	16.3000000000000007	0.0100000000000000002
60982	MN4	273.199999999999989	0.0200000000000000004
60982	NU2	250	0.23899999999999999
60982	MU2	231.300000000000011	0.135000000000000009
60982	2N2	219.599999999999994	0.147999999999999993
60982	OO1	292.100000000000023	0.0560000000000000012
60982	LDA2	277.899999999999977	0.0389999999999999999
60982	S1	45	0.0490000000000000019
60982	M1	276.300000000000011	0.0519999999999999976
60982	J1	275.5	0.0980000000000000038
60982	SSA	161.099999999999994	0.101999999999999993
60982	SA	273.699999999999989	0.377000000000000002
60982	MF	173	0.0889999999999999958
60982	RHO1	241	0.0359999999999999973
60982	Q1	237.400000000000006	0.176999999999999991
60982	T2	296.899999999999977	0.115000000000000005
60982	R2	340.5	0.0259999999999999988
60982	2Q1	236.599999999999994	0.0229999999999999996
60982	P1	258.5	0.531000000000000028
60982	2SM2	98.5	0.0129999999999999994
60982	M3	336.399999999999977	0.0589999999999999969
60982	L2	281.300000000000011	0.138000000000000012
60982	2MK3	53.1000000000000014	0.0129999999999999994
60982	K2	295.199999999999989	0.563999999999999946
60982	MS4	332.5	0.0429999999999999966
60983	M2	269.5	3.71700000000000008
60983	S2	301.600000000000023	1.15799999999999992
60983	N2	241.199999999999989	0.774000000000000021
60983	K1	263.100000000000023	1.38100000000000001
60983	M4	283.5	0.0129999999999999994
60983	O1	245.800000000000011	0.902000000000000024
60983	M6	236.300000000000011	0.00300000000000000006
60983	S4	235.900000000000006	0.00300000000000000006
60983	NU2	245	0.150999999999999995
60983	MU2	331.5	0.0889999999999999958
60983	2N2	212.900000000000006	0.101999999999999993
60983	OO1	280.5	0.0389999999999999999
60983	LDA2	284.399999999999977	0.0259999999999999988
60983	M1	254.5	0.0660000000000000031
60983	J1	271.800000000000011	0.0719999999999999946
60983	RHO1	238.300000000000011	0.0359999999999999973
60983	Q1	237.199999999999989	0.173999999999999988
60983	T2	300.300000000000011	0.0690000000000000058
60983	R2	302.899999999999977	0.0100000000000000002
60983	2Q1	228.5	0.0229999999999999996
60983	P1	261.800000000000011	0.459000000000000019
60983	L2	297.800000000000011	0.104999999999999996
60983	K2	304.199999999999989	0.315000000000000002
60983	M8	15.5999999999999996	0.00700000000000000015
60984	M2	269.300000000000011	3.7240000000000002
60984	S2	301.199999999999989	1.09899999999999998
60984	N2	243	0.778000000000000025
60984	K1	263.199999999999989	1.44999999999999996
60984	M4	294.300000000000011	0.0100000000000000002
60984	O1	247	0.892000000000000015
60984	S4	80.2999999999999972	0.00300000000000000006
60984	NU2	246.5	0.150999999999999995
60984	MU2	331.199999999999989	0.0889999999999999958
60984	2N2	216.699999999999989	0.104999999999999996
60984	OO1	279.399999999999977	0.0389999999999999999
60984	LDA2	284.100000000000023	0.0259999999999999988
60984	M1	255.099999999999994	0.0619999999999999996
60984	J1	271.199999999999989	0.0719999999999999946
60984	RHO1	240	0.0330000000000000016
60984	Q1	239	0.173999999999999988
60984	T2	299.899999999999977	0.0660000000000000031
60984	R2	302.5	0.0100000000000000002
60984	2Q1	230.900000000000006	0.0229999999999999996
60984	P1	262	0.478999999999999981
60984	L2	295.699999999999989	0.104999999999999996
60984	K2	303.800000000000011	0.298999999999999988
60984	M8	277.199999999999989	0.00300000000000000006
60985	M2	333.600000000000023	1.20399999999999996
60985	S2	357.899999999999977	0.331000000000000016
60985	N2	310.199999999999989	0.242999999999999994
60985	K1	334.100000000000023	0.603999999999999981
60985	M4	248.5	0.203000000000000014
60985	O1	348.899999999999977	0.387000000000000011
60985	M6	210.199999999999989	0.0299999999999999989
60985	S4	246	0.00700000000000000015
60985	NU2	313.399999999999977	0.0459999999999999992
60985	MU2	43.3999999999999986	0.0299999999999999989
60985	2N2	286.899999999999977	0.0330000000000000016
60985	OO1	319.300000000000011	0.0160000000000000003
60985	LDA2	344.800000000000011	0.0100000000000000002
60985	M1	341.399999999999977	0.0259999999999999988
60985	J1	326.800000000000011	0.0299999999999999989
60985	RHO1	355.199999999999989	0.0160000000000000003
60985	Q1	356.199999999999989	0.0749999999999999972
60985	T2	356.899999999999977	0.0200000000000000004
60985	R2	358.800000000000011	0.00300000000000000006
60985	2Q1	3.5	0.0100000000000000002
60985	P1	335.199999999999989	0.200000000000000011
60985	L2	356.899999999999977	0.0330000000000000016
60985	K2	359.800000000000011	0.0889999999999999958
60985	M8	89	0.00300000000000000006
60986	M2	272.899999999999977	6.35500000000000043
60986	S2	304.300000000000011	2.21799999999999997
60986	N2	246.800000000000011	1.34800000000000009
60986	K1	260.899999999999977	1.7390000000000001
60986	M4	272.300000000000011	0.107999999999999999
60986	O1	246.400000000000006	0.996999999999999997
60986	M6	355	0.0100000000000000002
60986	S4	41.8999999999999986	0.0200000000000000004
60986	NU2	250.300000000000011	0.262000000000000011
60986	S6	101.099999999999994	0.00300000000000000006
60986	MU2	336.5	0.153999999999999998
60986	2N2	220.800000000000011	0.179999999999999993
60986	OO1	275.5	0.0429999999999999966
60986	LDA2	287.5	0.0459999999999999992
60986	M1	253.699999999999989	0.0719999999999999946
60986	J1	268.100000000000023	0.0790000000000000008
60986	SSA	161.099999999999994	0.101999999999999993
60986	SA	273.699999999999989	0.377000000000000002
60986	RHO1	240.199999999999989	0.0389999999999999999
60986	Q1	239.199999999999989	0.194000000000000006
60986	T2	303	0.131000000000000005
60986	R2	305.5	0.0160000000000000003
60986	2Q1	232	0.0259999999999999988
60986	P1	259.800000000000011	0.573999999999999955
60986	L2	298.899999999999977	0.176999999999999991
60986	K2	306.800000000000011	0.603999999999999981
60986	M8	6.70000000000000018	0.00300000000000000006
60987	M2	271.300000000000011	6.11899999999999977
60987	S2	305	2.00499999999999989
60987	N2	249.599999999999994	1.2569999999999999
60987	K1	262.300000000000011	1.56800000000000006
60987	M4	334.199999999999989	0.0490000000000000019
60987	O1	243.199999999999989	1.0069999999999999
60987	M6	31.6999999999999993	0.0129999999999999994
60987	S4	314.300000000000011	0.0100000000000000002
60987	NU2	252.5	0.242999999999999994
60987	S6	315.5	0.0129999999999999994
60987	MU2	237.5	0.147999999999999993
60987	2N2	227.900000000000006	0.16700000000000001
60987	OO1	281.399999999999977	0.0429999999999999966
60987	LDA2	286.899999999999977	0.0429999999999999966
60987	M1	252.900000000000006	0.0719999999999999946
60987	J1	271.800000000000011	0.0790000000000000008
60987	SSA	161.099999999999994	0.101999999999999993
60987	SA	273.699999999999989	0.377000000000000002
60987	RHO1	235.099999999999994	0.0389999999999999999
60987	Q1	233.800000000000011	0.197000000000000008
60987	T2	303.699999999999989	0.117999999999999994
60987	R2	306.399999999999977	0.0160000000000000003
60987	2Q1	224.300000000000011	0.0259999999999999988
60987	P1	260.899999999999977	0.518000000000000016
60987	L2	293	0.171000000000000013
60987	K2	307.800000000000011	0.54500000000000004
60987	M8	18	0.00700000000000000015
60988	M2	267.199999999999989	3.86500000000000021
60988	S2	301.5	1.25299999999999989
60988	N2	240.800000000000011	0.755000000000000004
60988	K1	260.300000000000011	1.37799999999999989
60988	M4	236	0.0200000000000000004
60988	O1	244.5	0.872999999999999998
60988	M6	59.1000000000000014	0.0129999999999999994
60988	NU2	244.400000000000006	0.147999999999999993
60988	S6	23	0.00700000000000000015
60988	MU2	326.399999999999977	0.0919999999999999984
60988	2N2	214.400000000000006	0.101999999999999993
60988	OO1	276.199999999999989	0.0359999999999999973
60988	LDA2	283.100000000000023	0.0259999999999999988
60988	M1	252.5	0.0619999999999999996
60988	J1	268.199999999999989	0.0690000000000000058
60988	RHO1	237.699999999999989	0.0330000000000000016
60988	Q1	236.599999999999994	0.171000000000000013
60988	T2	300.100000000000023	0.0749999999999999972
60988	R2	302.800000000000011	0.0100000000000000002
60988	2Q1	228.699999999999989	0.0229999999999999996
60988	P1	259.100000000000023	0.456000000000000016
60988	L2	293.699999999999989	0.107999999999999999
60988	K2	304.300000000000011	0.341000000000000025
60988	M8	312.300000000000011	0.00300000000000000006
60989	M2	271.699999999999989	6.43700000000000028
60989	S2	304.800000000000011	2.09600000000000009
60989	N2	244.599999999999994	1.33200000000000007
60989	K1	262.899999999999977	1.60400000000000009
60989	M4	269	0.161000000000000004
60989	O1	244.800000000000011	1.02000000000000002
60989	M6	351.300000000000011	0.0129999999999999994
60989	S4	295.199999999999989	0.0299999999999999989
60989	NU2	248.199999999999989	0.259000000000000008
60989	S6	225	0.0100000000000000002
60989	MU2	334.300000000000011	0.153999999999999998
60989	2N2	217.400000000000006	0.176999999999999991
60989	OO1	281.100000000000023	0.0429999999999999966
60989	LDA2	287.100000000000023	0.0459999999999999992
60989	M1	253.900000000000006	0.0719999999999999946
60989	J1	272	0.0820000000000000034
60989	RHO1	237	0.0389999999999999999
60989	Q1	235.800000000000011	0.197000000000000008
60989	T2	303.399999999999977	0.125
60989	R2	306.100000000000023	0.0160000000000000003
60989	2Q1	226.699999999999989	0.0259999999999999988
60989	P1	261.600000000000023	0.531000000000000028
60989	L2	298.899999999999977	0.179999999999999993
60989	K2	307.399999999999977	0.570999999999999952
60989	M8	42.2999999999999972	0.00300000000000000006
60990	M2	270.399999999999977	6.375
60990	S2	305.399999999999977	2.15200000000000014
60990	N2	242.400000000000006	1.30200000000000005
60990	K1	260.199999999999989	1.58499999999999996
60990	M4	268.800000000000011	0.0749999999999999972
60990	O1	244.800000000000011	1.01400000000000001
60990	M6	239.099999999999994	0.00300000000000000006
60990	S4	280.300000000000011	0.0299999999999999989
60990	NU2	246.199999999999989	0.253000000000000003
60990	S6	214.5	0.0100000000000000002
60990	MU2	235.400000000000006	0.153999999999999998
60990	2N2	214.400000000000006	0.173999999999999988
60990	OO1	275.5	0.0429999999999999966
60990	LDA2	286.600000000000023	0.0459999999999999992
60990	M1	252.5	0.0719999999999999946
60990	J1	267.800000000000011	0.0790000000000000008
60990	RHO1	238.199999999999989	0.0389999999999999999
60990	Q1	237.199999999999989	0.197000000000000008
60990	T2	304	0.128000000000000003
60990	R2	306.800000000000011	0.0160000000000000003
60990	2Q1	229.599999999999994	0.0259999999999999988
60990	P1	259	0.525000000000000022
60990	L2	298.399999999999977	0.176999999999999991
60990	K2	308.199999999999989	0.583999999999999964
60990	M8	336.600000000000023	0.0129999999999999994
60991	M2	272.300000000000011	6.49300000000000033
60991	S2	302.699999999999989	2.14599999999999991
60991	N2	241.300000000000011	1.16799999999999993
60991	K1	261.699999999999989	1.70599999999999996
60991	M4	297.100000000000023	0.135000000000000009
60991	O1	245.5	1.03299999999999992
60991	M6	13.5999999999999996	0.00700000000000000015
60991	S4	290.600000000000023	0.0389999999999999999
60991	NU2	245.400000000000006	0.226000000000000006
60991	S6	47.2999999999999972	0.00300000000000000006
60991	MU2	337.800000000000011	0.157000000000000001
60991	2N2	210.199999999999989	0.153999999999999998
60991	OO1	277.800000000000011	0.0459999999999999992
60991	LDA2	286.399999999999977	0.0459999999999999992
60991	M1	253.699999999999989	0.0719999999999999946
60991	J1	269.699999999999989	0.0820000000000000034
60991	RHO1	238.599999999999994	0.0389999999999999999
60991	Q1	237.5	0.200000000000000011
60991	T2	301.5	0.128000000000000003
60991	R2	303.899999999999977	0.0160000000000000003
60991	2Q1	229.5	0.0259999999999999988
60991	P1	260.5	0.563999999999999946
60991	L2	303.399999999999977	0.179999999999999993
60991	K2	305.199999999999989	0.583999999999999964
60991	M8	220.800000000000011	0.0200000000000000004
60992	M2	271.300000000000011	4.18299999999999983
60992	S2	304.899999999999977	1.42399999999999993
60992	N2	250.099999999999994	0.902000000000000024
60992	K1	260.5	1.40700000000000003
60992	M4	260.399999999999977	0.0160000000000000003
60992	O1	247.099999999999994	0.906000000000000028
60992	M6	46.2999999999999972	0.0259999999999999988
60992	NU2	253	0.173999999999999988
60992	S6	47.7999999999999972	0.0100000000000000002
60992	MU2	237.699999999999989	0.0980000000000000038
60992	2N2	229	0.117999999999999994
60992	OO1	274.100000000000023	0.0389999999999999999
60992	LDA2	286.899999999999977	0.0299999999999999989
60992	M1	253.900000000000006	0.0660000000000000031
60992	J1	267.300000000000011	0.0719999999999999946
60992	SSA	161.099999999999994	0.101999999999999993
60992	SA	273.699999999999989	0.377000000000000002
60992	MF	173	0.0889999999999999958
60992	RHO1	241.300000000000011	0.0330000000000000016
60992	Q1	240.400000000000006	0.173999999999999988
60992	T2	303.5	0.0820000000000000034
60992	R2	306.199999999999989	0.0100000000000000002
60992	2Q1	233.699999999999989	0.0229999999999999996
60992	P1	259.5	0.466000000000000025
60992	L2	292.5	0.117999999999999994
60992	K2	307.600000000000023	0.387000000000000011
60992	M8	268.899999999999977	0.0100000000000000002
60993	M2	273	4.43599999999999994
60993	S2	307	1.52200000000000002
60993	N2	252.099999999999994	0.950999999999999956
60993	K1	261.300000000000011	1.42700000000000005
60993	M4	217.099999999999994	0.0229999999999999996
60993	O1	248	0.919000000000000039
60993	M6	104.200000000000003	0.0330000000000000016
60993	S4	274.600000000000023	0.00300000000000000006
60993	NU2	254.800000000000011	0.183999999999999997
60993	S6	52.7999999999999972	0.00300000000000000006
60993	MU2	238.900000000000006	0.104999999999999996
60993	2N2	231.199999999999989	0.125
60993	OO1	274.699999999999989	0.0389999999999999999
60993	LDA2	288.800000000000011	0.0299999999999999989
60993	M1	254.800000000000011	0.0660000000000000031
60993	J1	268	0.0719999999999999946
60993	SSA	161.099999999999994	0.101999999999999993
60993	SA	273.699999999999989	0.377000000000000002
60993	MF	173	0.0889999999999999958
60993	RHO1	242.300000000000011	0.0359999999999999973
60993	Q1	241.400000000000006	0.176999999999999991
60993	T2	305.699999999999989	0.0889999999999999958
60993	R2	308.399999999999977	0.0129999999999999994
60993	2Q1	234.800000000000011	0.0229999999999999996
60993	P1	260.300000000000011	0.471999999999999975
60993	L2	293.899999999999977	0.125
60993	K2	309.699999999999989	0.412999999999999978
60993	M8	223.800000000000011	0.0129999999999999994
60994	M2	272.699999999999989	6.42100000000000026
60994	S2	303.399999999999977	2.17799999999999994
60994	N2	247	1.27299999999999991
60994	K1	263.600000000000023	1.76200000000000001
60994	M4	267.199999999999989	0.150999999999999995
60994	O1	246.400000000000006	1.04000000000000004
60994	M6	300.199999999999989	0.0100000000000000002
60994	S4	346.699999999999989	0.0229999999999999996
60994	NU2	250.5	0.245999999999999996
60994	S6	101.799999999999997	0.00300000000000000006
60994	MU2	336.600000000000023	0.153999999999999998
60994	2N2	221.400000000000006	0.171000000000000013
60994	OO1	281	0.0459999999999999992
60994	LDA2	286.899999999999977	0.0459999999999999992
60994	M1	255.099999999999994	0.0749999999999999972
60994	J1	272.300000000000011	0.0820000000000000034
60994	RHO1	239	0.0389999999999999999
60994	Q1	237.800000000000011	0.203000000000000014
60994	T2	302.100000000000023	0.128000000000000003
60994	R2	304.600000000000023	0.0160000000000000003
60994	2Q1	229.199999999999989	0.0259999999999999988
60994	P1	262.300000000000011	0.583999999999999964
60994	L2	298.300000000000011	0.179999999999999993
60994	K2	305.800000000000011	0.593999999999999972
60994	M8	158.800000000000011	0.00700000000000000015
60995	M2	274.699999999999989	6.77200000000000024
60995	S2	305.199999999999989	2.17499999999999982
60995	N2	251.099999999999994	1.32499999999999996
60995	K1	262	1.6399999999999999
60995	M4	249.099999999999994	0.115000000000000005
60995	O1	249.800000000000011	1.02400000000000002
60995	M6	352.600000000000023	0.0330000000000000016
60995	S4	44.6000000000000014	0.0820000000000000034
60995	NU2	254.300000000000011	0.256000000000000005
60995	S6	92.5	0.0299999999999999989
60995	MU2	341	0.164000000000000007
60995	2N2	227.599999999999994	0.176999999999999991
60995	OO1	274.100000000000023	0.0429999999999999966
60995	LDA2	288.899999999999977	0.0459999999999999992
60995	M1	256	0.0719999999999999946
60995	J1	268	0.0820000000000000034
60995	RHO1	244.599999999999994	0.0389999999999999999
60995	Q1	243.800000000000011	0.200000000000000011
60995	T2	304	0.128000000000000003
60995	R2	306.399999999999977	0.0160000000000000003
60995	2Q1	237.800000000000011	0.0259999999999999988
60995	P1	261.100000000000023	0.54500000000000004
60995	L2	298.199999999999989	0.190000000000000002
60995	K2	307.699999999999989	0.59099999999999997
60995	M8	53.3999999999999986	0.0229999999999999996
60996	M2	273.399999999999977	6.54499999999999993
60996	S2	304.100000000000023	2.16500000000000004
60996	N2	246.400000000000006	1.371
60996	K1	263.399999999999977	1.72900000000000009
60996	M4	260.5	0.203000000000000014
60996	O1	245.900000000000006	1.04299999999999993
60996	M6	11.1999999999999993	0.0229999999999999996
60996	S4	14.8000000000000007	0.0389999999999999999
60996	NU2	250	0.266000000000000014
60996	S6	111.599999999999994	0.00300000000000000006
60996	MU2	338	0.157000000000000001
60996	2N2	219.400000000000006	0.183999999999999997
60996	OO1	280.800000000000011	0.0459999999999999992
60996	LDA2	287.600000000000023	0.0459999999999999992
60996	M1	254.699999999999989	0.0749999999999999972
60996	J1	272	0.0820000000000000034
60996	RHO1	238.5	0.0389999999999999999
60996	Q1	237.300000000000011	0.203000000000000014
60996	T2	302.899999999999977	0.128000000000000003
60996	R2	305.300000000000011	0.0160000000000000003
60996	2Q1	228.599999999999994	0.0259999999999999988
60996	P1	262.100000000000023	0.570999999999999952
60996	L2	300.300000000000011	0.183999999999999997
60996	K2	306.600000000000023	0.586999999999999966
60996	M8	13	0.00700000000000000015
60997	M2	275.699999999999989	4.07500000000000018
60997	S2	307.600000000000023	1.34800000000000009
60997	N2	251.300000000000011	0.842999999999999972
60997	K1	263.100000000000023	1.52600000000000002
60997	M4	281.399999999999977	0.0129999999999999994
60997	O1	248	0.937999999999999945
60997	M6	138	0.00700000000000000015
60997	MK3	258.899999999999977	0.0229999999999999996
60997	MN4	268	0.00300000000000000006
60997	NU2	255.699999999999989	0.164000000000000007
60997	MU2	233.199999999999989	0.0950000000000000011
60997	2N2	226.099999999999994	0.0980000000000000038
60997	OO1	295.199999999999989	0.0519999999999999976
60997	LDA2	292.100000000000023	0.0229999999999999996
60997	S1	43.1000000000000014	0.0299999999999999989
60997	M1	275.899999999999977	0.0490000000000000019
60997	J1	275.399999999999977	0.0850000000000000061
60997	SA	271.100000000000023	0.350999999999999979
60997	MF	196.800000000000011	0.0950000000000000011
60997	RHO1	238.800000000000011	0.0299999999999999989
60997	Q1	240.5	0.16700000000000001
60997	T2	298	0.0719999999999999946
60997	R2	266.600000000000023	0.00300000000000000006
60997	2Q1	238	0.0160000000000000003
60997	P1	260	0.478999999999999981
60997	2SM2	91.7000000000000028	0.00700000000000000015
60997	M3	326.300000000000011	0.0100000000000000002
60997	L2	287.600000000000023	0.0919999999999999984
60997	2MK3	212.900000000000006	0.0160000000000000003
60997	K2	300.199999999999989	0.360999999999999988
60997	MS4	340.5	0.0100000000000000002
60998	M2	270.699999999999989	5.84299999999999997
60998	S2	301.399999999999977	1.97199999999999998
60998	N2	244	1.15799999999999992
60998	K1	262.300000000000011	1.70300000000000007
60998	M4	227.900000000000006	0.0850000000000000061
60998	O1	246.400000000000006	0.993999999999999995
60998	M6	65.2000000000000028	0.0229999999999999996
60998	S4	16	0.0160000000000000003
60998	NU2	247.599999999999994	0.223000000000000004
60998	S6	34.7999999999999972	0.00700000000000000015
60998	MU2	333.899999999999977	0.140999999999999986
60998	2N2	217.400000000000006	0.153999999999999998
60998	OO1	278.5	0.0429999999999999966
60998	LDA2	284.899999999999977	0.0389999999999999999
60998	M1	254.5	0.0719999999999999946
60998	J1	270.399999999999977	0.0790000000000000008
60998	RHO1	239.5	0.0389999999999999999
60998	Q1	238.5	0.194000000000000006
60998	T2	300.199999999999989	0.115000000000000005
60998	R2	302.699999999999989	0.0160000000000000003
60998	2Q1	230.5	0.0259999999999999988
60998	P1	261.100000000000023	0.563999999999999946
60998	L2	297.300000000000011	0.164000000000000007
60998	K2	303.899999999999977	0.538000000000000034
60998	M8	356.199999999999989	0.00700000000000000015
60999	M2	273.199999999999989	6.41099999999999959
60999	S2	304.100000000000023	2.14900000000000002
60999	N2	250.5	1.21399999999999997
60999	K1	264.100000000000023	1.78800000000000003
60999	M4	262.600000000000023	0.150999999999999995
60999	O1	246.400000000000006	1.02400000000000002
60999	M6	353.100000000000023	0.0100000000000000002
60999	S4	348	0.0229999999999999996
60999	NU2	253.599999999999994	0.235999999999999988
60999	S6	173.800000000000011	0.00300000000000000006
60999	MU2	337.199999999999989	0.153999999999999998
60999	2N2	227.900000000000006	0.161000000000000004
60999	OO1	281.800000000000011	0.0429999999999999966
60999	LDA2	287.5	0.0459999999999999992
60999	M1	255.300000000000011	0.0719999999999999946
60999	J1	272.899999999999977	0.0820000000000000034
60999	RHO1	238.800000000000011	0.0389999999999999999
60999	Q1	237.599999999999994	0.200000000000000011
60999	T2	302.800000000000011	0.128000000000000003
60999	R2	305.300000000000011	0.0160000000000000003
60999	2Q1	228.900000000000006	0.0259999999999999988
60999	P1	262.800000000000011	0.59099999999999997
60999	L2	295.899999999999977	0.179999999999999993
60999	K2	306.600000000000023	0.583999999999999964
60999	M8	111.599999999999994	0.00700000000000000015
61000	M2	274.399999999999977	6.51199999999999957
61000	S2	304.5	2.2280000000000002
61000	N2	247.300000000000011	1.29899999999999993
61000	K1	263.899999999999977	1.77800000000000002
61000	M4	275.800000000000011	0.16700000000000001
61000	O1	247.5	1.04299999999999993
61000	M6	23.3000000000000007	0.0200000000000000004
61000	S4	324.699999999999989	0.0389999999999999999
61000	NU2	250.900000000000006	0.253000000000000003
61000	S6	143	0.00300000000000000006
61000	MU2	340.100000000000023	0.157000000000000001
61000	2N2	220.099999999999994	0.173999999999999988
61000	OO1	280.300000000000011	0.0459999999999999992
61000	LDA2	288.399999999999977	0.0459999999999999992
61000	M1	255.800000000000011	0.0749999999999999972
61000	J1	272	0.0820000000000000034
61000	RHO1	240.5	0.0389999999999999999
61000	Q1	239.400000000000006	0.203000000000000014
61000	T2	303.300000000000011	0.131000000000000005
61000	R2	305.699999999999989	0.0160000000000000003
61000	2Q1	231.300000000000011	0.0259999999999999988
61000	P1	262.699999999999989	0.59099999999999997
61000	L2	301.600000000000023	0.183999999999999997
61000	K2	306.899999999999977	0.606999999999999984
61000	M8	84	0.00700000000000000015
61001	M2	273.399999999999977	6.44700000000000006
61001	S2	304.199999999999989	2.129
61001	N2	245.300000000000011	1.34200000000000008
61001	K1	264.100000000000023	1.72599999999999998
61001	M4	260.5	0.20699999999999999
61001	O1	246.300000000000011	1.02699999999999991
61001	M6	13.0999999999999996	0.0129999999999999994
61001	S4	18.8000000000000007	0.0359999999999999973
61001	NU2	249.099999999999994	0.259000000000000008
61001	S6	102.599999999999994	0.00300000000000000006
61001	MU2	337.800000000000011	0.153999999999999998
61001	2N2	217.199999999999989	0.176999999999999991
61001	OO1	281.899999999999977	0.0459999999999999992
61001	LDA2	287.699999999999989	0.0459999999999999992
61001	M1	255.300000000000011	0.0719999999999999946
61001	J1	272.899999999999977	0.0820000000000000034
61001	RHO1	238.699999999999989	0.0389999999999999999
61001	Q1	237.5	0.200000000000000011
61001	T2	303	0.125
61001	R2	305.5	0.0160000000000000003
61001	2Q1	228.699999999999989	0.0259999999999999988
61001	P1	262.800000000000011	0.570999999999999952
61001	L2	301.5	0.179999999999999993
61001	K2	306.699999999999989	0.580999999999999961
61001	M8	224.5	0.00700000000000000015
61002	M2	273.399999999999977	4.92799999999999994
61002	S2	303.699999999999989	1.68599999999999994
61002	N2	252.099999999999994	1.004
61002	K1	261	1.57499999999999996
61002	M4	243	0.0719999999999999946
61002	O1	247.599999999999994	0.932000000000000051
61002	M6	108.400000000000006	0.0200000000000000004
61002	S4	48.2999999999999972	0.00300000000000000006
61002	NU2	255	0.194000000000000006
61002	S6	90	0.00300000000000000006
61002	MU2	335.5	0.117999999999999994
61002	2N2	230.800000000000011	0.135000000000000009
61002	OO1	274.399999999999977	0.0389999999999999999
61002	LDA2	287.5	0.0359999999999999973
61002	M1	254.400000000000006	0.0660000000000000031
61002	J1	267.600000000000023	0.0719999999999999946
61002	RHO1	241.900000000000006	0.0359999999999999973
61002	Q1	241	0.179999999999999993
61002	T2	302.5	0.0980000000000000038
61002	R2	305	0.0129999999999999994
61002	2Q1	234.300000000000011	0.0229999999999999996
61002	P1	260	0.52200000000000002
61002	L2	294.699999999999989	0.138000000000000012
61002	K2	306.199999999999989	0.459000000000000019
61002	M8	89.9000000000000057	0.0160000000000000003
61003	M2	275.399999999999977	6.01400000000000023
61003	S2	306.100000000000023	2.06000000000000005
61003	N2	253.099999999999994	1.21100000000000008
61003	K1	262.600000000000023	1.64399999999999991
61003	M4	246.300000000000011	0.190000000000000002
61003	O1	248.300000000000011	0.996999999999999997
61003	M6	40.8999999999999986	0.0100000000000000002
61003	S4	323.699999999999989	0.0200000000000000004
61003	NU2	256.100000000000023	0.235999999999999988
61003	S6	209	0.0100000000000000002
61003	MU2	338.800000000000011	0.143999999999999989
61003	2N2	230.699999999999989	0.161000000000000004
61003	OO1	276.800000000000011	0.0429999999999999966
61003	LDA2	289.600000000000023	0.0429999999999999966
61003	M1	255.5	0.0719999999999999946
61003	J1	269.600000000000023	0.0790000000000000008
61003	RHO1	242.199999999999989	0.0389999999999999999
61003	Q1	241.199999999999989	0.194000000000000006
61003	T2	304.899999999999977	0.120999999999999996
61003	R2	307.300000000000011	0.0160000000000000003
61003	2Q1	234.099999999999994	0.0259999999999999988
61003	P1	261.5	0.54500000000000004
61003	L2	297.800000000000011	0.16700000000000001
61003	K2	308.600000000000023	0.561000000000000054
61003	M8	150.400000000000006	0.0100000000000000002
61004	M2	279.100000000000023	6.15500000000000025
61004	S2	311.100000000000023	2.1160000000000001
61004	N2	257.600000000000023	1.23399999999999999
61004	K1	264.899999999999977	1.63700000000000001
61004	M4	254.199999999999989	0.197000000000000008
61004	O1	250.599999999999994	1.0069999999999999
61004	M6	86.0999999999999943	0.0330000000000000016
61004	S4	336.5	0.0160000000000000003
61004	NU2	260.5	0.23899999999999999
61004	S6	219	0.0100000000000000002
61004	MU2	341.199999999999989	0.147999999999999993
61004	2N2	236.099999999999994	0.164000000000000007
61004	OO1	279.100000000000023	0.0429999999999999966
61004	LDA2	294	0.0429999999999999966
61004	M1	257.800000000000011	0.0719999999999999946
61004	J1	271.899999999999977	0.0790000000000000008
61004	RHO1	244.5	0.0389999999999999999
61004	Q1	243.599999999999994	0.197000000000000008
61004	T2	309.800000000000011	0.125
61004	R2	312.399999999999977	0.0160000000000000003
61004	2Q1	236.5	0.0259999999999999988
61004	P1	263.800000000000011	0.541000000000000036
61004	L2	300.600000000000023	0.173999999999999988
61004	K2	313.699999999999989	0.573999999999999955
61004	M8	116.5	0.0100000000000000002
61005	M2	290.699999999999989	6.24699999999999989
61005	S2	326.800000000000011	2.1549999999999998
61005	N2	273.199999999999989	1.26000000000000001
61005	K1	271.5	1.61099999999999999
61005	M4	159.599999999999994	0.112000000000000002
61005	O1	257.600000000000023	1.03000000000000003
61005	M6	116.799999999999997	0.107999999999999999
61005	S4	239.099999999999994	0.0389999999999999999
61005	NU2	275.5	0.245999999999999996
61005	S6	251.099999999999994	0.00700000000000000015
61005	MU2	348.699999999999989	0.150999999999999995
61005	2N2	255.699999999999989	0.16700000000000001
61005	OO1	285.5	0.0459999999999999992
61005	LDA2	307.399999999999977	0.0429999999999999966
61005	M1	264.600000000000023	0.0719999999999999946
61005	J1	278.399999999999977	0.0820000000000000034
61005	RHO1	251.599999999999994	0.0389999999999999999
61005	Q1	250.599999999999994	0.200000000000000011
61005	T2	325.399999999999977	0.128000000000000003
61005	R2	328.300000000000011	0.0160000000000000003
61005	2Q1	243.699999999999989	0.0259999999999999988
61005	P1	270.5	0.531000000000000028
61005	L2	308.199999999999989	0.173999999999999988
61005	K2	329.699999999999989	0.586999999999999966
61005	M8	39.7000000000000028	0.0100000000000000002
61006	M2	293	6.39100000000000001
61006	S2	329.199999999999989	2.21099999999999985
61006	N2	275.800000000000011	1.28000000000000003
61006	K1	271.800000000000011	1.6080000000000001
61006	M4	132.599999999999994	0.176999999999999991
61006	O1	258.800000000000011	1.03299999999999992
61006	M6	127	0.131000000000000005
61006	S4	241.099999999999994	0.0589999999999999969
61006	NU2	278.100000000000023	0.248999999999999999
61006	S6	10.9000000000000004	0.00700000000000000015
61006	MU2	351	0.153999999999999998
61006	2N2	258.699999999999989	0.171000000000000013
61006	OO1	284.800000000000011	0.0459999999999999992
61006	LDA2	309.800000000000011	0.0459999999999999992
61006	M1	265.300000000000011	0.0719999999999999946
61006	J1	278.199999999999989	0.0820000000000000034
61006	SSA	161.099999999999994	0.101999999999999993
61006	SA	273.699999999999989	0.377000000000000002
61006	RHO1	253.199999999999989	0.0389999999999999999
61006	Q1	252.300000000000011	0.200000000000000011
61006	T2	327.800000000000011	0.131000000000000005
61006	R2	330.699999999999989	0.0160000000000000003
61006	2Q1	245.800000000000011	0.0259999999999999988
61006	P1	270.800000000000011	0.531000000000000028
61006	L2	310.199999999999989	0.179999999999999993
61006	K2	332.100000000000023	0.599999999999999978
61006	M8	345.399999999999977	0.0299999999999999989
61007	M2	286.899999999999977	5.98099999999999987
61007	S2	320.699999999999989	2.09299999999999997
61007	N2	266.600000000000023	1.21399999999999997
61007	K1	266.5	1.64399999999999991
61007	M4	15.3000000000000007	0.101999999999999993
61007	O1	252.400000000000006	0.983999999999999986
61007	M6	82.5	0.112000000000000002
61007	S4	166.800000000000011	0.00700000000000000015
61007	NU2	269.399999999999977	0.235999999999999988
61007	S6	47.6000000000000014	0.00300000000000000006
61007	MU2	345.699999999999989	0.143999999999999989
61007	2N2	246.300000000000011	0.161000000000000004
61007	OO1	280.600000000000023	0.0429999999999999966
61007	LDA2	302.600000000000023	0.0429999999999999966
61007	M1	259.5	0.0690000000000000058
61007	J1	273.5	0.0790000000000000008
61007	RHO1	246.400000000000006	0.0359999999999999973
61007	Q1	245.400000000000006	0.190000000000000002
61007	T2	319.300000000000011	0.125
61007	R2	322	0.0160000000000000003
61007	2Q1	238.5	0.0259999999999999988
61007	P1	265.5	0.54500000000000004
61007	L2	307.199999999999989	0.16700000000000001
61007	K2	323.399999999999977	0.570999999999999952
61007	M8	88.0999999999999943	0.0229999999999999996
61008	M2	272.699999999999989	3.53299999999999992
61008	S2	305	1.10200000000000009
61008	N2	248.300000000000011	0.714999999999999969
61008	K1	261.199999999999989	1.40399999999999991
61008	M4	336.199999999999989	0.00300000000000000006
61008	O1	243.199999999999989	0.883000000000000007
61008	M6	218.900000000000006	0.00300000000000000006
61008	S4	355.399999999999977	0.00300000000000000006
61008	NU2	251.599999999999994	0.138000000000000012
61008	S6	149.300000000000011	0.0100000000000000002
61008	MU2	329.600000000000023	0.0850000000000000061
61008	2N2	224	0.0950000000000000011
61008	OO1	279.300000000000011	0.0389999999999999999
61008	LDA2	287.699999999999989	0.0259999999999999988
61008	M1	252.300000000000011	0.0619999999999999996
61008	J1	270.199999999999989	0.0690000000000000058
61008	RHO1	235.400000000000006	0.0330000000000000016
61008	Q1	234.199999999999989	0.171000000000000013
61008	T2	303.699999999999989	0.0660000000000000031
61008	R2	306.300000000000011	0.0100000000000000002
61008	2Q1	225.300000000000011	0.0229999999999999996
61008	P1	259.899999999999977	0.466000000000000025
61008	L2	297.100000000000023	0.0980000000000000038
61008	K2	307.600000000000023	0.298999999999999988
61008	M8	120.900000000000006	0.00700000000000000015
61009	M2	283	6.42400000000000038
61009	S2	319.699999999999989	2.09600000000000009
61009	N2	263.399999999999977	1.23999999999999999
61009	K1	267.899999999999977	1.59099999999999997
61009	M4	47.5	0.125
61009	O1	250.699999999999989	0.983999999999999986
61009	M6	284.100000000000023	0.0229999999999999996
61009	S4	130.5	0.0200000000000000004
61009	NU2	266	0.23899999999999999
61009	S6	68.5	0.00300000000000000006
61009	MU2	341.399999999999977	0.153999999999999998
61009	2N2	243.699999999999989	0.164000000000000007
61009	OO1	285	0.0429999999999999966
61009	LDA2	300	0.0459999999999999992
61009	M1	259.399999999999977	0.0690000000000000058
61009	J1	276.399999999999977	0.0790000000000000008
61009	RHO1	243.400000000000006	0.0359999999999999973
61009	Q1	242.199999999999989	0.190000000000000002
61009	T2	318.199999999999989	0.125
61009	R2	321.100000000000023	0.0160000000000000003
61009	2Q1	233.699999999999989	0.0259999999999999988
61009	P1	266.600000000000023	0.525000000000000022
61009	L2	302.699999999999989	0.179999999999999993
61009	K2	322.600000000000023	0.570999999999999952
61009	M8	130.699999999999989	0.0129999999999999994
61010	M2	287	6.3019999999999996
61010	S2	322.199999999999989	1.998
61010	N2	264.399999999999977	1.13500000000000001
61010	K1	272.399999999999977	1.68599999999999994
61010	M4	112.200000000000003	0.0790000000000000008
61010	O1	253.400000000000006	0.970999999999999974
61010	M6	125.299999999999997	0.0919999999999999984
61010	S4	142.099999999999994	0.0160000000000000003
61010	NU2	267.5	0.220000000000000001
61010	S6	15.9000000000000004	0.0100000000000000002
61010	MU2	345.899999999999977	0.150999999999999995
61010	2N2	241.900000000000006	0.150999999999999995
61010	OO1	291.300000000000011	0.0429999999999999966
61010	LDA2	303.300000000000011	0.0429999999999999966
61010	M1	263	0.0690000000000000058
61010	J1	281.800000000000011	0.0749999999999999972
61010	RHO1	245.300000000000011	0.0359999999999999973
61010	Q1	244	0.187
61010	T2	320.800000000000011	0.117999999999999994
61010	R2	323.600000000000023	0.0160000000000000003
61010	2Q1	234.599999999999994	0.0259999999999999988
61010	P1	270.899999999999977	0.558000000000000052
61010	L2	309.600000000000023	0.176999999999999991
61010	K2	325	0.54500000000000004
61010	M8	28	0.0229999999999999996
61011	M2	279.699999999999989	5.75499999999999989
61011	S2	313.199999999999989	1.76800000000000002
61011	N2	255.900000000000006	1.09899999999999998
61011	K1	265.800000000000011	1.57800000000000007
61011	M4	354.300000000000011	0.0660000000000000031
61011	O1	247.400000000000006	0.980999999999999983
61011	M6	77.5	0.0229999999999999996
61011	S4	53.2000000000000028	0.0129999999999999994
61011	NU2	259.100000000000023	0.212999999999999995
61011	S6	91.2000000000000028	0.00300000000000000006
61011	MU2	338.600000000000023	0.138000000000000012
61011	2N2	232	0.147999999999999993
61011	OO1	284.199999999999989	0.0429999999999999966
61011	LDA2	295.300000000000011	0.0389999999999999999
61011	M1	256.699999999999989	0.0690000000000000058
61011	J1	274.899999999999977	0.0790000000000000008
61011	RHO1	239.5	0.0359999999999999973
61011	Q1	238.300000000000011	0.190000000000000002
61011	T2	311.899999999999977	0.104999999999999996
61011	R2	314.600000000000023	0.0129999999999999994
61011	2Q1	229.199999999999989	0.0259999999999999988
61011	P1	264.399999999999977	0.52200000000000002
61011	L2	303.5	0.161000000000000004
61011	K2	315.899999999999977	0.481999999999999984
61011	M8	36	0.0200000000000000004
61012	M2	279.699999999999989	4.95399999999999974
61012	S2	316.100000000000023	1.68300000000000005
61012	N2	252.099999999999994	0.983999999999999986
61012	K1	264	1.52899999999999991
61012	M4	14.5999999999999996	0.101999999999999993
61012	O1	247.699999999999989	0.97799999999999998
61012	M6	38.2999999999999972	0.0160000000000000003
61012	S4	42.1000000000000014	0.00300000000000000006
61012	NU2	255.800000000000011	0.190000000000000002
61012	S6	9.40000000000000036	0.00300000000000000006
61012	MU2	243.300000000000011	0.117999999999999994
61012	2N2	224.5	0.131000000000000005
61012	OO1	280.300000000000011	0.0429999999999999966
61012	LDA2	296.600000000000023	0.0359999999999999973
61012	M1	255.900000000000006	0.0690000000000000058
61012	J1	272.100000000000023	0.0790000000000000008
61012	RHO1	240.699999999999989	0.0359999999999999973
61012	Q1	239.699999999999989	0.190000000000000002
61012	T2	314.600000000000023	0.0980000000000000038
61012	R2	317.5	0.0129999999999999994
61012	2Q1	231.599999999999994	0.0259999999999999988
61012	P1	262.800000000000011	0.505000000000000004
61012	L2	307.300000000000011	0.138000000000000012
61012	K2	319	0.456000000000000016
61012	M8	81.4000000000000057	0.00300000000000000006
61013	M2	276.300000000000011	5.3019999999999996
61013	S2	305.699999999999989	1.76800000000000002
61013	N2	254.099999999999994	0.964999999999999969
61013	K1	262.800000000000011	1.68999999999999995
61013	M4	358.100000000000023	0.0749999999999999972
61013	O1	246.5	0.944999999999999951
61013	S4	46.8999999999999986	0.0100000000000000002
61013	NU2	257.100000000000023	0.187
61013	S6	232.800000000000011	0.00300000000000000006
61013	MU2	247	0.128000000000000003
61013	2N2	232	0.128000000000000003
61013	OO1	279.100000000000023	0.0389999999999999999
61013	LDA2	289.899999999999977	0.0359999999999999973
61013	M1	254.699999999999989	0.0660000000000000031
61013	J1	270.800000000000011	0.0749999999999999972
61013	SA	274.800000000000011	0.39700000000000002
61013	MF	176.800000000000011	0.0889999999999999958
61013	RHO1	239.5	0.0359999999999999973
61013	Q1	238.400000000000006	0.183999999999999997
61013	T2	304.5	0.104999999999999996
61013	R2	306.800000000000011	0.0129999999999999994
61013	2Q1	230.300000000000011	0.0229999999999999996
61013	P1	261.5	0.558000000000000052
61013	L2	298.5	0.147999999999999993
61013	K2	308	0.481999999999999984
61013	M8	144.599999999999994	0.00700000000000000015
61014	M2	279.399999999999977	5.65299999999999958
61014	S2	313.600000000000023	1.87999999999999989
61014	N2	254.300000000000011	1.21100000000000008
61014	K1	259.899999999999977	1.627
61014	M4	21.8000000000000007	0.0950000000000000011
61014	O1	251.199999999999989	0.987999999999999989
61014	M6	285	0.0129999999999999994
61014	S4	39.1000000000000014	0.0160000000000000003
61014	NU2	257.600000000000023	0.235999999999999988
61014	S6	66.2000000000000028	0.00300000000000000006
61014	MU2	337.300000000000011	0.135000000000000009
61014	2N2	229.199999999999989	0.161000000000000004
61014	OO1	268.5	0.0429999999999999966
61014	LDA2	295.300000000000011	0.0389999999999999999
61014	M1	255.599999999999994	0.0690000000000000058
61014	J1	264.100000000000023	0.0790000000000000008
61014	RHO1	247.5	0.0359999999999999973
61014	Q1	246.900000000000006	0.190000000000000002
61014	T2	312.300000000000011	0.112000000000000002
61014	R2	315	0.0160000000000000003
61014	2Q1	242.699999999999989	0.0259999999999999988
61014	P1	259.199999999999989	0.538000000000000034
61014	L2	304.399999999999977	0.157000000000000001
61014	K2	316.399999999999977	0.512000000000000011
61014	M8	50.2000000000000028	0.00300000000000000006
61015	M2	273.800000000000011	3.629
61015	S2	304.899999999999977	1.16500000000000004
61015	N2	249.199999999999989	0.755000000000000004
61015	K1	259.899999999999977	1.51600000000000001
61015	O1	244.400000000000006	0.919000000000000039
61015	NU2	253.599999999999994	0.143999999999999989
61015	MU2	228.699999999999989	0.0850000000000000061
61015	2N2	223.800000000000011	0.0889999999999999958
61015	OO1	289.100000000000023	0.0519999999999999976
61015	LDA2	293	0.0259999999999999988
61015	S1	35.2999999999999972	0.0359999999999999973
61015	M1	273.399999999999977	0.0519999999999999976
61015	J1	272.899999999999977	0.0889999999999999958
61015	SA	274.800000000000011	0.39700000000000002
61015	MF	176.800000000000011	0.0889999999999999958
61015	RHO1	238.900000000000006	0.0330000000000000016
61015	Q1	237.199999999999989	0.161000000000000004
61015	T2	296.600000000000023	0.0690000000000000058
61015	R2	306	0.0100000000000000002
61015	2Q1	240.5	0.0160000000000000003
61015	P1	257.600000000000023	0.475999999999999979
61015	L2	288.800000000000011	0.0790000000000000008
61015	K2	298.399999999999977	0.322000000000000008
61016	M2	279.300000000000011	5.38999999999999968
61016	S2	310	1.877
61016	N2	255.5	1.07299999999999995
61016	K1	262.300000000000011	1.59800000000000009
61016	M4	0.599999999999999978	0.0660000000000000031
61016	O1	248.699999999999989	0.957999999999999963
61016	M6	299.899999999999977	0.0100000000000000002
61016	S4	134.800000000000011	0.00300000000000000006
61016	NU2	258.699999999999989	0.209999999999999992
61016	S6	198.099999999999994	0.00300000000000000006
61016	MU2	338.899999999999977	0.128000000000000003
61016	2N2	231.800000000000011	0.143999999999999989
61016	OO1	275.899999999999977	0.0429999999999999966
61016	LDA2	293.600000000000023	0.0389999999999999999
61016	M1	255.5	0.0690000000000000058
61016	J1	269.100000000000023	0.0749999999999999972
61016	RHO1	242.800000000000011	0.0359999999999999973
61016	Q1	241.900000000000006	0.187
61016	T2	308.800000000000011	0.112000000000000002
61016	R2	311.300000000000011	0.0160000000000000003
61016	2Q1	235.099999999999994	0.0259999999999999988
61016	P1	261.300000000000011	0.528000000000000025
61016	L2	303	0.150999999999999995
61016	K2	312.5	0.512000000000000011
61016	M8	135	0.00700000000000000015
61017	M2	276.600000000000023	3.64500000000000002
61017	S2	309.699999999999989	1.14500000000000002
61017	N2	248.800000000000011	0.751000000000000001
61017	K1	264	1.44399999999999995
61017	M4	139.400000000000006	0.0100000000000000002
61017	O1	246.699999999999989	0.935000000000000053
61017	M6	24.8000000000000007	0.0100000000000000002
61017	S4	219.300000000000011	0.00700000000000000015
61017	NU2	252.5	0.143999999999999989
61017	S6	211.5	0.00300000000000000006
61017	MU2	243.400000000000006	0.0889999999999999958
61017	2N2	221	0.0980000000000000038
61017	OO1	281.199999999999989	0.0389999999999999999
61017	LDA2	291.899999999999977	0.0259999999999999988
61017	M1	255.400000000000006	0.0660000000000000031
61017	J1	272.5	0.0719999999999999946
61017	SA	274.800000000000011	0.39700000000000002
61017	MF	176.800000000000011	0.0889999999999999958
61017	RHO1	239.300000000000011	0.0359999999999999973
61017	Q1	238.099999999999994	0.179999999999999993
61017	T2	308.399999999999977	0.0690000000000000058
61017	R2	311.100000000000023	0.0100000000000000002
61017	2Q1	229.599999999999994	0.0229999999999999996
61017	P1	262.699999999999989	0.478999999999999981
61017	L2	304.300000000000011	0.101999999999999993
61017	K2	312.399999999999977	0.312
61017	M8	152.800000000000011	0.0100000000000000002
61018	M2	280	5.88600000000000012
61018	S2	312.800000000000011	1.93900000000000006
61018	N2	257.600000000000023	1.20399999999999996
61018	K1	264.300000000000011	1.6399999999999999
61018	M4	8.09999999999999964	0.0889999999999999958
61018	O1	248.5	0.987999999999999989
61018	M6	219.599999999999994	0.00700000000000000015
61018	S4	31.1000000000000014	0.0160000000000000003
61018	NU2	260.600000000000023	0.233000000000000013
61018	S6	43	0.00300000000000000006
61018	MU2	247.300000000000011	0.140999999999999986
61018	2N2	235.099999999999994	0.157000000000000001
61018	OO1	280.100000000000023	0.0429999999999999966
61018	LDA2	295.300000000000011	0.0429999999999999966
61018	M1	256.5	0.0690000000000000058
61018	J1	272.199999999999989	0.0790000000000000008
61018	SA	255.599999999999994	0.262000000000000011
61018	MF	176.099999999999994	0.0820000000000000034
61018	RHO1	241.699999999999989	0.0359999999999999973
61018	Q1	240.699999999999989	0.190000000000000002
61018	T2	311.5	0.115000000000000005
61018	R2	314.100000000000023	0.0160000000000000003
61018	2Q1	232.800000000000011	0.0259999999999999988
61018	P1	263.100000000000023	0.541000000000000036
61018	L2	302.300000000000011	0.164000000000000007
61018	K2	315.5	0.528000000000000025
61019	M2	273.5	3.56000000000000005
61019	S2	304.800000000000011	1.125
61019	N2	251	0.758000000000000007
61019	K1	263.800000000000011	1.55800000000000005
61019	M4	292.399999999999977	0.00300000000000000006
61019	O1	244.400000000000006	0.964999999999999969
61019	M6	341.199999999999989	0.00700000000000000015
61019	NU2	254	0.147999999999999993
61019	MU2	330.899999999999977	0.0850000000000000061
61019	2N2	228.400000000000006	0.101999999999999993
61019	OO1	283.199999999999989	0.0429999999999999966
61019	LDA2	288	0.0259999999999999988
61019	M1	254.099999999999994	0.0690000000000000058
61019	J1	273.399999999999977	0.0749999999999999972
61019	SA	274.800000000000011	0.39700000000000002
61019	MF	176.800000000000011	0.0889999999999999958
61019	RHO1	236	0.0359999999999999973
61019	Q1	234.699999999999989	0.187
61019	T2	303.5	0.0660000000000000031
61019	R2	306	0.0100000000000000002
61019	2Q1	225.099999999999994	0.0259999999999999988
61019	P1	262.300000000000011	0.515000000000000013
61019	L2	296.100000000000023	0.0980000000000000038
61019	K2	307.300000000000011	0.304999999999999993
61019	M8	191.800000000000011	0.00300000000000000006
61020	M2	282.399999999999977	4.91099999999999959
61020	S2	314.5	1.61099999999999999
61020	N2	261.199999999999989	1.06299999999999994
61020	K1	266.199999999999989	1.65700000000000003
61020	M4	35	0.115000000000000005
61020	O1	247.800000000000011	0.973999999999999977
61020	M6	167.5	0.0359999999999999973
61020	S4	41	0.0129999999999999994
61020	NU2	264.100000000000023	0.20699999999999999
61020	MU2	339	0.117999999999999994
61020	2N2	240.099999999999994	0.140999999999999986
61020	OO1	284.600000000000023	0.0429999999999999966
61020	LDA2	297.300000000000011	0.0330000000000000016
61020	M1	257.100000000000023	0.0690000000000000058
61020	J1	275.399999999999977	0.0749999999999999972
61020	SA	274.800000000000011	0.39700000000000002
61020	MF	176.800000000000011	0.0889999999999999958
61020	RHO1	239.900000000000006	0.0359999999999999973
61020	Q1	238.699999999999989	0.190000000000000002
61020	T2	313.199999999999989	0.0950000000000000011
61020	R2	315.699999999999989	0.0129999999999999994
61020	2Q1	229.599999999999994	0.0259999999999999988
61020	P1	264.899999999999977	0.548000000000000043
61020	L2	303.5	0.138000000000000012
61020	K2	317.100000000000023	0.440000000000000002
61020	M8	268.199999999999989	0.00700000000000000015
61021	M2	281.199999999999989	5.83699999999999974
61021	S2	313.199999999999989	1.96199999999999997
61021	N2	259.100000000000023	1.21399999999999997
61021	K1	266.699999999999989	1.68599999999999994
61021	M4	21	0.104999999999999996
61021	O1	248.599999999999994	0.990999999999999992
61021	M6	122.799999999999997	0.0459999999999999992
61021	S4	14	0.0160000000000000003
61021	NU2	262	0.235999999999999988
61021	MU2	338	0.140999999999999986
61021	2N2	236.900000000000006	0.161000000000000004
61021	OO1	284.899999999999977	0.0429999999999999966
61021	LDA2	296.100000000000023	0.0389999999999999999
61021	M1	257.699999999999989	0.0690000000000000058
61021	J1	275.699999999999989	0.0790000000000000008
61021	SA	274.800000000000011	0.39700000000000002
61021	MF	176.800000000000011	0.0889999999999999958
61021	RHO1	240.800000000000011	0.0359999999999999973
61021	Q1	239.5	0.190000000000000002
61021	T2	311.899999999999977	0.115000000000000005
61021	R2	314.5	0.0160000000000000003
61021	2Q1	230.5	0.0259999999999999988
61021	P1	265.300000000000011	0.558000000000000052
61021	L2	303.300000000000011	0.164000000000000007
61021	K2	315.800000000000011	0.535000000000000031
61021	M8	308.399999999999977	0.0100000000000000002
61022	M2	328.399999999999977	4.00900000000000034
61022	S2	10.0999999999999996	1.25
61022	N2	317.300000000000011	0.755000000000000004
61022	K1	296	1.31600000000000006
61022	M4	196.400000000000006	0.0889999999999999958
61022	O1	284.5	0.872999999999999998
61022	M6	261.199999999999989	0.117999999999999994
61022	S4	278.300000000000011	0.0330000000000000016
61022	NU2	318.800000000000011	0.147999999999999993
61022	S6	160.699999999999989	0.00700000000000000015
61022	MU2	17.8999999999999986	0.0950000000000000011
61022	2N2	306.300000000000011	0.101999999999999993
61022	OO1	307.5	0.0359999999999999973
61022	LDA2	347.800000000000011	0.0299999999999999989
61022	M1	290.300000000000011	0.0619999999999999996
61022	J1	301.699999999999989	0.0690000000000000058
61022	RHO1	279.600000000000023	0.0330000000000000016
61022	Q1	278.800000000000011	0.171000000000000013
61022	T2	8.40000000000000036	0.0749999999999999972
61022	R2	11.8000000000000007	0.0100000000000000002
61022	2Q1	273.100000000000023	0.0229999999999999996
61022	P1	295.100000000000023	0.435999999999999999
61022	L2	339.5	0.112000000000000002
61022	K2	13.5	0.341000000000000025
61022	M8	139.5	0.0160000000000000003
61023	M2	282.5	6.54499999999999993
61023	S2	315.5	2.23099999999999987
61023	N2	258.199999999999989	1.32899999999999996
61023	K1	265	1.70599999999999996
61023	M4	8.90000000000000036	0.125
61023	O1	250.199999999999989	1.02000000000000002
61023	M6	239.800000000000011	0.0160000000000000003
61023	MK3	255.199999999999989	0.0889999999999999958
61023	S4	55.6000000000000014	0.0160000000000000003
61023	MN4	335.800000000000011	0.0490000000000000019
61023	NU2	262.800000000000011	0.256000000000000005
61023	MU2	251.699999999999989	0.147999999999999993
61023	2N2	231.400000000000006	0.153999999999999998
61023	OO1	294	0.0589999999999999969
61023	LDA2	285.699999999999989	0.0429999999999999966
61023	S1	55.6000000000000014	0.0259999999999999988
61023	M1	281	0.0560000000000000012
61023	J1	277.699999999999989	0.101999999999999993
61023	SA	255.599999999999994	0.262000000000000011
61023	MF	176.099999999999994	0.0820000000000000034
61023	RHO1	241.400000000000006	0.0330000000000000016
61023	Q1	243.699999999999989	0.179999999999999993
61023	T2	309.600000000000023	0.117999999999999994
61023	R2	9.59999999999999964	0.0129999999999999994
61023	2Q1	241.599999999999994	0.0200000000000000004
61023	P1	263.699999999999989	0.538000000000000034
61023	2SM2	96.5999999999999943	0.0160000000000000003
61023	M3	0.800000000000000044	0.0429999999999999966
61023	L2	289.199999999999989	0.147999999999999993
61023	2MK3	197.300000000000011	0.0660000000000000031
61023	K2	309	0.622999999999999998
61023	MS4	47.7000000000000028	0.0719999999999999946
61024	M2	281.600000000000023	5.99699999999999989
61024	S2	315.5	1.93599999999999994
61024	N2	258.199999999999989	1.21999999999999997
61024	K1	266.100000000000023	1.6399999999999999
61024	M4	27.6000000000000014	0.131000000000000005
61024	O1	249.400000000000006	1.02000000000000002
61024	M6	16.6999999999999993	0.00700000000000000015
61024	S4	294.600000000000023	0.00300000000000000006
61024	NU2	261.300000000000011	0.235999999999999988
61024	S6	24	0.00700000000000000015
61024	MU2	338.100000000000023	0.143999999999999989
61024	2N2	234.900000000000006	0.164000000000000007
61024	OO1	282.899999999999977	0.0429999999999999966
61024	LDA2	297.300000000000011	0.0429999999999999966
61024	M1	257.899999999999977	0.0719999999999999946
61024	J1	274.399999999999977	0.0820000000000000034
61024	SA	255.599999999999994	0.262000000000000011
61024	MF	176.099999999999994	0.0820000000000000034
61024	RHO1	242.199999999999989	0.0389999999999999999
61024	Q1	241.099999999999994	0.197000000000000008
61024	T2	314.100000000000023	0.115000000000000005
61024	R2	316.800000000000011	0.0160000000000000003
61024	2Q1	232.800000000000011	0.0259999999999999988
61024	P1	264.899999999999977	0.54500000000000004
61024	L2	304.899999999999977	0.16700000000000001
61024	K2	318.199999999999989	0.525000000000000022
61024	M8	337.399999999999977	0.0100000000000000002
61025	M2	283.199999999999989	5.94500000000000028
61025	S2	314.100000000000023	2.08300000000000018
61025	N2	259.600000000000023	1.21100000000000008
61025	K1	263.399999999999977	1.65700000000000003
61025	M4	27.8999999999999986	0.107999999999999999
61025	O1	249.5	0.993999999999999995
61025	M6	27.6000000000000014	0.0330000000000000016
61025	S4	134	0.0129999999999999994
61025	NU2	262.699999999999989	0.235999999999999988
61025	S6	208.900000000000006	0.0100000000000000002
61025	MU2	342.399999999999977	0.143999999999999989
61025	2N2	236	0.161000000000000004
61025	OO1	277.300000000000011	0.0429999999999999966
61025	LDA2	297.600000000000023	0.0429999999999999966
61025	M1	256.5	0.0719999999999999946
61025	J1	270.300000000000011	0.0790000000000000008
61025	RHO1	243.5	0.0389999999999999999
61025	Q1	242.599999999999994	0.194000000000000006
61025	T2	312.899999999999977	0.125
61025	R2	315.399999999999977	0.0160000000000000003
61025	2Q1	235.699999999999989	0.0259999999999999988
61025	P1	262.399999999999977	0.548000000000000043
61025	L2	306.800000000000011	0.16700000000000001
61025	K2	316.699999999999989	0.567999999999999949
61025	M8	113.299999999999997	0.0100000000000000002
61026	M2	284.100000000000023	6.65700000000000003
61026	S2	317.899999999999977	2.29999999999999982
61026	N2	260.300000000000011	1.35200000000000009
61026	K1	265.600000000000023	1.73599999999999999
61026	M4	26	0.135000000000000009
61026	O1	250.5	1.04000000000000004
61026	M6	69	0.0560000000000000012
61026	MK3	267.600000000000023	0.0749999999999999972
61026	S4	78.2999999999999972	0.0129999999999999994
61026	MN4	358.100000000000023	0.0519999999999999976
61026	NU2	263	0.262000000000000011
61026	MU2	255.900000000000006	0.161000000000000004
61026	2N2	235.900000000000006	0.161000000000000004
61026	OO1	295.100000000000023	0.0589999999999999969
61026	LDA2	273	0.0459999999999999992
61026	S1	50.5	0.0229999999999999996
61026	M1	276.300000000000011	0.0560000000000000012
61026	J1	280.800000000000011	0.101999999999999993
61026	MM	143.5	0.0519999999999999976
61026	SSA	312.699999999999989	0.0259999999999999988
61026	SA	191.5	0.220000000000000001
61026	MSF	20.1000000000000014	0.0330000000000000016
61026	MF	197.099999999999994	0.0950000000000000011
61026	RHO1	240.900000000000006	0.0359999999999999973
61026	Q1	243.599999999999994	0.183999999999999997
61026	T2	314.800000000000011	0.117999999999999994
61026	R2	95.7000000000000028	0.0200000000000000004
61026	2Q1	242.199999999999989	0.0229999999999999996
61026	P1	261.399999999999977	0.541000000000000036
61026	2SM2	93.7000000000000028	0.0259999999999999988
61026	M3	359.600000000000023	0.0459999999999999992
61026	L2	289.699999999999989	0.153999999999999998
61026	2MK3	201.400000000000006	0.0459999999999999992
61026	K2	310.600000000000023	0.61399999999999999
61026	M8	207.099999999999994	0.00700000000000000015
61026	MS4	64.2000000000000028	0.0820000000000000034
61027	M2	282.800000000000011	6.48000000000000043
61027	S2	316.600000000000023	2.19499999999999984
61027	N2	257.600000000000023	1.27000000000000002
61027	K1	267.399999999999977	1.63100000000000001
61027	M4	27.8000000000000007	0.101999999999999993
61027	O1	249.5	1.01000000000000001
61027	M6	72.9000000000000057	0.0560000000000000012
61027	S4	88	0.00300000000000000006
61027	NU2	261	0.245999999999999996
61027	S6	223.5	0.0100000000000000002
61027	MU2	338.300000000000011	0.153999999999999998
61027	2N2	232.400000000000006	0.171000000000000013
61027	OO1	285.300000000000011	0.0429999999999999966
61027	LDA2	298.5	0.0459999999999999992
61027	M1	258.5	0.0719999999999999946
61027	J1	276.300000000000011	0.0790000000000000008
61027	SA	190	0.194000000000000006
61027	RHO1	241.800000000000011	0.0389999999999999999
61027	Q1	240.599999999999994	0.197000000000000008
61027	T2	315.300000000000011	0.128000000000000003
61027	R2	318	0.0160000000000000003
61027	2Q1	231.699999999999989	0.0259999999999999988
61027	P1	266.100000000000023	0.538000000000000034
61027	L2	308.100000000000023	0.179999999999999993
61027	K2	319.300000000000011	0.596999999999999975
61027	M8	0.599999999999999978	0.00300000000000000006
61028	M2	284.199999999999989	5.96799999999999997
61028	S2	319.800000000000011	1.95500000000000007
61028	N2	263.5	1.22999999999999998
61028	K1	263.300000000000011	1.69900000000000007
61028	M4	32.3999999999999986	0.0850000000000000061
61028	O1	252.5	1.0169999999999999
61028	M6	48.8999999999999986	0.0160000000000000003
61028	S4	68.5	0.0200000000000000004
61028	NU2	266.300000000000011	0.23899999999999999
61028	S6	45.8999999999999986	0.0100000000000000002
61028	MU2	337.800000000000011	0.143999999999999989
61028	2N2	242.800000000000011	0.164000000000000007
61028	OO1	274.100000000000023	0.0429999999999999966
61028	LDA2	300.699999999999989	0.0429999999999999966
61028	M1	257.899999999999977	0.0719999999999999946
61028	J1	268.600000000000023	0.0820000000000000034
61028	RHO1	247.800000000000011	0.0389999999999999999
61028	Q1	247.099999999999994	0.197000000000000008
61028	T2	318.399999999999977	0.115000000000000005
61028	R2	321.199999999999989	0.0160000000000000003
61028	2Q1	241.800000000000011	0.0259999999999999988
61028	P1	262.5	0.561000000000000054
61028	L2	304.899999999999977	0.16700000000000001
61028	K2	322.699999999999989	0.531000000000000028
61028	M8	263.100000000000023	0.00700000000000000015
61029	M2	298.699999999999989	6.61399999999999988
61029	S2	335	2.129
61029	N2	277.100000000000023	1.20700000000000007
61029	K1	273.5	1.752
61029	M4	147.400000000000006	0.143999999999999989
61029	O1	258.100000000000023	1.02000000000000002
61029	M6	223.699999999999989	0.0719999999999999946
61029	S4	181.699999999999989	0.0160000000000000003
61029	NU2	280	0.233000000000000013
61029	MU2	350.199999999999989	0.157000000000000001
61029	2N2	255.5	0.161000000000000004
61029	OO1	288.800000000000011	0.0429999999999999966
61029	LDA2	315.5	0.0459999999999999992
61029	M1	265.800000000000011	0.0719999999999999946
61029	J1	281.100000000000023	0.0820000000000000034
61029	RHO1	251.5	0.0389999999999999999
61029	Q1	250.5	0.197000000000000008
61029	T2	333.600000000000023	0.125
61029	R2	336.5	0.0160000000000000003
61029	2Q1	242.900000000000006	0.0259999999999999988
61029	P1	272.300000000000011	0.580999999999999961
61029	L2	320.300000000000011	0.183999999999999997
61029	K2	338	0.580999999999999961
61029	M8	27.3000000000000007	0.00700000000000000015
61030	M2	276.300000000000011	3.89800000000000013
61030	S2	308	1.25
61030	N2	253.400000000000006	0.816999999999999948
61030	K1	262.5	1.52600000000000002
61030	M4	268.399999999999977	0.0259999999999999988
61030	O1	250.5	0.964999999999999969
61030	M6	169.900000000000006	0.0200000000000000004
61030	S4	105.599999999999994	0.00700000000000000015
61030	NU2	256.399999999999977	0.157000000000000001
61030	S6	356.100000000000023	0.00300000000000000006
61030	MU2	332.199999999999989	0.0950000000000000011
61030	2N2	230.5	0.107999999999999999
61030	OO1	274.399999999999977	0.0429999999999999966
61030	LDA2	291	0.0259999999999999988
61030	M1	256.600000000000023	0.0690000000000000058
61030	J1	268.399999999999977	0.0749999999999999972
61030	RHO1	245.400000000000006	0.0359999999999999973
61030	Q1	244.599999999999994	0.187
61030	T2	306.699999999999989	0.0749999999999999972
61030	R2	309.199999999999989	0.0100000000000000002
61030	2Q1	238.699999999999989	0.0259999999999999988
61030	P1	261.600000000000023	0.505000000000000004
61030	L2	299.199999999999989	0.107999999999999999
61030	K2	310.5	0.341000000000000025
61030	M8	147.199999999999989	0.0100000000000000002
61031	M2	275.5	4.07099999999999973
61031	S2	306.800000000000011	1.34200000000000008
61031	N2	250.599999999999994	0.832999999999999963
61031	K1	264	1.55499999999999994
61031	M4	189.199999999999989	0.0259999999999999988
61031	O1	248.800000000000011	0.964999999999999969
61031	M6	144.599999999999994	0.0129999999999999994
61031	MK3	235.599999999999994	0.0129999999999999994
61031	S4	254.300000000000011	0.00700000000000000015
61031	MN4	158.5	0.0100000000000000002
61031	NU2	254.699999999999989	0.164000000000000007
61031	MU2	226.099999999999994	0.0889999999999999958
61031	2N2	224	0.0980000000000000038
61031	OO1	295.600000000000023	0.0519999999999999976
61031	LDA2	296.199999999999989	0.0259999999999999988
61031	S1	49.8999999999999986	0.0519999999999999976
61031	M1	277.300000000000011	0.0490000000000000019
61031	J1	273.600000000000023	0.0919999999999999984
61031	MM	0	0.0330000000000000016
61031	SA	272.399999999999977	0.36399999999999999
61031	MF	192.699999999999989	0.107999999999999999
61031	RHO1	240.900000000000006	0.0330000000000000016
61031	Q1	240.800000000000011	0.171000000000000013
61031	T2	301.199999999999989	0.0749999999999999972
61031	R2	103.5	0.00300000000000000006
61031	2Q1	237.699999999999989	0.0200000000000000004
61031	P1	259.800000000000011	0.48899999999999999
61031	2SM2	146.800000000000011	0.00700000000000000015
61031	M3	306.5	0.0100000000000000002
61031	L2	292.300000000000011	0.0950000000000000011
61031	2MK3	198.400000000000006	0.0160000000000000003
61031	K2	299.600000000000023	0.360999999999999988
61031	MS4	228.699999999999989	0.0160000000000000003
61032	M2	299.5	6.66999999999999993
61032	S2	335.600000000000023	2.21499999999999986
61032	N2	280.100000000000023	1.31200000000000006
61032	K1	273.199999999999989	1.79800000000000004
61032	M4	141.099999999999994	0.164000000000000007
61032	O1	258.100000000000023	1.06000000000000005
61032	M6	230.699999999999989	0.0749999999999999972
61032	S4	199.199999999999989	0.0200000000000000004
61032	NU2	282.699999999999989	0.256000000000000005
61032	S6	209.400000000000006	0.0100000000000000002
61032	MU2	349.600000000000023	0.161000000000000004
61032	2N2	260.600000000000023	0.173999999999999988
61032	OO1	288.300000000000011	0.0459999999999999992
61032	LDA2	316.300000000000011	0.0459999999999999992
61032	M1	265.699999999999989	0.0749999999999999972
61032	J1	280.699999999999989	0.0850000000000000061
61032	SA	255.599999999999994	0.262000000000000011
61032	MF	176.099999999999994	0.0820000000000000034
61032	RHO1	251.599999999999994	0.0389999999999999999
61032	Q1	250.599999999999994	0.20699999999999999
61032	T2	334.199999999999989	0.131000000000000005
61032	R2	337.100000000000023	0.0160000000000000003
61032	2Q1	243	0.0259999999999999988
61032	P1	272	0.593999999999999972
61032	L2	318.899999999999977	0.187
61032	K2	338.600000000000023	0.603999999999999981
61032	M8	194.199999999999989	0.0100000000000000002
61033	M2	281.399999999999977	3.70100000000000007
61033	S2	312.699999999999989	1.20700000000000007
61033	N2	257.199999999999989	0.768000000000000016
61033	K1	268	1.49900000000000011
61033	M4	309.100000000000023	0.00300000000000000006
61033	O1	252.900000000000006	0.925000000000000044
61033	M6	309.100000000000023	0.00700000000000000015
61033	MK3	26.6000000000000014	0.00300000000000000006
61033	S4	245.800000000000011	0.00700000000000000015
61033	NU2	260.699999999999989	0.147999999999999993
61033	S6	186.400000000000006	0.00300000000000000006
61033	MU2	235.199999999999989	0.0889999999999999958
61033	2N2	232.300000000000011	0.0919999999999999984
61033	OO1	296	0.0519999999999999976
61033	LDA2	298.800000000000011	0.0229999999999999996
61033	S1	19.1000000000000014	0.0490000000000000019
61033	M1	275.399999999999977	0.0519999999999999976
61033	J1	280.199999999999989	0.0889999999999999958
61033	MM	172.800000000000011	0.0660000000000000031
61033	SA	257.899999999999977	0.370999999999999996
61033	MSF	346.300000000000011	0.0459999999999999992
61033	MF	203.199999999999989	0.112000000000000002
61033	RHO1	245.699999999999989	0.0299999999999999989
61033	Q1	246.300000000000011	0.164000000000000007
61033	T2	303.899999999999977	0.0719999999999999946
61033	R2	59	0.00300000000000000006
61033	2Q1	241.300000000000011	0.0200000000000000004
61033	P1	264.399999999999977	0.466000000000000025
61033	2SM2	123.900000000000006	0.00700000000000000015
61033	M3	266.399999999999977	0.0100000000000000002
61033	L2	299.300000000000011	0.0749999999999999972
61033	2MK3	232.800000000000011	0.00300000000000000006
61033	K2	305.800000000000011	0.322000000000000008
61033	M8	230.800000000000011	0.00700000000000000015
61033	MS4	35.3999999999999986	0.00700000000000000015
61034	M2	290.199999999999989	4.77400000000000002
61034	S2	322.199999999999989	1.627
61034	N2	265.899999999999977	0.97799999999999998
61034	K1	273.699999999999989	1.64399999999999991
61034	M4	13.8000000000000007	0.179999999999999993
61034	O1	256.800000000000011	1.004
61034	M6	115.400000000000006	0.0359999999999999973
61034	S4	5.29999999999999982	0.0519999999999999976
61034	MN4	331.100000000000023	0.0519999999999999976
61034	NU2	269.5	0.187
61034	MU2	255.5	0.101999999999999993
61034	2N2	239	0.115000000000000005
61034	OO1	300.399999999999977	0.0519999999999999976
61034	LDA2	297.399999999999977	0.0330000000000000016
61034	S1	61.7000000000000028	0.0660000000000000031
61034	M1	289.100000000000023	0.0519999999999999976
61034	J1	287.699999999999989	0.0950000000000000011
61034	SA	254.199999999999989	0.429999999999999993
61034	MF	179.900000000000006	0.0919999999999999984
61034	RHO1	249.400000000000006	0.0330000000000000016
61034	Q1	250.300000000000011	0.173999999999999988
61034	T2	313.800000000000011	0.0919999999999999984
61034	R2	323.5	0.0129999999999999994
61034	2Q1	250.900000000000006	0.0200000000000000004
61034	P1	271.199999999999989	0.509000000000000008
61034	2SM2	132.800000000000011	0.0129999999999999994
61034	M3	277.800000000000011	0.0229999999999999996
61034	L2	299.399999999999977	0.112000000000000002
61034	2MK3	174.099999999999994	0.0100000000000000002
61034	K2	316.199999999999989	0.453000000000000014
61034	M8	186.699999999999989	0.0129999999999999994
61034	MS4	97.0999999999999943	0.107999999999999999
61035	M2	287.699999999999989	4.5730000000000004
61035	S2	320.399999999999977	1.57200000000000006
61035	N2	263.100000000000023	0.941999999999999948
61035	K1	272	1.6399999999999999
61035	M4	19.3999999999999986	0.153999999999999998
61035	O1	256	0.993999999999999995
61035	M6	197.599999999999994	0.0100000000000000002
61035	S4	351.100000000000023	0.0389999999999999999
61035	MN4	338.399999999999977	0.0389999999999999999
61035	NU2	267.600000000000023	0.176999999999999991
61035	MU2	244.400000000000006	0.107999999999999999
61035	2N2	237.900000000000006	0.112000000000000002
61035	OO1	298.100000000000023	0.0519999999999999976
61035	LDA2	303.5	0.0299999999999999989
61035	S1	359.100000000000023	0.0200000000000000004
61035	M1	286.800000000000011	0.0519999999999999976
61035	J1	282.199999999999989	0.0950000000000000011
61035	SA	243.099999999999994	0.366999999999999993
61035	MF	176.5	0.0850000000000000061
61035	RHO1	251.800000000000011	0.0299999999999999989
61035	Q1	249.400000000000006	0.173999999999999988
61035	T2	306.199999999999989	0.0919999999999999984
61035	R2	9.59999999999999964	0.0200000000000000004
61035	2Q1	249.599999999999994	0.0229999999999999996
61035	P1	269.699999999999989	0.531000000000000028
61035	2SM2	136.099999999999994	0.0100000000000000002
61035	M3	273.600000000000023	0.0229999999999999996
61035	L2	300.100000000000023	0.101999999999999993
61035	K2	313.800000000000011	0.429999999999999993
61035	MS4	103.400000000000006	0.115000000000000005
61036	M2	286.899999999999977	4.37300000000000022
61036	S2	317.399999999999977	1.49900000000000011
61036	N2	261.800000000000011	0.868999999999999995
61036	K1	271.600000000000023	1.62400000000000011
61036	M4	19.6999999999999993	0.140999999999999986
61036	O1	255.5	0.990999999999999992
61036	M6	202.5	0.00700000000000000015
61036	S4	353.399999999999977	0.0429999999999999966
61036	NU2	265.199999999999989	0.16700000000000001
61036	S6	179.300000000000011	0.00300000000000000006
61036	MU2	321.5	0.104999999999999996
61036	2N2	236.699999999999989	0.115000000000000005
61036	OO1	287.800000000000011	0.0429999999999999966
61036	LDA2	301	0.0299999999999999989
61036	M1	263.600000000000023	0.0690000000000000058
61036	J1	279.699999999999989	0.0790000000000000008
61036	SA	254.199999999999989	0.429999999999999993
61036	MF	179.900000000000006	0.0919999999999999984
61036	RHO1	248.599999999999994	0.0389999999999999999
61036	Q1	247.5	0.194000000000000006
61036	T2	316.199999999999989	0.0889999999999999958
61036	R2	318.600000000000023	0.0129999999999999994
61036	2Q1	239.5	0.0259999999999999988
61036	P1	270.399999999999977	0.538000000000000034
61036	L2	311.899999999999977	0.120999999999999996
61036	K2	319.899999999999977	0.406999999999999973
61036	M8	31.3999999999999986	0.00700000000000000015
61037	M2	289.5	3.71700000000000008
61037	S2	319.899999999999977	1.2629999999999999
61037	N2	265.300000000000011	0.801000000000000045
61037	K1	272.100000000000023	1.55499999999999994
61037	M4	32.2000000000000028	0.0490000000000000019
61037	O1	257.800000000000011	0.944999999999999951
61037	M6	347.100000000000023	0.00700000000000000015
61037	S4	311.699999999999989	0.00700000000000000015
61037	NU2	268.5	0.153999999999999998
61037	S6	241.800000000000011	0.0100000000000000002
61037	MU2	324.199999999999989	0.0889999999999999958
61037	2N2	241.099999999999994	0.107999999999999999
61037	OO1	286.399999999999977	0.0389999999999999999
61037	LDA2	303.600000000000023	0.0259999999999999988
61037	M1	265	0.0660000000000000031
61037	J1	279.199999999999989	0.0749999999999999972
61037	RHO1	251.599999999999994	0.0359999999999999973
61037	Q1	250.599999999999994	0.183999999999999997
61037	T2	318.699999999999989	0.0749999999999999972
61037	R2	321.199999999999989	0.0100000000000000002
61037	2Q1	243.5	0.0259999999999999988
61037	P1	271	0.515000000000000013
61037	L2	313.699999999999989	0.104999999999999996
61037	K2	322.399999999999977	0.343999999999999972
61037	M8	214.300000000000011	0.0129999999999999994
61038	M2	288.800000000000011	4.41600000000000037
61038	S2	319.600000000000023	1.4930000000000001
61038	N2	264.399999999999977	0.915000000000000036
61038	K1	273.199999999999989	1.60099999999999998
61038	M4	33.8999999999999986	0.117999999999999994
61038	O1	258	0.960999999999999965
61038	M6	183	0.00300000000000000006
61038	S4	359.199999999999989	0.0330000000000000016
61038	NU2	267.699999999999989	0.176999999999999991
61038	MU2	323.300000000000011	0.104999999999999996
61038	2N2	240	0.120999999999999996
61038	OO1	288.399999999999977	0.0429999999999999966
61038	LDA2	303.100000000000023	0.0299999999999999989
61038	M1	265.600000000000023	0.0690000000000000058
61038	J1	280.699999999999989	0.0749999999999999972
61038	SA	243.099999999999994	0.366999999999999993
61038	RHO1	251.400000000000006	0.0359999999999999973
61038	Q1	250.400000000000006	0.187
61038	T2	318.399999999999977	0.0889999999999999958
61038	R2	320.800000000000011	0.0129999999999999994
61038	2Q1	242.900000000000006	0.0259999999999999988
61038	P1	272	0.528000000000000025
61038	L2	313.300000000000011	0.125
61038	K2	322.100000000000023	0.406999999999999973
61038	M8	271.5	0.00700000000000000015
61039	M2	287.899999999999977	4.57699999999999996
61039	S2	319	1.5089999999999999
61039	N2	262.100000000000023	0.973999999999999977
61039	K1	270.399999999999977	1.57800000000000007
61039	M4	25.3999999999999986	0.125
61039	O1	256.300000000000011	1.01000000000000001
61039	M6	158.699999999999989	0.00700000000000000015
61039	S4	24.6999999999999993	0.0719999999999999946
61039	NU2	265.5	0.190000000000000002
61039	S6	158.800000000000011	0.00700000000000000015
61039	MU2	322	0.112000000000000002
61039	2N2	236.300000000000011	0.131000000000000005
61039	OO1	284.600000000000023	0.0429999999999999966
61039	LDA2	302.300000000000011	0.0330000000000000016
61039	M1	263.399999999999977	0.0719999999999999946
61039	J1	277.399999999999977	0.0790000000000000008
61039	RHO1	250.199999999999989	0.0389999999999999999
61039	Q1	249.300000000000011	0.197000000000000008
61039	T2	317.699999999999989	0.0889999999999999958
61039	R2	320.199999999999989	0.0129999999999999994
61039	2Q1	242.300000000000011	0.0259999999999999988
61039	P1	269.399999999999977	0.52200000000000002
61039	L2	313.699999999999989	0.128000000000000003
61039	K2	321.5	0.409999999999999976
61039	M8	189.300000000000011	0.00300000000000000006
61040	M2	288.899999999999977	4.29499999999999993
61040	S2	318.899999999999977	1.46300000000000008
61040	N2	267	0.865999999999999992
61040	K1	272.300000000000011	1.53899999999999992
61040	M4	22.8000000000000007	0.112000000000000002
61040	O1	258.199999999999989	0.970999999999999974
61040	M6	181.900000000000006	0.00300000000000000006
61040	S4	13.9000000000000004	0.0200000000000000004
61040	NU2	269.899999999999977	0.16700000000000001
61040	MU2	323.800000000000011	0.101999999999999993
61040	2N2	245.099999999999994	0.115000000000000005
61040	OO1	286.399999999999977	0.0429999999999999966
61040	LDA2	302.800000000000011	0.0299999999999999989
61040	M1	265.300000000000011	0.0690000000000000058
61040	J1	279.300000000000011	0.0749999999999999972
61040	SA	254.199999999999989	0.429999999999999993
61040	MF	179.900000000000006	0.0919999999999999984
61040	RHO1	252.099999999999994	0.0359999999999999973
61040	Q1	251.199999999999989	0.187
61040	T2	317.699999999999989	0.0850000000000000061
61040	R2	320.100000000000023	0.0129999999999999994
61040	2Q1	244.199999999999989	0.0259999999999999988
61040	P1	271.300000000000011	0.509000000000000008
61040	L2	310.800000000000011	0.120999999999999996
61040	K2	321.300000000000011	0.39700000000000002
61040	M8	47.7999999999999972	0.00300000000000000006
61041	M2	289.100000000000023	4.42900000000000027
61041	S2	319.800000000000011	1.54200000000000004
61041	N2	267.699999999999989	0.919000000000000039
61041	K1	271.600000000000023	1.66700000000000004
61041	M4	33.3999999999999986	0.115000000000000005
61041	O1	258.699999999999989	0.960999999999999965
61041	M6	198.699999999999989	0.00300000000000000006
61041	S4	2.5	0.0330000000000000016
61041	NU2	270.600000000000023	0.176999999999999991
61041	S6	116.099999999999994	0.00300000000000000006
61041	MU2	323	0.104999999999999996
61041	2N2	246.199999999999989	0.120999999999999996
61041	OO1	284.5	0.0429999999999999966
61041	LDA2	303.399999999999977	0.0299999999999999989
61041	M1	265.199999999999989	0.0690000000000000058
61041	J1	278	0.0749999999999999972
61041	SA	243.099999999999994	0.366999999999999993
61041	RHO1	253.199999999999989	0.0359999999999999973
61041	Q1	252.300000000000011	0.187
61041	T2	318.600000000000023	0.0919999999999999984
61041	R2	321.100000000000023	0.0129999999999999994
61041	2Q1	245.900000000000006	0.0259999999999999988
61041	P1	270.600000000000023	0.551000000000000045
61041	L2	310.600000000000023	0.125
61041	K2	322.300000000000011	0.419999999999999984
61042	M2	288.800000000000011	4.32399999999999984
61042	S2	319.300000000000011	1.50299999999999989
61042	N2	262.5	0.842999999999999972
61042	K1	272.699999999999989	1.55200000000000005
61042	M4	21.3999999999999986	0.131000000000000005
61042	O1	258	0.944999999999999951
61042	M6	195.099999999999994	0.0129999999999999994
61042	S4	17.8000000000000007	0.0359999999999999973
61042	NU2	266	0.164000000000000007
61042	S6	204.199999999999989	0.00300000000000000006
61042	MU2	322.899999999999977	0.104999999999999996
61042	2N2	236.099999999999994	0.112000000000000002
61042	OO1	287.5	0.0389999999999999999
61042	LDA2	302.899999999999977	0.0299999999999999989
61042	M1	265.399999999999977	0.0660000000000000031
61042	J1	280	0.0749999999999999972
61042	SA	254.199999999999989	0.429999999999999993
61042	MF	179.900000000000006	0.0919999999999999984
61042	RHO1	251.699999999999989	0.0359999999999999973
61042	Q1	250.699999999999989	0.183999999999999997
61042	T2	318.100000000000023	0.0889999999999999958
61042	R2	320.5	0.0129999999999999994
61042	2Q1	243.400000000000006	0.0229999999999999996
61042	P1	271.600000000000023	0.515000000000000013
61042	L2	315.100000000000023	0.120999999999999996
61042	K2	321.699999999999989	0.409999999999999976
61042	M8	138.699999999999989	0.00300000000000000006
61043	M2	288.899999999999977	4.48800000000000043
61043	S2	319	1.53200000000000003
61043	N2	265	0.915000000000000036
61043	K1	272.300000000000011	1.58099999999999996
61043	M4	40.1000000000000014	0.140999999999999986
61043	O1	257.199999999999989	0.95499999999999996
61043	S4	7.70000000000000018	0.0429999999999999966
61043	NU2	268.199999999999989	0.176999999999999991
61043	MU2	323.100000000000023	0.107999999999999999
61043	2N2	241.099999999999994	0.120999999999999996
61043	OO1	287.5	0.0429999999999999966
61043	LDA2	302.899999999999977	0.0330000000000000016
61043	M1	264.800000000000011	0.0690000000000000058
61043	J1	279.800000000000011	0.0749999999999999972
61043	SA	253.300000000000011	0.387000000000000011
61043	RHO1	250.599999999999994	0.0359999999999999973
61043	Q1	249.599999999999994	0.183999999999999997
61043	T2	317.800000000000011	0.0919999999999999984
61043	R2	320.300000000000011	0.0129999999999999994
61043	2Q1	242.099999999999994	0.0259999999999999988
61043	P1	271.199999999999989	0.525000000000000022
61043	L2	312.800000000000011	0.125
61043	K2	321.5	0.416999999999999982
61044	M2	288.600000000000023	4.50800000000000001
61044	S2	318.899999999999977	1.55200000000000005
61044	N2	265.300000000000011	0.925000000000000044
61044	K1	273.100000000000023	1.6339999999999999
61044	M4	29.1000000000000014	0.120999999999999996
61044	O1	258.899999999999977	0.964999999999999969
61044	M6	207.5	0.0129999999999999994
61044	S4	1.30000000000000004	0.0359999999999999973
61044	NU2	268.5	0.179999999999999993
61044	S6	179.199999999999989	0.00300000000000000006
61044	MU2	322.5	0.107999999999999999
61044	2N2	242	0.120999999999999996
61044	OO1	287.300000000000011	0.0429999999999999966
61044	LDA2	302.699999999999989	0.0330000000000000016
61044	M1	266.100000000000023	0.0690000000000000058
61044	J1	280.199999999999989	0.0749999999999999972
61044	SA	243.099999999999994	0.366999999999999993
61044	RHO1	252.800000000000011	0.0359999999999999973
61044	Q1	251.800000000000011	0.187
61044	T2	317.699999999999989	0.0919999999999999984
61044	R2	320.100000000000023	0.0129999999999999994
61044	2Q1	244.800000000000011	0.0259999999999999988
61044	P1	272	0.541000000000000036
61044	L2	312	0.125
61044	K2	321.300000000000011	0.422999999999999987
61044	M8	95.2000000000000028	0.00700000000000000015
61045	M2	288	4.34400000000000031
61045	S2	319.600000000000023	1.55499999999999994
61045	N2	262.199999999999989	0.941999999999999948
61045	K1	272.5	1.59800000000000009
61045	M4	22.6000000000000014	0.101999999999999993
61045	O1	256.600000000000023	0.957999999999999963
61045	M6	318.199999999999989	0.0129999999999999994
61045	S4	315.399999999999977	0.0259999999999999988
61045	NU2	265.699999999999989	0.183999999999999997
61045	S6	174.199999999999989	0.00300000000000000006
61045	MU2	320.300000000000011	0.104999999999999996
61045	2N2	236.5	0.125
61045	OO1	288.399999999999977	0.0429999999999999966
61045	LDA2	302.699999999999989	0.0299999999999999989
61045	M1	264.600000000000023	0.0690000000000000058
61045	J1	280.399999999999977	0.0749999999999999972
61045	SA	254.199999999999989	0.429999999999999993
61045	MF	179.900000000000006	0.0919999999999999984
61045	RHO1	249.800000000000011	0.0359999999999999973
61045	Q1	248.699999999999989	0.187
61045	T2	318.399999999999977	0.0919999999999999984
61045	R2	320.899999999999977	0.0129999999999999994
61045	2Q1	240.800000000000011	0.0259999999999999988
61045	P1	271.300000000000011	0.528000000000000025
61045	L2	313.699999999999989	0.120999999999999996
61045	K2	322.199999999999989	0.422999999999999987
61046	M2	286.199999999999989	3.89400000000000013
61046	S2	318.600000000000023	1.31200000000000006
61046	N2	263.800000000000011	0.751000000000000001
61046	K1	273.800000000000011	1.3839999999999999
61046	M4	31.8000000000000007	0.0690000000000000058
61046	O1	256.399999999999977	0.993999999999999995
61046	M6	354.300000000000011	0.00700000000000000015
61046	S4	344.699999999999989	0.0299999999999999989
61046	NU2	266.800000000000011	0.143999999999999989
61046	S6	124.5	0.0129999999999999994
61046	MU2	317.399999999999977	0.0919999999999999984
61046	2N2	241.300000000000011	0.0980000000000000038
61046	OO1	291.300000000000011	0.0429999999999999966
61046	LDA2	301.300000000000011	0.0259999999999999988
61046	M1	265.199999999999989	0.0719999999999999946
61046	J1	282.5	0.0790000000000000008
61046	SA	253.300000000000011	0.387000000000000011
61046	MF	163.900000000000006	0.0790000000000000008
61046	RHO1	248.900000000000006	0.0359999999999999973
61046	Q1	247.800000000000011	0.194000000000000006
61046	T2	317.300000000000011	0.0790000000000000008
61046	R2	319.899999999999977	0.0100000000000000002
61046	2Q1	239.099999999999994	0.0259999999999999988
61046	P1	272.5	0.459000000000000019
61046	L2	308.800000000000011	0.107999999999999999
61046	K2	321.300000000000011	0.357999999999999985
61046	M8	178.5	0.00700000000000000015
61047	M2	288.600000000000023	4.60299999999999976
61047	S2	320.300000000000011	1.60099999999999998
61047	N2	264.100000000000023	0.90900000000000003
61047	K1	272.199999999999989	1.61699999999999999
61047	M4	16.3999999999999986	0.171000000000000013
61047	O1	256.699999999999989	0.990999999999999992
61047	M6	202.900000000000006	0.0100000000000000002
61047	S4	353.199999999999989	0.0589999999999999969
61047	MN4	334.399999999999977	0.0519999999999999976
61047	NU2	270.800000000000011	0.194000000000000006
61047	S6	12.5	0.00300000000000000006
61047	MU2	245	0.112000000000000002
61047	2N2	238.199999999999989	0.0980000000000000038
61047	OO1	309.399999999999977	0.0519999999999999976
61047	LDA2	305.600000000000023	0.0299999999999999989
61047	S1	35.7999999999999972	0.0490000000000000019
61047	M1	279.5	0.0589999999999999969
61047	J1	286	0.0980000000000000038
61047	MM	256.5	0.161000000000000004
61047	SSA	114.099999999999994	0.161000000000000004
61047	SA	240.599999999999994	0.463000000000000023
61047	MSF	144.199999999999989	0.0790000000000000008
61047	MF	162	0.143999999999999989
61047	RHO1	255.800000000000011	0.0229999999999999996
61047	Q1	247.800000000000011	0.173999999999999988
61047	T2	307.100000000000023	0.0950000000000000011
61047	R2	209.900000000000006	0.0129999999999999994
61047	2Q1	228	0.0259999999999999988
61047	P1	267.800000000000011	0.494999999999999996
61047	2SM2	149.699999999999989	0.00700000000000000015
61047	M3	279.800000000000011	0.0229999999999999996
61047	L2	304.699999999999989	0.117999999999999994
61047	2MK3	255.400000000000006	0.00700000000000000015
61047	K2	312.699999999999989	0.429999999999999993
61047	MS4	102.700000000000003	0.104999999999999996
61048	M2	288	3.93000000000000016
61048	S2	319.5	1.34800000000000009
61048	N2	264	0.804000000000000048
61048	K1	272.899999999999977	1.51899999999999991
61048	M4	22.3000000000000007	0.0330000000000000016
61048	O1	257.699999999999989	0.947999999999999954
61048	M6	28.6000000000000014	0.0200000000000000004
61048	MK3	131.099999999999994	0.00700000000000000015
61048	S4	10	0.00700000000000000015
61048	MN4	343.600000000000023	0.0100000000000000002
61048	NU2	267.199999999999989	0.153999999999999998
61048	S6	210.699999999999989	0.00300000000000000006
61048	MU2	238.800000000000011	0.0980000000000000038
61048	2N2	239.099999999999994	0.0919999999999999984
61048	OO1	295	0.0519999999999999976
61048	LDA2	307.100000000000023	0.0229999999999999996
61048	S1	51.3999999999999986	0.0299999999999999989
61048	M1	278.5	0.0589999999999999969
61048	J1	286.399999999999977	0.0919999999999999984
61048	SA	242.900000000000006	0.463000000000000023
61048	MF	181.900000000000006	0.0889999999999999958
61048	RHO1	253.400000000000006	0.0299999999999999989
61048	Q1	250.300000000000011	0.16700000000000001
61048	T2	312.399999999999977	0.0850000000000000061
61048	R2	348.899999999999977	0.00300000000000000006
61048	2Q1	245.099999999999994	0.0160000000000000003
61048	P1	268.800000000000011	0.475999999999999979
61048	2SM2	122.599999999999994	0.00300000000000000006
61048	M3	276	0.0129999999999999994
61048	L2	312.399999999999977	0.0850000000000000061
61048	2MK3	139.300000000000011	0.00300000000000000006
61048	K2	312.699999999999989	0.360999999999999988
61048	M8	21.1999999999999993	0.00300000000000000006
61048	MS4	95.2000000000000028	0.0200000000000000004
61049	M2	288.600000000000023	3.93400000000000016
61049	S2	318.5	1.3879999999999999
61049	N2	263.899999999999977	0.758000000000000007
61049	K1	271.399999999999977	1.56800000000000006
61049	M4	37.7999999999999972	0.0359999999999999973
61049	O1	257.600000000000023	0.915000000000000036
61049	M6	30.6999999999999993	0.0129999999999999994
61049	S4	327.699999999999989	0.00700000000000000015
61049	NU2	267.199999999999989	0.147999999999999993
61049	S6	74.4000000000000057	0.00700000000000000015
61049	MU2	319.600000000000023	0.0950000000000000011
61049	2N2	239.199999999999989	0.101999999999999993
61049	OO1	285.199999999999989	0.0389999999999999999
61049	LDA2	302.5	0.0259999999999999988
61049	M1	264.600000000000023	0.0660000000000000031
61049	J1	278.199999999999989	0.0719999999999999946
61049	SA	253.300000000000011	0.387000000000000011
61049	MF	163.900000000000006	0.0790000000000000008
61049	RHO1	251.699999999999989	0.0359999999999999973
61049	Q1	250.800000000000011	0.176999999999999991
61049	T2	317.300000000000011	0.0820000000000000034
61049	R2	319.699999999999989	0.0100000000000000002
61049	2Q1	244	0.0229999999999999996
61049	P1	270.399999999999977	0.518000000000000016
61049	L2	313.300000000000011	0.112000000000000002
61049	K2	320.899999999999977	0.377000000000000002
61049	M8	358.800000000000011	0.00700000000000000015
61050	M2	288.800000000000011	3.93400000000000016
61050	S2	322.300000000000011	1.38100000000000001
61050	N2	266.5	0.76100000000000001
61050	K1	272.899999999999977	1.45300000000000007
61050	M4	30.8999999999999986	0.0299999999999999989
61050	O1	257.800000000000011	0.922000000000000042
61050	M6	44.8999999999999986	0.0229999999999999996
61050	S4	48.8999999999999986	0.00700000000000000015
61050	NU2	269.5	0.147999999999999993
61050	S6	168.599999999999994	0.00700000000000000015
61050	MU2	255.199999999999989	0.0950000000000000011
61050	2N2	244.199999999999989	0.101999999999999993
61050	OO1	287.899999999999977	0.0389999999999999999
61050	LDA2	304.399999999999977	0.0259999999999999988
61050	M1	265.399999999999977	0.0660000000000000031
61050	J1	280.300000000000011	0.0719999999999999946
61050	SA	253.300000000000011	0.387000000000000011
61050	MF	163.900000000000006	0.0790000000000000008
61050	RHO1	251.400000000000006	0.0359999999999999973
61050	Q1	250.300000000000011	0.176999999999999991
61050	T2	321	0.0820000000000000034
61050	R2	323.699999999999989	0.0100000000000000002
61050	2Q1	242.900000000000006	0.0229999999999999996
61050	P1	271.699999999999989	0.478999999999999981
61050	L2	311.199999999999989	0.112000000000000002
61050	K2	325.100000000000023	0.377000000000000002
61050	M8	331.800000000000011	0.00700000000000000015
61051	M2	288.899999999999977	3.94399999999999995
61051	S2	320.699999999999989	1.36499999999999999
61051	N2	264	0.797000000000000042
61051	K1	273.399999999999977	1.4830000000000001
61051	M4	24.6999999999999993	0.0259999999999999988
61051	O1	258.5	0.928000000000000047
61051	M6	40.8999999999999986	0.0160000000000000003
61051	S4	348	0.00300000000000000006
61051	NU2	267.300000000000011	0.153999999999999998
61051	S6	104.5	0.00300000000000000006
61051	MU2	257	0.0950000000000000011
61051	2N2	239.099999999999994	0.104999999999999996
61051	OO1	288.399999999999977	0.0389999999999999999
61051	LDA2	303.600000000000023	0.0259999999999999988
61051	M1	266	0.0660000000000000031
61051	J1	280.899999999999977	0.0719999999999999946
61051	RHO1	252	0.0359999999999999973
61051	Q1	251	0.179999999999999993
61051	T2	319.399999999999977	0.0820000000000000034
61051	R2	321.899999999999977	0.0100000000000000002
61051	2Q1	243.599999999999994	0.0229999999999999996
61051	P1	272.300000000000011	0.491999999999999993
61051	L2	313.699999999999989	0.112000000000000002
61051	K2	323.300000000000011	0.370999999999999996
61051	M8	20.1999999999999993	0.00700000000000000015
61052	M2	288.399999999999977	3.95699999999999985
61052	S2	318.199999999999989	1.3580000000000001
61052	N2	260.199999999999989	0.810000000000000053
61052	K1	273.100000000000023	1.49900000000000011
61052	M4	33.2000000000000028	0.0229999999999999996
61052	O1	258.699999999999989	0.937999999999999945
61052	M6	44.8999999999999986	0.0160000000000000003
61052	S4	332.800000000000011	0.00300000000000000006
61052	NU2	264	0.157000000000000001
61052	S6	31.8000000000000007	0.00300000000000000006
61052	MU2	319	0.0950000000000000011
61052	2N2	232.099999999999994	0.107999999999999999
61052	OO1	287.5	0.0389999999999999999
61052	LDA2	302.199999999999989	0.0259999999999999988
61052	M1	265.899999999999977	0.0660000000000000031
61052	J1	280.199999999999989	0.0749999999999999972
61052	SA	253.300000000000011	0.387000000000000011
61052	MF	163.900000000000006	0.0790000000000000008
61052	RHO1	252.5	0.0359999999999999973
61052	Q1	251.599999999999994	0.179999999999999993
61052	T2	317	0.0790000000000000008
61052	R2	319.399999999999977	0.0100000000000000002
61052	2Q1	244.400000000000006	0.0229999999999999996
61052	P1	272	0.494999999999999996
61052	L2	316.5	0.112000000000000002
61052	K2	320.600000000000023	0.370999999999999996
61052	M8	25.3000000000000007	0.0100000000000000002
61053	M2	289.199999999999989	4.00600000000000023
61053	S2	320	1.39100000000000001
61053	N2	264	0.807000000000000051
61053	K1	273.199999999999989	1.49900000000000011
61053	M4	28	0.0330000000000000016
61053	O1	257.600000000000023	0.928000000000000047
61053	M6	28.3999999999999986	0.0259999999999999988
61053	S4	351.699999999999989	0.00300000000000000006
61053	NU2	267.399999999999977	0.157000000000000001
61053	S6	61.7000000000000028	0.00300000000000000006
61053	MU2	318.899999999999977	0.0950000000000000011
61053	2N2	238.800000000000011	0.107999999999999999
61053	OO1	288.899999999999977	0.0389999999999999999
61053	LDA2	303.5	0.0299999999999999989
61053	M1	265.5	0.0660000000000000031
61053	J1	281	0.0719999999999999946
61053	SA	253.300000000000011	0.387000000000000011
61053	MF	163.900000000000006	0.0790000000000000008
61053	RHO1	250.900000000000006	0.0359999999999999973
61053	Q1	249.900000000000006	0.179999999999999993
61053	T2	318.800000000000011	0.0820000000000000034
61053	R2	321.300000000000011	0.0100000000000000002
61053	2Q1	242.099999999999994	0.0229999999999999996
61053	P1	272.100000000000023	0.494999999999999996
61053	L2	314.399999999999977	0.112000000000000002
61053	K2	322.5	0.377000000000000002
61053	M8	352.800000000000011	0.00300000000000000006
61054	M2	294.300000000000011	4.01900000000000013
61054	S2	328.600000000000023	1.43999999999999995
61054	N2	270.300000000000011	0.82999999999999996
61054	K1	276	1.50600000000000001
61054	M4	120.599999999999994	0.0660000000000000031
61054	O1	260.699999999999989	0.944999999999999951
61054	M6	77	0.0389999999999999999
61054	S4	260.699999999999989	0.0129999999999999994
61054	NU2	273.5	0.161000000000000004
61054	S6	189.300000000000011	0.00300000000000000006
61054	MU2	319.800000000000011	0.0950000000000000011
61054	2N2	246.300000000000011	0.112000000000000002
61054	OO1	291.300000000000011	0.0389999999999999999
61054	LDA2	310.199999999999989	0.0299999999999999989
61054	M1	268.399999999999977	0.0660000000000000031
61054	J1	283.600000000000023	0.0749999999999999972
61054	SA	253.300000000000011	0.387000000000000011
61054	MF	163.900000000000006	0.0790000000000000008
61054	RHO1	254.099999999999994	0.0359999999999999973
61054	Q1	253.099999999999994	0.183999999999999997
61054	T2	327.300000000000011	0.0850000000000000061
61054	R2	330	0.0100000000000000002
61054	2Q1	245.5	0.0229999999999999996
61054	P1	274.800000000000011	0.498999999999999999
61054	L2	318.199999999999989	0.112000000000000002
61054	K2	331.399999999999977	0.390000000000000013
61054	M8	303.199999999999989	0.0129999999999999994
61055	M2	324	7.28699999999999992
61055	S2	358.300000000000011	2.72299999999999986
61055	N2	298.399999999999977	1.496
61055	K1	279.800000000000011	1.84699999999999998
61055	M4	71.2000000000000028	0.101999999999999993
61055	O1	263.600000000000023	1.129
61055	M6	194.699999999999989	0.0519999999999999976
61055	MK3	199.5	0.0589999999999999969
61055	S4	137	0.0160000000000000003
61055	MN4	42	0.0359999999999999973
61055	NU2	302.199999999999989	0.253000000000000003
61055	MU2	275.800000000000011	0.294999999999999984
61055	2N2	267.699999999999989	0.171000000000000013
61055	OO1	314.399999999999977	0.0619999999999999996
61055	LDA2	304.199999999999989	0.0299999999999999989
61055	S1	52.5	0.0459999999999999992
61055	M1	297	0.0660000000000000031
61055	J1	295	0.104999999999999996
61055	SA	250.199999999999989	0.412999999999999978
61055	MF	171.699999999999989	0.0749999999999999972
61055	RHO1	250.400000000000006	0.0389999999999999999
61055	Q1	255.800000000000011	0.203000000000000014
61055	T2	351.899999999999977	0.147999999999999993
61055	R2	7.70000000000000018	0.0299999999999999989
61055	2Q1	248.300000000000011	0.0229999999999999996
61055	P1	277.899999999999977	0.586999999999999966
61055	2SM2	92.5	0.0259999999999999988
61055	M3	7.5	0.0330000000000000016
61055	L2	332.399999999999977	0.112000000000000002
61055	2MK3	180.900000000000006	0.0889999999999999958
61055	K2	350.300000000000011	0.744999999999999996
61055	M8	350.199999999999989	0.0129999999999999994
61055	MS4	117.5	0.0889999999999999958
61056	M2	324.800000000000011	7.30299999999999994
61056	S2	357.300000000000011	2.86100000000000021
61056	N2	300.699999999999989	1.6140000000000001
61056	K1	277.899999999999977	1.86299999999999999
61056	M4	76.0999999999999943	0.112000000000000002
61056	O1	263.5	1.1120000000000001
61056	M6	180.699999999999989	0.0560000000000000012
61056	S4	181.5	0.0299999999999999989
61056	NU2	303.899999999999977	0.312
61056	S6	36.2999999999999972	0.0100000000000000002
61056	MU2	349	0.173999999999999988
61056	2N2	276.699999999999989	0.212999999999999995
61056	OO1	292.399999999999977	0.0490000000000000019
61056	LDA2	339.899999999999977	0.0519999999999999976
61056	M1	270.800000000000011	0.0790000000000000008
61056	J1	285.100000000000023	0.0889999999999999958
61056	RHO1	257.199999999999989	0.0429999999999999966
61056	Q1	256.300000000000011	0.216999999999999998
61056	T2	356	0.171000000000000013
61056	R2	358.600000000000023	0.0229999999999999996
61056	2Q1	249.099999999999994	0.0299999999999999989
61056	P1	276.899999999999977	0.616999999999999993
61056	L2	348.800000000000011	0.203000000000000014
61056	K2	0	0.778000000000000025
61056	M8	63.2999999999999972	0.00700000000000000015
61057	M2	325.199999999999989	7.53300000000000036
61057	S2	357.899999999999977	2.95900000000000007
61057	N2	301.399999999999977	1.65700000000000003
61057	K1	277.800000000000011	1.877
61057	M4	69.5	0.107999999999999999
61057	O1	263.800000000000011	1.1120000000000001
61057	M6	182.400000000000006	0.0719999999999999946
61057	S4	178.699999999999989	0.0299999999999999989
61057	NU2	304.600000000000023	0.322000000000000008
61057	S6	31.6999999999999993	0.0129999999999999994
61057	MU2	350.600000000000023	0.179999999999999993
61057	2N2	277.5	0.220000000000000001
61057	OO1	291.800000000000011	0.0490000000000000019
61057	LDA2	340.399999999999977	0.0519999999999999976
61057	M1	270.800000000000011	0.0790000000000000008
61057	J1	284.800000000000011	0.0889999999999999958
61057	RHO1	257.800000000000011	0.0429999999999999966
61057	Q1	256.800000000000011	0.216999999999999998
61057	T2	356.600000000000023	0.173999999999999988
61057	R2	359.199999999999989	0.0229999999999999996
61057	2Q1	249.900000000000006	0.0299999999999999989
61057	P1	276.800000000000011	0.619999999999999996
61057	L2	349.100000000000023	0.209999999999999992
61057	K2	0.5	0.804000000000000048
61057	M8	49.6000000000000014	0.0129999999999999994
61058	M2	335	7.49300000000000033
61058	S2	6.90000000000000036	2.66100000000000003
61058	N2	307	1.48599999999999999
61058	K1	284.600000000000023	1.877
61058	M4	51.8999999999999986	0.187
61058	O1	269.899999999999977	1.125
61058	M6	205.800000000000011	0.0389999999999999999
61058	S4	123	0.0299999999999999989
61058	NU2	310.800000000000011	0.288999999999999979
61058	S6	312.699999999999989	0.00300000000000000006
61058	MU2	359.399999999999977	0.179999999999999993
61058	2N2	279	0.197000000000000008
61058	OO1	299.300000000000011	0.0490000000000000019
61058	LDA2	349.800000000000011	0.0519999999999999976
61058	M1	277.300000000000011	0.0790000000000000008
61058	J1	291.899999999999977	0.0889999999999999958
61058	RHO1	263.600000000000023	0.0429999999999999966
61058	Q1	262.600000000000023	0.220000000000000001
61058	T2	5.70000000000000018	0.157000000000000001
61058	R2	8.19999999999999929	0.0229999999999999996
61058	2Q1	255.300000000000011	0.0299999999999999989
61058	P1	283.5	0.619999999999999996
61058	L2	3.10000000000000009	0.209999999999999992
61058	K2	9.5	0.724999999999999978
61058	M8	103.5	0.00700000000000000015
61059	M2	353.800000000000011	7.77899999999999991
61059	S2	25	2.91699999999999982
61059	N2	320.600000000000023	1.56499999999999995
61059	K1	291.800000000000011	1.98199999999999998
61059	M4	175.199999999999989	0.0919999999999999984
61059	O1	275.800000000000011	1.14799999999999991
61059	M6	79	0.0690000000000000058
61059	S4	219.900000000000006	0.0229999999999999996
61059	NU2	325	0.304999999999999993
61059	S6	252.900000000000006	0.00300000000000000006
61059	MU2	322.600000000000023	0.187
61059	2N2	287.399999999999977	0.20699999999999999
61059	OO1	307.899999999999977	0.0490000000000000019
61059	LDA2	8.30000000000000071	0.0560000000000000012
61059	M1	283.899999999999977	0.0820000000000000034
61059	J1	299.800000000000011	0.0919999999999999984
61059	SA	250.199999999999989	0.412999999999999978
61059	MF	171.699999999999989	0.0749999999999999972
61059	RHO1	268.899999999999977	0.0429999999999999966
61059	Q1	267.800000000000011	0.223000000000000004
61059	T2	23.8000000000000007	0.171000000000000013
61059	R2	26.3000000000000007	0.0229999999999999996
61059	2Q1	259.800000000000011	0.0299999999999999989
61059	P1	290.600000000000023	0.656000000000000028
61059	L2	27	0.216999999999999998
61059	K2	27.5	0.794000000000000039
61059	M8	227.699999999999989	0.00300000000000000006
61060	M2	8.90000000000000036	8.15000000000000036
61060	S2	40.6000000000000014	3.14000000000000012
61060	N2	339.899999999999977	1.79099999999999993
61060	K1	297.199999999999989	1.89999999999999991
61060	M4	260.800000000000011	0.276000000000000023
61060	O1	280.800000000000011	1.25299999999999989
61060	M6	108.599999999999994	0.153999999999999998
61060	S4	345.600000000000023	0.0330000000000000016
61060	NU2	343.800000000000011	0.347999999999999976
61060	S6	316.899999999999977	0.0129999999999999994
61060	MU2	337.100000000000023	0.197000000000000008
61060	2N2	310.899999999999977	0.23899999999999999
61060	OO1	313.600000000000023	0.0519999999999999976
61060	LDA2	23.6000000000000014	0.0560000000000000012
61060	M1	289.100000000000023	0.0889999999999999958
61060	J1	305.300000000000011	0.0980000000000000038
61060	SA	243.699999999999989	0.394000000000000017
61060	MF	163	0.0919999999999999984
61060	RHO1	273.800000000000011	0.0490000000000000019
61060	Q1	272.699999999999989	0.242999999999999994
61060	T2	39.2999999999999972	0.183999999999999997
61060	R2	41.8999999999999986	0.0259999999999999988
61060	2Q1	264.5	0.0330000000000000016
61060	P1	296	0.630000000000000004
61060	L2	37.7999999999999972	0.23000000000000001
61060	K2	43.2000000000000028	0.85299999999999998
61060	M8	293.5	0.0229999999999999996
61061	M2	15.1999999999999993	7.45399999999999974
61061	S2	47.2000000000000028	2.90399999999999991
61061	N2	346.5	1.66999999999999993
61061	K1	301.899999999999977	1.91900000000000004
61061	M4	232.400000000000006	0.183999999999999997
61061	O1	284.300000000000011	1.25299999999999989
61061	M6	95.2999999999999972	0.0919999999999999984
61061	S4	313.199999999999989	0.0229999999999999996
61061	NU2	350.300000000000011	0.325000000000000011
61061	S6	244.900000000000006	0.00700000000000000015
61061	MU2	343.300000000000011	0.179999999999999993
61061	2N2	317.699999999999989	0.223000000000000004
61061	OO1	319.5	0.0519999999999999976
61061	LDA2	30.1000000000000014	0.0519999999999999976
61061	M1	293.199999999999989	0.0889999999999999958
61061	J1	310.600000000000023	0.0980000000000000038
61061	SA	243.699999999999989	0.0389999999999999999
61061	RHO1	276.699999999999989	0.0490000000000000019
61061	Q1	275.600000000000023	0.242999999999999994
61061	T2	45.8999999999999986	0.171000000000000013
61061	R2	48.5	0.0229999999999999996
61061	2Q1	266.800000000000011	0.0330000000000000016
61061	P1	300.600000000000023	0.63600000000000001
61061	L2	44	0.209999999999999992
61061	K2	49.7999999999999972	0.791000000000000036
61061	M8	135.300000000000011	0.00300000000000000006
61062	M2	16.6000000000000014	8.20899999999999963
61062	S2	52.3999999999999986	3.01799999999999979
61062	N2	351.600000000000023	1.69300000000000006
61062	K1	301.699999999999989	1.89300000000000002
61062	M4	277.300000000000011	0.404000000000000026
61062	O1	288.399999999999977	1.22700000000000009
61062	M6	117.299999999999997	0.233000000000000013
61062	S4	64.2000000000000028	0.0129999999999999994
61062	NU2	354.899999999999977	0.328000000000000014
61062	S6	198.900000000000006	0.0100000000000000002
61062	MU2	340.899999999999977	0.197000000000000008
61062	2N2	326.600000000000023	0.226000000000000006
61062	OO1	315.199999999999989	0.0519999999999999976
61062	LDA2	33.2000000000000028	0.0560000000000000012
61062	M1	295.100000000000023	0.0850000000000000061
61062	J1	308.399999999999977	0.0950000000000000011
61062	SA	243.699999999999989	0.394000000000000017
61062	MF	163	0.0919999999999999984
61062	RHO1	282.699999999999989	0.0459999999999999992
61062	Q1	281.699999999999989	0.235999999999999988
61062	T2	51	0.176999999999999991
61062	R2	53.7999999999999972	0.0229999999999999996
61062	2Q1	275.100000000000023	0.0330000000000000016
61062	P1	300.699999999999989	0.627000000000000002
61062	L2	41.7000000000000028	0.23000000000000001
61062	K2	55.2999999999999972	0.819999999999999951
61062	M8	349.399999999999977	0.0429999999999999966
61063	M2	32.2999999999999972	8.20500000000000007
61063	S2	63.1000000000000014	2.82500000000000018
61063	N2	1.60000000000000009	1.62400000000000011
61063	K1	307.899999999999977	2.11299999999999999
61063	M4	279.100000000000023	0.291999999999999982
61063	O1	291.100000000000023	1.2569999999999999
61063	M6	141.199999999999989	0.233000000000000013
61063	MK3	253.300000000000011	0.143999999999999989
61063	S4	17.8000000000000007	0.0299999999999999989
61063	MN4	259.899999999999977	0.115000000000000005
61063	NU2	22.6999999999999993	0.284999999999999976
61063	MU2	274.699999999999989	0.343999999999999972
61063	2N2	332.300000000000011	0.183999999999999997
61063	OO1	11.9000000000000004	0.0560000000000000012
61063	LDA2	60.1000000000000014	0.101999999999999993
61063	S1	107.5	0.0259999999999999988
61063	M1	353.100000000000023	0.0790000000000000008
61063	J1	342.300000000000011	0.0790000000000000008
61063	SA	243.699999999999989	0.394000000000000017
61063	MF	163	0.0919999999999999984
61063	RHO1	276.800000000000011	0.0459999999999999992
61063	Q1	290.199999999999989	0.209999999999999992
61063	T2	59.5	0.161000000000000004
61063	R2	97.4000000000000057	0.0490000000000000019
61063	2Q1	288.399999999999977	0.0229999999999999996
61063	P1	308.199999999999989	0.606999999999999984
61063	2SM2	282.699999999999989	0.0490000000000000019
61063	M3	103.900000000000006	0.0330000000000000016
61063	L2	79.9000000000000057	0.235999999999999988
61063	2MK3	244.900000000000006	0.147999999999999993
61063	K2	55.7999999999999972	0.797000000000000042
61063	M8	14	0.0330000000000000016
61063	MS4	319.100000000000023	0.23000000000000001
61064	M2	87.2000000000000028	10.2720000000000002
61064	S2	122.900000000000006	3.13600000000000012
61064	N2	50.1000000000000014	1.84699999999999998
61064	K1	326.100000000000023	2.21499999999999986
61064	M4	63.2999999999999972	0.643000000000000016
61064	O1	309.600000000000023	1.52200000000000002
61064	M6	297.600000000000023	0.338000000000000023
61064	S4	194.699999999999989	0.0660000000000000031
61064	NU2	55.1000000000000014	0.357999999999999985
61064	S6	235.300000000000011	0.0330000000000000016
61064	MU2	110.599999999999994	0.245999999999999996
61064	2N2	13.0999999999999996	0.245999999999999996
61064	OO1	342.5	0.0660000000000000031
61064	LDA2	103.799999999999997	0.0719999999999999946
61064	M1	317.899999999999977	0.107999999999999999
61064	J1	334.300000000000011	0.120999999999999996
61064	RHO1	302.600000000000023	0.0589999999999999969
61064	Q1	301.5	0.294999999999999984
61064	T2	121.5	0.183999999999999997
61064	R2	124.299999999999997	0.0259999999999999988
61064	2Q1	293.300000000000011	0.0389999999999999999
61064	P1	324.899999999999977	0.731999999999999984
61064	L2	124.200000000000003	0.288999999999999979
61064	K2	125.799999999999997	0.85299999999999998
61064	M8	295.399999999999977	0.0459999999999999992
61065	M2	75.0999999999999943	8.13599999999999923
61065	S2	108.900000000000006	2.42799999999999994
61065	N2	39.7000000000000028	1.46999999999999997
61065	K1	327.300000000000011	1.94199999999999995
61065	M4	15.6999999999999993	0.256000000000000005
61065	O1	313.399999999999977	1.18799999999999994
61065	M6	229.5	0.209999999999999992
61065	S4	132.400000000000006	0.0299999999999999989
61065	NU2	44.3999999999999986	0.284999999999999976
61065	S6	116.700000000000003	0.00300000000000000006
61065	MU2	98.9000000000000057	0.194000000000000006
61065	2N2	4.29999999999999982	0.194000000000000006
61065	OO1	340.699999999999989	0.0490000000000000019
61065	LDA2	90.7999999999999972	0.0560000000000000012
61065	M1	320.300000000000011	0.0850000000000000061
61065	J1	333.800000000000011	0.0950000000000000011
61065	SA	243.699999999999989	0.394000000000000017
61065	MF	163	0.0919999999999999984
61065	RHO1	307.5	0.0459999999999999992
61065	Q1	306.600000000000023	0.23000000000000001
61065	T2	107.5	0.143999999999999989
61065	R2	110.200000000000003	0.0200000000000000004
61065	2Q1	299.800000000000011	0.0299999999999999989
61065	P1	326.199999999999989	0.643000000000000016
61065	L2	110.5	0.226000000000000006
61065	K2	111.599999999999994	0.65900000000000003
61065	M8	128.199999999999989	0.0389999999999999999
61066	M2	96.7000000000000028	10.8659999999999997
61066	S2	139.400000000000006	3.08700000000000019
61066	N2	74	1.82400000000000007
61066	K1	336.399999999999977	2.06999999999999984
61066	M4	64.5999999999999943	0.731999999999999984
61066	O1	323.5	1.32899999999999996
61066	M6	333.100000000000023	0.435999999999999999
61066	S4	217.199999999999989	0.0429999999999999966
61066	NU2	77	0.353999999999999981
61066	S6	304.199999999999989	0.00700000000000000015
61066	MU2	53.8999999999999986	0.259000000000000008
61066	2N2	51.2999999999999972	0.242999999999999994
61066	OO1	349.100000000000023	0.0560000000000000012
61066	LDA2	116.5	0.0749999999999999972
61066	M1	329.899999999999977	0.0950000000000000011
61066	J1	342.600000000000023	0.104999999999999996
61066	SA	243.699999999999989	0.394000000000000017
61066	MF	163	0.0919999999999999984
61066	RHO1	317.899999999999977	0.0490000000000000019
61066	Q1	317.100000000000023	0.256000000000000005
61066	T2	137.699999999999989	0.179999999999999993
61066	R2	141.099999999999994	0.0259999999999999988
61066	2Q1	310.899999999999977	0.0330000000000000016
61066	P1	335.5	0.686000000000000054
61066	L2	119.400000000000006	0.304999999999999993
61066	K2	142.900000000000006	0.839999999999999969
61066	M8	293.800000000000011	0.0820000000000000034
61067	M2	105.200000000000003	11.4990000000000006
61067	S2	147.400000000000006	3.20500000000000007
61067	N2	79.2000000000000028	1.95900000000000007
61067	K1	342.100000000000023	2.20100000000000007
61067	M4	80.7000000000000028	0.889000000000000012
61067	O1	325	1.21700000000000008
61067	M6	18.1999999999999993	0.505000000000000004
61067	MK3	8.80000000000000071	0.269000000000000017
61067	S4	207	0.0660000000000000031
61067	MN4	60	0.315000000000000002
61067	NU2	82.2999999999999972	0.563999999999999946
61067	S6	278.399999999999977	0.00700000000000000015
61067	MU2	234	0.695999999999999952
61067	2N2	48.1000000000000014	0.187
61067	OO1	79.2999999999999972	0.0589999999999999969
61067	LDA2	111.099999999999994	0.304999999999999993
61067	S1	74.2000000000000028	0.0100000000000000002
61067	M1	40.2000000000000028	0.0980000000000000038
61067	J1	65.2000000000000028	0.0820000000000000034
61067	MM	36.1000000000000014	0.16700000000000001
61067	SSA	283	0.0790000000000000008
61067	SA	217.400000000000006	0.315000000000000002
61067	MSF	39.6000000000000014	0.443000000000000005
61067	MF	94.7000000000000028	0.0820000000000000034
61067	RHO1	296.199999999999989	0.0459999999999999992
61067	Q1	330.600000000000023	0.197000000000000008
61067	T2	128.699999999999989	0.176999999999999991
61067	R2	233.5	0.0359999999999999973
61067	2Q1	328.399999999999977	0.0160000000000000003
61067	P1	340.899999999999977	0.576999999999999957
61067	2SM2	348.600000000000023	0.187
61067	M3	148	0.0589999999999999969
61067	L2	125.200000000000003	0.691999999999999948
61067	2MK3	21.1999999999999993	0.325000000000000011
61067	K2	138.099999999999994	0.889000000000000012
61067	M8	346.199999999999989	0.147999999999999993
61067	MS4	128.199999999999989	0.573999999999999955
61067	SIG1	24.3999999999999986	0.153999999999999998
61067	MP1	67.2000000000000028	0.216999999999999998
61067	CHI1	278.399999999999977	0.0229999999999999996
61067	2PO1	143	0.0589999999999999969
61067	SO1	151.099999999999994	0.242999999999999994
61067	MSN2	335.100000000000023	0.164000000000000007
61067	MNS2	201.800000000000011	0.194000000000000006
61067	OP2	100.5	0.0229999999999999996
61067	MKS2	300.100000000000023	0.0519999999999999976
61067	2NS2	167.199999999999989	0.0299999999999999989
61067	MLN2S2	201.5	0.128000000000000003
61067	2ML2S2	43.3999999999999986	0.0820000000000000034
61067	SKM2	340.699999999999989	0.0790000000000000008
61067	2MS2K2	245	0.0160000000000000003
61067	MKL2S2	108.5	0.0100000000000000002
61067	M2(KS)2	126.900000000000006	0.0229999999999999996
61067	2SN(MK)2	137.699999999999989	0.00300000000000000006
61067	2KM(SN)2	167.5	0.00700000000000000015
61067	SO3	31.3999999999999986	0.173999999999999988
61067	SK3	67.5999999999999943	0.138000000000000012
61067	NO3	353.699999999999989	0.135000000000000009
61067	MK4	122.200000000000003	0.140999999999999986
61067	SN4	146.900000000000006	0.0719999999999999946
61067	2MLS4	220.800000000000011	0.0919999999999999984
61067	3MS4	161.199999999999989	0.120999999999999996
61067	ML4	72.5999999999999943	0.0919999999999999984
61067	N4	36.3999999999999986	0.0589999999999999969
61067	SL4	117.400000000000006	0.0690000000000000058
61067	MNO5	249.699999999999989	0.0619999999999999996
61067	2MO5	268.300000000000011	0.115000000000000005
61067	2MK5	256.300000000000011	0.200000000000000011
61067	MSK5	324.600000000000023	0.0950000000000000011
61067	3KM5	305.5	0.0330000000000000016
61067	2MP5	285.100000000000023	0.0919999999999999984
61067	3MP5	357.399999999999977	0.0719999999999999946
61067	MNK5	239.099999999999994	0.0690000000000000058
61067	2SM6	114.599999999999994	0.0889999999999999958
61067	2MN6	352.699999999999989	0.266000000000000014
61067	MSN6	48.1000000000000014	0.0889999999999999958
61067	2MS6	59.3999999999999986	0.471999999999999975
61067	2NMLS6	297.699999999999989	0.0790000000000000008
61067	2NM6	325.399999999999977	0.0690000000000000058
61067	MSL6	70.2000000000000028	0.107999999999999999
61067	2ML6	34.2999999999999972	0.0820000000000000034
61067	MSK6	91.7999999999999972	0.0560000000000000012
61067	2MNLS6	325.100000000000023	0.101999999999999993
61067	3MLS6	176.099999999999994	0.0980000000000000038
61067	2MK6	46.7000000000000028	0.125
61067	2MNO7	245.699999999999989	0.0490000000000000019
61067	2NMK7	204.400000000000006	0.0129999999999999994
61067	2MSO7	293.199999999999989	0.0820000000000000034
61067	MSKO7	122.5	0.101999999999999993
61067	2MSN8	14	0.0790000000000000008
61067	3MS8	26	0.209999999999999992
61067	2(MS)8	80.2999999999999972	0.0749999999999999972
61067	2(MN)8	292.899999999999977	0.0359999999999999973
61067	3MN8	319.300000000000011	0.107999999999999999
61067	2MSL8	30.1000000000000014	0.0660000000000000031
61067	4MLS8	128.400000000000006	0.0459999999999999992
61067	3ML8	350.600000000000023	0.0259999999999999988
61067	3MK8	16.8000000000000007	0.0459999999999999992
61067	2MSK8	62.5	0.0459999999999999992
61067	2M2NK9	144.400000000000006	0.0100000000000000002
61067	3MNK9	171.400000000000006	0.0229999999999999996
61067	4MK9	201.199999999999989	0.0299999999999999989
61067	3MSK9	244.699999999999989	0.0459999999999999992
61067	4MN10	273.100000000000023	0.0519999999999999976
61067	M10	299.199999999999989	0.0560000000000000012
61067	3MNS10	315.199999999999989	0.0660000000000000031
61067	4MS10	336.300000000000011	0.112000000000000002
61067	3MSL10	346.300000000000011	0.0429999999999999966
61067	3M2S10	22.5	0.0619999999999999996
61067	4MSK11	204	0.0299999999999999989
61067	4MNS12	276.199999999999989	0.0459999999999999992
61067	5MS12	298.300000000000011	0.0589999999999999969
61067	4MSL12	307	0.0259999999999999988
61067	4M2S12	343	0.0459999999999999992
61067	TK1	352.899999999999977	0.0299999999999999989
61067	PSI1	322.100000000000023	0.0259999999999999988
61067	KP1	324.699999999999989	0.0129999999999999994
61067	THE1	310.699999999999989	0.0389999999999999999
61067	KJ2-IHO	314.899999999999977	0.0160000000000000003
61067	OQ2-HORN	31	0.0820000000000000034
61068	M2	105.900000000000006	11.8499999999999996
61068	S2	151.300000000000011	3.31000000000000005
61068	N2	83.4000000000000057	1.91599999999999993
61068	K1	340.899999999999977	2.07699999999999996
61068	M4	77.5	0.778000000000000025
61068	O1	328.5	1.28299999999999992
61068	M6	23.8999999999999986	0.646000000000000019
61068	S4	248.599999999999994	0.0389999999999999999
61068	NU2	86.4000000000000057	0.370999999999999996
61068	S6	276.399999999999977	0.00300000000000000006
61068	MU2	60.6000000000000014	0.284999999999999976
61068	2N2	60.8999999999999986	0.256000000000000005
61068	OO1	352.899999999999977	0.0560000000000000012
61068	LDA2	127	0.0820000000000000034
61068	M1	334.600000000000023	0.0919999999999999984
61068	J1	346.800000000000011	0.101999999999999993
61068	RHO1	323.199999999999989	0.0490000000000000019
61068	Q1	322.399999999999977	0.248999999999999999
61068	T2	149.400000000000006	0.194000000000000006
61068	R2	153	0.0259999999999999988
61068	2Q1	316.100000000000023	0.0330000000000000016
61068	P1	340	0.686000000000000054
61068	L2	128.5	0.331000000000000016
61068	K2	154.900000000000006	0.902000000000000024
61068	M8	350.899999999999977	0.171000000000000013
61069	M2	116.400000000000006	12.2210000000000001
61069	S2	161.300000000000011	3.6549999999999998
61069	N2	93.0999999999999943	2.22100000000000009
61069	K1	345.300000000000011	2.04700000000000015
61069	M4	114.5	1.12200000000000011
61069	O1	336.899999999999977	1.4890000000000001
61069	M6	73.5999999999999943	0.797000000000000042
61069	S4	306.800000000000011	0.0749999999999999972
61069	NU2	96.2999999999999972	0.429999999999999993
61069	S6	252.599999999999994	0.00700000000000000015
61069	MU2	71.5	0.291999999999999982
61069	2N2	69.9000000000000057	0.294999999999999984
61069	OO1	353.699999999999989	0.0660000000000000031
61069	LDA2	137.300000000000011	0.0850000000000000061
61069	M1	341.199999999999989	0.104999999999999996
61069	J1	349.5	0.117999999999999994
61069	MM	39.7000000000000028	0.203000000000000014
61069	SSA	45.6000000000000014	0.235999999999999988
61069	SA	230.199999999999989	0.176999999999999991
61069	MSF	50.3999999999999986	0.468999999999999972
61069	RHO1	333.300000000000011	0.0560000000000000012
61069	Q1	332.800000000000011	0.288999999999999979
61069	T2	159.5	0.216999999999999998
61069	R2	163.099999999999994	0.0299999999999999989
61069	2Q1	328.600000000000023	0.0389999999999999999
61069	P1	344.699999999999989	0.679000000000000048
61069	L2	139.699999999999989	0.341000000000000025
61069	K2	165	0.993999999999999995
61069	M8	73.9000000000000057	0.259000000000000008
61070	M2	323.5	5.32099999999999973
61070	S2	1.89999999999999991	1.90300000000000002
61070	N2	293.899999999999977	1.09600000000000009
61070	K1	288.100000000000023	1.56800000000000006
61070	M4	194.900000000000006	0.0330000000000000016
61070	O1	268.600000000000023	1.07000000000000006
61070	M6	7.70000000000000018	0.0259999999999999988
61070	S4	319.399999999999977	0.0200000000000000004
61070	NU2	297.899999999999977	0.212999999999999995
61070	S6	326.199999999999989	0.00300000000000000006
61070	MU2	337.300000000000011	0.128000000000000003
61070	2N2	264.300000000000011	0.147999999999999993
61070	OO1	307.600000000000023	0.0459999999999999992
61070	LDA2	341.300000000000011	0.0359999999999999973
61070	M1	278.399999999999977	0.0749999999999999972
61070	J1	297.800000000000011	0.0850000000000000061
61070	SSA	151.699999999999989	0.0490000000000000019
61070	SA	262.100000000000023	0.256000000000000005
61070	RHO1	260.199999999999989	0.0389999999999999999
61070	Q1	258.899999999999977	0.20699999999999999
61070	T2	0.299999999999999989	0.112000000000000002
61070	R2	3.39999999999999991	0.0160000000000000003
61070	2Q1	249.300000000000011	0.0299999999999999989
61070	P1	286.600000000000023	0.518000000000000016
61070	L2	353.199999999999989	0.147999999999999993
61070	K2	5	0.518000000000000016
61070	M8	89.7000000000000028	0.00700000000000000015
61071	M2	322.699999999999989	5.32800000000000029
61071	S2	358.699999999999989	1.90599999999999992
61071	N2	298.100000000000023	1.16500000000000004
61071	K1	287.199999999999989	1.56499999999999995
61071	M4	213.199999999999989	0.0490000000000000019
61071	O1	269.300000000000011	1.06299999999999994
61071	M6	35.7999999999999972	0.0229999999999999996
61071	S4	312.699999999999989	0.0200000000000000004
61071	NU2	301.399999999999977	0.226000000000000006
61071	S6	218.199999999999989	0.00700000000000000015
61071	MU2	338.100000000000023	0.128000000000000003
61071	2N2	273.5	0.153999999999999998
61071	OO1	305.199999999999989	0.0459999999999999992
61071	LDA2	339.399999999999977	0.0359999999999999973
61071	M1	278.300000000000011	0.0749999999999999972
61071	J1	296.100000000000023	0.0850000000000000061
61071	SSA	151.699999999999989	0.0490000000000000019
61071	SA	262.100000000000023	0.256000000000000005
61071	RHO1	261.600000000000023	0.0389999999999999999
61071	Q1	260.399999999999977	0.20699999999999999
61071	T2	357.199999999999989	0.112000000000000002
61071	R2	0.100000000000000006	0.0160000000000000003
61071	2Q1	251.5	0.0259999999999999988
61071	P1	285.899999999999977	0.518000000000000016
61071	L2	347.300000000000011	0.150999999999999995
61071	K2	1.60000000000000009	0.518000000000000016
61071	M8	72.2000000000000028	0.00300000000000000006
61072	M2	308.300000000000011	3.16900000000000004
61072	S2	341.600000000000023	1.14799999999999991
61072	N2	283.600000000000023	0.622999999999999998
61072	K1	284.600000000000023	1.31899999999999995
61072	M4	54.8999999999999986	0.0560000000000000012
61072	O1	273.800000000000011	0.797000000000000042
61072	M6	83.2999999999999972	0.0429999999999999966
61072	S4	141.099999999999994	0.0229999999999999996
61072	NU2	286.899999999999977	0.120999999999999996
61072	S6	198.699999999999989	0.0200000000000000004
61072	MU2	330.100000000000023	0.0749999999999999972
61072	2N2	258.800000000000011	0.0820000000000000034
61072	OO1	295.300000000000011	0.0359999999999999973
61072	LDA2	323.800000000000011	0.0229999999999999996
61072	M1	279.199999999999989	0.0560000000000000012
61072	J1	289.899999999999977	0.0619999999999999996
61072	SA	151.699999999999989	0.0490000000000000019
61072	MSF	262.100000000000023	0.256000000000000005
61072	RHO1	269.199999999999989	0.0299999999999999989
61072	Q1	268.5	0.153999999999999998
61072	T2	340.300000000000011	0.0690000000000000058
61072	R2	343	0.0100000000000000002
61072	2Q1	263.199999999999989	0.0200000000000000004
61072	P1	283.800000000000011	0.435999999999999999
61072	L2	333.100000000000023	0.0889999999999999958
61072	K2	344.300000000000011	0.312
61072	M8	202.699999999999989	0.0100000000000000002
61073	M2	307.399999999999977	3.16599999999999993
61073	S2	340.899999999999977	1.06299999999999994
61073	N2	283.399999999999977	0.656000000000000028
61073	K1	288.5	1.30200000000000005
61073	M4	24.6999999999999993	0.0299999999999999989
61073	O1	272.699999999999989	0.842999999999999972
61073	M6	85.9000000000000057	0.0330000000000000016
61073	MK3	259.600000000000023	0.0129999999999999994
61073	S4	175.599999999999994	0.00300000000000000006
61073	MN4	357.600000000000023	0.0100000000000000002
61073	NU2	285.100000000000023	0.128000000000000003
61073	S6	271	0.00300000000000000006
61073	MU2	277.800000000000011	0.0749999999999999972
61073	2N2	258.100000000000023	0.0790000000000000008
61073	OO1	311	0.0429999999999999966
61073	LDA2	306.300000000000011	0.0229999999999999996
61073	S1	49.8999999999999986	0.0429999999999999966
61073	M1	292.899999999999977	0.0459999999999999992
61073	J1	297.199999999999989	0.0749999999999999972
61073	SA	246.099999999999994	0.256000000000000005
61073	MSF	25.1999999999999993	0.0259999999999999988
61073	MF	193.300000000000011	0.107999999999999999
61073	RHO1	266.600000000000023	0.0299999999999999989
61073	Q1	264.600000000000023	0.147999999999999993
61073	T2	331	0.0660000000000000031
61073	R2	298.399999999999977	0.00300000000000000006
61073	2Q1	266.600000000000023	0.0200000000000000004
61073	P1	284.199999999999989	0.412999999999999978
61073	2SM2	130.900000000000006	0.0100000000000000002
61073	M3	286.800000000000011	0.00700000000000000015
61073	L2	314.899999999999977	0.0749999999999999972
61073	2MK3	240.800000000000011	0.0129999999999999994
61073	K2	332.100000000000023	0.288999999999999979
61073	M8	211.5	0.00700000000000000015
61073	MS4	69.9000000000000057	0.0200000000000000004
61074	M2	317.5	4.04900000000000038
61074	S2	355.5	1.43700000000000006
61074	N2	297.5	0.855999999999999983
61074	K1	287.399999999999977	1.43999999999999995
61074	M4	184.099999999999994	0.312
61074	O1	267.699999999999989	1.04699999999999993
61074	M6	37.7999999999999972	0.0850000000000000061
61074	S4	217.699999999999989	0.0100000000000000002
61074	NU2	300.199999999999989	0.16700000000000001
61074	S6	206.699999999999989	0.0160000000000000003
61074	MU2	279.5	0.0980000000000000038
61074	2N2	277.600000000000023	0.115000000000000005
61074	OO1	307.199999999999989	0.0459999999999999992
61074	LDA2	335.100000000000023	0.0299999999999999989
61074	M1	277.600000000000023	0.0749999999999999972
61074	J1	297.300000000000011	0.0820000000000000034
61074	SSA	151.699999999999989	0.0490000000000000019
61074	SA	262.100000000000023	0.256000000000000005
61074	RHO1	259.199999999999989	0.0389999999999999999
61074	Q1	257.899999999999977	0.203000000000000014
61074	T2	353.899999999999977	0.0850000000000000061
61074	R2	357	0.0129999999999999994
61074	2Q1	248	0.0259999999999999988
61074	P1	286	0.475999999999999979
61074	L2	337.399999999999977	0.115000000000000005
61074	K2	358.5	0.390000000000000013
61074	M8	81.4000000000000057	0.0330000000000000016
61075	M2	308.399999999999977	3.39900000000000002
61075	S2	342.199999999999989	1.27299999999999991
61075	N2	285.600000000000023	0.676000000000000045
61075	K1	286.600000000000023	1.29899999999999993
61075	M4	15.8000000000000007	0.0259999999999999988
61075	O1	273.399999999999977	0.859999999999999987
61075	M6	102.5	0.0429999999999999966
61075	S4	176.699999999999989	0.00700000000000000015
61075	NU2	288.600000000000023	0.131000000000000005
61075	S6	225	0.0129999999999999994
61075	MU2	328.899999999999977	0.0820000000000000034
61075	2N2	262.699999999999989	0.0889999999999999958
61075	OO1	299.800000000000011	0.0359999999999999973
61075	LDA2	324.100000000000023	0.0229999999999999996
61075	M1	280.100000000000023	0.0619999999999999996
61075	J1	293.199999999999989	0.0690000000000000058
61075	SSA	151.699999999999989	0.0490000000000000019
61075	SA	262.100000000000023	0.256000000000000005
61075	RHO1	267.800000000000011	0.0330000000000000016
61075	Q1	266.899999999999977	0.16700000000000001
61075	T2	340.800000000000011	0.0749999999999999972
61075	R2	343.5	0.0100000000000000002
61075	2Q1	260.300000000000011	0.0229999999999999996
61075	P1	285.600000000000023	0.429999999999999993
61075	L2	331.199999999999989	0.0950000000000000011
61075	K2	344.899999999999977	0.343999999999999972
61075	M8	236.599999999999994	0.0129999999999999994
61076	M2	308.800000000000011	3.46799999999999997
61076	S2	340.300000000000011	1.15199999999999991
61076	N2	284.600000000000023	0.768000000000000016
61076	K1	288.699999999999989	1.37799999999999989
61076	M4	21.1000000000000014	0.0259999999999999988
61076	O1	273.699999999999989	0.868999999999999995
61076	M6	86.7000000000000028	0.0490000000000000019
61076	S4	265.399999999999977	0.0100000000000000002
61076	NU2	287.899999999999977	0.147999999999999993
61076	S6	123.5	0.0160000000000000003
61076	MU2	277.300000000000011	0.0820000000000000034
61076	2N2	260.5	0.101999999999999993
61076	OO1	303.699999999999989	0.0359999999999999973
61076	LDA2	323.399999999999977	0.0229999999999999996
61076	M1	281.300000000000011	0.0619999999999999996
61076	J1	296.199999999999989	0.0690000000000000058
61076	MM	191.699999999999989	0.0619999999999999996
61076	SSA	151.699999999999989	0.0490000000000000019
61076	SA	262.100000000000023	0.256000000000000005
61076	MSF	51.5	0.0490000000000000019
61076	MF	165.199999999999989	0.0660000000000000031
61076	RHO1	267.300000000000011	0.0330000000000000016
61076	Q1	266.300000000000011	0.16700000000000001
61076	T2	339	0.0690000000000000058
61076	R2	341.600000000000023	0.0100000000000000002
61076	2Q1	258.899999999999977	0.0229999999999999996
61076	P1	287.600000000000023	0.456000000000000016
61076	L2	332.899999999999977	0.0980000000000000038
61076	K2	342.899999999999977	0.315000000000000002
61076	M8	260.800000000000011	0.0129999999999999994
61077	M2	323.899999999999977	5.19700000000000006
61077	S2	2.39999999999999991	1.93199999999999994
61077	N2	303.600000000000023	1.129
61077	K1	286.600000000000023	1.59400000000000008
61077	M4	191.400000000000006	0.0560000000000000012
61077	O1	267.800000000000011	1.07299999999999995
61077	M6	16.1999999999999993	0.101999999999999993
61077	S4	317.800000000000011	0.0160000000000000003
61077	NU2	306.300000000000011	0.220000000000000001
61077	S6	182.400000000000006	0.00300000000000000006
61077	MU2	285.300000000000011	0.125
61077	2N2	283.399999999999977	0.150999999999999995
61077	OO1	305.399999999999977	0.0459999999999999992
61077	LDA2	341.800000000000011	0.0359999999999999973
61077	M1	277.300000000000011	0.0749999999999999972
61077	J1	295.899999999999977	0.0850000000000000061
61077	SSA	151.699999999999989	0.0490000000000000019
61077	SA	262.100000000000023	0.256000000000000005
61077	RHO1	259.800000000000011	0.0389999999999999999
61077	Q1	258.5	0.20699999999999999
61077	T2	0.900000000000000022	0.115000000000000005
61077	R2	4	0.0160000000000000003
61077	2Q1	249.199999999999989	0.0299999999999999989
61077	P1	285.199999999999989	0.528000000000000025
61077	L2	344.100000000000023	0.143999999999999989
61077	K2	5.59999999999999964	0.525000000000000022
61077	M8	116.900000000000006	0.00300000000000000006
61078	M2	323.399999999999977	5.49899999999999967
61078	S2	357.600000000000023	2.01399999999999979
61078	N2	302	1.09899999999999998
61078	K1	285.800000000000011	1.73199999999999998
61078	M4	225.699999999999989	0.0589999999999999969
61078	O1	269.399999999999977	1.01400000000000001
61078	M6	15.9000000000000004	0.0259999999999999988
61078	S4	337.5	0.00700000000000000015
61078	NU2	304.899999999999977	0.212999999999999995
61078	S6	184.900000000000006	0.00700000000000000015
61078	MU2	289.199999999999989	0.131000000000000005
61078	2N2	280.699999999999989	0.147999999999999993
61078	OO1	302.100000000000023	0.0429999999999999966
61078	LDA2	339.300000000000011	0.0389999999999999999
61078	M1	277.600000000000023	0.0719999999999999946
61078	J1	293.899999999999977	0.0790000000000000008
61078	SA	250.199999999999989	0.412999999999999978
61078	MF	171.699999999999989	0.0749999999999999972
61078	RHO1	262.300000000000011	0.0389999999999999999
61078	Q1	261.199999999999989	0.197000000000000008
61078	T2	356.300000000000011	0.117999999999999994
61078	R2	359	0.0160000000000000003
61078	2Q1	253.099999999999994	0.0259999999999999988
61078	P1	284.5	0.573999999999999955
61078	L2	344.800000000000011	0.153999999999999998
61078	K2	0.400000000000000022	0.548000000000000043
61078	M8	105.799999999999997	0.00300000000000000006
61079	M2	298.699999999999989	2.97900000000000009
61079	S2	329.199999999999989	1.07600000000000007
61079	N2	274.600000000000023	0.59099999999999997
61079	K1	272.199999999999989	1.09899999999999998
61079	M4	45.2000000000000028	0.0129999999999999994
61079	O1	258.100000000000023	0.744999999999999996
61079	M6	155.599999999999994	0.0100000000000000002
61079	S4	211.5	0.0299999999999999989
61079	NU2	277.800000000000011	0.115000000000000005
61079	S6	352.199999999999989	0.00700000000000000015
61079	MU2	268.100000000000023	0.0719999999999999946
61079	2N2	250.5	0.0790000000000000008
61079	OO1	286.399999999999977	0.0330000000000000016
61079	LDA2	312.899999999999977	0.0200000000000000004
61079	M1	265.199999999999989	0.0519999999999999976
61079	J1	279.199999999999989	0.0589999999999999969
61079	RHO1	252.099999999999994	0.0299999999999999989
61079	Q1	251.099999999999994	0.143999999999999989
61079	T2	328	0.0619999999999999996
61079	R2	330.5	0.0100000000000000002
61079	2Q1	244.099999999999994	0.0200000000000000004
61079	P1	271.199999999999989	0.36399999999999999
61079	L2	322.800000000000011	0.0820000000000000034
61079	K2	331.699999999999989	0.291999999999999982
61079	M8	122.599999999999994	0.00300000000000000006
61080	M2	298.899999999999977	2.99500000000000011
61080	S2	327	1.0169999999999999
61080	N2	276	0.65900000000000003
61080	K1	270.899999999999977	1.20100000000000007
61080	M4	169.099999999999994	0.0129999999999999994
61080	O1	262	0.721999999999999975
61080	M6	158.5	0.0200000000000000004
61080	S4	214.599999999999994	0.00700000000000000015
61080	NU2	279.100000000000023	0.128000000000000003
61080	S6	179.599999999999994	0.00300000000000000006
61080	MU2	324.199999999999989	0.0719999999999999946
61080	2N2	253.099999999999994	0.0889999999999999958
61080	OO1	279.699999999999989	0.0330000000000000016
61080	LDA2	311.899999999999977	0.0200000000000000004
61080	M1	266.5	0.0519999999999999976
61080	J1	275.300000000000011	0.0560000000000000012
61080	SSA	151.699999999999989	0.0490000000000000019
61080	SA	262.100000000000023	0.256000000000000005
61080	RHO1	258.199999999999989	0.0259999999999999988
61080	Q1	257.600000000000023	0.140999999999999986
61080	T2	325.800000000000011	0.0589999999999999969
61080	R2	328.100000000000023	0.0100000000000000002
61080	2Q1	253.199999999999989	0.0200000000000000004
61080	P1	270.199999999999989	0.39700000000000002
61080	L2	321.800000000000011	0.0850000000000000061
61080	K2	329.199999999999989	0.276000000000000023
61080	M8	91.7000000000000028	0.0100000000000000002
61081	M2	322.699999999999989	5.44000000000000039
61081	S2	359.300000000000011	2.00499999999999989
61081	N2	300.600000000000023	1.14799999999999991
61081	K1	286.100000000000023	1.63100000000000001
61081	M4	217.699999999999989	0.0490000000000000019
61081	O1	268.300000000000011	1.05600000000000005
61081	M6	20	0.0259999999999999988
61081	S4	315.5	0.0129999999999999994
61081	NU2	303.600000000000023	0.223000000000000004
61081	S6	218.800000000000011	0.00300000000000000006
61081	MU2	286	0.131000000000000005
61081	2N2	278.5	0.150999999999999995
61081	OO1	304	0.0459999999999999992
61081	LDA2	339.699999999999989	0.0389999999999999999
61081	M1	277.300000000000011	0.0749999999999999972
61081	J1	295	0.0820000000000000034
61081	SA	250.199999999999989	0.412999999999999978
61081	MF	171.699999999999989	0.0749999999999999972
61081	RHO1	260.699999999999989	0.0389999999999999999
61081	Q1	259.5	0.203000000000000014
61081	T2	357.800000000000011	0.117999999999999994
61081	R2	0.800000000000000044	0.0160000000000000003
61081	2Q1	250.699999999999989	0.0259999999999999988
61081	P1	284.800000000000011	0.538000000000000034
61081	L2	344.800000000000011	0.150999999999999995
61081	K2	2.29999999999999982	0.54500000000000004
61081	M8	198.599999999999994	0.00300000000000000006
61082	M2	299.399999999999977	2.98899999999999988
61082	S2	330.699999999999989	1.004
61082	N2	278	0.640000000000000013
61082	K1	268.899999999999977	1.11899999999999999
61082	M4	149.400000000000006	0.0100000000000000002
61082	O1	256.300000000000011	0.744999999999999996
61082	M6	151.800000000000011	0.0129999999999999994
61082	S4	193.300000000000011	0.0100000000000000002
61082	NU2	280.899999999999977	0.120999999999999996
61082	S6	224.199999999999989	0.00700000000000000015
61082	MU2	268.100000000000023	0.0719999999999999946
61082	2N2	256.699999999999989	0.0850000000000000061
61082	OO1	281.5	0.0330000000000000016
61082	LDA2	314	0.0200000000000000004
61082	M1	262.699999999999989	0.0519999999999999976
61082	J1	275.199999999999989	0.0589999999999999969
61082	MM	191.699999999999989	0.0619999999999999996
61082	SSA	151.699999999999989	0.0490000000000000019
61082	SA	262.100000000000023	0.256000000000000005
61082	MSF	51.5	0.0490000000000000019
61082	MF	165.199999999999989	0.0660000000000000031
61082	RHO1	251	0.0299999999999999989
61082	Q1	250.099999999999994	0.143999999999999989
61082	T2	329.5	0.0589999999999999969
61082	R2	332	0.00700000000000000015
61082	2Q1	243.900000000000006	0.0200000000000000004
61082	P1	268	0.366999999999999993
61082	L2	320.800000000000011	0.0820000000000000034
61082	K2	333.300000000000011	0.27200000000000002
61082	M8	337	0.00300000000000000006
61083	M2	322.600000000000023	5.32099999999999973
61083	S2	355.600000000000023	1.95199999999999996
61083	N2	303.100000000000023	1.07000000000000006
61083	K1	285.100000000000023	1.7649999999999999
61083	M4	221.800000000000011	0.101999999999999993
61083	O1	268.899999999999977	1.02400000000000002
61083	M6	169.400000000000006	0.0200000000000000004
61083	S4	318	0.0259999999999999988
61083	NU2	305.699999999999989	0.20699999999999999
61083	S6	278.600000000000023	0.00300000000000000006
61083	MU2	341.600000000000023	0.128000000000000003
61083	2N2	283.600000000000023	0.140999999999999986
61083	OO1	301.399999999999977	0.0429999999999999966
61083	LDA2	337.899999999999977	0.0359999999999999973
61083	M1	277.100000000000023	0.0719999999999999946
61083	J1	293.199999999999989	0.0820000000000000034
61083	SSA	151.699999999999989	0.0490000000000000019
61083	SA	262.100000000000023	0.256000000000000005
61083	RHO1	261.899999999999977	0.0389999999999999999
61083	Q1	260.800000000000011	0.200000000000000011
61083	T2	354.199999999999989	0.115000000000000005
61083	R2	356.899999999999977	0.0160000000000000003
61083	2Q1	252.699999999999989	0.0259999999999999988
61083	P1	283.899999999999977	0.583999999999999964
61083	L2	342	0.147999999999999993
61083	K2	358.199999999999989	0.531000000000000028
61083	M8	6.20000000000000018	0.00300000000000000006
61084	M2	302.100000000000023	3.16900000000000004
61084	S2	332.300000000000011	1.1379999999999999
61084	N2	277.199999999999989	0.656000000000000028
61084	K1	269.800000000000011	1.17500000000000004
61084	M4	201.699999999999989	0.0560000000000000012
61084	O1	255.5	0.751000000000000001
61084	M6	175.599999999999994	0.0259999999999999988
61084	S4	218	0.0160000000000000003
61084	NU2	280.5	0.128000000000000003
61084	S6	329.399999999999977	0.00300000000000000006
61084	MU2	271.800000000000011	0.0749999999999999972
61084	2N2	252.400000000000006	0.0889999999999999958
61084	OO1	284.199999999999989	0.0330000000000000016
61084	LDA2	316.100000000000023	0.0229999999999999996
61084	M1	262.699999999999989	0.0519999999999999976
61084	J1	276.899999999999977	0.0589999999999999969
61084	RHO1	249.400000000000006	0.0299999999999999989
61084	Q1	248.400000000000006	0.143999999999999989
61084	T2	331.100000000000023	0.0660000000000000031
61084	R2	333.5	0.0100000000000000002
61084	2Q1	241.300000000000011	0.0200000000000000004
61084	P1	268.800000000000011	0.387000000000000011
61084	L2	326.899999999999977	0.0889999999999999958
61084	K2	334.699999999999989	0.307999999999999996
61084	M8	38.7000000000000028	0.00700000000000000015
61085	M2	319.300000000000011	5.26600000000000001
61085	S2	357.199999999999989	1.89599999999999991
61085	N2	293.899999999999977	1.06000000000000005
61085	K1	284.800000000000011	1.6339999999999999
61085	M4	219.300000000000011	0.0820000000000000034
61085	O1	267.699999999999989	1.07000000000000006
61085	M6	51.3999999999999986	0.0100000000000000002
61085	S4	319.300000000000011	0.0229999999999999996
61085	NU2	297.300000000000011	0.20699999999999999
61085	S6	356.300000000000011	0.00300000000000000006
61085	MU2	333.399999999999977	0.128000000000000003
61085	2N2	268.5	0.140999999999999986
61085	OO1	301.899999999999977	0.0459999999999999992
61085	LDA2	336.800000000000011	0.0359999999999999973
61085	M1	276.300000000000011	0.0749999999999999972
61085	J1	293.300000000000011	0.0850000000000000061
61085	SSA	151.699999999999989	0.0490000000000000019
61085	SA	262.100000000000023	0.256000000000000005
61085	RHO1	260.300000000000011	0.0389999999999999999
61085	Q1	259.199999999999989	0.20699999999999999
61085	T2	355.600000000000023	0.112000000000000002
61085	R2	358.699999999999989	0.0160000000000000003
61085	2Q1	250.699999999999989	0.0259999999999999988
61085	P1	283.5	0.541000000000000036
61085	L2	344.600000000000023	0.147999999999999993
61085	K2	0.200000000000000011	0.515000000000000013
61085	M8	173.300000000000011	0.00300000000000000006
61086	M2	314.199999999999989	4.42600000000000016
61086	S2	348.5	1.59400000000000008
61086	N2	291.300000000000011	0.932000000000000051
61086	K1	280.399999999999977	1.62400000000000011
61086	M4	209.599999999999994	0.107999999999999999
61086	O1	265.300000000000011	1.01400000000000001
61086	M6	89.7999999999999972	0.0429999999999999966
61086	MK3	103.400000000000006	0.0560000000000000012
61086	S4	299.699999999999989	0.0129999999999999994
61086	MN4	177.800000000000011	0.0389999999999999999
61086	NU2	291.300000000000011	0.173999999999999988
61086	S6	82.9000000000000057	0.00300000000000000006
61086	MU2	296	0.164000000000000007
61086	2N2	266.399999999999977	0.115000000000000005
61086	OO1	313.300000000000011	0.0560000000000000012
61086	LDA2	265.100000000000023	0.0299999999999999989
61086	S1	55.2000000000000028	0.0490000000000000019
61086	M1	293.199999999999989	0.0589999999999999969
61086	J1	298.199999999999989	0.0980000000000000038
61086	SSA	328.300000000000011	0.0160000000000000003
61086	SA	243.599999999999994	0.233000000000000013
61086	MF	184.099999999999994	0.107999999999999999
61086	RHO1	254.199999999999989	0.0330000000000000016
61086	Q1	258.100000000000023	0.183999999999999997
61086	T2	338.5	0.0950000000000000011
61086	2Q1	257.699999999999989	0.0229999999999999996
61086	P1	277.399999999999977	0.512000000000000011
61086	2SM2	101	0.0299999999999999989
61086	L2	299.699999999999989	0.0919999999999999984
61086	2MK3	71.9000000000000057	0.0490000000000000019
61086	K2	339.300000000000011	0.422999999999999987
61086	M8	325	0.0100000000000000002
61086	MS4	258.699999999999989	0.0690000000000000058
61087	M2	321.800000000000011	4.68200000000000038
61087	S2	357.600000000000023	1.59800000000000009
61087	N2	297.699999999999989	1.04000000000000004
61087	K1	286.399999999999977	1.52899999999999991
61087	M4	215.300000000000011	0.0950000000000000011
61087	O1	268.100000000000023	1.04699999999999993
61087	M6	154.099999999999994	0.0200000000000000004
61087	S4	303.199999999999989	0.0229999999999999996
61087	NU2	301	0.200000000000000011
61087	S6	28.1000000000000014	0.00300000000000000006
61087	MU2	286.100000000000023	0.112000000000000002
61087	2N2	273.600000000000023	0.138000000000000012
61087	OO1	304.600000000000023	0.0459999999999999992
61087	LDA2	338.399999999999977	0.0330000000000000016
61087	M1	277.300000000000011	0.0749999999999999972
61087	J1	295.399999999999977	0.0820000000000000034
61087	SSA	151.699999999999989	0.0490000000000000019
61087	SA	262.100000000000023	0.256000000000000005
61087	RHO1	260.300000000000011	0.0389999999999999999
61087	Q1	259.100000000000023	0.203000000000000014
61087	T2	356.100000000000023	0.0950000000000000011
61087	R2	359	0.0129999999999999994
61087	2Q1	250	0.0259999999999999988
61087	P1	285	0.505000000000000004
61087	L2	345.899999999999977	0.131000000000000005
61087	K2	0.5	0.435999999999999999
61087	M8	91.9000000000000057	0.00700000000000000015
61088	M2	302.899999999999977	2.96300000000000008
61088	S2	335.399999999999977	1.0169999999999999
61088	N2	280.5	0.586999999999999966
61088	K1	277.199999999999989	1.44399999999999995
61088	M4	246	0.0690000000000000058
61088	O1	260.399999999999977	0.983999999999999986
61088	M6	254.199999999999989	0.0129999999999999994
61088	S4	258.199999999999989	0.0100000000000000002
61088	NU2	283.5	0.115000000000000005
61088	S6	249.599999999999994	0.00300000000000000006
61088	MU2	318.899999999999977	0.0719999999999999946
61088	2N2	258.199999999999989	0.0790000000000000008
61088	OO1	294	0.0429999999999999966
61088	LDA2	318	0.0200000000000000004
61088	M1	268.899999999999977	0.0690000000000000058
61088	J1	285.5	0.0790000000000000008
61088	RHO1	253.199999999999989	0.0359999999999999973
61088	Q1	252.099999999999994	0.190000000000000002
61088	T2	334.100000000000023	0.0589999999999999969
61088	R2	336.699999999999989	0.0100000000000000002
61088	2Q1	243.800000000000011	0.0259999999999999988
61088	P1	275.899999999999977	0.478999999999999981
61088	L2	325.199999999999989	0.0820000000000000034
61088	K2	338	0.276000000000000023
61088	M8	149.199999999999989	0.00300000000000000006
61089	M2	315.699999999999989	3.15300000000000002
61089	S2	352.300000000000011	1.06299999999999994
61089	N2	292.100000000000023	0.653000000000000025
61089	K1	282	1.41700000000000004
61089	M4	254.800000000000011	0.0560000000000000012
61089	O1	265.699999999999989	0.95499999999999996
61089	M6	244.099999999999994	0.0229999999999999996
61089	S4	311.600000000000023	0.0100000000000000002
61089	NU2	295.199999999999989	0.125
61089	S6	184.099999999999994	0.00300000000000000006
61089	MU2	279.300000000000011	0.0749999999999999972
61089	2N2	268.399999999999977	0.0850000000000000061
61089	OO1	298.399999999999977	0.0389999999999999999
61089	LDA2	332.800000000000011	0.0229999999999999996
61089	M1	274	0.0660000000000000031
61089	J1	290.100000000000023	0.0749999999999999972
61089	SSA	54.2000000000000028	0.0490000000000000019
61089	SA	267.800000000000011	0.179999999999999993
61089	RHO1	258.699999999999989	0.0359999999999999973
61089	Q1	257.600000000000023	0.183999999999999997
61089	T2	350.800000000000011	0.0619999999999999996
61089	R2	353.800000000000011	0.0100000000000000002
61089	2Q1	249.5	0.0229999999999999996
61089	P1	280.699999999999989	0.468999999999999972
61089	L2	339.5	0.0889999999999999958
61089	K2	355.199999999999989	0.288999999999999979
61089	M8	250.400000000000006	0.00300000000000000006
61090	M2	9	3.32299999999999995
61090	S2	45.2999999999999972	1.17100000000000004
61090	N2	344.199999999999989	0.737999999999999989
61090	K1	311	1.42700000000000005
61090	M4	334	0.0790000000000000008
61090	O1	292.899999999999977	0.964999999999999969
61090	M6	22.5	0.0299999999999999989
61090	S4	19.5	0.0160000000000000003
61090	NU2	347.5	0.143999999999999989
61090	MU2	332.699999999999989	0.0790000000000000008
61090	2N2	319.5	0.0980000000000000038
61090	OO1	328.899999999999977	0.0429999999999999966
61090	LDA2	25.8000000000000007	0.0229999999999999996
61090	M1	302	0.0690000000000000058
61090	J1	319.899999999999977	0.0749999999999999972
61090	RHO1	285.199999999999989	0.0359999999999999973
61090	Q1	284.100000000000023	0.187
61090	T2	43.7000000000000028	0.0690000000000000058
61090	R2	46.7000000000000028	0.0100000000000000002
61090	2Q1	275.199999999999989	0.0259999999999999988
61090	P1	309.600000000000023	0.471999999999999975
61090	L2	33.7000000000000028	0.104999999999999996
61090	K2	48.1000000000000014	0.318000000000000005
61091	M2	324.5	3.04499999999999993
61091	S2	356.199999999999989	0.97799999999999998
61091	N2	301.300000000000011	0.653000000000000025
61091	K1	289.5	1.4830000000000001
61091	M4	259.699999999999989	0.0589999999999999969
61091	O1	271.899999999999977	0.944999999999999951
61091	M6	266.100000000000023	0.0359999999999999973
61091	S4	125	0.00300000000000000006
61091	NU2	304.399999999999977	0.128000000000000003
61091	S6	205.099999999999994	0.0100000000000000002
61091	MU2	292.800000000000011	0.0719999999999999946
61091	2N2	278	0.0850000000000000061
61091	OO1	307	0.0389999999999999999
61091	LDA2	339.199999999999989	0.0200000000000000004
61091	M1	280.800000000000011	0.0660000000000000031
61091	J1	298.199999999999989	0.0749999999999999972
61091	SA	272.300000000000011	0.404000000000000026
61091	RHO1	264.399999999999977	0.0359999999999999973
61091	Q1	263.199999999999989	0.183999999999999997
61091	T2	354.899999999999977	0.0589999999999999969
61091	R2	357.5	0.00700000000000000015
61091	2Q1	254.5	0.0229999999999999996
61091	P1	288.100000000000023	0.491999999999999993
61091	L2	347.699999999999989	0.0850000000000000061
61091	K2	358.800000000000011	0.266000000000000014
61091	M8	41.2000000000000028	0.00300000000000000006
61092	M2	323.100000000000023	2.66699999999999982
61092	S2	355.699999999999989	0.935000000000000053
61092	N2	298.699999999999989	0.59099999999999997
61092	K1	288.199999999999989	1.3620000000000001
61092	M4	249.800000000000011	0.0330000000000000016
61092	O1	273	0.912000000000000033
61092	M6	286.5	0.0359999999999999973
61092	S4	297	0.00300000000000000006
61092	NU2	302	0.115000000000000005
61092	S6	238.800000000000011	0.00700000000000000015
61092	MU2	333.300000000000011	0.0660000000000000031
61092	2N2	274.199999999999989	0.0790000000000000008
61092	OO1	303.399999999999977	0.0389999999999999999
61092	LDA2	338.300000000000011	0.0200000000000000004
61092	M1	280.699999999999989	0.0660000000000000031
61092	J1	295.699999999999989	0.0719999999999999946
61092	SA	272.300000000000011	0.404000000000000026
61092	RHO1	266.5	0.0359999999999999973
61092	Q1	265.5	0.176999999999999991
61092	T2	354.399999999999977	0.0560000000000000012
61092	R2	357	0.00700000000000000015
61092	2Q1	257.899999999999977	0.0229999999999999996
61092	P1	287.100000000000023	0.44900000000000001
61092	L2	347.600000000000023	0.0749999999999999972
61092	K2	358.399999999999977	0.256000000000000005
61092	M8	234.300000000000011	0.00300000000000000006
61093	M2	322.199999999999989	2.58899999999999997
61093	S2	351.199999999999989	0.899000000000000021
61093	N2	300.199999999999989	0.580999999999999961
61093	K1	286.199999999999989	1.40700000000000003
61093	M4	271.699999999999989	0.0299999999999999989
61093	O1	271.399999999999977	0.879000000000000004
61093	M6	290.600000000000023	0.0359999999999999973
61093	NU2	303.100000000000023	0.112000000000000002
61093	S6	252.5	0.00700000000000000015
61093	MU2	335.600000000000023	0.0619999999999999996
61093	2N2	278.100000000000023	0.0790000000000000008
61093	OO1	301.100000000000023	0.0389999999999999999
61093	LDA2	335.699999999999989	0.0200000000000000004
61093	M1	278.899999999999977	0.0619999999999999996
61093	J1	293.600000000000023	0.0690000000000000058
61093	RHO1	265	0.0330000000000000016
61093	Q1	264	0.171000000000000013
61093	T2	350	0.0519999999999999976
61093	R2	352.399999999999977	0.00700000000000000015
61093	2Q1	256.699999999999989	0.0229999999999999996
61093	P1	285.100000000000023	0.466000000000000025
61093	L2	344.199999999999989	0.0719999999999999946
61093	K2	353.5	0.245999999999999996
61093	M8	302.300000000000011	0.00300000000000000006
61094	M2	322.5	2.3879999999999999
61094	S2	353	0.813999999999999946
61094	N2	297.399999999999977	0.512000000000000011
61094	K1	286.600000000000023	1.371
61094	M4	308.399999999999977	0.0229999999999999996
61094	O1	270.300000000000011	0.915000000000000036
61094	M6	332.800000000000011	0.0200000000000000004
61094	S4	212.099999999999994	0.00700000000000000015
61094	NU2	300.699999999999989	0.0980000000000000038
61094	S6	250.400000000000006	0.00700000000000000015
61094	MU2	333.199999999999989	0.0560000000000000012
61094	2N2	272.199999999999989	0.0690000000000000058
61094	OO1	302.899999999999977	0.0389999999999999999
61094	LDA2	336.699999999999989	0.0160000000000000003
61094	M1	278.5	0.0660000000000000031
61094	J1	294.699999999999989	0.0719999999999999946
61094	SA	272.300000000000011	0.404000000000000026
61094	RHO1	263.300000000000011	0.0359999999999999973
61094	Q1	262.199999999999989	0.176999999999999991
61094	T2	351.800000000000011	0.0490000000000000019
61094	R2	354.300000000000011	0.00700000000000000015
61094	2Q1	254.099999999999994	0.0229999999999999996
61094	P1	285.399999999999977	0.453000000000000014
61094	L2	347.699999999999989	0.0660000000000000031
61094	K2	355.5	0.220000000000000001
61094	M8	39.2999999999999972	0.00300000000000000006
61095	M2	318.399999999999977	2.25700000000000012
61095	S2	344.699999999999989	0.771000000000000019
61095	N2	295.899999999999977	0.491999999999999993
61095	K1	282.199999999999989	1.35200000000000009
61095	M4	303.5	0.00300000000000000006
61095	O1	266	0.896000000000000019
61095	M6	353.800000000000011	0.0129999999999999994
61095	S4	227	0.0100000000000000002
61095	NU2	298.899999999999977	0.0950000000000000011
61095	S6	213.699999999999989	0.00300000000000000006
61095	MU2	292.199999999999989	0.0560000000000000012
61095	2N2	273.399999999999977	0.0660000000000000031
61095	OO1	298.300000000000011	0.0389999999999999999
61095	LDA2	330.600000000000023	0.0160000000000000003
61095	M1	274.199999999999989	0.0619999999999999996
61095	J1	290.199999999999989	0.0719999999999999946
61095	SA	272.300000000000011	0.404000000000000026
61095	RHO1	259.100000000000023	0.0330000000000000016
61095	Q1	258	0.173999999999999988
61095	T2	343.600000000000023	0.0459999999999999992
61095	R2	345.699999999999989	0.00700000000000000015
61095	2Q1	250	0.0229999999999999996
61095	P1	281	0.446000000000000008
61095	L2	340.899999999999977	0.0619999999999999996
61095	K2	346.800000000000011	0.209999999999999992
61095	M8	50.2000000000000028	0.00300000000000000006
61096	M2	322.199999999999989	2.4049999999999998
61096	S2	349.399999999999977	0.797000000000000042
61096	N2	299.300000000000011	0.52200000000000002
61096	K1	285.100000000000023	1.3620000000000001
61096	M4	276.100000000000023	0.0100000000000000002
61096	O1	270.300000000000011	0.872999999999999998
61096	M6	26.3999999999999986	0.0299999999999999989
61096	MK3	118.400000000000006	0.00300000000000000006
61096	S4	200.800000000000011	0.00700000000000000015
61096	MN4	264.899999999999977	0.00300000000000000006
61096	NU2	303	0.101999999999999993
61096	S6	282.800000000000011	0.00700000000000000015
61096	MU2	276.199999999999989	0.0589999999999999969
61096	2N2	273.800000000000011	0.0619999999999999996
61096	OO1	315.600000000000023	0.0459999999999999992
61096	LDA2	335.600000000000023	0.0160000000000000003
61096	S1	65	0.0299999999999999989
61096	M1	293.699999999999989	0.0490000000000000019
61096	J1	297.600000000000023	0.0820000000000000034
61096	SA	266.399999999999977	0.466000000000000025
61096	RHO1	262.199999999999989	0.0330000000000000016
61096	Q1	263.300000000000011	0.157000000000000001
61096	T2	340.199999999999989	0.0490000000000000019
61096	2Q1	269	0.0160000000000000003
61096	P1	281.699999999999989	0.426999999999999991
61096	2SM2	173.900000000000006	0.00700000000000000015
61096	M3	226.099999999999994	0.00700000000000000015
61096	L2	343.699999999999989	0.0519999999999999976
61096	2MK3	359.699999999999989	0.00300000000000000006
61096	K2	343.100000000000023	0.216999999999999998
61096	M8	36.6000000000000014	0.00300000000000000006
61096	MS4	301.800000000000011	0.0100000000000000002
61097	M2	324.100000000000023	2.49000000000000021
61097	S2	351.600000000000023	0.842999999999999972
61097	N2	301.5	0.528000000000000025
61097	K1	286.300000000000011	1.34200000000000008
61097	M4	267.800000000000011	0.00700000000000000015
61097	O1	270.600000000000023	0.868999999999999995
61097	M6	15.6999999999999993	0.0359999999999999973
61097	NU2	304.5	0.101999999999999993
61097	MU2	296.699999999999989	0.0589999999999999969
61097	2N2	279	0.0690000000000000058
61097	OO1	302	0.0359999999999999973
61097	LDA2	336.800000000000011	0.0160000000000000003
61097	M1	278.5	0.0619999999999999996
61097	J1	294.100000000000023	0.0690000000000000058
61097	SA	266.399999999999977	0.466000000000000025
61097	RHO1	263.899999999999977	0.0330000000000000016
61097	Q1	262.800000000000011	0.16700000000000001
61097	T2	350.399999999999977	0.0490000000000000019
61097	R2	352.699999999999989	0.00700000000000000015
61097	2Q1	255	0.0229999999999999996
61097	P1	285.100000000000023	0.443000000000000005
61097	L2	346.699999999999989	0.0690000000000000058
61097	K2	353.800000000000011	0.23000000000000001
61097	M8	20.8000000000000007	0.00300000000000000006
61098	M2	326.300000000000011	2.2410000000000001
61098	S2	356.199999999999989	0.717999999999999972
61098	N2	300.399999999999977	0.505000000000000004
61098	K1	285	1.27600000000000002
61098	M4	87.0999999999999943	0.00700000000000000015
61098	O1	270.100000000000023	0.842999999999999972
61098	M6	109.5	0.0619999999999999996
61098	S4	187.099999999999994	0.0129999999999999994
61098	NU2	303.899999999999977	0.0980000000000000038
61098	S6	96.0999999999999943	0.00700000000000000015
61098	MU2	332.800000000000011	0.0519999999999999976
61098	2N2	274.5	0.0690000000000000058
61098	OO1	299.899999999999977	0.0359999999999999973
61098	LDA2	340.199999999999989	0.0160000000000000003
61098	M1	277.600000000000023	0.0589999999999999969
61098	J1	292.399999999999977	0.0660000000000000031
61098	RHO1	263.699999999999989	0.0330000000000000016
61098	Q1	262.699999999999989	0.164000000000000007
61098	T2	355	0.0429999999999999966
61098	R2	357.399999999999977	0.00700000000000000015
61098	2Q1	255.300000000000011	0.0229999999999999996
61098	P1	283.899999999999977	0.422999999999999987
61098	L2	352.199999999999989	0.0619999999999999996
61098	K2	358.600000000000023	0.197000000000000008
61098	M8	94.5	0.00300000000000000006
61099	M2	328.199999999999989	2.21499999999999986
61099	S2	353.600000000000023	0.734999999999999987
61099	N2	303.899999999999977	0.48899999999999999
61099	K1	284.300000000000011	1.3620000000000001
61099	M4	45.6000000000000014	0.00700000000000000015
61099	O1	269.899999999999977	0.865999999999999992
61099	M6	133.900000000000006	0.0459999999999999992
61099	MK3	47.7000000000000028	0.00700000000000000015
61099	S4	207.199999999999989	0.00700000000000000015
61099	MN4	359.899999999999977	0.00300000000000000006
61099	NU2	308.699999999999989	0.0950000000000000011
61099	S6	175.599999999999994	0.00300000000000000006
61099	MU2	277.300000000000011	0.0589999999999999969
61099	2N2	276.399999999999977	0.0619999999999999996
61099	OO1	311	0.0429999999999999966
61099	LDA2	343	0.0129999999999999994
61099	S1	69	0.0389999999999999999
61099	M1	300.5	0.0459999999999999992
61099	J1	294.699999999999989	0.0749999999999999972
61099	SA	258.600000000000023	0.350999999999999979
61099	MF	170	0.0950000000000000011
61099	RHO1	256.600000000000023	0.0259999999999999988
61099	Q1	264.899999999999977	0.161000000000000004
61099	T2	343.699999999999989	0.0459999999999999992
61099	R2	295.899999999999977	0.00700000000000000015
61099	2Q1	270.899999999999977	0.0200000000000000004
61099	P1	279.800000000000011	0.422999999999999987
61099	2SM2	171.099999999999994	0.00300000000000000006
61099	M3	229	0.00700000000000000015
61099	L2	337.5	0.0519999999999999976
61099	2MK3	0.900000000000000022	0.00700000000000000015
61099	K2	346.100000000000023	0.200000000000000011
61099	M8	262	0.00300000000000000006
61100	M2	335.199999999999989	2.33899999999999997
61100	S2	359.5	0.758000000000000007
61100	N2	313.600000000000023	0.551000000000000045
61100	K1	288.800000000000011	1.40399999999999991
61100	M4	167.5	0.0229999999999999996
61100	O1	277.600000000000023	0.85299999999999998
61100	M6	196.400000000000006	0.101999999999999993
61100	S4	183.599999999999994	0.0100000000000000002
61100	NU2	316.5	0.107999999999999999
61100	S6	217.199999999999989	0.0229999999999999996
61100	MU2	310.800000000000011	0.0560000000000000012
61100	2N2	291.899999999999977	0.0719999999999999946
61100	OO1	300.100000000000023	0.0359999999999999973
61100	LDA2	346.5	0.0160000000000000003
61100	M1	283.199999999999989	0.0589999999999999969
61100	J1	294.399999999999977	0.0690000000000000058
61100	SA	272.300000000000011	0.404000000000000026
61100	RHO1	272.800000000000011	0.0330000000000000016
61100	Q1	272	0.164000000000000007
61100	T2	358.600000000000023	0.0459999999999999992
61100	R2	0.5	0.00700000000000000015
61100	2Q1	266.399999999999977	0.0229999999999999996
61100	P1	288	0.466000000000000025
61100	L2	356.800000000000011	0.0660000000000000031
61100	K2	1.5	0.20699999999999999
61100	M8	195.699999999999989	0.00700000000000000015
61101	M2	178.300000000000011	0.740999999999999992
61101	S2	252.400000000000006	0.112000000000000002
61101	N2	134.400000000000006	0.197000000000000008
61101	K1	3.89999999999999991	1.11899999999999999
61101	O1	12.8000000000000007	0.778000000000000025
61101	NU2	140.300000000000011	0.0389999999999999999
61101	2N2	90.4000000000000057	0.0259999999999999988
61101	OO1	354.899999999999977	0.0330000000000000016
61101	S1	161.5	0.0490000000000000019
61101	M1	5.5	0.0389999999999999999
61101	J1	359.5	0.0619999999999999996
61101	SSA	197.300000000000011	0.259000000000000008
61101	SA	264.5	0.294999999999999984
61101	RHO1	16.6999999999999993	0.0299999999999999989
61101	Q1	16.3000000000000007	0.147999999999999993
61101	2Q1	21.6000000000000014	0.0200000000000000004
61101	P1	5.70000000000000018	0.381000000000000005
61101	L2	222.199999999999989	0.0200000000000000004
61101	K2	235.699999999999989	0.0330000000000000016
61102	M2	81.4000000000000057	0.63600000000000001
61102	S2	262.600000000000023	0.0619999999999999996
61102	N2	32.3999999999999986	0.23000000000000001
61102	K1	332.800000000000011	1.3680000000000001
61102	O1	310.300000000000011	0.937999999999999945
61102	MK3	113.599999999999994	0.00300000000000000006
61102	NU2	43.8999999999999986	0.0429999999999999966
61102	MU2	328.399999999999977	0.0330000000000000016
61102	2N2	352.100000000000023	0.0389999999999999999
61102	OO1	9.69999999999999929	0.0359999999999999973
61102	LDA2	137.699999999999989	0.00700000000000000015
61102	S1	101.900000000000006	0.0429999999999999966
61102	M1	335.100000000000023	0.0490000000000000019
61102	J1	346.100000000000023	0.0719999999999999946
61102	SSA	227.300000000000011	0.0950000000000000011
61102	SA	273.300000000000011	0.23000000000000001
61102	RHO1	298.699999999999989	0.0330000000000000016
61102	Q1	299.800000000000011	0.16700000000000001
61102	T2	321	0.0100000000000000002
61102	2Q1	306.199999999999989	0.0229999999999999996
61102	P1	326.699999999999989	0.429999999999999993
61102	2SM2	287.300000000000011	0.00300000000000000006
61102	M3	150.099999999999994	0.0100000000000000002
61102	L2	125.299999999999997	0.00700000000000000015
61102	K2	319.199999999999989	0.0129999999999999994
61103	M2	90.7999999999999972	0.563999999999999946
61103	S2	281.5	0.104999999999999996
61103	N2	36	0.220000000000000001
61103	K1	336	1.25
61103	M4	297.600000000000023	0.00700000000000000015
61103	O1	315.600000000000023	0.889000000000000012
61103	M6	250.699999999999989	0.00300000000000000006
61103	MK3	123.400000000000006	0.0100000000000000002
61103	MN4	241.699999999999989	0.00300000000000000006
61103	NU2	50.2000000000000028	0.0429999999999999966
61103	MU2	335	0.0359999999999999973
61103	2N2	351.699999999999989	0.0389999999999999999
61103	OO1	7	0.0330000000000000016
61103	S1	113.599999999999994	0.0459999999999999992
61103	M1	344.5	0.0429999999999999966
61103	J1	351.399999999999977	0.0660000000000000031
61103	SSA	235.800000000000011	0.0919999999999999984
61103	SA	254.699999999999989	0.190000000000000002
61103	RHO1	302.5	0.0330000000000000016
61103	Q1	305.5	0.164000000000000007
61103	T2	313.399999999999977	0.0129999999999999994
61103	R2	272.399999999999977	0.00300000000000000006
61103	2Q1	306.699999999999989	0.0160000000000000003
61103	P1	331.100000000000023	0.404000000000000026
61103	M3	155.199999999999989	0.0129999999999999994
61103	2MK3	69.9000000000000057	0.0100000000000000002
61103	K2	306.5	0.0330000000000000016
61104	M2	66.4000000000000057	0.859999999999999987
61104	S2	327	0.0519999999999999976
61104	N2	21.8999999999999986	0.307999999999999996
61104	K1	318.100000000000023	1.31600000000000006
61104	M4	341	0.0129999999999999994
61104	O1	302.600000000000023	0.879000000000000004
61104	MK3	92	0.0259999999999999988
61104	MN4	288.100000000000023	0.00300000000000000006
61104	NU2	32.6000000000000014	0.0589999999999999969
61104	MU2	326.699999999999989	0.0519999999999999976
61104	2N2	339.899999999999977	0.0519999999999999976
61104	OO1	358.5	0.0429999999999999966
61104	LDA2	136.300000000000011	0.00700000000000000015
61104	S1	138.599999999999994	0.0359999999999999973
61104	M1	324.100000000000023	0.0359999999999999973
61104	J1	327.100000000000023	0.0660000000000000031
61104	SSA	202.099999999999994	0.0660000000000000031
61104	SA	265.5	0.266000000000000014
61104	MF	176.199999999999989	0.135000000000000009
61104	RHO1	294.100000000000023	0.0299999999999999989
61104	Q1	296.699999999999989	0.161000000000000004
61104	T2	334.5	0.00700000000000000015
61104	R2	216.300000000000011	0.00700000000000000015
61104	2Q1	294.5	0.0229999999999999996
61104	P1	313.899999999999977	0.422999999999999987
61104	M3	157	0.0100000000000000002
61104	2MK3	50.5	0.0200000000000000004
61104	K2	23.8999999999999986	0.0330000000000000016
61105	M2	80.2000000000000028	0.88600000000000001
61105	S2	310	0.0820000000000000034
61105	N2	30.3000000000000007	0.338000000000000023
61105	K1	318.699999999999989	1.10899999999999999
61105	O1	306.800000000000011	0.747999999999999998
61105	NU2	42.5	0.0660000000000000031
61105	MU2	332.5	0.0560000000000000012
61105	2N2	346.5	0.0619999999999999996
61105	OO1	334.600000000000023	0.0389999999999999999
61105	LDA2	19.8999999999999986	0.00700000000000000015
61105	S1	96.5999999999999943	0.0259999999999999988
61105	M1	337.300000000000011	0.0429999999999999966
61105	J1	339.699999999999989	0.0660000000000000031
61105	SSA	216.199999999999989	0.128000000000000003
61105	SA	277.699999999999989	0.307999999999999996
61105	MF	208.400000000000006	0.0749999999999999972
61105	RHO1	292.300000000000011	0.0299999999999999989
61105	Q1	301	0.140999999999999986
61105	T2	337.5	0.0129999999999999994
61105	2Q1	295.899999999999977	0.0200000000000000004
61105	P1	318.399999999999977	0.353999999999999981
61105	M3	167.800000000000011	0.0129999999999999994
61105	L2	130.099999999999994	0.0490000000000000019
61105	K2	341	0.0259999999999999988
61106	M2	344.899999999999977	1.3879999999999999
61106	S2	359.399999999999977	0.491999999999999993
61106	N2	325	0.33500000000000002
61106	K1	287.600000000000023	1.21700000000000008
61106	M4	95.2999999999999972	0.0359999999999999973
61106	O1	273.399999999999977	0.816999999999999948
61106	M6	289	0.0490000000000000019
61106	S4	208.699999999999989	0.00300000000000000006
61106	NU2	327.699999999999989	0.0660000000000000031
61106	MU2	358	0.0330000000000000016
61106	2N2	305	0.0459999999999999992
61106	OO1	301.800000000000011	0.0359999999999999973
61106	LDA2	351.600000000000023	0.0100000000000000002
61106	M1	280.600000000000023	0.0589999999999999969
61106	J1	294.699999999999989	0.0660000000000000031
61106	RHO1	267.300000000000011	0.0330000000000000016
61106	Q1	266.399999999999977	0.157000000000000001
61106	T2	358.800000000000011	0.0299999999999999989
61106	R2	0	0.00300000000000000006
61106	2Q1	259.300000000000011	0.0229999999999999996
61106	P1	286.600000000000023	0.404000000000000026
61106	L2	4.90000000000000036	0.0389999999999999999
61106	K2	0.599999999999999978	0.135000000000000009
61106	M8	286.5	0.0160000000000000003
61107	M2	69.7000000000000028	0.85299999999999998
61107	S2	318.5	0.0719999999999999946
61107	N2	30.1000000000000014	0.307999999999999996
61107	K1	311.600000000000023	1.10899999999999999
61107	M4	182.400000000000006	0.0359999999999999973
61107	O1	300.199999999999989	0.787000000000000033
61107	M6	86.9000000000000057	0.0200000000000000004
61107	S4	19.8999999999999986	0.00700000000000000015
61107	NU2	35.3999999999999986	0.0589999999999999969
61107	S6	206.699999999999989	0.00300000000000000006
61107	MU2	208.599999999999994	0.0200000000000000004
61107	2N2	350.5	0.0429999999999999966
61107	OO1	323.100000000000023	0.0330000000000000016
61107	LDA2	18.1000000000000014	0.00700000000000000015
61107	M1	305.899999999999977	0.0560000000000000012
61107	J1	317.300000000000011	0.0619999999999999996
61107	RHO1	295.199999999999989	0.0299999999999999989
61107	Q1	294.5	0.153999999999999998
61107	T2	323	0.00300000000000000006
61107	2Q1	288.800000000000011	0.0200000000000000004
61107	P1	310.800000000000011	0.366999999999999993
61107	L2	109.299999999999997	0.0229999999999999996
61107	K2	309.5	0.0200000000000000004
61107	M8	86.7000000000000028	0.0160000000000000003
61108	M2	345.5	1.54499999999999993
61108	S2	359.899999999999977	0.498999999999999999
61108	N2	324.399999999999977	0.381000000000000005
61108	K1	285.699999999999989	1.2629999999999999
61108	M4	106.400000000000006	0.0389999999999999999
61108	O1	269.699999999999989	0.849999999999999978
61108	M6	290.199999999999989	0.0429999999999999966
61108	S4	235.099999999999994	0.0100000000000000002
61108	NU2	327.199999999999989	0.0719999999999999946
61108	S6	192.699999999999989	0.00300000000000000006
61108	MU2	331	0.0359999999999999973
61108	2N2	303.300000000000011	0.0490000000000000019
61108	OO1	301.899999999999977	0.0359999999999999973
61108	LDA2	352.199999999999989	0.0100000000000000002
61108	M1	277.800000000000011	0.0589999999999999969
61108	J1	293.699999999999989	0.0660000000000000031
61108	SSA	216.199999999999989	0.128000000000000003
61108	SA	277.699999999999989	0.307999999999999996
61108	MF	208.400000000000006	0.0749999999999999972
61108	RHO1	262.699999999999989	0.0330000000000000016
61108	Q1	261.699999999999989	0.164000000000000007
61108	T2	359.399999999999977	0.0299999999999999989
61108	R2	0.5	0.00300000000000000006
61108	2Q1	253.699999999999989	0.0229999999999999996
61108	P1	284.5	0.416999999999999982
61108	L2	6.59999999999999964	0.0429999999999999966
61108	K2	1.10000000000000009	0.135000000000000009
61108	M8	270.800000000000011	0.00700000000000000015
61109	M2	81.2999999999999972	0.912000000000000033
61109	S2	320	0.104999999999999996
61109	N2	31	0.322000000000000008
61109	K1	321.399999999999977	1.22399999999999998
61109	M4	156.699999999999989	0.0100000000000000002
61109	O1	302.600000000000023	0.810000000000000053
61109	M6	9.80000000000000071	0.00300000000000000006
61109	S4	309	0.00300000000000000006
61109	NU2	37.7999999999999972	0.0619999999999999996
61109	S6	79.5999999999999943	0.00300000000000000006
61109	MU2	231	0.0229999999999999996
61109	2N2	340.699999999999989	0.0429999999999999966
61109	OO1	340.300000000000011	0.0359999999999999973
61109	LDA2	25	0.00700000000000000015
61109	M1	312.100000000000023	0.0589999999999999969
61109	J1	330.800000000000011	0.0660000000000000031
61109	RHO1	294.5	0.0299999999999999989
61109	Q1	293.199999999999989	0.157000000000000001
61109	T2	324.899999999999977	0.00700000000000000015
61109	2Q1	283.899999999999977	0.0200000000000000004
61109	P1	320	0.404000000000000026
61109	L2	131.5	0.0259999999999999988
61109	K2	310.199999999999989	0.0299999999999999989
61109	M8	223.800000000000011	0.00300000000000000006
61110	M2	344.399999999999977	1.32499999999999996
61110	S2	356.600000000000023	0.518000000000000016
61110	N2	328	0.347999999999999976
61110	K1	289.300000000000011	1.21100000000000008
61110	M4	209.599999999999994	0.0160000000000000003
61110	O1	272.300000000000011	0.842999999999999972
61110	M6	195.599999999999994	0.00300000000000000006
61110	S4	211.900000000000006	0.00700000000000000015
61110	NU2	330.199999999999989	0.0660000000000000031
61110	S6	261.300000000000011	0.00300000000000000006
61110	MU2	332.100000000000023	0.0330000000000000016
61110	2N2	311.699999999999989	0.0459999999999999992
61110	OO1	306.300000000000011	0.0359999999999999973
61110	LDA2	350	0.0100000000000000002
61110	M1	280.899999999999977	0.0589999999999999969
61110	J1	297.699999999999989	0.0660000000000000031
61110	SSA	216.199999999999989	0.128000000000000003
61110	SA	277.699999999999989	0.307999999999999996
61110	MF	208.400000000000006	0.0749999999999999972
61110	RHO1	265	0.0330000000000000016
61110	Q1	263.800000000000011	0.164000000000000007
61110	T2	356.199999999999989	0.0299999999999999989
61110	R2	357.100000000000023	0.00300000000000000006
61110	2Q1	255.400000000000006	0.0229999999999999996
61110	P1	288	0.400000000000000022
61110	L2	0.699999999999999956	0.0359999999999999973
61110	K2	357.600000000000023	0.140999999999999986
61110	M8	229.900000000000006	0.00300000000000000006
61111	M2	83.7999999999999972	0.865999999999999992
61111	S2	300.800000000000011	0.0950000000000000011
61111	N2	32.1000000000000014	0.347999999999999976
61111	K1	318.300000000000011	1.21100000000000008
61111	M4	130	0.00700000000000000015
61111	O1	301.600000000000023	0.787000000000000033
61111	M6	348.199999999999989	0.00700000000000000015
61111	S4	266.100000000000023	0.0100000000000000002
61111	NU2	39	0.0690000000000000058
61111	S6	201.900000000000006	0.00300000000000000006
61111	MU2	226.699999999999989	0.0200000000000000004
61111	2N2	340.300000000000011	0.0459999999999999992
61111	OO1	334.899999999999977	0.0330000000000000016
61111	LDA2	17.5	0.00700000000000000015
61111	M1	310	0.0560000000000000012
61111	J1	326.5	0.0619999999999999996
61111	SSA	216.199999999999989	0.128000000000000003
61111	SA	277.699999999999989	0.307999999999999996
61111	MF	208.400000000000006	0.0749999999999999972
61111	RHO1	294.399999999999977	0.0299999999999999989
61111	Q1	293.300000000000011	0.153999999999999998
61111	T2	306.699999999999989	0.00700000000000000015
61111	2Q1	285.100000000000023	0.0200000000000000004
61111	P1	317	0.400000000000000022
61111	L2	135.5	0.0229999999999999996
61111	K2	289.399999999999977	0.0259999999999999988
61111	M8	256.300000000000011	0.00300000000000000006
61112	M2	69	0.509000000000000008
61112	S2	325.100000000000023	0.212999999999999995
61112	N2	26.6999999999999993	0.262000000000000011
61112	K1	316.199999999999989	1.03299999999999992
61112	M4	248.699999999999989	0.0259999999999999988
61112	O1	301.399999999999977	0.740999999999999992
61112	M6	180	0.00700000000000000015
61112	MK3	131.300000000000011	0.0229999999999999996
61112	S4	345.199999999999989	0.00300000000000000006
61112	MN4	185.400000000000006	0.0100000000000000002
61112	NU2	46.5	0.0519999999999999976
61112	MU2	338.100000000000023	0.0429999999999999966
61112	2N2	331.600000000000023	0.0660000000000000031
61112	OO1	318.899999999999977	0.0299999999999999989
61112	LDA2	237.199999999999989	0.00300000000000000006
61112	S1	318.300000000000011	0.0519999999999999976
61112	M1	327.100000000000023	0.0490000000000000019
61112	J1	324.399999999999977	0.0660000000000000031
61112	SSA	216.199999999999989	0.128000000000000003
61112	SA	277.699999999999989	0.307999999999999996
61112	RHO1	292.600000000000023	0.0259999999999999988
61112	Q1	293.5	0.147999999999999993
61112	T2	7.79999999999999982	0.0129999999999999994
61112	R2	308.5	0.0229999999999999996
61112	2Q1	301.5	0.0299999999999999989
61112	P1	316	0.288999999999999979
61112	2SM2	270.600000000000023	0.00700000000000000015
61112	M3	163.400000000000006	0.0129999999999999994
61112	L2	38.6000000000000014	0.0259999999999999988
61112	2MK3	192.800000000000011	0.0100000000000000002
61112	K2	325.100000000000023	0.0619999999999999996
61112	M8	70.5	0.00300000000000000006
61112	MS4	303.100000000000023	0.0200000000000000004
61113	M2	340.399999999999977	0.826999999999999957
61113	S2	336.399999999999977	0.400000000000000022
61113	N2	335.399999999999977	0.248999999999999999
61113	K1	300.100000000000023	1.07299999999999995
61113	M4	224.5	0.131000000000000005
61113	O1	285.5	0.781000000000000028
61113	M6	321.699999999999989	0.0200000000000000004
61113	S4	357	0.00300000000000000006
61113	NU2	336.199999999999989	0.0459999999999999992
61113	S6	260.199999999999989	0.00700000000000000015
61113	MU2	344.5	0.0200000000000000004
61113	2N2	330.100000000000023	0.0330000000000000016
61113	OO1	314.699999999999989	0.0330000000000000016
61113	LDA2	338.600000000000023	0.00700000000000000015
61113	M1	292.800000000000011	0.0560000000000000012
61113	J1	307.300000000000011	0.0619999999999999996
61113	SSA	216.199999999999989	0.128000000000000003
61113	SA	277.699999999999989	0.307999999999999996
61113	MF	208.400000000000006	0.0749999999999999972
61113	RHO1	279.300000000000011	0.0299999999999999989
61113	Q1	278.199999999999989	0.150999999999999995
61113	T2	336.600000000000023	0.0229999999999999996
61113	R2	336.300000000000011	0.00300000000000000006
61113	2Q1	271.100000000000023	0.0200000000000000004
61113	P1	299	0.353999999999999981
61113	L2	345.600000000000023	0.0229999999999999996
61113	K2	336.100000000000023	0.107999999999999999
61113	M8	106.099999999999994	0.00300000000000000006
61114	M2	340.600000000000023	1.3879999999999999
61114	S2	353.300000000000011	0.478999999999999981
61114	N2	322.399999999999977	0.384000000000000008
61114	K1	287.600000000000023	1.17500000000000004
61114	M4	218.199999999999989	0.0330000000000000016
61114	O1	272.100000000000023	0.810000000000000053
61114	M6	243	0.0299999999999999989
61114	S4	326.600000000000023	0.00700000000000000015
61114	NU2	324.899999999999977	0.0749999999999999972
61114	S6	189.099999999999994	0.00300000000000000006
61114	MU2	327.899999999999977	0.0330000000000000016
61114	2N2	304.300000000000011	0.0519999999999999976
61114	OO1	303.100000000000023	0.0359999999999999973
61114	LDA2	346.5	0.0100000000000000002
61114	M1	279.899999999999977	0.0589999999999999969
61114	J1	295.300000000000011	0.0660000000000000031
61114	SSA	216.199999999999989	0.128000000000000003
61114	SA	277.699999999999989	0.307999999999999996
61114	MF	208.400000000000006	0.0749999999999999972
61114	RHO1	265.399999999999977	0.0299999999999999989
61114	Q1	264.399999999999977	0.157000000000000001
61114	T2	352.800000000000011	0.0299999999999999989
61114	R2	353.800000000000011	0.00300000000000000006
61114	2Q1	256.699999999999989	0.0200000000000000004
61114	P1	286.399999999999977	0.387000000000000011
61114	L2	358.800000000000011	0.0389999999999999999
61114	K2	354.300000000000011	0.131000000000000005
61114	M8	229.800000000000011	0.0100000000000000002
61115	M2	25.6000000000000014	0.404000000000000026
61115	S2	323.800000000000011	0.279000000000000026
61115	N2	12.3000000000000007	0.256000000000000005
61115	K1	310.699999999999989	1.02699999999999991
61115	M4	203.900000000000006	0.0389999999999999999
61115	O1	296.5	0.731999999999999984
61115	M6	151.199999999999989	0.0200000000000000004
61115	S4	177.599999999999994	0.00300000000000000006
61115	NU2	14.1999999999999993	0.0490000000000000019
61115	S6	262.199999999999989	0.00300000000000000006
61115	MU2	87.4000000000000057	0.0100000000000000002
61115	2N2	359	0.0359999999999999973
61115	OO1	325.100000000000023	0.0330000000000000016
61115	LDA2	356.899999999999977	0.00300000000000000006
61115	M1	303.699999999999989	0.0519999999999999976
61115	J1	317.800000000000011	0.0560000000000000012
61115	SSA	216.199999999999989	0.128000000000000003
61115	SA	277.699999999999989	0.307999999999999996
61115	MF	208.400000000000006	0.0749999999999999972
61115	RHO1	290.399999999999977	0.0259999999999999988
61115	Q1	289.399999999999977	0.140999999999999986
61115	T2	326.300000000000011	0.0160000000000000003
61115	R2	321.300000000000011	0.00300000000000000006
61115	2Q1	282.300000000000011	0.0200000000000000004
61115	P1	309.699999999999989	0.341000000000000025
61115	L2	39	0.0100000000000000002
61115	K2	318.800000000000011	0.0749999999999999972
61115	M8	96	0.00700000000000000015
61116	M2	334.399999999999977	1.46700000000000008
61116	S2	355	0.54500000000000004
61116	N2	319	0.347999999999999976
61116	K1	288.199999999999989	1.20100000000000007
61116	M4	193.5	0.0229999999999999996
61116	O1	272.100000000000023	0.836999999999999966
61116	M6	334.899999999999977	0.0100000000000000002
61116	S4	246.800000000000011	0.00700000000000000015
61116	NU2	321.100000000000023	0.0660000000000000031
61116	S6	221.5	0.00300000000000000006
61116	MU2	313.699999999999989	0.0359999999999999973
61116	2N2	303.600000000000023	0.0459999999999999992
61116	OO1	304.199999999999989	0.0359999999999999973
61116	LDA2	344	0.0100000000000000002
61116	M1	280.199999999999989	0.0589999999999999969
61116	J1	296.100000000000023	0.0660000000000000031
61116	SSA	216.199999999999989	0.128000000000000003
61116	SA	277.699999999999989	0.307999999999999996
61116	MF	208.400000000000006	0.0749999999999999972
61116	RHO1	265.199999999999989	0.0330000000000000016
61116	Q1	264.100000000000023	0.161000000000000004
61116	T2	354.300000000000011	0.0330000000000000016
61116	R2	355.899999999999977	0.00300000000000000006
61116	2Q1	256.100000000000023	0.0229999999999999996
61116	P1	287	0.39700000000000002
61116	L2	349.899999999999977	0.0429999999999999966
61116	K2	356.800000000000011	0.147999999999999993
61116	M8	204.400000000000006	0.00300000000000000006
61117	M2	65.2000000000000028	1.34499999999999997
61117	S2	5.09999999999999964	0.0889999999999999958
61117	N2	24.5	0.443000000000000005
61117	K1	308.699999999999989	1.30600000000000005
61117	M4	200.199999999999989	0.0330000000000000016
61117	O1	296.100000000000023	0.925000000000000044
61117	M6	168.5	0.0129999999999999994
61117	S4	359.300000000000011	0.00300000000000000006
61117	NU2	30	0.0850000000000000061
61117	S6	275.699999999999989	0.00300000000000000006
61117	MU2	155.400000000000006	0.0330000000000000016
61117	2N2	343.899999999999977	0.0589999999999999969
61117	OO1	321.300000000000011	0.0389999999999999999
61117	LDA2	37.2999999999999972	0.0100000000000000002
61117	M1	302.5	0.0660000000000000031
61117	J1	315	0.0719999999999999946
61117	RHO1	290.699999999999989	0.0359999999999999973
61117	Q1	289.800000000000011	0.179999999999999993
61117	T2	7.5	0.00700000000000000015
61117	2Q1	283.600000000000023	0.0229999999999999996
61117	P1	307.800000000000011	0.432999999999999996
61117	L2	105.799999999999997	0.0389999999999999999
61117	K2	0.200000000000000011	0.0229999999999999996
61117	M8	102	0.00700000000000000015
61118	M2	356.300000000000011	1.66999999999999993
61118	S2	6.29999999999999982	0.515000000000000013
61118	N2	329.399999999999977	0.426999999999999991
61118	K1	292.5	1.4830000000000001
61118	M4	208.599999999999994	0.0790000000000000008
61118	O1	274.899999999999977	1.01000000000000001
61118	M6	9.30000000000000071	0.00300000000000000006
61118	NU2	333	0.0820000000000000034
61118	S6	175.099999999999994	0.00300000000000000006
61118	MU2	16.8000000000000007	0.0389999999999999999
61118	2N2	302.600000000000023	0.0560000000000000012
61118	OO1	310.199999999999989	0.0429999999999999966
61118	LDA2	0.900000000000000022	0.0129999999999999994
61118	M1	283.800000000000011	0.0719999999999999946
61118	J1	301.300000000000011	0.0790000000000000008
61118	SSA	216.199999999999989	0.128000000000000003
61118	SA	277.699999999999989	0.307999999999999996
61118	MF	208.400000000000006	0.0749999999999999972
61118	RHO1	267.300000000000011	0.0389999999999999999
61118	Q1	266.100000000000023	0.197000000000000008
61118	T2	5.90000000000000036	0.0299999999999999989
61118	R2	6.70000000000000018	0.00300000000000000006
61118	2Q1	257.300000000000011	0.0259999999999999988
61118	P1	291.199999999999989	0.491999999999999993
61118	L2	23.1000000000000014	0.0459999999999999992
61118	K2	7.09999999999999964	0.140999999999999986
61118	M8	122.900000000000006	0.00300000000000000006
61119	M2	117.200000000000003	2.32299999999999995
61119	S2	294.300000000000011	0.0660000000000000031
61119	N2	67.9000000000000057	0.822999999999999954
61119	K1	321.899999999999977	1.59099999999999997
61119	M4	106.200000000000003	0.0619999999999999996
61119	O1	305.699999999999989	1.07899999999999996
61119	M6	71.7999999999999972	0.0299999999999999989
61119	S4	76.7000000000000028	0.00700000000000000015
61119	NU2	74.5	0.161000000000000004
61119	S6	7.20000000000000018	0.0100000000000000002
61119	MU2	300.199999999999989	0.0560000000000000012
61119	2N2	18.5	0.107999999999999999
61119	OO1	338.100000000000023	0.0459999999999999992
61119	LDA2	199.400000000000006	0.0160000000000000003
61119	M1	313.899999999999977	0.0749999999999999972
61119	J1	329.899999999999977	0.0850000000000000061
61119	SSA	241.900000000000006	0.0229999999999999996
61119	SA	243.699999999999989	0.233000000000000013
61119	RHO1	298.800000000000011	0.0389999999999999999
61119	Q1	297.699999999999989	0.209999999999999992
61119	T2	287.199999999999989	0.00300000000000000006
61119	2Q1	289.600000000000023	0.0299999999999999989
61119	P1	320.699999999999989	0.525000000000000022
61119	L2	166.599999999999994	0.0660000000000000031
61119	K2	308.600000000000023	0.0160000000000000003
61119	M8	136.699999999999989	0.00300000000000000006
61120	M2	51.7999999999999972	0.774000000000000021
61120	S2	18.5	0.419999999999999984
61120	N2	46.2000000000000028	0.347999999999999976
61120	K1	312.399999999999977	1.34200000000000008
61120	M4	276.699999999999989	0.0690000000000000058
61120	O1	292.300000000000011	0.849999999999999978
61120	M6	238.599999999999994	0.0389999999999999999
61120	S4	230.900000000000006	0.0129999999999999994
61120	NU2	47	0.0660000000000000031
61120	S6	148.199999999999989	0.00300000000000000006
61120	MU2	85.0999999999999943	0.0200000000000000004
61120	2N2	40.7000000000000028	0.0459999999999999992
61120	OO1	332.600000000000023	0.0359999999999999973
61120	LDA2	36.3999999999999986	0.00700000000000000015
61120	M1	302.5	0.0589999999999999969
61120	J1	322.399999999999977	0.0660000000000000031
61120	SSA	216.199999999999989	0.128000000000000003
61120	SA	277.699999999999989	0.307999999999999996
61120	RHO1	283.600000000000023	0.0330000000000000016
61120	Q1	282.300000000000011	0.164000000000000007
61120	T2	19.8999999999999986	0.0259999999999999988
61120	R2	17.1999999999999993	0.00300000000000000006
61120	2Q1	272.300000000000011	0.0229999999999999996
61120	P1	310.899999999999977	0.446000000000000008
61120	L2	57.2999999999999972	0.0229999999999999996
61120	K2	15.8000000000000007	0.115000000000000005
61120	M8	3.60000000000000009	0.00300000000000000006
61121	M2	17.3000000000000007	0.764000000000000012
61121	S2	12.8000000000000007	0.471999999999999975
61121	N2	29.6999999999999993	0.269000000000000017
61121	K1	307.699999999999989	1.29600000000000004
61121	M4	299.699999999999989	0.0950000000000000011
61121	O1	287.199999999999989	0.804000000000000048
61121	M6	173.5	0.00700000000000000015
61121	S4	236.800000000000011	0.0100000000000000002
61121	NU2	28.1000000000000014	0.0490000000000000019
61121	S6	156.400000000000006	0.00300000000000000006
61121	MU2	21.6000000000000014	0.0200000000000000004
61121	2N2	42.2000000000000028	0.0330000000000000016
61121	OO1	328.199999999999989	0.0359999999999999973
61121	LDA2	15.1999999999999993	0.00700000000000000015
61121	M1	297.5	0.0560000000000000012
61121	J1	317.800000000000011	0.0619999999999999996
61121	SSA	216.199999999999989	0.128000000000000003
61121	SA	277.699999999999989	0.307999999999999996
61121	RHO1	278.300000000000011	0.0299999999999999989
61121	Q1	277	0.153999999999999998
61121	T2	13	0.0259999999999999988
61121	R2	12.5999999999999996	0.00300000000000000006
61121	2Q1	266.800000000000011	0.0200000000000000004
61121	P1	306.100000000000023	0.429999999999999993
61121	L2	4.79999999999999982	0.0229999999999999996
61121	K2	12.5	0.128000000000000003
61122	M2	334	2.06700000000000017
61122	S2	357.399999999999977	0.698999999999999955
61122	N2	311.800000000000011	0.475999999999999979
61122	K1	285.100000000000023	1.32200000000000006
61122	M4	86.2000000000000028	0.0160000000000000003
61122	O1	269.800000000000011	0.872999999999999998
61122	M6	173.300000000000011	0.0389999999999999999
61122	S4	208.800000000000011	0.0129999999999999994
61122	NU2	314.800000000000011	0.0919999999999999984
61122	S6	141.400000000000006	0.00300000000000000006
61122	MU2	310.5	0.0490000000000000019
61122	2N2	289.600000000000023	0.0619999999999999996
61122	OO1	300.5	0.0359999999999999973
61122	LDA2	344.800000000000011	0.0129999999999999994
61122	M1	277.5	0.0619999999999999996
61122	J1	292.699999999999989	0.0690000000000000058
61122	SA	258.600000000000023	0.350999999999999979
61122	MF	170	0.0950000000000000011
61122	RHO1	263.199999999999989	0.0330000000000000016
61122	Q1	262.100000000000023	0.171000000000000013
61122	T2	356.5	0.0429999999999999966
61122	R2	358.300000000000011	0.00700000000000000015
61122	2Q1	254.5	0.0229999999999999996
61122	P1	283.899999999999977	0.440000000000000002
61122	L2	356.100000000000023	0.0589999999999999969
61122	K2	359.300000000000011	0.190000000000000002
61122	M8	180.199999999999989	0.00300000000000000006
61123	M2	206.5	3.38600000000000012
61123	S2	5.90000000000000036	0.0389999999999999999
61123	N2	154.900000000000006	1.05600000000000005
61123	K1	3.79999999999999982	2.12599999999999989
61123	M4	229.5	0.0850000000000000061
61123	O1	343.5	1.32499999999999996
61123	M6	316.300000000000011	0.0490000000000000019
61123	MK3	174.599999999999994	0.0299999999999999989
61123	S4	217.300000000000011	0.00700000000000000015
61123	MN4	182.5	0.0389999999999999999
61123	NU2	167.5	0.209999999999999992
61123	S6	40.7999999999999972	0.00300000000000000006
61123	MU2	75.5999999999999943	0.161000000000000004
61123	2N2	108.200000000000003	0.138000000000000012
61123	OO1	34.8999999999999986	0.0719999999999999946
61123	LDA2	246.5	0.0459999999999999992
61123	S1	163.199999999999989	0.0619999999999999996
61123	M1	45	0.0889999999999999958
61123	J1	9.90000000000000036	0.0690000000000000058
61123	SSA	241.900000000000006	0.0229999999999999996
61123	SA	243.699999999999989	0.233000000000000013
61123	RHO1	341.399999999999977	0.0459999999999999992
61123	Q1	340.800000000000011	0.23899999999999999
61123	T2	118	0.0330000000000000016
61123	R2	197.5	0.00700000000000000015
61123	2Q1	342.800000000000011	0.0259999999999999988
61123	P1	358.5	0.669000000000000039
61123	2SM2	88.5999999999999943	0.0129999999999999994
61123	M3	52.5	0.0259999999999999988
61123	L2	230.5	0.131000000000000005
61123	2MK3	236.099999999999994	0.0560000000000000012
61123	K2	242.900000000000006	0.0389999999999999999
61123	M8	19.8999999999999986	0.0100000000000000002
61123	MS4	253.900000000000006	0.0200000000000000004
61124	M2	117.599999999999994	0.740999999999999992
61124	S2	4.40000000000000036	0.0299999999999999989
61124	N2	64.7000000000000028	0.242999999999999994
61124	K1	339.899999999999977	1.04000000000000004
61124	M4	56.3999999999999986	0.00300000000000000006
61124	O1	326.100000000000023	0.688999999999999946
61124	M6	38.2999999999999972	0.00300000000000000006
61124	S4	185.5	0.00300000000000000006
61124	NU2	71.7999999999999972	0.0459999999999999992
61124	S6	103.5	0.0160000000000000003
61124	MU2	230.900000000000006	0.0160000000000000003
61124	2N2	11.8000000000000007	0.0330000000000000016
61124	OO1	353.699999999999989	0.0299999999999999989
61124	LDA2	65.0999999999999943	0.00700000000000000015
61124	M1	333.100000000000023	0.0490000000000000019
61124	J1	346.800000000000011	0.0560000000000000012
61124	SSA	222.300000000000011	0.0820000000000000034
61124	SA	235.599999999999994	0.187
61124	MF	175.699999999999989	0.0850000000000000061
61124	RHO1	320.199999999999989	0.0259999999999999988
61124	Q1	319.300000000000011	0.135000000000000009
61124	T2	8.90000000000000036	0.00300000000000000006
61124	2Q1	312.399999999999977	0.0160000000000000003
61124	P1	338.899999999999977	0.343999999999999972
61124	L2	170.5	0.0200000000000000004
61124	K2	355.199999999999989	0.00700000000000000015
61125	M2	95	0.822999999999999954
61125	S2	195.800000000000011	0.0129999999999999994
61125	N2	49.2000000000000028	0.279000000000000026
61125	K1	326.699999999999989	0.947999999999999954
61125	M4	13	0.00700000000000000015
61125	O1	312.800000000000011	0.640000000000000013
61125	MK3	300.899999999999977	0.0100000000000000002
61125	MN4	325	0.00300000000000000006
61125	NU2	58.6000000000000014	0.0519999999999999976
61125	MU2	350.100000000000023	0.0389999999999999999
61125	2N2	5.70000000000000018	0.0490000000000000019
61125	OO1	353	0.0259999999999999988
61125	S1	97.9000000000000057	0.0259999999999999988
61125	M1	329	0.0359999999999999973
61125	J1	342.699999999999989	0.0589999999999999969
61125	SSA	222.300000000000011	0.0820000000000000034
61125	SA	235.599999999999994	0.187
61125	MF	175.699999999999989	0.0850000000000000061
61125	RHO1	306.399999999999977	0.0229999999999999996
61125	Q1	303.100000000000023	0.120999999999999996
61125	T2	344.399999999999977	0.00700000000000000015
61125	2Q1	300.5	0.0160000000000000003
61125	P1	323	0.298999999999999988
61125	2SM2	302.899999999999977	0.00300000000000000006
61125	M3	171.699999999999989	0.0100000000000000002
61125	2MK3	325.899999999999977	0.0100000000000000002
61125	K2	48.1000000000000014	0.0100000000000000002
61125	M8	180.5	0.00300000000000000006
61126	M2	228.199999999999989	3.15300000000000002
61126	S2	21.1999999999999993	0.104999999999999996
61126	N2	158.699999999999989	1.18100000000000005
61126	K1	182.300000000000011	2.54300000000000015
61126	M4	258.800000000000011	0.0490000000000000019
61126	O1	148.5	1.6140000000000001
61126	M6	288.300000000000011	0.0259999999999999988
61126	S4	310.699999999999989	0.0160000000000000003
61126	NU2	168	0.23000000000000001
61126	S6	230.599999999999994	0.00700000000000000015
61126	MU2	70.5	0.0719999999999999946
61126	2N2	89.2000000000000028	0.157000000000000001
61126	OO1	216.099999999999994	0.0690000000000000058
61126	LDA2	301.399999999999977	0.0229999999999999996
61126	M1	165.5	0.115000000000000005
61126	J1	199.099999999999994	0.128000000000000003
61126	RHO1	134	0.0619999999999999996
61126	Q1	131.699999999999989	0.312
61126	T2	12.6999999999999993	0.00700000000000000015
61126	2Q1	115	0.0429999999999999966
61126	P1	179.699999999999989	0.839999999999999969
61126	L2	297.699999999999989	0.0889999999999999958
61126	K2	33.5	0.0299999999999999989
61126	M8	125.5	0.00700000000000000015
61127	M2	336.899999999999977	5.9740000000000002
61127	S2	90.4000000000000057	0.242999999999999994
61127	N2	279.399999999999977	1.85000000000000009
61127	K1	53.1000000000000014	2.74900000000000011
61127	M4	174.199999999999989	0.117999999999999994
61127	O1	30.3999999999999986	1.72900000000000009
61127	M6	56.1000000000000014	0.0229999999999999996
61127	S4	121	0.00300000000000000006
61127	NU2	287.100000000000023	0.357999999999999985
61127	S6	7	0.00300000000000000006
61127	MU2	224.699999999999989	0.140999999999999986
61127	2N2	221.900000000000006	0.245999999999999996
61127	OO1	75.7000000000000028	0.0719999999999999946
61127	LDA2	29	0.0429999999999999966
61127	M1	41.7999999999999972	0.125
61127	J1	64.2999999999999972	0.135000000000000009
61127	RHO1	20.6999999999999993	0.0660000000000000031
61127	Q1	19.1999999999999993	0.33500000000000002
61127	T2	85.9000000000000057	0.0129999999999999994
61127	R2	93.7000000000000028	0.00300000000000000006
61127	2Q1	7.90000000000000036	0.0459999999999999992
61127	P1	51.3999999999999986	0.90900000000000003
61127	L2	34.3999999999999986	0.16700000000000001
61127	K2	99.7000000000000028	0.0660000000000000031
61127	M8	119.599999999999994	0.0100000000000000002
61128	M2	315.5	1.25
61128	S2	125.900000000000006	0.0519999999999999976
61128	N2	221	0.27200000000000002
61128	K1	201.300000000000011	2.1160000000000001
61128	M4	129	0.187
61128	O1	166.5	1.3680000000000001
61128	M6	45.1000000000000014	0.0389999999999999999
61128	S4	330.100000000000023	0.0160000000000000003
61128	NU2	233.599999999999994	0.0519999999999999976
61128	S6	132.5	0.0129999999999999994
61128	MU2	145.199999999999989	0.0299999999999999989
61128	2N2	126.400000000000006	0.0359999999999999973
61128	OO1	236.199999999999989	0.0589999999999999969
61128	LDA2	34.6000000000000014	0.0100000000000000002
61128	M1	184	0.0980000000000000038
61128	J1	218.599999999999994	0.107999999999999999
61128	RHO1	151.5	0.0519999999999999976
61128	Q1	149.199999999999989	0.266000000000000014
61128	T2	119.099999999999994	0.00300000000000000006
61128	2Q1	131.900000000000006	0.0359999999999999973
61128	P1	198.699999999999989	0.701999999999999957
61128	L2	50.1000000000000014	0.0359999999999999973
61128	K2	139.699999999999989	0.0129999999999999994
61128	M8	127.599999999999994	0.00700000000000000015
61129	M2	254.300000000000011	2.38499999999999979
61129	S2	45.2999999999999972	0.0690000000000000058
61129	N2	183.300000000000011	0.85299999999999998
61129	K1	192.699999999999989	2.42799999999999994
61129	M4	89.2999999999999972	0.112000000000000002
61129	O1	159.800000000000011	1.57499999999999996
61129	M6	245.300000000000011	0.0160000000000000003
61129	S4	2.39999999999999991	0.0200000000000000004
61129	NU2	192.800000000000011	0.164000000000000007
61129	S6	229.400000000000006	0.00300000000000000006
61129	MU2	106.299999999999997	0.0429999999999999966
61129	2N2	112.200000000000003	0.112000000000000002
61129	OO1	225.5	0.0660000000000000031
61129	LDA2	294.899999999999977	0.0100000000000000002
61129	M1	176.400000000000006	0.112000000000000002
61129	J1	208.900000000000006	0.125
61129	RHO1	145.699999999999989	0.0589999999999999969
61129	Q1	143.5	0.304999999999999993
61129	T2	48.3999999999999986	0.00300000000000000006
61129	2Q1	127.200000000000003	0.0389999999999999999
61129	P1	190.199999999999989	0.804000000000000048
61129	L2	325.300000000000011	0.0660000000000000031
61129	K2	49.2000000000000028	0.0200000000000000004
61129	M8	178.099999999999994	0.00700000000000000015
61130	M2	248.099999999999994	2.67700000000000005
61130	S2	29.1999999999999993	0.0850000000000000061
61130	N2	174.900000000000006	0.990999999999999992
61130	K1	191.699999999999989	2.52300000000000013
61130	M4	86.2999999999999972	0.0389999999999999999
61130	O1	157.300000000000011	1.59400000000000008
61130	M6	303.399999999999977	0.0160000000000000003
61130	S4	350.5	0.0129999999999999994
61130	NU2	184.699999999999989	0.194000000000000006
61130	S6	252.199999999999989	0.00300000000000000006
61130	MU2	103.700000000000003	0.0619999999999999996
61130	2N2	101.700000000000003	0.131000000000000005
61130	OO1	226.099999999999994	0.0690000000000000058
61130	LDA2	315.199999999999989	0.0200000000000000004
61130	M1	174.599999999999994	0.115000000000000005
61130	J1	208.800000000000011	0.128000000000000003
61130	RHO1	142.5	0.0619999999999999996
61130	Q1	140.199999999999989	0.307999999999999996
61130	T2	22.5	0.00700000000000000015
61130	2Q1	123.099999999999994	0.0429999999999999966
61130	P1	189.099999999999994	0.836999999999999966
61130	L2	321.300000000000011	0.0749999999999999972
61130	K2	40.5	0.0229999999999999996
61130	M8	232.699999999999989	0.00300000000000000006
61131	M2	269.600000000000023	2.33899999999999997
61131	S2	41.1000000000000014	0.0660000000000000031
61131	N2	194.599999999999994	0.868999999999999995
61131	K1	198.300000000000011	2.62800000000000011
61131	M4	113.299999999999997	0.200000000000000011
61131	O1	163.199999999999989	1.59800000000000009
61131	M6	241.199999999999989	0.0359999999999999973
61131	S4	245.400000000000006	0.0100000000000000002
61131	NU2	204.599999999999994	0.16700000000000001
61131	S6	106.400000000000006	0.0129999999999999994
61131	MU2	176.5	0.0560000000000000012
61131	2N2	119.5	0.115000000000000005
61131	OO1	233.400000000000006	0.0690000000000000058
61131	LDA2	330.600000000000023	0.0160000000000000003
61131	M1	180.900000000000006	0.115000000000000005
61131	J1	215.699999999999989	0.128000000000000003
61131	RHO1	148.099999999999994	0.0619999999999999996
61131	Q1	145.800000000000011	0.312
61131	T2	35.7999999999999972	0.00300000000000000006
61131	2Q1	128.400000000000006	0.0429999999999999966
61131	P1	195.599999999999994	0.868999999999999995
61131	L2	344.600000000000023	0.0660000000000000031
61131	K2	51.7000000000000028	0.0160000000000000003
61131	M8	164.5	0.00700000000000000015
61132	M2	282.399999999999977	2.00099999999999989
61132	S2	14.6999999999999993	0.0299999999999999989
61132	N2	208.099999999999994	0.54500000000000004
61132	K1	199.599999999999994	2.37199999999999989
61132	M4	115.400000000000006	0.256000000000000005
61132	O1	163.900000000000006	1.56499999999999995
61132	M6	254.599999999999994	0.0229999999999999996
61132	S4	322.699999999999989	0.0229999999999999996
61132	NU2	218	0.104999999999999996
61132	S6	146	0.0129999999999999994
61132	MU2	227.800000000000011	0.0490000000000000019
61132	2N2	133.800000000000011	0.0719999999999999946
61132	OO1	235.300000000000011	0.0690000000000000058
61132	LDA2	325.199999999999989	0.0129999999999999994
61132	M1	181.900000000000006	0.112000000000000002
61132	J1	217.300000000000011	0.125
61132	RHO1	148.599999999999994	0.0589999999999999969
61132	Q1	146.199999999999989	0.304999999999999993
61132	T2	11	0.00300000000000000006
61132	2Q1	128.5	0.0389999999999999999
61132	P1	196.900000000000006	0.78400000000000003
61132	L2	356.600000000000023	0.0560000000000000012
61132	K2	22.1999999999999993	0.0100000000000000002
61132	M8	161.400000000000006	0.0129999999999999994
61133	M2	346.600000000000023	7.12899999999999956
61133	S2	96.5	0.235999999999999988
61133	N2	292.800000000000011	2.03100000000000014
61133	K1	59.1000000000000014	2.74299999999999988
61133	M4	218.400000000000006	0.406999999999999973
61133	O1	34.3999999999999986	1.65700000000000003
61133	M6	357.800000000000011	0.115000000000000005
61133	S4	200.099999999999994	0.0129999999999999994
61133	NU2	300	0.394000000000000017
61133	S6	93.7000000000000028	0.00300000000000000006
61133	MU2	239	0.171000000000000013
61133	2N2	239	0.269000000000000017
61133	OO1	83.7000000000000028	0.0690000000000000058
61133	LDA2	36.5	0.0490000000000000019
61133	M1	46.7999999999999972	0.115000000000000005
61133	J1	71.2999999999999972	0.128000000000000003
61133	RHO1	23.8000000000000007	0.0619999999999999996
61133	Q1	22.1999999999999993	0.322000000000000008
61133	T2	92.5	0.0129999999999999994
61133	R2	109.5	0.00300000000000000006
61133	2Q1	9.90000000000000036	0.0429999999999999966
61133	P1	57.2999999999999972	0.906000000000000028
61133	L2	40.2999999999999972	0.200000000000000011
61133	K2	105.299999999999997	0.0660000000000000031
61133	M8	187.099999999999994	0.0560000000000000012
61134	M2	239.5	3.06400000000000006
61134	S2	25.3000000000000007	0.112000000000000002
61134	N2	166.5	1.15199999999999991
61134	K1	186.900000000000006	2.60499999999999998
61134	M4	92.5999999999999943	0.0160000000000000003
61134	O1	152.599999999999994	1.63700000000000001
61134	M6	314.899999999999977	0.0259999999999999988
61134	S4	310.800000000000011	0.0100000000000000002
61134	NU2	176.300000000000011	0.223000000000000004
61134	S6	252.400000000000006	0.0100000000000000002
61134	MU2	96.5999999999999943	0.0719999999999999946
61134	2N2	93.4000000000000057	0.150999999999999995
61134	OO1	221.199999999999989	0.0690000000000000058
61134	LDA2	306	0.0200000000000000004
61134	M1	169.800000000000011	0.115000000000000005
61134	J1	203.900000000000006	0.128000000000000003
61134	RHO1	137.800000000000011	0.0619999999999999996
61134	Q1	135.5	0.318000000000000005
61134	T2	19.5	0.00700000000000000015
61134	2Q1	118.5	0.0429999999999999966
61134	P1	184.300000000000011	0.862999999999999989
61134	L2	312.699999999999989	0.0850000000000000061
61134	K2	37.2000000000000028	0.0299999999999999989
61134	M8	80.0999999999999943	0.0100000000000000002
61135	M2	251.400000000000006	2.86699999999999999
61135	S2	43	0.0889999999999999958
61135	N2	181.099999999999994	1.06299999999999994
61135	K1	190.699999999999989	2.63099999999999978
61135	M4	94.0999999999999943	0.0690000000000000058
61135	O1	156.199999999999989	1.65700000000000003
61135	M6	271.5	0.0160000000000000003
61135	S4	329	0.0100000000000000002
61135	NU2	190.5	0.20699999999999999
61135	S6	235.400000000000006	0.00300000000000000006
61135	MU2	103.200000000000003	0.0660000000000000031
61135	2N2	110.700000000000003	0.140999999999999986
61135	OO1	225.199999999999989	0.0719999999999999946
61135	LDA2	320.300000000000011	0.0200000000000000004
61135	M1	173.599999999999994	0.117999999999999994
61135	J1	207.800000000000011	0.131000000000000005
61135	RHO1	141.400000000000006	0.0619999999999999996
61135	Q1	139.099999999999994	0.322000000000000008
61135	T2	34.7000000000000028	0.00700000000000000015
61135	2Q1	122	0.0429999999999999966
61135	P1	188.099999999999994	0.868999999999999995
61135	L2	321.699999999999989	0.0820000000000000034
61135	K2	54.7999999999999972	0.0229999999999999996
61135	M8	228.599999999999994	0.00700000000000000015
61136	M2	7	7.15899999999999981
61136	S2	105.700000000000003	0.256000000000000005
61136	N2	314.300000000000011	1.89300000000000002
61136	K1	69.4000000000000057	2.60199999999999987
61136	M4	278.199999999999989	0.622999999999999998
61136	O1	41.1000000000000014	1.51200000000000001
61136	M6	94.4000000000000057	0.20699999999999999
61136	S4	334.5	0.00700000000000000015
61136	NU2	321.300000000000011	0.366999999999999993
61136	S6	100	0.00700000000000000015
61136	MU2	272.600000000000023	0.16700000000000001
61136	2N2	261.399999999999977	0.248999999999999999
61136	OO1	97.7000000000000028	0.0660000000000000031
61136	LDA2	50.8999999999999986	0.0490000000000000019
61136	M1	55.3999999999999986	0.107999999999999999
61136	J1	83.5	0.120999999999999996
61136	RHO1	29	0.0589999999999999969
61136	Q1	27.1000000000000014	0.294999999999999984
61136	T2	100.799999999999997	0.0160000000000000003
61136	R2	114.799999999999997	0.00300000000000000006
61136	2Q1	13	0.0389999999999999999
61136	P1	67.4000000000000057	0.859999999999999987
61136	L2	60	0.200000000000000011
61136	K2	113.599999999999994	0.0690000000000000058
61136	M8	321.699999999999989	0.0719999999999999946
61137	M2	164.800000000000011	2.72299999999999986
61137	S2	301.800000000000011	0.203000000000000014
61137	N2	101	0.606999999999999984
61137	K1	98.5999999999999943	1.87999999999999989
61137	M4	16.6000000000000014	0.120999999999999996
61137	O1	67.5	1.29299999999999993
61137	M6	170.699999999999989	0.0589999999999999969
61137	S4	97.5999999999999943	0.0129999999999999994
61137	NU2	109.5	0.117999999999999994
61137	S6	54.2999999999999972	0.00300000000000000006
61137	MU2	62.8999999999999986	0.0560000000000000012
61137	2N2	37.2999999999999972	0.0820000000000000034
61137	OO1	129.699999999999989	0.0560000000000000012
61137	LDA2	229	0.0200000000000000004
61137	M1	83.2000000000000028	0.0919999999999999984
61137	J1	114	0.101999999999999993
61137	RHO1	54.1000000000000014	0.0490000000000000019
61137	Q1	52.1000000000000014	0.248999999999999999
61137	T2	296.399999999999977	0.0129999999999999994
61137	2Q1	36.6000000000000014	0.0330000000000000016
61137	P1	96.2999999999999972	0.622999999999999998
61137	L2	228.599999999999994	0.0800000000000000017
61137	K2	312.800000000000011	0.0500000000000000028
61137	M8	13.5	0.0100000000000000002
61138	M2	182.599999999999994	3.60899999999999999
61138	S2	8.19999999999999929	0.338000000000000023
61138	N2	110.799999999999997	0.832999999999999963
61138	K1	107.799999999999997	2.1419999999999999
61138	M4	125.099999999999994	0.117999999999999994
61138	O1	72.7000000000000028	1.35200000000000009
61138	M6	226.199999999999989	0.0560000000000000012
61138	MK3	156.699999999999989	0.0690000000000000058
61138	S4	128.400000000000006	0.00700000000000000015
61138	MN4	67.5999999999999943	0.0660000000000000031
61138	NU2	146.5	0.183999999999999997
61138	S6	96.4000000000000057	0.00300000000000000006
61138	MU2	343.399999999999977	0.107999999999999999
61138	2N2	124.200000000000003	0.0980000000000000038
61138	OO1	150.5	0.0619999999999999996
61138	LDA2	258.199999999999989	0.104999999999999996
61138	S1	287.699999999999989	0.176999999999999991
61138	M1	150.699999999999989	0.0820000000000000034
61138	J1	69.7999999999999972	0.0459999999999999992
61138	RHO1	60.8999999999999986	0.0950000000000000011
61138	Q1	62.5	0.259000000000000008
61138	T2	13.3000000000000007	0.131000000000000005
61138	R2	218.900000000000006	0.357999999999999985
61138	2Q1	154	0.0299999999999999989
61138	P1	96.5999999999999943	0.717999999999999972
61138	2SM2	90.0999999999999943	0.0200000000000000004
61138	M3	87.0999999999999943	0.0429999999999999966
61138	L2	248.900000000000006	0.350999999999999979
61138	2MK3	103.799999999999997	0.0330000000000000016
61138	K2	242.400000000000006	0.209999999999999992
61138	M8	142.400000000000006	0.00700000000000000015
61138	MS4	307.5	0.00700000000000000015
61139	M2	211	4.15700000000000003
61139	S2	88	0.322000000000000008
61139	N2	140.599999999999994	0.868999999999999995
61139	K1	121	2.18199999999999994
61139	M4	284	0.0790000000000000008
61139	O1	85.2000000000000028	1.42700000000000005
61139	M6	323.300000000000011	0.101999999999999993
61139	MK3	220	0.20699999999999999
61139	S4	192.300000000000011	0.00700000000000000015
61139	MN4	191.300000000000011	0.0519999999999999976
61139	NU2	172.300000000000011	0.233000000000000013
61139	S6	215.800000000000011	0.00300000000000000006
61139	MU2	1.30000000000000004	0.101999999999999993
61139	2N2	115.299999999999997	0.171000000000000013
61139	OO1	181.199999999999989	0.0589999999999999969
61139	LDA2	277.100000000000023	0.112000000000000002
61139	S1	255.300000000000011	0.0889999999999999958
61139	M1	159.400000000000006	0.0850000000000000061
61139	J1	57.1000000000000014	0.0519999999999999976
61139	RHO1	76.7000000000000028	0.0690000000000000058
61139	Q1	82.7000000000000028	0.27200000000000002
61139	T2	78.9000000000000057	0.197000000000000008
61139	R2	298.899999999999977	0.331000000000000016
61139	2Q1	119.599999999999994	0.0560000000000000012
61139	P1	110.400000000000006	0.666000000000000036
61139	2SM2	108.5	0.0160000000000000003
61139	M3	109.700000000000003	0.0889999999999999958
61139	L2	275.800000000000011	0.422999999999999987
61139	2MK3	154.5	0.157000000000000001
61139	K2	292.199999999999989	0.128000000000000003
61139	M8	333.199999999999989	0.00700000000000000015
61139	MS4	76	0.0330000000000000016
61140	M2	232	2.93999999999999995
61140	S2	323.699999999999989	0.138000000000000012
61140	N2	174.300000000000011	0.791000000000000036
61140	K1	164.5	1.57499999999999996
61140	M4	322.199999999999989	0.107999999999999999
61140	O1	125.299999999999997	0.970999999999999974
61140	M6	333.699999999999989	0.0850000000000000061
61140	S4	146.599999999999994	0.0100000000000000002
61140	NU2	182	0.153999999999999998
61140	S6	70.2000000000000028	0.0129999999999999994
61140	MU2	141.900000000000006	0.0690000000000000058
61140	2N2	116.700000000000003	0.104999999999999996
61140	OO1	204	0.0429999999999999966
61140	LDA2	273.800000000000011	0.0200000000000000004
61140	M1	145.099999999999994	0.0690000000000000058
61140	J1	184.099999999999994	0.0749999999999999972
61140	RHO1	108.400000000000006	0.0359999999999999973
61140	Q1	105.799999999999997	0.187
61140	T2	320.5	0.00700000000000000015
61140	2Q1	86.2999999999999972	0.0259999999999999988
61140	P1	161.599999999999994	0.52200000000000002
61140	L2	289.5	0.0820000000000000034
61140	K2	331	0.0359999999999999973
61140	M8	52.5	0.00300000000000000006
61141	M2	241.900000000000006	2.89400000000000013
61141	S2	336.100000000000023	0.223000000000000004
61141	N2	188.599999999999994	0.76100000000000001
61141	K1	189.900000000000006	0.701999999999999957
61141	M4	323	0.0490000000000000019
61141	O1	149.800000000000011	0.44900000000000001
61141	M6	106.200000000000003	0.0229999999999999996
61141	S4	24.5	0.00700000000000000015
61141	NU2	195.800000000000011	0.147999999999999993
61141	S6	167.400000000000006	0.00300000000000000006
61141	MU2	148.400000000000006	0.0690000000000000058
61141	2N2	135.400000000000006	0.0980000000000000038
61141	OO1	230	0.0200000000000000004
61141	LDA2	285.399999999999977	0.0200000000000000004
61141	M1	170	0.0330000000000000016
61141	J1	209.800000000000011	0.0330000000000000016
61141	RHO1	132.599999999999994	0.0160000000000000003
61141	Q1	129.900000000000006	0.0850000000000000061
61141	T2	331.800000000000011	0.0129999999999999994
61141	R2	344.399999999999977	0.00300000000000000006
61141	2Q1	109.5	0.0100000000000000002
61141	P1	186.900000000000006	0.233000000000000013
61141	L2	295.199999999999989	0.0790000000000000008
61141	K2	343.699999999999989	0.0619999999999999996
61141	M8	115.200000000000003	0.00300000000000000006
61142	M2	260.300000000000011	3.61900000000000022
61142	S2	18	0.20699999999999999
61142	N2	192	0.708999999999999964
61142	K1	148.300000000000011	1.96199999999999997
61142	M4	71.0999999999999943	0.256000000000000005
61142	O1	110.900000000000006	1.43700000000000006
61142	M6	112.099999999999994	0.112000000000000002
61142	S4	293.399999999999977	0.0100000000000000002
61142	NU2	201.199999999999989	0.138000000000000012
61142	S6	17.3000000000000007	0.00300000000000000006
61142	MU2	144.300000000000011	0.0820000000000000034
61142	2N2	123.799999999999997	0.0919999999999999984
61142	OO1	185.599999999999994	0.0619999999999999996
61142	LDA2	314.300000000000011	0.0259999999999999988
61142	M1	129.800000000000011	0.101999999999999993
61142	J1	166.800000000000011	0.112000000000000002
61142	RHO1	94.9000000000000057	0.0560000000000000012
61142	Q1	92.4000000000000057	0.279000000000000026
61142	T2	12.9000000000000004	0.0129999999999999994
61142	2Q1	73.9000000000000057	0.0359999999999999973
61142	P1	145.400000000000006	0.650000000000000022
61142	L2	328.5	0.101999999999999993
61142	K2	27.5	0.0560000000000000012
61142	M8	285	0.0259999999999999988
61143	M2	283.899999999999977	3.33000000000000007
61143	S2	46.3999999999999986	0.150999999999999995
61143	N2	217	0.599999999999999978
61143	K1	163	1.873
61143	M4	115.799999999999997	0.276000000000000023
61143	O1	124.200000000000003	1.38100000000000001
61143	M6	191.300000000000011	0.101999999999999993
61143	S4	328.800000000000011	0.0200000000000000004
61143	NU2	225.900000000000006	0.117999999999999994
61143	S6	335.100000000000023	0.00300000000000000006
61143	MU2	149.199999999999989	0.0619999999999999996
61143	2N2	150	0.0790000000000000008
61143	OO1	201.699999999999989	0.0589999999999999969
61143	LDA2	306.100000000000023	0.0129999999999999994
61143	M1	143.699999999999989	0.0980000000000000038
61143	J1	182.099999999999994	0.107999999999999999
61143	RHO1	107.5	0.0519999999999999976
61143	Q1	105	0.269000000000000017
61143	T2	47.2999999999999972	0.00700000000000000015
61143	2Q1	85.5999999999999943	0.0359999999999999973
61143	P1	160.099999999999994	0.619999999999999996
61143	L2	350.800000000000011	0.0950000000000000011
61143	K2	52.6000000000000014	0.0429999999999999966
61143	M8	14	0.0229999999999999996
61144	M2	233.599999999999994	3.07100000000000017
61144	S2	315.300000000000011	0.318000000000000005
61144	N2	181.699999999999989	0.794000000000000039
61144	K1	262.5	0.899000000000000021
61144	M4	25.3999999999999986	0.0359999999999999973
61144	O1	221.300000000000011	0.463000000000000023
61144	M6	314.5	0.0519999999999999976
61144	S4	23.8000000000000007	0.00300000000000000006
61144	NU2	188.699999999999989	0.153999999999999998
61144	S6	74.5	0.00700000000000000015
61144	MU2	180.400000000000006	0.0719999999999999946
61144	2N2	129.900000000000006	0.104999999999999996
61144	OO1	303.199999999999989	0.0200000000000000004
61144	LDA2	271.199999999999989	0.0229999999999999996
61144	M1	241.900000000000006	0.0330000000000000016
61144	J1	282.600000000000023	0.0359999999999999973
61144	RHO1	203.699999999999989	0.0160000000000000003
61144	Q1	200.900000000000006	0.0889999999999999958
61144	T2	312	0.0200000000000000004
61144	R2	318.399999999999977	0.00300000000000000006
61144	2Q1	180.599999999999994	0.0129999999999999994
61144	P1	259.399999999999977	0.298999999999999988
61144	L2	285.399999999999977	0.0850000000000000061
61144	K2	321.899999999999977	0.0850000000000000061
61144	M8	59.5	0.0129999999999999994
61145	M2	251.599999999999994	3.7370000000000001
61145	S2	337.600000000000023	0.33500000000000002
61145	N2	200.099999999999994	0.95499999999999996
61145	K1	215.400000000000006	1.03000000000000003
61145	M4	13.5999999999999996	0.0889999999999999958
61145	O1	170	0.622999999999999998
61145	M6	45	0.0619999999999999996
61145	S4	77.2999999999999972	0.0129999999999999994
61145	NU2	207	0.183999999999999997
61145	S6	170	0.00300000000000000006
61145	MU2	184.599999999999994	0.0850000000000000061
61145	2N2	148.599999999999994	0.128000000000000003
61145	OO1	260.800000000000011	0.0259999999999999988
61145	LDA2	291.100000000000023	0.0259999999999999988
61145	M1	192.900000000000006	0.0429999999999999966
61145	J1	237.800000000000011	0.0490000000000000019
61145	RHO1	150.699999999999989	0.0229999999999999996
61145	Q1	147.599999999999994	0.120999999999999996
61145	T2	334.300000000000011	0.0200000000000000004
61145	R2	341.199999999999989	0.00300000000000000006
61145	2Q1	125.400000000000006	0.0160000000000000003
61145	P1	212	0.341000000000000025
61145	L2	303.300000000000011	0.104999999999999996
61145	K2	344.5	0.0919999999999999984
61145	M8	271.300000000000011	0.0100000000000000002
61146	M2	348.399999999999977	2.31300000000000017
61146	S2	173.400000000000006	0.0690000000000000058
61146	N2	277.5	0.422999999999999987
61146	K1	201.199999999999989	1.53499999999999992
61146	M4	238.800000000000011	0.245999999999999996
61146	O1	161	1.25
61146	M6	343	0.0519999999999999976
61146	S4	33.7000000000000028	0.00700000000000000015
61146	NU2	287	0.0820000000000000034
61146	S6	51.7000000000000028	0.00300000000000000006
61146	MU2	176.599999999999994	0.0229999999999999996
61146	2N2	206.599999999999994	0.0560000000000000012
61146	OO1	241.099999999999994	0.0560000000000000012
61146	LDA2	21.1999999999999993	0.0100000000000000002
61146	M1	181.199999999999989	0.0889999999999999958
61146	J1	220.900000000000006	0.0980000000000000038
61146	RHO1	143.900000000000006	0.0490000000000000019
61146	Q1	141.199999999999989	0.242999999999999994
61146	T2	156.199999999999989	0.00300000000000000006
61146	2Q1	121.400000000000006	0.0330000000000000016
61146	P1	198.099999999999994	0.509000000000000008
61146	L2	59.2000000000000028	0.0660000000000000031
61146	K2	179.900000000000006	0.0229999999999999996
61146	M8	237.099999999999994	0.0229999999999999996
61147	M2	62.7000000000000028	0.896000000000000019
61147	S2	21.1999999999999993	0.125
61147	N2	0.299999999999999989	0.197000000000000008
61147	K1	248.599999999999994	0.787000000000000033
61147	M4	38.3999999999999986	0.173999999999999988
61147	O1	205.199999999999989	0.721999999999999975
61147	M6	97.2999999999999972	0.0129999999999999994
61147	MK3	217	0.209999999999999992
61147	S4	273.399999999999977	0.0100000000000000002
61147	MN4	328.100000000000023	0.0660000000000000031
61147	NU2	81.2999999999999972	0.0359999999999999973
61147	MU2	196.099999999999994	0.0389999999999999999
61147	2N2	7.29999999999999982	0.0889999999999999958
61147	OO1	281.5	0.0200000000000000004
61147	LDA2	159.300000000000011	0.0589999999999999969
61147	S1	185.5	0.107999999999999999
61147	M1	271.699999999999989	0.0589999999999999969
61147	J1	206.5	0.0749999999999999972
61147	RHO1	222.699999999999989	0.0200000000000000004
61147	Q1	187.300000000000011	0.128000000000000003
61147	2Q1	169.400000000000006	0.0299999999999999989
61147	P1	258.100000000000023	0.312
61147	2SM2	279.100000000000023	0.0160000000000000003
61147	M3	97.9000000000000057	0.0690000000000000058
61147	L2	149.599999999999994	0.115000000000000005
61147	2MK3	162.199999999999989	0.147999999999999993
61147	K2	181	0.0359999999999999973
61147	M8	163.199999999999989	0.0129999999999999994
61147	MS4	241.199999999999989	0.0229999999999999996
61148	M2	285.100000000000023	1.64999999999999991
61148	S2	46.7999999999999972	0.197000000000000008
61148	N2	228.5	0.468999999999999972
61148	K1	285.699999999999989	0.816999999999999948
61148	M4	196.300000000000011	0.220000000000000001
61148	O1	265.399999999999977	0.453000000000000014
61148	M6	66.7000000000000028	0.0160000000000000003
61148	S4	64.9000000000000057	0.0299999999999999989
61148	NU2	236.099999999999994	0.0919999999999999984
61148	S6	99.9000000000000057	0.00700000000000000015
61148	MU2	168.400000000000006	0.0330000000000000016
61148	2N2	172	0.0619999999999999996
61148	OO1	305.300000000000011	0.0200000000000000004
61148	LDA2	298.800000000000011	0.00700000000000000015
61148	M1	275.5	0.0330000000000000016
61148	J1	295.399999999999977	0.0359999999999999973
61148	RHO1	256.800000000000011	0.0160000000000000003
61148	Q1	255.5	0.0889999999999999958
61148	T2	43.7999999999999972	0.0100000000000000002
61148	R2	43.7999999999999972	0.00300000000000000006
61148	2Q1	245.5	0.0100000000000000002
61148	P1	284.199999999999989	0.27200000000000002
61148	L2	341.300000000000011	0.0459999999999999992
61148	K2	52.2000000000000028	0.0560000000000000012
61148	M8	335.600000000000023	0.00700000000000000015
61149	M2	54.1000000000000014	0.650000000000000022
61149	S2	182.5	0.120999999999999996
61149	N2	8.40000000000000036	0.235999999999999988
61149	K1	23.8999999999999986	0.616999999999999993
61149	M4	37.3999999999999986	0.115000000000000005
61149	O1	0.699999999999999956	0.459000000000000019
61149	M6	113	0.00700000000000000015
61149	S4	278	0.0100000000000000002
61149	NU2	14.5	0.0459999999999999992
61149	S6	324.5	0.00300000000000000006
61149	MU2	283.699999999999989	0.0160000000000000003
61149	2N2	322.800000000000011	0.0299999999999999989
61149	OO1	47	0.0200000000000000004
61149	LDA2	114.700000000000003	0.00300000000000000006
61149	M1	12.3000000000000007	0.0330000000000000016
61149	J1	35.1000000000000014	0.0359999999999999973
61149	RHO1	351	0.0160000000000000003
61149	Q1	349.199999999999989	0.0889999999999999958
61149	T2	176.800000000000011	0.00700000000000000015
61149	2Q1	338.600000000000023	0.0100000000000000002
61149	P1	22.1000000000000014	0.203000000000000014
61149	L2	99.5999999999999943	0.0160000000000000003
61149	K2	193	0.0330000000000000016
61149	M8	222.5	0.00300000000000000006
61150	M2	284.5	0.957999999999999963
61150	S2	22.1000000000000014	0.223000000000000004
61150	N2	235.400000000000006	0.16700000000000001
61150	K1	6.59999999999999964	0.294999999999999984
61150	M4	30.8000000000000007	0.0299999999999999989
61150	O1	341.300000000000011	0.190000000000000002
61150	M6	223.900000000000006	0.0160000000000000003
61150	S4	7.79999999999999982	0.00300000000000000006
61150	NU2	242.099999999999994	0.0330000000000000016
61150	S6	35.2000000000000028	0.00300000000000000006
61150	MU2	186.900000000000006	0.0229999999999999996
61150	2N2	186.400000000000006	0.0200000000000000004
61150	OO1	32	0.00700000000000000015
61150	LDA2	329.800000000000011	0.00700000000000000015
61150	M1	354	0.0129999999999999994
61150	J1	19.3000000000000007	0.0129999999999999994
61150	RHO1	330.300000000000011	0.00700000000000000015
61150	Q1	328.699999999999989	0.0359999999999999973
61150	T2	18.1000000000000014	0.0129999999999999994
61150	R2	26	0.00300000000000000006
61150	2Q1	317.300000000000011	0.00300000000000000006
61150	P1	4.79999999999999982	0.0980000000000000038
61150	L2	331.800000000000011	0.0259999999999999988
61150	K2	30	0.0589999999999999969
61150	M8	50.7000000000000028	0.00300000000000000006
61151	M2	257.399999999999977	0.554000000000000048
61151	S2	2.20000000000000018	0.120999999999999996
61151	N2	199.300000000000011	0.179999999999999993
61151	K1	129.400000000000006	1.35499999999999998
61151	M4	194.300000000000011	0.0429999999999999966
61151	O1	77.0999999999999943	0.76100000000000001
61151	NU2	207.099999999999994	0.0359999999999999973
61151	2N2	141.199999999999989	0.0229999999999999996
61151	OO1	181.699999999999989	0.0330000000000000016
61151	M1	103.200000000000003	0.0519999999999999976
61151	J1	155.599999999999994	0.0589999999999999969
61151	SSA	195.300000000000011	0.0229999999999999996
61151	RHO1	54.6000000000000014	0.0299999999999999989
61151	Q1	50.8999999999999986	0.147999999999999993
61151	R2	164.800000000000011	0.0229999999999999996
61151	2Q1	24.8000000000000007	0.0200000000000000004
61151	P1	129.199999999999989	0.44900000000000001
61151	L2	315.5	0.0160000000000000003
61151	K2	2.29999999999999982	0.0330000000000000016
61152	M2	222.5	0.97799999999999998
61152	S2	324.399999999999977	0.197000000000000008
61152	N2	167.199999999999989	0.171000000000000013
61152	K1	345.300000000000011	0.343999999999999972
61152	M4	22.6000000000000014	0.0229999999999999996
61152	O1	317.399999999999977	0.203000000000000014
61152	M6	68.2000000000000028	0.0100000000000000002
61152	S4	34.1000000000000014	0.00300000000000000006
61152	NU2	174.699999999999989	0.0330000000000000016
61152	S6	237.800000000000011	0.00300000000000000006
61152	MU2	120.799999999999997	0.0229999999999999996
61152	2N2	111.799999999999997	0.0229999999999999996
61152	OO1	13.3000000000000007	0.0100000000000000002
61152	LDA2	269.800000000000011	0.00700000000000000015
61152	M1	331.5	0.0129999999999999994
61152	J1	359.199999999999989	0.0160000000000000003
61152	RHO1	305.199999999999989	0.00700000000000000015
61152	Q1	303.399999999999977	0.0389999999999999999
61152	T2	320.399999999999977	0.0129999999999999994
61152	2Q1	289.5	0.00700000000000000015
61152	P1	343.199999999999989	0.115000000000000005
61152	L2	277.300000000000011	0.0259999999999999988
61152	K2	332.699999999999989	0.0519999999999999976
61152	M8	57.5	0.00700000000000000015
61153	M2	196.400000000000006	1.05000000000000004
61153	S2	294.300000000000011	0.20699999999999999
61153	N2	142.5	0.200000000000000011
61153	K1	335.899999999999977	0.373999999999999999
61153	M4	339.5	0.0200000000000000004
61153	O1	303	0.226000000000000006
61153	M6	26.6999999999999993	0.0160000000000000003
61153	S4	350.899999999999977	0.00300000000000000006
61153	NU2	149.699999999999989	0.0389999999999999999
61153	S6	252.400000000000006	0.00300000000000000006
61153	MU2	98.5999999999999943	0.0259999999999999988
61153	2N2	88.7999999999999972	0.0259999999999999988
61153	OO1	8.90000000000000036	0.0100000000000000002
61153	LDA2	241.900000000000006	0.00700000000000000015
61153	M1	319.5	0.0160000000000000003
61153	J1	352	0.0160000000000000003
61153	RHO1	288.800000000000011	0.0100000000000000002
61153	Q1	286.800000000000011	0.0429999999999999966
61153	T2	290.399999999999977	0.0100000000000000002
61153	R2	298.800000000000011	0.00300000000000000006
61153	2Q1	270.199999999999989	0.00700000000000000015
61153	P1	333.399999999999977	0.125
61153	L2	250.400000000000006	0.0299999999999999989
61153	K2	302.199999999999989	0.0560000000000000012
61153	M8	0.400000000000000022	0.00300000000000000006
61154	M2	219.900000000000006	0.509000000000000008
61154	S2	287	0.0519999999999999976
61154	N2	172.400000000000006	0.164000000000000007
61154	K1	112.299999999999997	1.14799999999999991
61154	M4	98.9000000000000057	0.0160000000000000003
61154	O1	65	0.688999999999999946
61154	M6	168	0.00300000000000000006
61154	MK3	295.5	0.0519999999999999976
61154	S4	259.800000000000011	0.00300000000000000006
61154	MN4	13.5	0.00700000000000000015
61154	NU2	146.800000000000011	0.0429999999999999966
61154	MU2	23.3999999999999986	0.0200000000000000004
61154	2N2	39.8999999999999986	0.0299999999999999989
61154	OO1	121.900000000000006	0.0749999999999999972
61154	LDA2	175.5	0.0330000000000000016
61154	S1	62.8999999999999986	0.120999999999999996
61154	M1	204.300000000000011	0.115000000000000005
61154	J1	7.70000000000000018	0.0589999999999999969
61154	SSA	194.300000000000011	0.0589999999999999969
61154	SA	126	0.242999999999999994
61154	RHO1	330.899999999999977	0.0589999999999999969
61154	Q1	44.3999999999999986	0.0950000000000000011
61154	T2	54.7000000000000028	0.00700000000000000015
61154	R2	77.2999999999999972	0.0129999999999999994
61154	2Q1	9.40000000000000036	0.0490000000000000019
61154	P1	108.400000000000006	0.394000000000000017
61154	2SM2	144.400000000000006	0.0100000000000000002
61154	M3	215.900000000000006	0.0129999999999999994
61154	L2	351.100000000000023	0.00300000000000000006
61154	2MK3	223.599999999999994	0.0259999999999999988
61154	K2	307.800000000000011	0.0719999999999999946
61154	MS4	162.099999999999994	0.0100000000000000002
61155	M2	232.5	0.59099999999999997
61155	S2	348.5	0.117999999999999994
61155	N2	177.199999999999989	0.176999999999999991
61155	K1	112.200000000000003	1.45999999999999996
61155	M4	158.300000000000011	0.0129999999999999994
61155	O1	58.6000000000000014	0.859999999999999987
61155	M6	324.399999999999977	0.00700000000000000015
61155	S4	340.699999999999989	0.00300000000000000006
61155	NU2	184.599999999999994	0.0359999999999999973
61155	S6	65.4000000000000057	0.00300000000000000006
61155	MU2	116.5	0.0129999999999999994
61155	2N2	121.799999999999997	0.0229999999999999996
61155	OO1	165.800000000000011	0.0359999999999999973
61155	LDA2	286.300000000000011	0.00300000000000000006
61155	M1	85.5999999999999943	0.0619999999999999996
61155	J1	138.800000000000011	0.0690000000000000058
61155	RHO1	35.7000000000000028	0.0330000000000000016
61155	Q1	32.1000000000000014	0.16700000000000001
61155	T2	343.899999999999977	0.00700000000000000015
61155	2Q1	5.5	0.0229999999999999996
61155	P1	108.200000000000003	0.481999999999999984
61155	L2	287.800000000000011	0.0160000000000000003
61155	K2	357.899999999999977	0.0330000000000000016
61155	M8	57.7999999999999972	0.00300000000000000006
61156	M2	37.7000000000000028	0.36399999999999999
61156	S2	106.900000000000006	0.0459999999999999992
61156	N2	340.199999999999989	0.120999999999999996
61156	K1	146.900000000000006	0.288999999999999979
61156	M4	181.199999999999989	0.0160000000000000003
61156	O1	79	0.200000000000000011
61156	M6	64.4000000000000057	0.0129999999999999994
61156	MK3	66.5	0.0259999999999999988
61156	MN4	145.5	0.00700000000000000015
61156	NU2	343.800000000000011	0.0200000000000000004
61156	S6	289.699999999999989	0.00300000000000000006
61156	MU2	245.199999999999989	0.0229999999999999996
61156	2N2	283.399999999999977	0.0229999999999999996
61156	OO1	239.599999999999994	0.0229999999999999996
61156	S1	130.300000000000011	0.0749999999999999972
61156	SA	245.699999999999989	0.387000000000000011
61156	MSF	128.699999999999989	0.176999999999999991
61156	Q1	67.5	0.0359999999999999973
61156	T2	166.800000000000011	0.00700000000000000015
61156	P1	137.599999999999994	0.0820000000000000034
61156	2MK3	33.3999999999999986	0.0100000000000000002
61156	K2	88.7999999999999972	0.0560000000000000012
61156	MS4	238.699999999999989	0.0100000000000000002
61157	M2	186.900000000000006	0.429999999999999993
61157	S2	293.899999999999977	0.0889999999999999958
61157	N2	116.299999999999997	0.107999999999999999
61157	K1	254.599999999999994	0.143999999999999989
61157	M4	219.099999999999994	0.0790000000000000008
61157	O1	121.799999999999997	0.0560000000000000012
61157	M6	148.5	0.00300000000000000006
61157	S4	235.5	0.00700000000000000015
61157	NU2	125.700000000000003	0.0200000000000000004
61157	MU2	81	0.0100000000000000002
61157	2N2	46.2000000000000028	0.0129999999999999994
61157	OO1	30	0.00300000000000000006
61157	LDA2	236.099999999999994	0.00300000000000000006
61157	M1	189.099999999999994	0.00300000000000000006
61157	J1	321.800000000000011	0.00300000000000000006
61157	RHO1	67.0999999999999943	0.00300000000000000006
61157	Q1	55.7999999999999972	0.0100000000000000002
61157	T2	290.600000000000023	0.00300000000000000006
61157	2Q1	352.199999999999989	0.00300000000000000006
61157	P1	244.599999999999994	0.0459999999999999992
61157	L2	258.399999999999977	0.0129999999999999994
61157	K2	302.800000000000011	0.0229999999999999996
61157	M8	235.900000000000006	0.00300000000000000006
61158	M2	206	0.360999999999999988
61158	S2	321.699999999999989	0.112000000000000002
61158	N2	130.099999999999994	0.104999999999999996
61158	K1	262.899999999999977	0.107999999999999999
61158	M4	270.300000000000011	0.0850000000000000061
61158	O1	118.5	0.0330000000000000016
61158	M6	67.2000000000000028	0.00300000000000000006
61158	S4	318.100000000000023	0.0129999999999999994
61158	NU2	140.199999999999989	0.0200000000000000004
61158	S6	30.8000000000000007	0.00300000000000000006
61158	MU2	117.5	0.0100000000000000002
61158	2N2	54.2000000000000028	0.0129999999999999994
61158	LDA2	259.699999999999989	0.00300000000000000006
61158	M1	191.300000000000011	0.00300000000000000006
61158	J1	334.5	0.00300000000000000006
61158	Q1	47	0.00700000000000000015
61158	T2	317.100000000000023	0.00700000000000000015
61158	P1	252.099999999999994	0.0359999999999999973
61158	L2	281.899999999999977	0.0100000000000000002
61158	K2	331.100000000000023	0.0299999999999999989
61158	M8	128.800000000000011	0.00300000000000000006
61159	M2	188.5	0.360999999999999988
61159	S2	313.199999999999989	0.0850000000000000061
61159	N2	123.900000000000006	0.117999999999999994
61159	K1	265.199999999999989	0.143999999999999989
61159	M4	213.800000000000011	0.0259999999999999988
61159	O1	130.300000000000011	0.0560000000000000012
61159	M6	194.5	0.00700000000000000015
61159	S4	74.5999999999999943	0.0100000000000000002
61159	NU2	132.5	0.0229999999999999996
61159	S6	38.2999999999999972	0.00700000000000000015
61159	MU2	89.5	0.0100000000000000002
61159	2N2	59.2000000000000028	0.0160000000000000003
61159	OO1	40.1000000000000014	0.00300000000000000006
61159	LDA2	246.400000000000006	0.00300000000000000006
61159	M1	198.300000000000011	0.00300000000000000006
61159	J1	332.100000000000023	0.00300000000000000006
61159	RHO1	72.4000000000000057	0.00300000000000000006
61159	Q1	63.2999999999999972	0.0100000000000000002
61159	T2	308.199999999999989	0.00700000000000000015
61159	P1	255.099999999999994	0.0490000000000000019
61159	L2	253.199999999999989	0.0100000000000000002
61159	K2	323.300000000000011	0.0229999999999999996
61160	M2	199.400000000000006	0.406999999999999973
61160	S2	296.899999999999977	0.0980000000000000038
61160	N2	124.400000000000006	0.0950000000000000011
61160	K1	266.300000000000011	0.125
61160	M4	182.800000000000011	0.00700000000000000015
61160	O1	108.200000000000003	0.0560000000000000012
61160	M6	207.599999999999994	0.00300000000000000006
61160	S4	254	0.00300000000000000006
61160	NU2	134.5	0.0200000000000000004
61160	S6	68.4000000000000057	0.00300000000000000006
61160	MU2	125.900000000000006	0.0100000000000000002
61160	2N2	49.5	0.0129999999999999994
61160	OO1	64.5	0.00300000000000000006
61160	LDA2	244.599999999999994	0.00300000000000000006
61160	M1	187.900000000000006	0.00300000000000000006
61160	J1	344.800000000000011	0.00300000000000000006
61160	RHO1	40.3999999999999986	0.00300000000000000006
61160	Q1	29.8000000000000007	0.0100000000000000002
61160	T2	293	0.00700000000000000015
61160	P1	254.5	0.0429999999999999966
61160	L2	274.399999999999977	0.0129999999999999994
61160	K2	304.800000000000011	0.0259999999999999988
61160	M8	6.70000000000000018	0.00300000000000000006
61161	M2	213.599999999999994	0.446000000000000008
61161	S2	317.399999999999977	0.120999999999999996
61161	N2	140.400000000000006	0.0919999999999999984
61161	K1	284.100000000000023	0.0980000000000000038
61161	M4	150.400000000000006	0.00700000000000000015
61161	O1	92.2000000000000028	0.0259999999999999988
61161	M6	283.600000000000023	0.0100000000000000002
61161	S4	219.199999999999989	0.00700000000000000015
61161	NU2	150.199999999999989	0.0200000000000000004
61161	MU2	109.700000000000003	0.0100000000000000002
61161	2N2	67.2000000000000028	0.0129999999999999994
61161	LDA2	261.800000000000011	0.00300000000000000006
61161	M1	7.5	0.00300000000000000006
61161	J1	200.699999999999989	0.00300000000000000006
61161	Q1	175.599999999999994	0.00300000000000000006
61161	T2	313.300000000000011	0.00700000000000000015
61161	P1	296.699999999999989	0.0330000000000000016
61161	L2	286.699999999999989	0.0129999999999999994
61161	K2	325.899999999999977	0.0330000000000000016
61161	M8	343.100000000000023	0.00300000000000000006
61162	M2	64.2000000000000028	0.695999999999999952
61162	S2	132.800000000000011	0.171000000000000013
61162	N2	355.899999999999977	0.153999999999999998
61162	K1	4.5	0.233000000000000013
61162	M4	309.600000000000023	0.0100000000000000002
61162	O1	159.699999999999989	0.112000000000000002
61162	M6	265.100000000000023	0.00300000000000000006
61162	S4	239.800000000000011	0.00700000000000000015
61162	NU2	5.09999999999999964	0.0299999999999999989
61162	S6	42.3999999999999986	0.00300000000000000006
61162	MU2	354.100000000000023	0.0160000000000000003
61162	2N2	287.899999999999977	0.0200000000000000004
61162	OO1	206.300000000000011	0.00300000000000000006
61162	LDA2	94.7000000000000028	0.00300000000000000006
61162	M1	48	0.00300000000000000006
61162	J1	304.800000000000011	0.00300000000000000006
61162	RHO1	180.5	0.00300000000000000006
61162	Q1	192	0.0160000000000000003
61162	T2	129.900000000000006	0.0100000000000000002
61162	2Q1	335.699999999999989	0.00300000000000000006
61162	P1	5.40000000000000036	0.0790000000000000008
61162	L2	132.599999999999994	0.0200000000000000004
61162	K2	138.300000000000011	0.0459999999999999992
61162	M8	124.599999999999994	0.00300000000000000006
61163	M2	62.5	0.708999999999999964
61163	S2	135.300000000000011	0.147999999999999993
61163	N2	3.39999999999999991	0.187
61163	K1	1.69999999999999996	0.171000000000000013
61163	M4	20.8000000000000007	0.0259999999999999988
61163	O1	33.2000000000000028	0.0160000000000000003
61163	M6	224.099999999999994	0.0200000000000000004
61163	S4	194.599999999999994	0.00300000000000000006
61163	NU2	11.4000000000000004	0.0359999999999999973
61163	S6	312.600000000000023	0.00300000000000000006
61163	MU2	349.600000000000023	0.0160000000000000003
61163	2N2	304	0.0229999999999999996
61163	OO1	47.2999999999999972	0.00300000000000000006
61163	LDA2	96.4000000000000057	0.00700000000000000015
61163	M1	356.800000000000011	0.00300000000000000006
61163	J1	16.1999999999999993	0.00300000000000000006
61163	Q1	93.7000000000000028	0.0100000000000000002
61163	T2	132.599999999999994	0.0100000000000000002
61163	2Q1	58	0.00300000000000000006
61163	P1	359.199999999999989	0.0560000000000000012
61163	L2	121.599999999999994	0.0200000000000000004
61163	K2	141.199999999999989	0.0389999999999999999
61163	M8	164.199999999999989	0.00300000000000000006
61164	M2	265.300000000000011	0.404000000000000026
61164	S2	332.300000000000011	0.125
61164	N2	208.400000000000006	0.112000000000000002
61164	K1	334	0.131000000000000005
61164	M4	294.100000000000023	0.0200000000000000004
61164	O1	66.4000000000000057	0.0519999999999999976
61164	M6	113.5	0.00700000000000000015
61164	S4	297.399999999999977	0.00300000000000000006
61164	NU2	216	0.0229999999999999996
61164	S6	231.900000000000006	0.00300000000000000006
61164	MU2	226.199999999999989	0.0100000000000000002
61164	2N2	151.5	0.0160000000000000003
61164	OO1	241.5	0.00300000000000000006
61164	LDA2	296.399999999999977	0.00300000000000000006
61164	M1	19.8000000000000007	0.00300000000000000006
61164	J1	288.100000000000023	0.00300000000000000006
61164	RHO1	106.099999999999994	0.00300000000000000006
61164	Q1	112.299999999999997	0.0100000000000000002
61164	T2	329.600000000000023	0.00700000000000000015
61164	P1	340.899999999999977	0.0429999999999999966
61164	L2	322.199999999999989	0.0100000000000000002
61164	K2	337.800000000000011	0.0330000000000000016
61164	M8	231	0.00700000000000000015
61165	M2	312	0.370999999999999996
61165	S2	22	0.0889999999999999958
61165	N2	252	0.0950000000000000011
61165	K1	335.399999999999977	0.128000000000000003
61165	M4	111.599999999999994	0.0160000000000000003
61165	O1	182.199999999999989	0.0389999999999999999
61165	M6	278.199999999999989	0.00700000000000000015
61165	NU2	260	0.0200000000000000004
61165	S6	50.8999999999999986	0.00300000000000000006
61165	MU2	241.900000000000006	0.0100000000000000002
61165	2N2	192	0.0129999999999999994
61165	OO1	128.599999999999994	0.00300000000000000006
61165	LDA2	344.5	0.00300000000000000006
61165	M1	259.399999999999977	0.00300000000000000006
61165	J1	51.3999999999999986	0.00300000000000000006
61165	Q1	106.200000000000003	0.00700000000000000015
61165	T2	19.1999999999999993	0.00700000000000000015
61165	P1	323.899999999999977	0.0429999999999999966
61165	L2	11.9000000000000004	0.0100000000000000002
61165	K2	27.6999999999999993	0.0229999999999999996
61166	M2	133.300000000000011	0.187
61166	S2	210.900000000000006	0.0459999999999999992
61166	N2	66.5999999999999943	0.0459999999999999992
61166	K1	56.7999999999999972	0.164000000000000007
61166	M4	184.099999999999994	0.0200000000000000004
61166	O1	33.8999999999999986	0.0359999999999999973
61166	M6	103.799999999999997	0.00700000000000000015
61166	S4	352.899999999999977	0.00700000000000000015
61166	NU2	76.2999999999999972	0.0100000000000000002
61166	S6	146.699999999999989	0.00300000000000000006
61166	MU2	56.5	0.00300000000000000006
61166	2N2	1.60000000000000009	0.00700000000000000015
61166	M1	29.6000000000000014	0.00300000000000000006
61166	J1	89.7000000000000028	0.00300000000000000006
61166	RHO1	29.5	0.00300000000000000006
61166	Q1	38.8999999999999986	0.00700000000000000015
61166	T2	207.300000000000011	0.00300000000000000006
61166	P1	52.3999999999999986	0.0519999999999999976
61166	L2	195.599999999999994	0.00700000000000000015
61166	K2	216.599999999999994	0.0129999999999999994
61167	M2	194.400000000000006	0.120999999999999996
61167	S2	280.699999999999989	0.0330000000000000016
61167	N2	110.200000000000003	0.0200000000000000004
61167	K1	25.3000000000000007	0.171000000000000013
61167	M4	139.300000000000011	0.0100000000000000002
61167	O1	196.099999999999994	0.0589999999999999969
61167	M6	11.3000000000000007	0.00700000000000000015
61167	NU2	118.700000000000003	0.00300000000000000006
61167	S6	356	0.00300000000000000006
61167	MU2	105.700000000000003	0.00300000000000000006
61167	2N2	44.5	0.00300000000000000006
61167	OO1	224	0.00300000000000000006
61167	M1	21.8000000000000007	0.00300000000000000006
61167	J1	27.3999999999999986	0.00300000000000000006
61167	RHO1	194	0.00300000000000000006
61167	Q1	198.900000000000006	0.0129999999999999994
61167	T2	271.300000000000011	0.00300000000000000006
61167	P1	21.1999999999999993	0.0560000000000000012
61167	L2	279.600000000000023	0.00300000000000000006
61167	K2	287	0.0100000000000000002
61167	M8	212.5	0.00300000000000000006
61168	M2	280.800000000000011	0.242999999999999994
61168	S2	335	0.0459999999999999992
61168	N2	225.900000000000006	0.0589999999999999969
61168	K1	84.5999999999999943	0.0660000000000000031
61168	M4	97	0.00300000000000000006
61168	O1	127.299999999999997	0.0330000000000000016
61168	M6	275	0.00300000000000000006
61168	MK3	75.2000000000000028	0.0100000000000000002
61168	MN4	43.5	0.00300000000000000006
61168	NU2	236.199999999999989	0.0100000000000000002
61168	MU2	77.7000000000000028	0.00700000000000000015
61168	2N2	143.099999999999994	0.00700000000000000015
61168	OO1	108.5	0.0100000000000000002
61168	LDA2	338.300000000000011	0.00300000000000000006
61168	S1	297.800000000000011	0.0359999999999999973
61168	M1	194.699999999999989	0.00300000000000000006
61168	J1	147.199999999999989	0.00300000000000000006
61168	SSA	239.599999999999994	0.284999999999999976
61168	SA	144.5	0.535000000000000031
61168	RHO1	97.0999999999999943	0.00300000000000000006
61168	Q1	132	0.0129999999999999994
61168	T2	46.2000000000000028	0.0160000000000000003
61168	R2	9.40000000000000036	0.0330000000000000016
61168	P1	95.4000000000000057	0.0160000000000000003
61168	2SM2	234.400000000000006	0.00300000000000000006
61168	M3	333.800000000000011	0.00300000000000000006
61168	L2	324.899999999999977	0.00700000000000000015
61168	2MK3	335.899999999999977	0.00700000000000000015
61168	K2	314.600000000000023	0.0259999999999999988
61169	M2	268.699999999999989	0.338000000000000023
61169	S2	334.800000000000011	0.120999999999999996
61169	N2	210.800000000000011	0.0950000000000000011
61169	K1	30.3999999999999986	0.120999999999999996
61169	M4	79.2999999999999972	0.00700000000000000015
61169	O1	129.300000000000011	0.0359999999999999973
61169	M6	288.699999999999989	0.00300000000000000006
61169	S4	65.7999999999999972	0.00300000000000000006
61169	NU2	218.599999999999994	0.0200000000000000004
61169	S6	23.1000000000000014	0.00300000000000000006
61169	MU2	233.400000000000006	0.0100000000000000002
61169	2N2	152.900000000000006	0.0129999999999999994
61169	OO1	291.600000000000023	0.00300000000000000006
61169	LDA2	299.399999999999977	0.00300000000000000006
61169	M1	79.5	0.00300000000000000006
61169	J1	341.399999999999977	0.00300000000000000006
61169	Q1	178.300000000000011	0.00700000000000000015
61169	T2	332.100000000000023	0.00700000000000000015
61169	P1	37.8999999999999986	0.0389999999999999999
61169	L2	326.600000000000023	0.0100000000000000002
61169	K2	340.100000000000023	0.0330000000000000016
61169	M8	86.5999999999999943	0.00300000000000000006
61170	M2	298.800000000000011	0.248999999999999999
61170	S2	3	0.0299999999999999989
61170	N2	245.199999999999989	0.0790000000000000008
61170	K1	50.6000000000000014	0.0619999999999999996
61170	M4	237.099999999999994	0.00300000000000000006
61170	O1	162.400000000000006	0.0259999999999999988
61170	M6	272.300000000000011	0.00300000000000000006
61170	S4	224.5	0.00300000000000000006
61170	NU2	252.400000000000006	0.0160000000000000003
61170	MU2	234.5	0.00700000000000000015
61170	2N2	191.599999999999994	0.0100000000000000002
61170	LDA2	328.600000000000023	0.00300000000000000006
61170	M1	106	0.00300000000000000006
61170	J1	355.100000000000023	0.00300000000000000006
61170	SSA	239.599999999999994	0.284999999999999976
61170	SA	144.5	0.535000000000000031
61170	Q1	217.800000000000011	0.00300000000000000006
61170	T2	0.5	0.00300000000000000006
61170	P1	59	0.0200000000000000004
61170	L2	352.300000000000011	0.00700000000000000015
61170	K2	8.30000000000000071	0.00700000000000000015
61171	M2	270	0.176999999999999991
61171	S2	320	0.0790000000000000008
61171	N2	248.300000000000011	0.0229999999999999996
61171	K1	150.300000000000011	0.0690000000000000058
61171	O1	153.199999999999989	0.0589999999999999969
61171	S1	91.7999999999999972	0.0129999999999999994
61171	J1	141.300000000000011	0.00700000000000000015
61171	SSA	252.400000000000006	0.220000000000000001
61171	SA	155.5	0.387000000000000011
61171	RHO1	109.599999999999994	0.00700000000000000015
61171	Q1	130.900000000000006	0.0129999999999999994
61171	T2	7.29999999999999982	0.00700000000000000015
61171	R2	353.600000000000023	0.0100000000000000002
61171	2Q1	127.099999999999994	0.00700000000000000015
61171	P1	147	0.0259999999999999988
61171	K2	306	0.0200000000000000004
61172	M2	275.699999999999989	0.209999999999999992
61172	S2	314.899999999999977	0.0950000000000000011
61172	N2	258.199999999999989	0.0330000000000000016
61172	K1	158.400000000000006	0.0790000000000000008
61172	O1	186.800000000000011	0.107999999999999999
61172	NU2	234.300000000000011	0.00700000000000000015
61172	MU2	273.300000000000011	0.00700000000000000015
61172	2N2	241.099999999999994	0.00300000000000000006
61172	OO1	173.900000000000006	0.00300000000000000006
61172	LDA2	252.699999999999989	0.00300000000000000006
61172	S1	290.600000000000023	0.0100000000000000002
61172	M1	207.099999999999994	0.00300000000000000006
61172	J1	159.699999999999989	0.0100000000000000002
61172	SSA	249	0.203000000000000014
61172	SA	145.300000000000011	0.384000000000000008
61172	RHO1	169.199999999999989	0.00700000000000000015
61172	Q1	173.599999999999994	0.0359999999999999973
61172	T2	337.800000000000011	0.0100000000000000002
61172	R2	343.399999999999977	0.0100000000000000002
61172	2Q1	94.0999999999999943	0.00700000000000000015
61172	P1	177.199999999999989	0.0299999999999999989
61172	L2	299	0.00700000000000000015
61172	K2	318.399999999999977	0.0299999999999999989
61173	M2	287.699999999999989	0.233000000000000013
61173	S2	334.600000000000023	0.107999999999999999
61173	N2	268.5	0.0330000000000000016
61173	K1	156.300000000000011	0.0490000000000000019
61173	O1	195.900000000000006	0.147999999999999993
61173	NU2	271.199999999999989	0.00700000000000000015
61173	2N2	249.300000000000011	0.00700000000000000015
61173	OO1	116.799999999999997	0.00700000000000000015
61173	M1	176.099999999999994	0.0100000000000000002
61173	J1	136.5	0.0129999999999999994
61173	RHO1	213	0.00700000000000000015
61173	Q1	215.699999999999989	0.0299999999999999989
61173	T2	334.600000000000023	0.00700000000000000015
61173	2Q1	235.5	0.00300000000000000006
61173	P1	156.400000000000006	0.0160000000000000003
61173	L2	306.899999999999977	0.00700000000000000015
61173	K2	334.600000000000023	0.0299999999999999989
61174	M2	308.199999999999989	0.212999999999999995
61174	S2	349.5	0.0950000000000000011
61174	N2	289.199999999999989	0.0359999999999999973
61174	K1	172	0.0749999999999999972
61174	O1	198	0.0980000000000000038
61174	NU2	291.899999999999977	0.00700000000000000015
61174	2N2	270.300000000000011	0.00700000000000000015
61174	OO1	145.900000000000006	0.00300000000000000006
61174	M1	185	0.00700000000000000015
61174	J1	158.900000000000006	0.00700000000000000015
61174	RHO1	209.199999999999989	0.00300000000000000006
61174	Q1	190	0.0330000000000000016
61174	T2	349.399999999999977	0.00700000000000000015
61174	2Q1	224	0.00300000000000000006
61174	P1	171.800000000000011	0.0259999999999999988
61174	L2	327.100000000000023	0.00700000000000000015
61174	K2	349.600000000000023	0.0259999999999999988
61175	M2	281	0.194000000000000006
61175	S2	328.300000000000011	0.0820000000000000034
61175	N2	253.5	0.0160000000000000003
61175	K1	144.400000000000006	0.0850000000000000061
61175	M4	180.599999999999994	0.00300000000000000006
61175	O1	189.900000000000006	0.0589999999999999969
61175	S4	179	0.00300000000000000006
61175	NU2	257.199999999999989	0.00300000000000000006
61175	S6	59	0.00300000000000000006
61175	MU2	306.5	0.00300000000000000006
61175	2N2	226.099999999999994	0.00300000000000000006
61175	OO1	98.9000000000000057	0.00300000000000000006
61175	M1	166.900000000000006	0.00300000000000000006
61175	J1	121.799999999999997	0.00700000000000000015
61175	RHO1	209.400000000000006	0.00300000000000000006
61175	Q1	212.5	0.0129999999999999994
61175	T2	326.399999999999977	0.00700000000000000015
61175	2Q1	235	0.00300000000000000006
61175	P1	147.800000000000011	0.0299999999999999989
61175	L2	308.399999999999977	0.00700000000000000015
61175	K2	332.100000000000023	0.0229999999999999996
61175	M8	266.5	0.00300000000000000006
61176	M2	15.3000000000000007	0.328000000000000014
61176	S2	42.5	0.0560000000000000012
61176	N2	356.300000000000011	0.0719999999999999946
61176	K1	217.099999999999994	0.256000000000000005
61176	M4	278	0.0129999999999999994
61176	O1	215.199999999999989	0.187
61176	M6	290.399999999999977	0.00300000000000000006
61176	NU2	359	0.0129999999999999994
61176	MU2	348.199999999999989	0.00700000000000000015
61176	2N2	336.100000000000023	0.0100000000000000002
61176	OO1	219.599999999999994	0.00700000000000000015
61176	LDA2	28	0.00300000000000000006
61176	M1	216.199999999999989	0.0129999999999999994
61176	J1	218.199999999999989	0.0129999999999999994
61176	SSA	47.2000000000000028	0.0619999999999999996
61176	SA	181.800000000000011	0.200000000000000011
61176	RHO1	214.400000000000006	0.00700000000000000015
61176	Q1	214.300000000000011	0.0359999999999999973
61176	T2	41.5	0.00300000000000000006
61176	2Q1	212.900000000000006	0.00300000000000000006
61176	P1	216.900000000000006	0.0850000000000000061
61176	L2	35	0.0100000000000000002
61176	K2	44.6000000000000014	0.0160000000000000003
61177	M2	344.600000000000023	0.101999999999999993
61177	S2	19.6999999999999993	0.0330000000000000016
61177	N2	310.600000000000023	0.0129999999999999994
61177	K1	228.5	0.269000000000000017
61177	M4	263.100000000000023	0.00700000000000000015
61177	O1	222.199999999999989	0.197000000000000008
61177	MK3	185.599999999999994	0.00300000000000000006
61177	S4	133.199999999999989	0.00300000000000000006
61177	MN4	149.5	0.00300000000000000006
61177	NU2	297.300000000000011	0.00300000000000000006
61177	MU2	46.5	0.00300000000000000006
61177	2N2	225.699999999999989	0.00300000000000000006
61177	OO1	234.099999999999994	0.0129999999999999994
61177	LDA2	330.899999999999977	0.00300000000000000006
61177	S1	242.5	0.0100000000000000002
61177	M1	239.5	0.0100000000000000002
61177	J1	229.900000000000006	0.0160000000000000003
61177	MM	322.100000000000023	0.0229999999999999996
61177	SA	179.800000000000011	0.179999999999999993
61177	MF	0.100000000000000006	0.0519999999999999976
61177	RHO1	219.699999999999989	0.00700000000000000015
61177	Q1	209.300000000000011	0.0330000000000000016
61177	T2	358.800000000000011	0.00300000000000000006
61177	R2	133.5	0.00300000000000000006
61177	2Q1	197.5	0.00300000000000000006
61177	P1	229	0.0820000000000000034
61177	M3	47.2000000000000028	0.00300000000000000006
61177	L2	359.800000000000011	0.00700000000000000015
61177	K2	16	0.0100000000000000002
61177	MS4	349.399999999999977	0.00300000000000000006
61178	M2	16	0.176999999999999991
61178	S2	26.3999999999999986	0.0299999999999999989
61178	N2	2	0.0299999999999999989
61178	K1	226.199999999999989	0.281999999999999973
61178	M4	298.399999999999977	0.0100000000000000002
61178	O1	222.699999999999989	0.194000000000000006
61178	S4	225.5	0.00700000000000000015
61178	NU2	3.89999999999999991	0.00700000000000000015
61178	MU2	236.400000000000006	0.00300000000000000006
61178	2N2	347.600000000000023	0.00300000000000000006
61178	OO1	229.800000000000011	0.0100000000000000002
61178	M1	224.5	0.0129999999999999994
61178	J1	228	0.0160000000000000003
61178	MM	333.600000000000023	0.0229999999999999996
61178	SSA	47.2000000000000028	0.0619999999999999996
61178	SA	181.800000000000011	0.200000000000000011
61178	MF	352.399999999999977	0.0429999999999999966
61178	RHO1	221.199999999999989	0.00700000000000000015
61178	Q1	220.900000000000006	0.0389999999999999999
61178	T2	26.1000000000000014	0.00300000000000000006
61178	2Q1	219.199999999999989	0.00700000000000000015
61178	P1	226	0.0919999999999999984
61178	L2	29.1999999999999993	0.00300000000000000006
61178	K2	27.3000000000000007	0.00700000000000000015
61178	M8	123.900000000000006	0.00300000000000000006
61179	M2	23.8000000000000007	0.153999999999999998
61179	S2	22.8000000000000007	0.0259999999999999988
61179	N2	11.4000000000000004	0.0330000000000000016
61179	K1	228.900000000000006	0.27200000000000002
61179	M4	298.5	0.00300000000000000006
61179	O1	222	0.194000000000000006
61179	M6	327.5	0.00300000000000000006
61179	MK3	193.599999999999994	0.00300000000000000006
61179	S4	133.300000000000011	0.00300000000000000006
61179	MN4	183.300000000000011	0.00300000000000000006
61179	NU2	5.20000000000000018	0.00700000000000000015
61179	MU2	63.3999999999999986	0.00300000000000000006
61179	2N2	4.5	0.00700000000000000015
61179	OO1	235.5	0.0129999999999999994
61179	LDA2	23.1000000000000014	0.00300000000000000006
61179	S1	165.5	0.00700000000000000015
61179	M1	242.099999999999994	0.0100000000000000002
61179	J1	230.400000000000006	0.0200000000000000004
61179	MM	324.300000000000011	0.0200000000000000004
61179	SSA	53.2000000000000028	0.0459999999999999992
61179	SA	191.599999999999994	0.197000000000000008
61179	MSF	266.199999999999989	0.00700000000000000015
61179	MF	358.600000000000023	0.0490000000000000019
61179	RHO1	216.599999999999994	0.00700000000000000015
61179	Q1	210.400000000000006	0.0330000000000000016
61179	R2	195.5	0.00300000000000000006
61179	2Q1	206	0.00300000000000000006
61179	P1	230.800000000000011	0.0850000000000000061
61179	M3	35.1000000000000014	0.00300000000000000006
61179	L2	38.2999999999999972	0.00700000000000000015
61179	K2	16.6999999999999993	0.00700000000000000015
61179	MS4	6.29999999999999982	0.00300000000000000006
61180	M2	328.899999999999977	0.0459999999999999992
61180	S2	11.6999999999999993	0.0259999999999999988
61180	N2	232.199999999999989	0.0100000000000000002
61180	K1	237	0.276000000000000023
61180	M4	290.699999999999989	0.00700000000000000015
61180	O1	228.599999999999994	0.209999999999999992
61180	MK3	99.5999999999999943	0.00300000000000000006
61180	MN4	190	0.00300000000000000006
61180	MU2	153.800000000000011	0.00300000000000000006
61180	2N2	137.199999999999989	0.00300000000000000006
61180	OO1	248.400000000000006	0.0129999999999999994
61180	LDA2	350.100000000000023	0.00300000000000000006
61180	S1	240.699999999999989	0.0160000000000000003
61180	M1	273.5	0.0129999999999999994
61180	J1	234.300000000000011	0.0160000000000000003
61180	MM	349	0.0259999999999999988
61180	SA	173.699999999999989	0.212999999999999995
61180	MF	356.899999999999977	0.0519999999999999976
61180	RHO1	213.599999999999994	0.0100000000000000002
61180	Q1	210.599999999999994	0.0330000000000000016
61180	T2	192.5	0.00700000000000000015
61180	R2	214.400000000000006	0.00300000000000000006
61180	2Q1	204.400000000000006	0.00300000000000000006
61180	P1	236.099999999999994	0.0850000000000000061
61180	M3	27.1999999999999993	0.00300000000000000006
61180	L2	31.3000000000000007	0.00300000000000000006
61180	K2	355.399999999999977	0.00700000000000000015
61180	MS4	355.199999999999989	0.00700000000000000015
61181	M2	11.3000000000000007	0.301999999999999991
61181	S2	70.5	0.0560000000000000012
61181	N2	354.899999999999977	0.0619999999999999996
61181	K1	224.5	0.233000000000000013
61181	M4	308.600000000000023	0.0160000000000000003
61181	O1	215.900000000000006	0.187
61181	M6	325.600000000000023	0.0100000000000000002
61181	MK3	57.8999999999999986	0.0129999999999999994
61181	MN4	257.800000000000011	0.00700000000000000015
61181	NU2	353.899999999999977	0.0160000000000000003
61181	MU2	53.6000000000000014	0.0100000000000000002
61181	2N2	26.6000000000000014	0.0100000000000000002
61181	OO1	231.400000000000006	0.0100000000000000002
61181	LDA2	319.100000000000023	0.00700000000000000015
61181	S1	191.300000000000011	0.0359999999999999973
61181	M1	207.699999999999989	0.0129999999999999994
61181	J1	226.199999999999989	0.0160000000000000003
61181	RHO1	186.199999999999989	0.00300000000000000006
61181	Q1	192.099999999999994	0.0299999999999999989
61181	T2	111.299999999999997	0.0129999999999999994
61181	R2	318	0.0359999999999999973
61181	P1	231.599999999999994	0.0619999999999999996
61181	2SM2	154.400000000000006	0.00700000000000000015
61181	M3	16.3999999999999986	0.00300000000000000006
61181	L2	342.300000000000011	0.0129999999999999994
61181	2MK3	73.5	0.00700000000000000015
61181	K2	21.3999999999999986	0.0330000000000000016
61181	MS4	17.3000000000000007	0.00700000000000000015
61182	M2	23.8000000000000007	0.147999999999999993
61182	S2	136.300000000000011	0.0229999999999999996
61182	N2	22.8999999999999986	0.0299999999999999989
61182	K1	230.900000000000006	0.253000000000000003
61182	M4	283.800000000000011	0.0129999999999999994
61182	O1	221.699999999999989	0.200000000000000011
61182	M6	275.899999999999977	0.00300000000000000006
61182	S4	163.300000000000011	0.00300000000000000006
61182	MN4	205.199999999999989	0.00700000000000000015
61182	NU2	30.1999999999999993	0.00700000000000000015
61182	MU2	99	0.00700000000000000015
61182	OO1	224.900000000000006	0.0100000000000000002
61182	S1	197.300000000000011	0.0299999999999999989
61182	M1	215.199999999999989	0.0129999999999999994
61182	J1	225.699999999999989	0.0200000000000000004
61182	SSA	47.2000000000000028	0.0619999999999999996
61182	SA	181.800000000000011	0.200000000000000011
61182	RHO1	245.199999999999989	0.00700000000000000015
61182	Q1	196.800000000000011	0.0299999999999999989
61182	T2	172.199999999999989	0.0200000000000000004
61182	R2	344	0.0459999999999999992
61182	2Q1	168	0.00700000000000000015
61182	P1	233.900000000000006	0.0619999999999999996
61182	2SM2	137.300000000000011	0.00300000000000000006
61182	M3	28.8999999999999986	0.00300000000000000006
61182	L2	32.2999999999999972	0.0100000000000000002
61182	K2	26	0.0299999999999999989
61182	MS4	323.399999999999977	0.00300000000000000006
61183	M2	28.1000000000000014	0.138000000000000012
61183	S2	18.8000000000000007	0.0229999999999999996
61183	N2	6.20000000000000018	0.0259999999999999988
61183	K1	228.400000000000006	0.266000000000000014
61183	O1	222.900000000000006	0.203000000000000014
61183	NU2	9.09999999999999964	0.00700000000000000015
61183	2N2	344.300000000000011	0.00300000000000000006
61183	OO1	233.900000000000006	0.0100000000000000002
61183	M1	225.599999999999994	0.0129999999999999994
61183	J1	231.099999999999994	0.0160000000000000003
61183	RHO1	220.5	0.00700000000000000015
61183	Q1	220.199999999999989	0.0389999999999999999
61183	2Q1	217.5	0.00700000000000000015
61183	P1	228	0.0889999999999999958
61183	L2	50	0.00300000000000000006
61183	K2	18	0.00700000000000000015
61184	M2	12.8000000000000007	0.353999999999999981
61184	S2	38	0.0589999999999999969
61184	N2	351.600000000000023	0.0790000000000000008
61184	K1	218.199999999999989	0.245999999999999996
61184	M4	301.600000000000023	0.00300000000000000006
61184	O1	217.099999999999994	0.190000000000000002
61184	M6	319	0.00700000000000000015
61184	NU2	354.300000000000011	0.0160000000000000003
61184	MU2	347.600000000000023	0.0100000000000000002
61184	2N2	330.399999999999977	0.0100000000000000002
61184	OO1	220.199999999999989	0.0100000000000000002
61184	LDA2	24.5	0.00300000000000000006
61184	M1	217.599999999999994	0.0129999999999999994
61184	J1	218.900000000000006	0.0160000000000000003
61184	SSA	47.2000000000000028	0.0619999999999999996
61184	SA	181.800000000000011	0.200000000000000011
61184	RHO1	216.5	0.00700000000000000015
61184	Q1	216.5	0.0359999999999999973
61184	T2	37.1000000000000014	0.00300000000000000006
61184	2Q1	215.800000000000011	0.00700000000000000015
61184	P1	218.099999999999994	0.0820000000000000034
61184	L2	34.2999999999999972	0.0100000000000000002
61184	K2	39.8999999999999986	0.0160000000000000003
61185	M2	43.8999999999999986	0.0719999999999999946
61185	S2	51.8999999999999986	0.0490000000000000019
61185	N2	44	0.0200000000000000004
61185	K1	237.300000000000011	0.235999999999999988
61185	M4	282.399999999999977	0.0100000000000000002
61185	O1	229	0.197000000000000008
61185	S4	191.199999999999989	0.00700000000000000015
61185	MN4	77	0.00300000000000000006
61185	NU2	225.400000000000006	0.00300000000000000006
61185	MU2	136.900000000000006	0.00700000000000000015
61185	2N2	83.7000000000000028	0.00300000000000000006
61185	OO1	247.400000000000006	0.0100000000000000002
61185	LDA2	227.400000000000006	0.0129999999999999994
61185	S1	199.199999999999989	0.0619999999999999996
61185	M1	219.5	0.0100000000000000002
61185	J1	226.400000000000006	0.0200000000000000004
61185	SSA	60	0.0490000000000000019
61185	SA	184.900000000000006	0.194000000000000006
61185	RHO1	241	0.00300000000000000006
61185	Q1	208.300000000000011	0.0299999999999999989
61185	R2	263.399999999999977	0.0359999999999999973
61185	2Q1	183.5	0.00300000000000000006
61185	P1	248	0.0589999999999999969
61185	2SM2	175	0.00700000000000000015
61185	M3	51.1000000000000014	0.00700000000000000015
61185	L2	150.400000000000006	0.00700000000000000015
61185	K2	325.5	0.0200000000000000004
61185	MS4	27.8000000000000007	0.00300000000000000006
61186	M2	23.1000000000000014	0.135000000000000009
61186	S2	9.90000000000000036	0.0299999999999999989
61186	N2	13.6999999999999993	0.0299999999999999989
61186	K1	229.5	0.262000000000000011
61186	M4	302	0.00700000000000000015
61186	O1	221.599999999999994	0.197000000000000008
61186	MK3	179.599999999999994	0.00300000000000000006
61186	S4	106.299999999999997	0.00300000000000000006
61186	MN4	203.599999999999994	0.00300000000000000006
61186	NU2	6.59999999999999964	0.00700000000000000015
61186	MU2	80.7999999999999972	0.00700000000000000015
61186	2N2	9.09999999999999964	0.00300000000000000006
61186	OO1	236.199999999999989	0.0129999999999999994
61186	LDA2	27.3000000000000007	0.00300000000000000006
61186	S1	201.099999999999994	0.0100000000000000002
61186	M1	240.800000000000011	0.0129999999999999994
61186	J1	235.099999999999994	0.0160000000000000003
61186	SSA	46	0.0519999999999999976
61186	SA	181.199999999999989	0.209999999999999992
61186	MF	358.699999999999989	0.0459999999999999992
61186	RHO1	214.800000000000011	0.00700000000000000015
61186	Q1	208.800000000000011	0.0359999999999999973
61186	T2	306.100000000000023	0.00300000000000000006
61186	2Q1	196.800000000000011	0.00300000000000000006
61186	P1	231.199999999999989	0.0790000000000000008
61186	M3	38.6000000000000014	0.00300000000000000006
61186	L2	41.6000000000000014	0.00700000000000000015
61186	K2	5	0.0100000000000000002
61186	MS4	3.20000000000000018	0.00300000000000000006
61187	M2	16.1000000000000014	0.422999999999999987
61187	S2	44.2000000000000028	0.0690000000000000058
61187	N2	354	0.0980000000000000038
61187	K1	210.199999999999989	0.223000000000000004
61187	M4	25	0.00300000000000000006
61187	O1	213.199999999999989	0.16700000000000001
61187	NU2	356.899999999999977	0.0200000000000000004
61187	MU2	348	0.0100000000000000002
61187	2N2	331.399999999999977	0.0129999999999999994
61187	OO1	207.300000000000011	0.00700000000000000015
61187	LDA2	29.1999999999999993	0.00300000000000000006
61187	M1	211.699999999999989	0.0129999999999999994
61187	J1	208.800000000000011	0.0129999999999999994
61187	SSA	47.2000000000000028	0.0619999999999999996
61187	SA	181.900000000000006	0.200000000000000011
61187	RHO1	214.5	0.00700000000000000015
61187	Q1	214.699999999999989	0.0330000000000000016
61187	T2	43.1000000000000014	0.00300000000000000006
61187	2Q1	216.199999999999989	0.00300000000000000006
61187	P1	210.400000000000006	0.0749999999999999972
61187	L2	38.2000000000000028	0.0129999999999999994
61187	K2	46.6000000000000014	0.0200000000000000004
61188	M2	15.9000000000000004	0.412999999999999978
61188	S2	73.2000000000000028	0.150999999999999995
61188	N2	359.699999999999989	0.0980000000000000038
61188	K1	216.099999999999994	0.220000000000000001
61188	M4	358.899999999999977	0.00700000000000000015
61188	O1	216	0.187
61188	MK3	65.9000000000000057	0.00300000000000000006
61188	NU2	5.90000000000000036	0.0229999999999999996
61188	MU2	35.5	0.0100000000000000002
61188	2N2	3.79999999999999982	0.00700000000000000015
61188	OO1	234.400000000000006	0.0129999999999999994
61188	LDA2	333.5	0.0100000000000000002
61188	S1	207.5	0.0429999999999999966
61188	M1	212.699999999999989	0.0100000000000000002
61188	J1	218	0.0200000000000000004
61188	SSA	47.2000000000000028	0.0619999999999999996
61188	SA	181.800000000000011	0.200000000000000011
61188	RHO1	186.199999999999989	0.00700000000000000015
61188	Q1	198.5	0.0330000000000000016
61188	T2	96.7999999999999972	0.0490000000000000019
61188	R2	256.399999999999977	0.0790000000000000008
61188	2Q1	128.300000000000011	0.00300000000000000006
61188	P1	220.199999999999989	0.0560000000000000012
61188	2SM2	139	0.00300000000000000006
61188	L2	328.699999999999989	0.0229999999999999996
61188	K2	329.600000000000023	0.0229999999999999996
61189	M2	12.9000000000000004	0.325000000000000011
61189	S2	32.5	0.0560000000000000012
61189	N2	347.300000000000011	0.0690000000000000058
61189	K1	224.400000000000006	0.248999999999999999
61189	M4	335.5	0.00700000000000000015
61189	O1	222.699999999999989	0.194000000000000006
61189	M6	306.699999999999989	0.00300000000000000006
61189	MK3	78.5	0.00300000000000000006
61189	S4	169.099999999999994	0.00300000000000000006
61189	NU2	345.399999999999977	0.0129999999999999994
61189	MU2	23.6000000000000014	0.0100000000000000002
61189	2N2	337.699999999999989	0.00700000000000000015
61189	OO1	231.5	0.0129999999999999994
61189	LDA2	31.6000000000000014	0.00700000000000000015
61189	S1	218.5	0.0160000000000000003
61189	M1	236.699999999999989	0.0100000000000000002
61189	J1	227.099999999999994	0.0160000000000000003
61189	SSA	60.7000000000000028	0.0719999999999999946
61189	SA	191	0.190000000000000002
61189	MF	0.100000000000000006	0.0490000000000000019
61189	RHO1	207.699999999999989	0.00700000000000000015
61189	Q1	209.300000000000011	0.0359999999999999973
61189	T2	13.8000000000000007	0.00700000000000000015
61189	2Q1	199.800000000000011	0.00300000000000000006
61189	P1	225	0.0719999999999999946
61189	2SM2	32.3999999999999986	0.00300000000000000006
61189	M3	24.5	0.00300000000000000006
61189	L2	38.5	0.0100000000000000002
61189	2MK3	19	0.00300000000000000006
61189	K2	29.8999999999999986	0.0129999999999999994
61189	MS4	13.4000000000000004	0.00300000000000000006
61190	M2	17.8000000000000007	0.366999999999999993
61190	S2	37.1000000000000014	0.0619999999999999996
61190	N2	353.199999999999989	0.0820000000000000034
61190	K1	222.5	0.248999999999999999
61190	M4	303.600000000000023	0.00300000000000000006
61190	O1	223.300000000000011	0.197000000000000008
61190	M6	295.800000000000011	0.00300000000000000006
61190	MK3	95.7999999999999972	0.00300000000000000006
61190	NU2	353.600000000000023	0.0129999999999999994
61190	MU2	26.6999999999999993	0.0129999999999999994
61190	2N2	346.5	0.0100000000000000002
61190	OO1	234.5	0.0100000000000000002
61190	LDA2	38.3999999999999986	0.00300000000000000006
61190	S1	250.699999999999989	0.0229999999999999996
61190	M1	248.400000000000006	0.0100000000000000002
61190	J1	220.199999999999989	0.0160000000000000003
61190	MM	332.100000000000023	0.0259999999999999988
61190	SA	197.699999999999989	0.138000000000000012
61190	MF	350.5	0.0560000000000000012
61190	RHO1	215.099999999999994	0.0100000000000000002
61190	Q1	208.599999999999994	0.0359999999999999973
61190	T2	11.6999999999999993	0.00700000000000000015
61190	2Q1	228.5	0.00300000000000000006
61190	P1	223.599999999999994	0.0749999999999999972
61190	2SM2	44.1000000000000014	0.00300000000000000006
61190	M3	21.8999999999999986	0.00300000000000000006
61190	L2	33.2999999999999972	0.0129999999999999994
61190	2MK3	7.09999999999999964	0.00300000000000000006
61190	K2	33.6000000000000014	0.0160000000000000003
61190	MS4	3.10000000000000009	0.00300000000000000006
61191	M2	343	0.0919999999999999984
61191	S2	9.19999999999999929	0.0299999999999999989
61191	N2	307.600000000000023	0.0129999999999999994
61191	K1	232.800000000000011	0.269000000000000017
61191	M4	250	0.00700000000000000015
61191	O1	226.099999999999994	0.20699999999999999
61191	MN4	151.099999999999994	0.00700000000000000015
61191	NU2	352.699999999999989	0.00300000000000000006
61191	MU2	166.400000000000006	0.00300000000000000006
61191	OO1	244.5	0.0129999999999999994
61191	LDA2	14.6999999999999993	0.00300000000000000006
61191	S1	234.900000000000006	0.0160000000000000003
61191	M1	255.099999999999994	0.0100000000000000002
61191	J1	233.599999999999994	0.0200000000000000004
61191	MM	340.199999999999989	0.0229999999999999996
61191	SA	179	0.179999999999999993
61191	MF	0.200000000000000011	0.0519999999999999976
61191	RHO1	221.599999999999994	0.00700000000000000015
61191	Q1	212.099999999999994	0.0359999999999999973
61191	2Q1	203	0.00700000000000000015
61191	P1	232.599999999999994	0.0820000000000000034
61191	2SM2	9.30000000000000071	0.00300000000000000006
61191	M3	34.7000000000000028	0.00300000000000000006
61191	L2	5.90000000000000036	0.00700000000000000015
61191	K2	5.70000000000000018	0.0100000000000000002
61191	MS4	349.399999999999977	0.00300000000000000006
61192	M2	14.6999999999999993	0.494999999999999996
61192	S2	359.300000000000011	0.120999999999999996
61192	N2	350.100000000000023	0.120999999999999996
61192	K1	220.599999999999994	0.23000000000000001
61192	M4	314.199999999999989	0.00300000000000000006
61192	O1	224.199999999999989	0.194000000000000006
61192	M6	325.800000000000011	0.00300000000000000006
61192	MK3	51.7000000000000028	0.00300000000000000006
61192	S4	241.099999999999994	0.00300000000000000006
61192	NU2	356.199999999999989	0.0200000000000000004
61192	MU2	11.5999999999999996	0.0129999999999999994
61192	2N2	322.399999999999977	0.0100000000000000002
61192	OO1	221.099999999999994	0.0129999999999999994
61192	LDA2	44.5	0.0129999999999999994
61192	S1	205.599999999999994	0.0299999999999999989
61192	M1	213.599999999999994	0.0100000000000000002
61192	J1	230.199999999999989	0.0160000000000000003
61192	SSA	37.1000000000000014	0.0690000000000000058
61192	SA	186.900000000000006	0.179999999999999993
61192	RHO1	253.800000000000011	0.00300000000000000006
61192	Q1	205.5	0.0299999999999999989
61192	T2	337.5	0.0359999999999999973
61192	R2	140.800000000000011	0.0950000000000000011
61192	P1	223.300000000000011	0.0749999999999999972
61192	M3	344.5	0.00300000000000000006
61192	L2	6.40000000000000036	0.0299999999999999989
61192	2MK3	328.100000000000023	0.00300000000000000006
61192	K2	156.199999999999989	0.0330000000000000016
61193	M2	12.5	0.515000000000000013
61193	S2	41.2000000000000028	0.0749999999999999972
61193	N2	345.199999999999989	0.125
61193	K1	219.199999999999989	0.242999999999999994
61193	O1	222.800000000000011	0.194000000000000006
61193	M6	342.899999999999977	0.00300000000000000006
61193	MK3	19.8999999999999986	0.00300000000000000006
61193	NU2	342.600000000000023	0.0229999999999999996
61193	MU2	10.9000000000000004	0.0160000000000000003
61193	2N2	338	0.0160000000000000003
61193	OO1	223.5	0.0129999999999999994
61193	LDA2	46.8999999999999986	0.00700000000000000015
61193	S1	224.400000000000006	0.0160000000000000003
61193	M1	230.800000000000011	0.0129999999999999994
61193	J1	226.099999999999994	0.0160000000000000003
61193	MM	318.399999999999977	0.0299999999999999989
61193	SSA	258.800000000000011	0.00700000000000000015
61193	SA	197.400000000000006	0.112000000000000002
61193	MSF	298.399999999999977	0.0100000000000000002
61193	MF	357.199999999999989	0.0560000000000000012
61193	RHO1	208.400000000000006	0.0100000000000000002
61193	Q1	212.900000000000006	0.0359999999999999973
61193	T2	18.3000000000000007	0.0100000000000000002
61193	2Q1	241.5	0.00300000000000000006
61193	P1	220.099999999999994	0.0749999999999999972
61193	2SM2	39.2000000000000028	0.00300000000000000006
61193	M3	321.699999999999989	0.00300000000000000006
61193	L2	38.5	0.0229999999999999996
61193	2MK3	325.5	0.00300000000000000006
61193	K2	39.3999999999999986	0.0200000000000000004
61193	MS4	22	0.00300000000000000006
61194	M2	29.6000000000000014	0.140999999999999986
61194	S2	307.100000000000023	0.0259999999999999988
61194	N2	16.1999999999999993	0.0299999999999999989
61194	K1	230.400000000000006	0.245999999999999996
61194	M4	298.300000000000011	0.00700000000000000015
61194	O1	230	0.200000000000000011
61194	MK3	242	0.00300000000000000006
61194	S4	213.800000000000011	0.00300000000000000006
61194	NU2	14.0999999999999996	0.0160000000000000003
61194	MU2	148.300000000000011	0.0160000000000000003
61194	2N2	168.5	0.0100000000000000002
61194	OO1	238.300000000000011	0.0160000000000000003
61194	LDA2	57	0.0129999999999999994
61194	S1	227.800000000000011	0.0299999999999999989
61194	M1	231.900000000000006	0.0100000000000000002
61194	J1	236.5	0.0200000000000000004
61194	SSA	37.1000000000000014	0.0690000000000000058
61194	SA	186.900000000000006	0.179999999999999993
61194	RHO1	149.300000000000011	0.00700000000000000015
61194	Q1	205	0.0359999999999999973
61194	R2	85.9000000000000057	0.0299999999999999989
61194	2Q1	349.899999999999977	0.00300000000000000006
61194	P1	229	0.0719999999999999946
61194	2SM2	41.2000000000000028	0.00300000000000000006
61194	M3	38.3999999999999986	0.00700000000000000015
61194	L2	51.8999999999999986	0.0160000000000000003
61194	2MK3	297.600000000000023	0.00300000000000000006
61194	K2	93.9000000000000057	0.0129999999999999994
61195	M2	18.1000000000000014	0.0519999999999999976
61195	S2	0.5	0.0229999999999999996
61195	N2	85	0.0100000000000000002
61195	K1	231.800000000000011	0.269000000000000017
61195	M4	281.300000000000011	0.00700000000000000015
61195	O1	227.800000000000011	0.200000000000000011
61195	S4	81.0999999999999943	0.00300000000000000006
61195	MN4	192.199999999999989	0.00300000000000000006
61195	NU2	51.7000000000000028	0.00700000000000000015
61195	S6	65.5999999999999943	0.00300000000000000006
61195	MU2	132.699999999999989	0.00700000000000000015
61195	2N2	84.4000000000000057	0.00300000000000000006
61195	OO1	240.300000000000011	0.0100000000000000002
61195	S1	215.800000000000011	0.0129999999999999994
61195	M1	257	0.0129999999999999994
61195	J1	230.5	0.0160000000000000003
61195	MM	318	0.0200000000000000004
61195	SA	184.5	0.176999999999999991
61195	MF	352.899999999999977	0.0490000000000000019
61195	RHO1	216.400000000000006	0.0100000000000000002
61195	Q1	211.699999999999989	0.0359999999999999973
61195	R2	123.900000000000006	0.00300000000000000006
61195	2Q1	204	0.00700000000000000015
61195	P1	231.300000000000011	0.0850000000000000061
61195	2SM2	103.5	0.00300000000000000006
61195	M3	51.6000000000000014	0.00300000000000000006
61195	L2	50.2999999999999972	0.00300000000000000006
61195	2MK3	276.100000000000023	0.00300000000000000006
61195	K2	336.600000000000023	0.0100000000000000002
61195	MS4	356.5	0.00300000000000000006
61196	M2	20.3000000000000007	0.505000000000000004
61196	S2	49.3999999999999986	0.0660000000000000031
61196	N2	358.300000000000011	0.120999999999999996
61196	K1	227.699999999999989	0.284999999999999976
61196	M4	250.900000000000006	0.00700000000000000015
61196	O1	226.400000000000006	0.248999999999999999
61196	M6	358.800000000000011	0.00300000000000000006
61196	MK3	35.3999999999999986	0.00700000000000000015
61196	S4	189.099999999999994	0.00300000000000000006
61196	MN4	191	0.00300000000000000006
61196	NU2	1.5	0.0229999999999999996
61196	MU2	18.8000000000000007	0.0160000000000000003
61196	2N2	337.300000000000011	0.0160000000000000003
61196	OO1	252.199999999999989	0.0129999999999999994
61196	LDA2	41.7999999999999972	0.00700000000000000015
61196	S1	153	0.0160000000000000003
61196	M1	266.100000000000023	0.0129999999999999994
61196	J1	214	0.0160000000000000003
61196	MM	354.5	0.0200000000000000004
61196	SSA	38.2999999999999972	0.0490000000000000019
61196	SA	181.400000000000006	0.179999999999999993
61196	MF	350.100000000000023	0.00300000000000000006
61196	RHO1	214.900000000000006	0.0100000000000000002
61196	Q1	211.199999999999989	0.0490000000000000019
61196	T2	24.8999999999999986	0.0100000000000000002
61196	2Q1	218.599999999999994	0.00700000000000000015
61196	P1	228.900000000000006	0.0919999999999999984
61196	2SM2	20.1000000000000014	0.00300000000000000006
61196	M3	46.2000000000000028	0.00300000000000000006
61196	L2	21.3000000000000007	0.0100000000000000002
61196	2MK3	24.5	0.00700000000000000015
61196	K2	49.6000000000000014	0.0229999999999999996
61196	M8	172.599999999999994	0.00300000000000000006
61196	MS4	348.5	0.00300000000000000006
61197	M2	65.9000000000000057	0.0389999999999999999
61197	S2	5	0.0359999999999999973
61197	N2	137.699999999999989	0.0200000000000000004
61197	K1	231.099999999999994	0.269000000000000017
61197	M4	266.800000000000011	0.00700000000000000015
61197	O1	229.699999999999989	0.194000000000000006
61197	M6	204.800000000000011	0.00300000000000000006
61197	S4	101	0.00300000000000000006
61197	NU2	136	0.00300000000000000006
61197	S6	214	0.00300000000000000006
61197	2N2	184.5	0.00300000000000000006
61197	OO1	231.5	0.00700000000000000015
61197	M1	229.900000000000006	0.0129999999999999994
61197	J1	231.300000000000011	0.0160000000000000003
61197	RHO1	229.800000000000011	0.00700000000000000015
61197	Q1	229.5	0.0359999999999999973
61197	2Q1	228.400000000000006	0.00700000000000000015
61197	P1	230.800000000000011	0.0889999999999999958
61197	K2	0.299999999999999989	0.0100000000000000002
61197	M8	334.699999999999989	0.00300000000000000006
61198	M2	11.1999999999999993	0.0259999999999999988
61198	S2	280.5	0.0790000000000000008
61198	N2	82.9000000000000057	0.0200000000000000004
61198	K1	238	0.248999999999999999
61198	M4	282.899999999999977	0.00700000000000000015
61198	O1	231.199999999999989	0.190000000000000002
61198	MN4	164.900000000000006	0.00700000000000000015
61198	NU2	5	0.0160000000000000003
61198	S6	109	0.00300000000000000006
61198	MU2	97.5	0.00700000000000000015
61198	2N2	122.099999999999994	0.00300000000000000006
61198	OO1	235.800000000000011	0.0160000000000000003
61198	LDA2	197.599999999999994	0.00700000000000000015
61198	S1	184.5	0.0589999999999999969
61198	M1	228.900000000000006	0.0129999999999999994
61198	J1	249.599999999999994	0.0160000000000000003
61198	SSA	42.6000000000000014	0.0519999999999999976
61198	SA	184.199999999999989	0.203000000000000014
61198	RHO1	239.599999999999994	0.00700000000000000015
61198	Q1	217.099999999999994	0.0330000000000000016
61198	R2	87.9000000000000057	0.0919999999999999984
61198	2Q1	245	0.00300000000000000006
61198	P1	250.400000000000006	0.0660000000000000031
61198	2SM2	112.400000000000006	0.00300000000000000006
61198	M3	46.5	0.00300000000000000006
61198	L2	227.199999999999989	0.0129999999999999994
61198	K2	124.099999999999994	0.0429999999999999966
61199	M2	3.29999999999999982	0.570999999999999952
61199	S2	39.2000000000000028	0.0889999999999999958
61199	N2	337.5	0.128000000000000003
61199	K1	209.300000000000011	0.322000000000000008
61199	M4	97.7999999999999972	0.00300000000000000006
61199	O1	211.199999999999989	0.256000000000000005
61199	M6	0.5	0.00300000000000000006
61199	MK3	77.7999999999999972	0.0100000000000000002
61199	MN4	73.2000000000000028	0.00300000000000000006
61199	NU2	341.800000000000011	0.0259999999999999988
61199	MU2	356.5	0.0160000000000000003
61199	2N2	318.899999999999977	0.0160000000000000003
61199	OO1	215.300000000000011	0.0129999999999999994
61199	LDA2	41.5	0.00300000000000000006
61199	S1	230.300000000000011	0.0160000000000000003
61199	M1	233.099999999999994	0.0129999999999999994
61199	J1	212.699999999999989	0.0200000000000000004
61199	MM	319.399999999999977	0.0229999999999999996
61199	SA	187.699999999999989	0.164000000000000007
61199	MF	350.5	0.0519999999999999976
61199	RHO1	200	0.00700000000000000015
61199	Q1	199.400000000000006	0.0490000000000000019
61199	T2	24.1999999999999993	0.0100000000000000002
61199	R2	182.699999999999989	0.00300000000000000006
61199	2Q1	173.099999999999994	0.00300000000000000006
61199	P1	208.800000000000011	0.0950000000000000011
61199	2SM2	46.5	0.00300000000000000006
61199	M3	346.199999999999989	0.00300000000000000006
61199	L2	10.3000000000000007	0.0160000000000000003
61199	2MK3	80.0999999999999943	0.00300000000000000006
61199	K2	42	0.0259999999999999988
61200	M2	39.1000000000000014	0.0259999999999999988
61200	S2	7.09999999999999964	0.0259999999999999988
61200	N2	102.900000000000006	0.0160000000000000003
61200	K1	233.800000000000011	0.269000000000000017
61200	M4	312.199999999999989	0.0100000000000000002
61200	O1	232.800000000000011	0.171000000000000013
61200	S4	81.5	0.00300000000000000006
61200	MN4	209.199999999999989	0.00700000000000000015
61200	NU2	137.099999999999994	0.00300000000000000006
61200	S6	72.5999999999999943	0.00300000000000000006
61200	MU2	205.599999999999994	0.00700000000000000015
61200	2N2	123.900000000000006	0.00700000000000000015
61200	OO1	241.099999999999994	0.0160000000000000003
61200	LDA2	94	0.00300000000000000006
61200	S1	133.5	0.0200000000000000004
61200	M1	250.5	0.0129999999999999994
61200	J1	232.699999999999989	0.0200000000000000004
61200	MM	344.199999999999989	0.0229999999999999996
61200	SSA	42.6000000000000014	0.0519999999999999976
61200	SA	184.199999999999989	0.203000000000000014
61200	MF	353	0.0490000000000000019
61200	RHO1	250	0.00700000000000000015
61200	Q1	224.400000000000006	0.0330000000000000016
61200	T2	50	0.00700000000000000015
61200	R2	104	0.00700000000000000015
61200	2Q1	257.600000000000023	0.00300000000000000006
61200	P1	240.300000000000011	0.0790000000000000008
61200	M3	59.1000000000000014	0.00300000000000000006
61200	L2	276.699999999999989	0.00700000000000000015
61200	2MK3	331.399999999999977	0.00300000000000000006
61200	K2	40.3999999999999986	0.0160000000000000003
61200	MS4	75.2000000000000028	0.00300000000000000006
61201	M2	9.90000000000000036	0.0229999999999999996
61201	S2	9.80000000000000071	0.0330000000000000016
61201	N2	90.2000000000000028	0.00300000000000000006
61201	K1	233.400000000000006	0.262000000000000011
61201	M4	295.199999999999989	0.00700000000000000015
61201	O1	227.800000000000011	0.176999999999999991
61201	MK3	176.800000000000011	0.00300000000000000006
61201	MN4	184.599999999999994	0.00300000000000000006
61201	NU2	14.5999999999999996	0.00300000000000000006
61201	OO1	251.199999999999989	0.0129999999999999994
61201	S1	203.699999999999989	0.0160000000000000003
61201	M1	280.100000000000023	0.0100000000000000002
61201	J1	233	0.0160000000000000003
61201	MM	341.300000000000011	0.0229999999999999996
61201	SA	179.900000000000006	0.179999999999999993
61201	MF	357.399999999999977	0.0490000000000000019
61201	RHO1	204	0.00700000000000000015
61201	Q1	215.300000000000011	0.0299999999999999989
61201	T2	358.899999999999977	0.00300000000000000006
61201	R2	247.699999999999989	0.00300000000000000006
61201	2Q1	200.900000000000006	0.00300000000000000006
61201	P1	233.599999999999994	0.0790000000000000008
61201	2SM2	341.399999999999977	0.00300000000000000006
61201	M3	48.1000000000000014	0.00300000000000000006
61201	L2	340.199999999999989	0.00700000000000000015
61201	2MK3	174.400000000000006	0.00300000000000000006
61201	K2	2.79999999999999982	0.00700000000000000015
61201	MS4	13.3000000000000007	0.00300000000000000006
61202	M2	7.29999999999999982	0.197000000000000008
61202	S2	332.100000000000023	0.0100000000000000002
61202	N2	3.20000000000000018	0.0429999999999999966
61202	K1	231.5	0.197000000000000008
61202	M4	276.399999999999977	0.0160000000000000003
61202	O1	224.900000000000006	0.164000000000000007
61202	M6	351.899999999999977	0.00700000000000000015
61202	MN4	229.599999999999994	0.00700000000000000015
61202	MU2	110.299999999999997	0.0100000000000000002
61202	OO1	237.300000000000011	0.0129999999999999994
61202	LDA2	230	0.0100000000000000002
61202	S1	192.099999999999994	0.0490000000000000019
61202	M1	212.099999999999994	0.0100000000000000002
61202	J1	231.699999999999989	0.0160000000000000003
61202	SSA	42.6000000000000014	0.0519999999999999976
61202	SA	184.199999999999989	0.203000000000000014
61202	RHO1	189.699999999999989	0.00700000000000000015
61202	Q1	199.199999999999989	0.0259999999999999988
61202	T2	241.300000000000011	0.0160000000000000003
61202	R2	38.1000000000000014	0.0429999999999999966
61202	P1	239.900000000000006	0.0619999999999999996
61202	2SM2	85	0.00300000000000000006
61202	M3	93.9000000000000057	0.00700000000000000015
61202	L2	145.199999999999989	0.00700000000000000015
61202	2MK3	77.9000000000000057	0.00300000000000000006
61202	K2	51.3999999999999986	0.0299999999999999989
61202	MS4	345.800000000000011	0.00700000000000000015
61203	M2	55	0.0330000000000000016
61203	S2	311.100000000000023	0.0619999999999999996
61203	N2	50.6000000000000014	0.0259999999999999988
61203	K1	231.800000000000011	0.220000000000000001
61203	M4	304.300000000000011	0.0100000000000000002
61203	O1	226.800000000000011	0.176999999999999991
61203	M6	62.6000000000000014	0.00300000000000000006
61203	MK3	282.600000000000023	0.00300000000000000006
61203	S4	182.900000000000006	0.00300000000000000006
61203	MN4	248.699999999999989	0.00300000000000000006
61203	NU2	185.699999999999989	0.0100000000000000002
61203	MU2	98.2999999999999972	0.0160000000000000003
61203	OO1	241.900000000000006	0.0129999999999999994
61203	LDA2	201.5	0.0160000000000000003
61203	S1	205.300000000000011	0.0589999999999999969
61203	M1	221.599999999999994	0.0129999999999999994
61203	J1	223.199999999999989	0.0160000000000000003
61203	SSA	42.6000000000000014	0.0519999999999999976
61203	SA	184.199999999999989	0.203000000000000014
61203	RHO1	207.599999999999994	0.0100000000000000002
61203	Q1	206.099999999999994	0.0299999999999999989
61203	T2	280.699999999999989	0.0389999999999999999
61203	R2	98.2999999999999972	0.0299999999999999989
61203	P1	242.199999999999989	0.0560000000000000012
61203	M3	84.5	0.00700000000000000015
61203	L2	143.900000000000006	0.0200000000000000004
61203	K2	19	0.0129999999999999994
61203	MS4	353.800000000000011	0.00300000000000000006
61204	M2	14.5	0.475999999999999979
61204	S2	41	0.0719999999999999946
61204	N2	350.699999999999989	0.115000000000000005
61204	K1	213.800000000000011	0.194000000000000006
61204	M4	321.300000000000011	0.0100000000000000002
61204	O1	210.800000000000011	0.153999999999999998
61204	M6	225.099999999999994	0.00300000000000000006
61204	MK3	331.899999999999977	0.00700000000000000015
61204	S4	256.699999999999989	0.00300000000000000006
61204	MN4	293.300000000000011	0.00300000000000000006
61204	NU2	350.300000000000011	0.0229999999999999996
61204	MU2	11.4000000000000004	0.0129999999999999994
61204	2N2	334.899999999999977	0.0200000000000000004
61204	OO1	223	0.0100000000000000002
61204	LDA2	35.5	0.00700000000000000015
61204	S1	209.599999999999994	0.0200000000000000004
61204	M1	219	0.0100000000000000002
61204	J1	218.199999999999989	0.0160000000000000003
61204	MM	317	0.0330000000000000016
61204	SSA	99.7999999999999972	0.0229999999999999996
61204	SA	187.699999999999989	0.161000000000000004
61204	MSF	351.199999999999989	0.0129999999999999994
61204	MF	356.699999999999989	0.0490000000000000019
61204	RHO1	200.099999999999994	0.00700000000000000015
61204	Q1	194.300000000000011	0.0299999999999999989
61204	T2	17.6999999999999993	0.0100000000000000002
61204	2Q1	173.800000000000011	0.00300000000000000006
61204	P1	217.599999999999994	0.0589999999999999969
61204	2SM2	39.5	0.00300000000000000006
61204	M3	345.699999999999989	0.00300000000000000006
61204	L2	46.7000000000000028	0.0160000000000000003
61204	2MK3	351.800000000000011	0.00700000000000000015
61204	K2	39.5	0.0200000000000000004
61204	MS4	33	0.00300000000000000006
61205	M2	0.599999999999999978	0.478999999999999981
61205	S2	29.8999999999999986	0.0950000000000000011
61205	N2	340.100000000000023	0.115000000000000005
61205	K1	208.5	0.23899999999999999
61205	M4	278	0.0100000000000000002
61205	O1	205.400000000000006	0.194000000000000006
61205	M6	358.5	0.00700000000000000015
61205	MK3	10.8000000000000007	0.00300000000000000006
61205	S4	54.7999999999999972	0.00300000000000000006
61205	MN4	242	0.00300000000000000006
61205	NU2	334.100000000000023	0.0200000000000000004
61205	MU2	349.600000000000023	0.0160000000000000003
61205	2N2	323.5	0.0160000000000000003
61205	OO1	221.5	0.0100000000000000002
61205	LDA2	6.79999999999999982	0.00700000000000000015
61205	S1	317.899999999999977	0.00700000000000000015
61205	M1	220.800000000000011	0.0100000000000000002
61205	J1	217.599999999999994	0.0129999999999999994
61205	MM	330.300000000000011	0.0229999999999999996
61205	SA	180	0.276000000000000023
61205	MF	355.399999999999977	0.0459999999999999992
61205	RHO1	206.199999999999989	0.00700000000000000015
61205	Q1	193.300000000000011	0.0359999999999999973
61205	T2	12.1999999999999993	0.0100000000000000002
61205	R2	13.5999999999999996	0.00300000000000000006
61205	2Q1	186	0.00300000000000000006
61205	P1	211	0.0719999999999999946
61205	2SM2	11.3000000000000007	0.00300000000000000006
61205	M3	353.199999999999989	0.00300000000000000006
61205	L2	20.8000000000000007	0.0160000000000000003
61205	2MK3	34	0.00300000000000000006
61205	K2	26.3999999999999986	0.0229999999999999996
61205	MS4	16.6999999999999993	0.00300000000000000006
61206	M2	5.59999999999999964	0.347999999999999976
61206	S2	34.7999999999999972	0.0619999999999999996
61206	N2	341.899999999999977	0.0719999999999999946
61206	K1	220.5	0.194000000000000006
61206	M4	315.699999999999989	0.0229999999999999996
61206	O1	218.5	0.157000000000000001
61206	M6	321.399999999999977	0.00700000000000000015
61206	S4	197.400000000000006	0.00300000000000000006
61206	NU2	345.100000000000023	0.0129999999999999994
61206	MU2	201.900000000000006	0.0100000000000000002
61206	2N2	318	0.0100000000000000002
61206	OO1	222.300000000000011	0.00700000000000000015
61206	M1	219.5	0.0100000000000000002
61206	J1	221.300000000000011	0.0129999999999999994
61206	SSA	42.6000000000000014	0.0519999999999999976
61206	SA	184.199999999999989	0.203000000000000014
61206	RHO1	217.699999999999989	0.00700000000000000015
61206	Q1	217.599999999999994	0.0299999999999999989
61206	T2	33.7999999999999972	0.00300000000000000006
61206	2Q1	216.699999999999989	0.00300000000000000006
61206	P1	220.400000000000006	0.0660000000000000031
61206	L2	29.3999999999999986	0.0100000000000000002
61206	K2	37.2000000000000028	0.0160000000000000003
61207	M2	7.59999999999999964	0.0749999999999999972
61207	S2	17.1999999999999993	0.0429999999999999966
61207	N2	27.1000000000000014	0.0129999999999999994
61207	K1	233.099999999999994	0.27200000000000002
61207	M4	0.599999999999999978	0.0359999999999999973
61207	O1	231.5	0.203000000000000014
61207	M6	123.799999999999997	0.00300000000000000006
61207	MK3	355.600000000000023	0.0100000000000000002
61207	S4	133.900000000000006	0.00300000000000000006
61207	MN4	322.600000000000023	0.0129999999999999994
61207	NU2	115.700000000000003	0.00300000000000000006
61207	MU2	21.6000000000000014	0.00300000000000000006
61207	2N2	59.7000000000000028	0.00300000000000000006
61207	OO1	235	0.0129999999999999994
61207	S1	204.599999999999994	0.0100000000000000002
61207	M1	264.899999999999977	0.0129999999999999994
61207	J1	229.199999999999989	0.0160000000000000003
61207	MM	348	0.0160000000000000003
61207	SA	180.900000000000006	0.143999999999999989
61207	MF	359.300000000000011	0.0660000000000000031
61207	RHO1	226	0.00700000000000000015
61207	Q1	219.900000000000006	0.0359999999999999973
61207	T2	0.100000000000000006	0.00300000000000000006
61207	R2	9.5	0.00300000000000000006
61207	2Q1	221.400000000000006	0.00300000000000000006
61207	P1	232.5	0.0820000000000000034
61207	M3	54.3999999999999986	0.00300000000000000006
61207	L2	355.399999999999977	0.00300000000000000006
61207	2MK3	11.3000000000000007	0.0100000000000000002
61207	K2	12.9000000000000004	0.0100000000000000002
61207	MS4	54.5	0.00700000000000000015
\.



COPY public.constituents (name, definition, speed) FROM stdin;
J1	Basic 1 1 1 -1 0 -90    0 -1 0 0 0 0     76	15.5854432999999997
K1	Compound 0 1 0 0 0 0 0 0	15.0410685999999991
K2	Compound 0 0 0 0 0 0 0 1	30.0821372999999994
L2	Compound 0 0 0 0 0 0 1 0	29.5284788999999996
M1	Basic 1 -1 1 0 0 -90    1 -1 0 0 1 0     206	14.4966939000000004
M2	Compound 0 0 0 1 0 0 0 0	28.9841042000000009
M3	Basic 3 -3 3 0 0 0      3 -3 0 0 0 0     149	43.4761562999999995
M4	Compound 0 0 0 2 0 0 0 0	57.9682084000000017
M6	Compound 0 0 0 3 0 0 0 0	86.9523125999999991
M8	Compound 0 0 0 4 0 0 0 0	115.936416899999998
N2	Compound 0 0 0 0 0 1 0 0	28.4397294999999986
2N2	Basic 2 -4 2 2 0 0      2 -2 0 0 0 0     78	27.8953547999999998
O1	Compound 1 0 0 0 0 0 0 0	13.9430356
OO1	Basic 1 2 1 0 0 -90     -2 -1 0 0 0 0    77	16.1391017000000012
P1	Compound 0 0 1 0 0 0 0 0	14.9589314000000009
Q1	Compound 0 0 0 0 0 0 0 0 1	13.3986608999999994
2Q1	Basic 1 -4 1 2 0 90     2 -1 0 0 0 0     75	12.8542862000000007
R2	Basic 2 0 1 0 -1 180    0 0 0 0 0 0      1	30.0410666999999982
S1	Basic 1 0 0 0 0 0       0 0 0 0 0 0      1	15
S2	Compound 0 0 0 0 1 0 0 0	30
S4	Compound 0 0 0 0 2 0 0 0	60
S6	Compound 0 0 0 0 3 0 0 0	90
T2	Basic 2 0 -1 0 1 0      0 0 0 0 0 0      1	29.9589333000000018
LDA2	Basic 2 -1 0 1 0 180    2 -2 0 0 0 0     78	29.4556253000000012
MU2	Basic 2 -4 4 0 0 0      2 -2 0 0 0 0     78	27.9682084000000017
NU2	Basic 2 -3 4 -1 0 0     2 -2 0 0 0 0     78	28.5125831000000005
RHO1	Basic 1 -3 3 -1 0 90    2 -1 0 0 0 0     75	13.4715144999999996
MK3	Compound 0 1 0 1 0 0 0 0	44.0251729000000012
2MK3	Compound 0 -1 0 2 0 0 0 0	42.9271397999999991
MN4	Compound 0 0 0 1 0 1 0 0	57.423833700000003
MS4	Compound 0 0 0 1 1 0 0 0	58.9841041999999973
2SM2	Compound 0 0 0 -1 2 0 0 0	31.0158957999999991
MF	Basic 0 2 0 0 0 0       -2 0 0 0 0 0     74	1.0980331000000001
MSF	Compound 0 0 0 -1 1 0 0 0	1.01589580000000002
MM	Basic 0 1 0 -1 0 0      0 0 0 0 0 0      73	0.544374699999999989
SA	Basic 0 0 1 0 0 0       0 0 0 0 0 0      1	0.0410685999999999968
SSA	Basic 0 0 2 0 0 0       0 0 0 0 0 0      1	0.0821372999999999964
SA-IOS	Doodson 0 0 1 0 -1 0    0	0.0410666999999999977
MF-IOS	Doodson 0 2 0 0  0 0    0	1.0980331000000001
S1-IOS	Doodson 1 0 0 0 1 -90   2\n  0  0 -2 .0  0.3534     0  1  0 .50 0.0264	15.0000020000000003
OO1-IOS	Doodson 1  2  1  0  0 -90    8\n  -2 -1  0 .50 0.0037    -2  0  0 .0  0.1496    -2  1  0 .0  0.0296\n  -1  0  0 .25 0.0240R1  -1  1  0 .25 0.0099R1   0  1  0 .0  0.6398\n  0  2  0 .0  0.1342     0  3  0 .0  0.0086	16.1391017000000012
R2-IOS	Doodson 2 0 1 0 -1 180    2\n  0  0  2 .50 0.2535     0  1  2 .0  0.0141	30.0410666999999982
A7	Basic 0 3 0 -1 0 0      -2 0 0 0 0 0     74	1.64240779999999997
2MK5	Compound 0  1  0  2  0  0  0  0	73.0092771000000056
2MK6	Compound 0  0  0  2  0  0  0  1	88.0503456999999941
2MN2	Compound 0  0  0  2  0 -1  0  0	29.5284788999999996
2MN6	Compound 0  0  0  2  0  1  0  0	86.4079378999999932
2MS6	Compound 0  0  0  2  1  0  0  0	87.9682083999999946
2NM6	Compound 0  0  0  1  0  2  0  0	85.8635632000000015
2SK5	Compound 0  1  0  0  2  0  0  0	75.0410686000000027
2SM6	Compound 0  0  0  1  2  0  0  0	88.9841042000000044
3MK7	Compound 0  1  0  3  0  0  0  0	101.993381299999996
3MN8	Compound 0  0  0  3  0  1  0  0	115.392042200000006
3MS2	Compound 0  0  0  3 -2  0  0  0	26.9523125999999991
3MS4	Compound 0  0  0  3 -1  0  0  0	56.9523125999999991
3MS8	Compound 0  0  0  3  1  0  0  0	116.952312599999999
ALP1	Doodson 1 -5 3 1 0 90     2\n  -1  0  0 .75 0.0360R1   0 -1  0 .00 0.1906	12.3827651000000003
BET1	Doodson 1 -1 -1 1 0 -90   1\n  0 -1  0 .00 0.2266	14.4145567000000003
CHI1	Basic 1 -1 3 -1 0 -90   0 -1 0 0 0 0     76	14.5695475999999999
H1	Doodson 2 -2 1 0 1 180    2\n  0 -1  0 .50 0.0224     1  0 -1 .50 0.0447	28.9430374999999991
H2	Doodson 2 -2 3 0 -1 0     1\n  0 -1  0 .50 0.0217	29.0251708999999991
KJ2	Basic 2 1 2 -1 0 0      0 -2 0 0 0 0     79	30.6265120000000017
ETA2	Doodson 2 1 2 -1 0 0      7\n  0 -1  0 .50 0.0187     0  1  0 .0  0.4355     0  2  0 .0  0.0467\n  1  0  0 .75 0.0747R2   1  1  0 .75 0.0482R2   1  2  0 .75 0.0093R2\n  2  0  0 .50 0.0078	30.6265120000000017
KQ1	Basic 1 3 1 -1 0 -90    -2 -1 0 0 0 0    77	16.6834764
UPS1	Doodson 1 3 1 -1 0 -90    5\n  -2  0  0 .00 0.0611     0  1  0 .00 0.6399     0  2  0 .00 0.1318\n  1  0  0 .25 0.0289R1   1  1  0 .25 0.0257R1	16.6834764
M10	Compound 0 0 0 5 0 0 0 0	144.920521100000002
M12	Compound 0 0 0 6 0 0 0 0	173.904625299999992
MK4	Compound 0  0  0  1  0  0  0  1	59.0662414999999967
MKS2	Compound 0  0  0  1 -1  0  0  1	29.0662415000000003
MNS2	Compound 0  0  0  1 -1  1  0  0	27.4238336999999994
EPS2	Doodson 2 -5 4 1 0 0   3\n  -1 -1  0 .25 0.0075R2  -1  0  0 .25 0.0402R2   0 -1  0 .50 0.0373	27.4238336999999994
MO3	Compound 1 0 0 1 0 0 0 0	42.9271397999999991
MP1	Basic 1 -2 3 0 0 -90    0 -1 0 0 0 0     76	14.0251728999999994
TAU1	Doodson 1 -2 3 0 0 -90    5\n  -2  0  0 .0  0.0446    -1  0  0 .25 0.0426R1   0 -1  0 .50 0.0284\n  0  1  0 .50 0.2170     0  2  0 .50 0.0142	14.0251728999999994
MPS2	Compound 0 0 1 1 0 0 0 0 0 0 -1	28.9430356000000018
MSK6	Compound 0  0  0  1  1  0  0  1	89.0662415000000038
MSM	Basic 0 1 -2 1 0 0      0 0 0 0 0 0      73	0.471521100000000026
MSN2	Compound 0  0  0  1  1 -1  0  0	30.5443746999999988
MSN6	Compound 0  0  0  1  1  1  0  0	87.423833700000003
NLK2	Compound 0 0 0 0 0 1 1 -1	27.8860710999999988
NO1	Compound -1 0 0 0 0 1 0 0	14.4966939000000004
OP2	Compound 1  0  1  0  0  0  0  0	28.9019669000000015
OQ2	Doodson 2 -5 2 3 0 0   2\n  -1  0  0 .25 0.1042R2   0 -1  0 .50 0.0386	27.350980100000001
PHI1	Basic 1 0 3 0 0 -90     0 0 0 0 0 0      1	15.1232059000000003
KP1	Compound 0 0 -1 0 0 0 0 1	15.1232059000000003
PI1	Basic 1 0 -2 0 1 90     0 0 0 0 0 0      1	14.9178647000000009
TK1	Basic 1 0 -2 0 1 90     0 0 1 0 0 0      227	14.9178647000000009
PSI1	Basic 1 0 2 0 -1 -90    0 0 0 0 0 0      1	15.0821352999999991
RP1	Basic 1 0 2 0 -1 90     0 0 0 0 0 0      1	15.0821352999999991
S3	Basic 3 0 0 0 0 0       0 0 0 0 0 0      1	45
SIG1	Basic 1 -4 3 0 0 90     2 -1 0 0 0 0     75	12.9271398000000008
SK3	Compound 0  1  0  0  1  0  0  0	45.0410686000000027
SK4	Compound 0 0 0 0 1 0 0 1	60.0821372999999994
SN4	Compound 0  0  0  0  1  1  0  0	58.4397294999999986
SNK6	Compound 0 0 0 0 1 1 0 1	88.521866799999998
SO1	Basic 1 2 -1 0 0 -90    0 -1 0 0 0 0     76	16.0569643999999982
SO3	Compound 1  0  0  0  1  0  0  0	43.9430356000000018
THE1	Basic 1 1 -1 1 0 -90    0 -1 0 0 0 0     76	15.5125896999999995
2PO1	Compound -1  0  2  0  0  0  0  0	15.9748271000000006
2NS2	Compound 0  0  0  0 -1  2  0  0	26.8794590000000007
MLN2S2	Compound 0  0  0  1 -2  1  1  0	26.9523125999999991
2ML2S2	Compound 0  0  0  2 -2  0  1  0	27.4966873000000014
SKM2	Compound 0  0  0 -1  1  0  0  1	31.0980330999999985
2MS2K2	Compound 0  0  0  2  1  0  0 -2	27.8039339000000005
MKL2S2	Compound 0  0  0  1 -2  0  1  1	28.5947203999999999
M2(KS)2	Compound 0  0  0  1 -2  0  0  2	29.1483787999999997
2SN(MK)2	Compound 0  0  0 -1  2  1  0 -1	29.3734879999999983
2KM(SN)2	Compound 0  0  0  1 -1 -1  0  2	30.7086493000000011
NO3	Compound 1  0  0  0  0  1  0  0	42.3827651000000003
2MLS4	Compound 0  0  0  2 -1  0  1  0	57.4966872999999978
ML4	Compound 0  0  0  1  0  0  1  0	58.5125831000000005
N4	Compound 0  0  0  0  0  2  0  0	56.8794589999999971
SL4	Compound 0  0  0  0  1  0  1  0	59.5284789000000032
MNO5	Compound 1  0  0  1  0  1  0  0	71.3668693000000047
2MO5	Compound 1  0  0  2  0  0  0  0	71.9112439999999964
MSK5	Compound 0  1  0  1  1  0  0  0	74.0251729000000012
2MP5	Compound 0  0  1  2  0  0  0  0	72.9271398000000062
3MP5	Compound 0  0 -1  3  0  0  0  0	71.9933812999999958
MNK5	Compound 0  1  0  1  0  1  0  0	72.4649023999999997
2NMLS6	Compound 0  0  0  1 -1  2  1  0	85.3920422000000059
MSL6	Compound 0  0  0  1  1  0  1  0	88.5125831000000005
2ML6	Compound 0  0  0  2  0  0  1  0	87.4966873000000049
2MNLS6	Compound 0  0  0  2 -1  1  1  0	85.9364168999999976
3MLS6	Compound 0  0  0  3 -1  0  1  0	86.4807916000000034
2MNO7	Compound 1  0  0  2  0  1  0  0	100.350973499999995
2NMK7	Compound 0  1  0  1  0  2  0  0	100.904631899999998
2MSO7	Compound 1  0  0  2  1  0  0  0	101.911243999999996
MSKO7	Compound 1  0  0  1  1  0  0  1	103.009277100000006
2MSN8	Compound 0  0  0  2  1  1  0  0	116.407937899999993
2(MS)8	Compound 0  0  0  2  2  0  0  0	117.968208399999995
2(MN)8	Compound 0  0  0  2  0  2  0  0	114.8476675
2MSL8	Compound 0  0  0  2  1  0  1  0	117.496687300000005
4MLS8	Compound 0  0  0  4 -1  0  1  0	115.464895799999994
3ML8	Compound 0  0  0  3  0  0  1  0	116.480791600000003
3MK8	Compound 0  0  0  3  0  0  0  1	117.034449899999998
2MSK8	Compound 0  0  0  2  1  0  0  1	118.050345699999994
2M2NK9	Compound 0  1  0  2  0  2  0  0	129.888736099999988
3MNK9	Compound 0  1  0  3  0  1  0  0	130.433110800000009
4MK9	Compound 0  1  0  4  0  0  0  0	130.9774855
3MSK9	Compound 0  1  0  3  1  0  0  0	131.99338130000001
4MN10	Compound 0  0  0  4  0  1  0  0	144.37614640000001
3MNS10	Compound 0  0  0  3  1  1  0  0	145.392042199999992
4MS10	Compound 0  0  0  4  1  0  0  0	145.936416900000012
3MSL10	Compound 0  0  0  3  1  0  1  0	146.480791600000003
3M2S10	Compound 0  0  0  3  2  0  0  0	146.952312599999999
4MSK11	Compound 0  1  0  4  1  0  0  0	160.9774855
4MNS12	Compound 0  0  0  4  1  1  0  0	174.37614640000001
5MS12	Compound 0  0  0  5  1  0  0  0	174.920521100000002
4MSL12	Compound 0  0  0  4  1  0  1  0	175.464895799999994
4M2S12	Compound 0  0  0  4  2  0  0  0	175.936416900000012
M1C	Basic 1 -1 1 0 0 0   1 -1 0 0 0 0   144	14.4920521000000004
3MKS2	Compound 0 0 0 3 -1 0 0 -1	26.8701754000000008
OQ2-HORN	Compound 1 0 0 0 0 0 0 0 1	27.3416965000000012
MSK2	Compound 0 0 0 1 1 0 0 -1	28.9019669000000015
MSP2	Compound 0 0 -1 1 0 0 0 0 0 0 1	29.0251729000000012
2MP3	Compound 0 0 -1 2 0 0 0 0	43.0092770999999985
4MS4	Compound 0 0 0 4 -2 0 0 0	55.9364168999999976
2MNS4	Compound 0 0 0 2 -1 1 0 0	56.4079379000000003
2MSK4	Compound 0 0 0 2 1 0 0 -1	57.8860711000000023
3MN4	Compound 0 0 0 3 0 -1 0 0	58.5125831000000005
2MSN4	Compound 0 0 0 2 1 -1 0 0	59.5284789000000032
3MK5	Compound 0 -1 0 3 0 0 0 0	71.9112439999999964
3MO5	Compound -1 0 0 3 0 0 0 0	73.0092771000000056
3MNS6	Compound 0 0 0 3 -1 1 0 0	85.3920422000000059
4MS6	Compound 0 0 0 4 -1 0 0 0	85.9364168999999976
2MNU6	Compound 0 0 0 2 0 0 0 0 0 1	86.4807916000000034
3MSK6	Compound 0 0 0 3 1 0 0 -1	86.8701753999999937
MKNU6	Compound 0 0 0 1 0 0 0 1 0 1	87.5788246000000044
3MSN6	Compound 0 0 0 3 1 -1 0 0	88.5125831000000005
M7	Compound 0 0 0 3 0 0 0 0 0 0 0 1	101.449006600000004
2MNK8	Compound 0 0 0 2 0 1 0 1	116.490075200000007
2(MS)N10	Compound 0 0 0 2 2 1 0 0	146.407937900000007
MNUS2	Compound 0 0 0 1 -1 0 0 0 0 1	27.4966873000000014
2MK2	Compound 0 0 0 2 0 0 0 -1	27.8860710999999988
3KM5	Compound 0  1  0  1  0  0  0  1	74.1073101000000065
KJ2-IHO	Basic  2 1 2 -1 0 180    0 -2 0 0 0 0   79	30.6265120000000017
\.



COPY public.data_sets (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
16159	San Diego Bay Entrance, California Current	NOS	PCT0031_1	32.6816669999999974	-117.230000000000004	:America/Los_Angeles	USA	knots	175	355	\N	\N	1      San Diego Bay Entr., California     T.M. 120 W.\n-00090 1 3 1 0 0 0 355 175	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.0899999999999999967	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entr., California     T.M. 120 W.	CA
16144	Baltimore Harbor Approach (off Sandy Point), Maryland Current	NOS	ACT4996_1	39.0129999999999981	-76.3683330000000069	:America/New_York	USA	knots	190	25	\N	\N	1      Baltimore Harbor, Maryland    T.M. 75 W.\n000000 1 3 1 0 0 0 025 190	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor, Maryland    T.M. 75 W.	MD
16149	Deception Pass (narrows), Washington Current	NOS	PCT1956_1	48.4061670000000035	-122.643000000000001	:America/Los_Angeles	USA	knots^2	270	90	\N	\N	1      Deception Pass, Washington    T.M. 120 W.\n-00650 1 3 1 1 0 0 090 270	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.650000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass, Washington    T.M. 120 W.	WA
16145	Bergen Point Reach (Bayonne Bridge), Kill van Kull, New York Current (16d)	NOS	ACT3951_1	40.6416669999999982	-74.1433329999999984	:America/New_York	USA	knots	76	259	\N	\N	1      Bayonne Bridge, Kill van Kull, New York      T.M. 75 W\n000000 1 3 1 0 0 0 259 076	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge, Kill van Kull, New York      T.M. 75 W	NY
16162	Savannah River Entrance (between jetties), Georgia Current (11d)	NOS	ACT7351_1	32.0356669999999966	-80.8903329999999983	:America/New_York	USA	knots	110	286	\N	\N	1      Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->\n000000 1 3 1 0 0 0 286 110 0 0 0   0   0   0	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->	GA
16157	Pollock Rip Channel (Butler Hole), Massachusetts Current	NOS	ACT1616_1	41.5499999999999972	-69.9833330000000018	:America/New_York	USA	knots	225	35	\N	\N	1      Pollock Rip Channel, Massachusetts    T.M. 75 W.\n  0150 1 3 1 0 0 0 035 225	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.149999999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel, Massachusetts    T.M. 75 W.	MA
16151	Hell Gate (off Mill Rock), New York Current	NOS	ACT3401_1	40.7783330000000035	-73.9383330000000001	:America/New_York	USA	knots^2	230	50	\N	\N	1      Hell Gate, New York     T.M. 75 W.\n-00600 1 3 1 1 0 0 050 230	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.599999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate, New York     T.M. 75 W.	NY
16148	Charleston Harbor (off Fort Sumter), South Carolina Current	NOS	ACT6651_1	32.7560000000000002	-79.8703330000000022	:America/New_York	USA	knots	127	313	\N	\N	1      Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **\n  -217 1 3 1 0 0 0 313 127 0                       Used 1997 ->	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.216999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **	SC
16146	Bolivar Roads, Texas Current (14d)	NOS	ACT8856_2	29.3433330000000012	-94.7813330000000036	:America/Chicago	USA	knots	123	296	\N	\N	1      Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->\n-00135 1 3 1 0 0 0 306 116\nHarmonized directions with 2009 predictions	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	-0.135000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->	TX
16143	Aransas Pass, Texas Current (35d)	NOS	ACT8896_2	27.8338329999999985	-97.0441670000000016	:America/Chicago	USA	knots	120	300	\N	\N	1      Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **\n+00032 1 3 1 0 0 0 300 120                    major axis only	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	0.0320000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **	TX
16150	Grays Harbor Entrance, Washington Current	NOS	PCT1291_1	46.9224999999999994	-124.132999999999996	:America/Los_Angeles	USA	knots	240	60	\N	\N	1      Grays Harbor Entrance, Washington    T.M. 120 W.\n-00300 1 3 1 0 0 0 060 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance, Washington    T.M. 120 W.	WA
16171	Vieques Passage, Puerto Rico Current	NOS	ACT8926_1	18.1883330000000001	-65.6183330000000069	:America/Puerto_Rico	USA	knots	55	250	\N	\N	1      Vieques Passage, Puerto Rico     T.M. 60 W.\n-00030 1 3 1 0 0 0 250 055	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-04:00:00	\N	-0.0299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage, Puerto Rico     T.M. 60 W.	PR
16163	St. Johns River Entrance (between jetties), Florida Current (16d)	NOS	SJR9801_8	30.4003329999999998	-81.3858330000000052	:America/New_York	USA	knots	82	262	\N	\N	1      St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->\n-00128 1 3 1 0 0 0 262 082	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.128000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->	FL
25446	Wrangell Narrows (off Petersburg), Alaska Current (6d)	NOS	SEA0103_8	56.8162999999999982	-132.963999999999999	:America/Anchorage	USA	knots	62	246	\N	\N	1      Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W\n   290 1 3 1 0 0 0 246 062         Used 2004 ->	NOS data via Mitch Cline and Dean Pentcheff, 2011-02-07	Public domain	2011-04-07	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.28999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W	AK
16165	Tampa Bay Entrance (Egmont Channel), Florida Current (15d)	NOS	ACT8411_1	27.6043330000000005	-82.7603330000000028	:America/New_York	USA	knots	297	118	\N	\N	1       Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.\n000037 1 3 1 0 0 0 118 297             major axis only, k'	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.0369999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	 Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.	FL
16154	Kvichak Bay (off Naknek River entrance), Alaska Current	NOS	PCT5776_1	58.7000000000000028	-157.25	:America/Anchorage	USA	knots	240	55	\N	\N	1      Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W\n-00300 1 3 1 0 0 0 055 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	-0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W	AK
60157	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.1284444444444475	-67.1446666666666658	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
16152	Isanotski Strait (False Pass Cannery), Alaska Current	NOS	PCT5446_1	54.8666669999999996	-163.400000000000006	:America/Anchorage	USA	knots^2	185	0	\N	\N	1      Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W\n000400 1 3 1 1 0 0 000 185	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.400000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W	AK
60135	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033000000000015	-159.592000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000515	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
60136	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9543999999999997	-159.356099999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
60137	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.3066944444444495	-157.86699999999999	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
60138	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.3299999999999983	-157.967000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
60139	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683000000000014	-157.939999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000000089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
60140	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.4330555555555584	-157.789999999999992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
60141	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.0850000000000009	-157.032000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
60142	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.8949999999999996	-156.476694444444405	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.11999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
60143	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.829399999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.919999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
60144	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.7302780151367188	-155.055557250976562	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
60145	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7382999999999988	-169.530000000000001	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
60146	Sand Island, Midway Islands	NOS	1619910	28.2117000000000004	-177.360000000000014	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.649999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
60147	Apra Harbor, Guam	NOS	1630000	13.4433888888888902	144.656361111111096	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
60148	Pago Bay, Guam	NOS	1631428	13.4283333000000002	144.796944400000001	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
60149	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2266999999999992	145.736999999999995	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
60150	Pago Pago, American Samoa	NOS	1770000	-14.2766666999999998	-170.689444400000014	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
60151	Kwajalein, Marshall Islands	NOS	1820000	8.73166656494140625	167.736114501953125	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
60152	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667000000000012	151.847000000000008	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000000089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
60153	Wake Island, Pacific Ocean	NOS	1890000	19.2906666666666702	166.6175833333333	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.14000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
60154	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.903305555555562	-66.9849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
60155	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.8699999999999974	-67.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
60156	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9232999999999976	-67.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
60158	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.8233333333333306	-67.1516666666666708	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
60159	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.6570281982421875	-67.2046661376953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
60160	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417000000000002	-67.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
60161	Milbridge, Narraguagus River, Maine	NOS	8412581	44.5399999999999991	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
60162	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.3921944444444421	-68.2042777777777758	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
60163	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.5349999999999966	-68.4217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
60164	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.1700000000000017	-68.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
60165	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.1923055555555635	-68.6209305555555602	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
60166	Bangor, Penobscot River, Maine	NOS	8414612	44.7849999999999966	-68.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
60167	Fort Point, Penobscot River, Maine	NOS	8414721	44.4716999999999985	-68.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
60168	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567000000000007	-68.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
60169	Rockland, Penobscot River, Maine	NOS	8415490	44.1049999999999969	-69.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.32999999999999918	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
60170	Thomaston, St. George River, Maine	NOS	8415709	44.0716999999999999	-69.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
60171	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333000000000027	-69.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
60172	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
60173	Phipps Point, Back River, Maine	NOS	8417087	43.898299999999999	-69.743300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Phipps Pt.	ME
60174	Gardiner, Kennebec River, Maine	NOS	8417134	44.2332999999999998	-69.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
60176	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.7550000000000026	-69.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
60177	Richmond, Kennebec River, Maine	NOS	8417208	44.0882999999999967	-69.7982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.97000000000000242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
60178	Bath, Kennebec River, Maine	NOS	8417227	43.9249999999999972	-69.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
60179	Portland, Casco Bay, Maine	NOS	8418150	43.6567000000000007	-70.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
60180	Pine Point, Maine	NOS	8418445	43.5450000000000017	-70.3332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.75999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
60181	Camp Ellis, Saco River Entrance, Maine	NOS	8418606	43.4617000000000004	-70.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.82000000000000117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
60182	Biddeford, Saco River, Maine	NOS	8418828	43.4917000000000016	-70.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
60183	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3582999999999998	-70.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.80999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
60184	Wells, Webhannet River, Maine	NOS	8419317	43.3200000000000003	-70.5633055555555586	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
60185	Seavey Island, Portsmouth Harbor, New Hampshire	NOS	8419870	43.0799999999999983	-70.7416999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	NH
60186	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983000000000033	-70.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.90999999999999925	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
60187	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167000000000016	-70.8117000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
60188	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.0713882446289062	-70.7105560302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
60189	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8382999999999967	-70.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
60190	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.8250000000000028	-70.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
60191	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts	NOS	8440452	42.8166999999999973	-70.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
60192	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.8149999999999977	-70.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
60193	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.763300000000001	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
60194	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.710138888888892	-70.7886111111111092	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
60195	Rockport Harbor, Massachusetts	NOS	8441551	42.658299999999997	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70999999999999908	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
60196	Essex, Essex River, Massachusetts	NOS	8441771	42.6317000000000021	-70.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.08000000000000096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
60197	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.523299999999999	-70.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
60198	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583000000000013	-70.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
60199	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.3950000000000031	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.23999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
60200	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3866999999999976	-71.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
60201	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.3539166666666631	-71.0503333333333273	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
60202	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3282999999999987	-70.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.91000000000000103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
60203	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.2800000000000011	-70.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.17000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
60204	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483000000000004	-70.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
60205	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017000000000024	-70.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
60206	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833000000000013	-70.6466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
60207	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.0495916666666574	-70.1821583333333336	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.03000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
60208	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0382999999999996	-70.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.48999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
60209	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.9600000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
60210	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.7749999999999986	-70.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
60211	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717000000000027	-70.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
60212	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.7700000000000031	-70.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
60213	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7516999999999996	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.22000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
60214	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.7449999999999974	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
60215	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417000000000016	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
60216	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.7349999999999994	-70.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.77000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
60217	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117000000000004	-70.7150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
60218	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.7043055555555569	-71.1641111111111115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.19999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
60219	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.6950000000000003	-70.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.90000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
60220	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.6884722222222166	-69.9510833333333295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham, Lydia Cove	MA
60221	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683000000000021	-70.0567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
60222	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6666999999999987	-69.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
60223	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317000000000021	-70.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.91999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
60224	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.6049999999999969	-70.6517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
60225	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5932999999999993	-70.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
60226	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5382999999999996	-70.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
60227	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.5236129760742188	-70.671112060546875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.979999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
60228	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583000000000013	-70.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
60229	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.4500000000000028	-70.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
60230	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.388300000000001	-70.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
60231	Menemsha Harbor, Massachusetts	NOS	8448725	41.3544444444444466	-70.7678333333333285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
60232	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.3262222222222206	-70.5903333333333336	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.43999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
60233	Nantucket, Nantucket Island, Nantucket Island, Massachusetts	NOS	8449130	41.2852783203125	-70.0963897705078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
60234	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.4650000000000034	-71.1932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61000000000000121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
60235	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6366999999999976	-71.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
60236	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.6967010498046875	-71.2932968139648438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
60237	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.5050000000000026	-71.3267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
60238	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.7166666666666686	-71.3433333333333337	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.10000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
60239	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.496699999999997	-71.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
60240	Providence, State Pier no.1, Narragansett Bay, Rhode Island	NOS	8454000	41.806666700000001	-71.4005556000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
60241	Quonset Point, Rhode Island	NOS	8454049	41.5867999999999967	-71.4110000000000014	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
60242	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5716999999999999	-71.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
60243	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.6650009155273438	-71.4449996948242188	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
60244	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633000000000024	-71.4899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
60245	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.7078018188476562	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.19000000000000128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
60246	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817000000000021	-71.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
60247	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3282999999999987	-71.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
60248	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1732999999999976	-71.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
60340	Atlantic City, New Jersey	NOS	8534720	39.3549999999999969	-74.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
60250	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1632999999999996	-71.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
60251	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.3432998657226562	-71.9749984741210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
60252	New London, Thames River, Connecticut	NOS	8461490	41.3549999999999969	-72.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.53999999999999959	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London, Thames River	CT
60253	Clinton Harbor, Connecticut	NOS	8463701	41.2683000000000035	-72.5317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.46999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
60254	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.283299999999997	-72.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
60255	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.1757500000000007	-73.1840277777777715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.61999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
60256	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567000000000007	-73.2133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.63000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
60257	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1332999999999984	-73.283299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
60258	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.1199989318847656	-73.3683013916015625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
60259	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0966999999999985	-73.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.80999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
60260	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0382999999999996	-73.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
60261	Mianus, Connecticut	NOS	8469057	41.0391940000000019	-73.5920279999999991	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
60262	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0382999999999996	-73.5467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
60264	Lake Montauk, Long Island, New York	NOS	8510448	41.0733000000000033	-71.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
60265	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.048333300000003	-71.9594443999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.23999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
60266	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567000000000021	-72.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42000000000000082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
60268	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717000000000013	-72.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
60269	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.003300000000003	-72.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
60270	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1366999999999976	-72.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
60271	Greenport, Shelter Island Sound, New York	NOS	8511907	41.1009999999999991	-72.3611666666666622	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
60272	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367000000000004	-72.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61000000000000298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
60273	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.8500000000000014	-72.5032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
60274	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.0150000000000006	-72.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
60275	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.9350000000000023	-72.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
60276	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.8185555555555624	-72.586611111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
60277	Northville, Long Island, New York	NOS	8512987	40.9816999999999965	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
60278	Moriches Coast Guard Station, Long Island, New York	NOS	8513388	40.7867000000000033	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.19000000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
60279	Moriches Inlet, Long Island, New York	NOS	8513398	40.7644166666666692	-72.7559722222222263	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
60280	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383000000000024	-72.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
60281	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.659999999999999698	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
60282	Cedar Beach, Long Island, New York	NOS	8514422	40.9650000000000034	-73.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
60283	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.6492500000000021	-73.1506111111111181	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.699999999999999289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
60284	Fire Island Coast Guard Station, Great South Bay, New York	NOS	8515186	40.6266999999999996	-73.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
60285	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.8999999999999986	-73.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.86999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
60286	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9532999999999987	-73.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
60287	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.9099999999999966	-73.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
60288	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.8733000000000004	-73.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRINGS HARBOR	NY
60289	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233000000000004	-73.5016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.75999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
60290	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033000000000015	-73.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
60291	Point Lookout, Long Island, New York	NOS	8516402	40.5938888888888911	-73.5839722222222292	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
60292	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6332999999999984	-73.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.41999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
60293	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.8346111111111085	-73.6524166666666673	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
60294	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633000000000024	-73.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
60295	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.6300000000000026	-73.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56000000000000227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
60296	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.5963333333333267	-73.6550833333333372	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.44000000000000128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
60297	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8316999999999979	-73.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
60298	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.5949999999999989	-73.743300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
60299	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.634999999999998	-73.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
60300	Kings Point, Long Island Sound, New York	NOS	8516945	40.8103055555555585	-73.7650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.88999999999999879	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
60301	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933000000000021	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
60302	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5882999999999967	-73.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
60303	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.6450000000000031	-73.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.02999999999999758	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
60304	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.7610000000000028	-73.8503611111111127	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
60306	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.5811996459960938	-73.9337997436523438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.64999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
60307	Brooklyn Bridge, East River, New York	NOS	8517847	40.7032999999999987	-73.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
60308	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617000000000004	-73.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
60309	Throgs Neck, New York	NOS	8518526	40.8049999999999997	-73.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
60310	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8016999999999967	-73.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
60311	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.7999999999999972	-73.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
60312	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7766999999999982	-73.9416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.52999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
60313	Queensboro Bridge, East River, New York	NOS	8518687	40.7582999999999984	-73.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.39999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
60314	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117000000000004	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
60315	The Battery, New York Harbor, New York	NOS	8518750	40.7005556000000013	-74.0141667000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
60316	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8682999999999979	-73.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
60319	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2182999999999993	-73.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
60320	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
60321	Hyde Park, Hudson River, New York	NOS	8518951	41.783299999999997	-73.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
60322	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.0139007568359375	-73.9392013549804688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.17000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point Hudson River NERRS	NY
60323	Albany, Hudson River, New York	NOS	8518995	42.6499999999999986	-73.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
60324	USCG Station, The Narrows, New York	NOS	8519050	40.6120000000000019	-74.059861111111104	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
60325	Great Kills Harbor, New Jersey	NOS	8519436	40.5433000000000021	-74.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.72999999999999687	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NJ
60326	Bergen Point West Reach, Kill Van Kull, New York	NOS	8519483	40.6366944444444371	-74.1416944444444397	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
60327	Port Reading, Arthur Kill, New York	NOS	8531142	40.5550003051757812	-74.2450027465820312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.96999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Reading	NY
60328	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4532999999999987	-74.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHEESEQUAKE CREEK	NJ
60329	Keasbey, Raritan River, New Jersey	NOS	8531262	40.50830078125	-74.3116989135742188	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.85999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEASBEY, RARITAN RIVER	NJ
60330	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.4166984558105469	-74.3632965087890625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.10999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH OLD BRIDGE, SOUTH RIVER	NJ
60331	Sayreville, Raritan River, New Jersey	NOS	8531390	40.4782981872558594	-74.3566970825195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAYREVILLE, RARITAN RIVER	NJ
60332	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.4883003234863281	-74.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BRUNSWICK  RARITAN RIVER	NJ
60333	Sandy Hook, New Jersey	NOS	8531680	40.4669444000000027	-74.0094444000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
60334	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365000000000002	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
60335	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.9500007629394531	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.490000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
60336	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.8449999999999989	-74.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.440000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
60337	Barnegat Inlet, USCG Station, Barnegat Bay, New Jersey	NOS	8533615	39.7616999999999976	-74.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
60338	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.50830078125	-74.3249969482421875	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01409335.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
60339	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483000000000033	-74.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
60341	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.3350000000000009	-74.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
60342	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083000000000027	-74.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.03000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
60343	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.2950000000000017	-74.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
60344	Bivalve, Maurice River, Delaware Bay, New Jersey	NOS	8535055	39.2324981689453125	-75.0327987670898438	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01412150.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.13000000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bivalve, Maurice River	NJ
60345	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.121699999999997	-74.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.19999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
60346	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.1099999999999994	-74.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
60347	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.05670166015625	-74.7649993896484375	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01411360.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STONE HARBOR, GREAT CHANNEL	NJ
60348	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.9750000000000014	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
60349	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.9677777777777834	-74.9597222222222257	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
60350	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.128300000000003	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
60351	Fortescue Creek, New Jersey	NOS	8536931	39.2383000000000024	-75.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
60352	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.3049999999999997	-75.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
60353	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.8350000000000009	-75.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
60354	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.0119400000000027	-75.0429999997880657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
60355	Burlington, Delaware River, New Jersey	NOS	8539094	40.0799999999999983	-74.8733333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
60356	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1366999999999976	-74.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
60357	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1882999999999981	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.47000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
60358	Marcus Hook, Pennsylvania	NOS	8540433	39.8116667000000035	-75.4094443999999982	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
60359	Philadelphia (USCG Station), Delaware River, Pennsylvania	NOS	8545240	39.93333333333333	-75.1416666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
60360	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9532999999999987	-75.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.49999999999999956	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
60361	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.9833333333333272	-75.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
60362	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.1373055555555567	-74.7518888888888853	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
60363	Delaware City, Delaware River, Delaware	NOS	8551762	39.5816999999999979	-75.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.96000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
60364	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583000000000027	-75.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.91999999999999948	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
60365	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.1850000000000023	-75.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
60366	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.9866699999999966	-75.1133333333333297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61000000000000298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
60367	Lewes, Fort Miles, Delaware	NOS	8557380	38.7827796936035156	-75.1191635131835938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
60368	Inlet (Coast Guard Station), Indian River, Delaware	NOS	8558690	38.6099999999999994	-75.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
60369	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267000000000024	-75.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
60370	Ocean City Inlet, Maryland	NOS	8570283	38.3283300000000011	-75.0916666666666686	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
60371	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.2150000000000034	-75.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
60372	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.148299999999999	-75.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
60373	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.1389444444444479	-75.1835277777777833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
60374	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.976700000000001	-75.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
60375	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.9949999999999974	-76.0317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
60376	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.1783300000000025	-75.3966666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
60377	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.2203888888888912	-76.0386666666666713	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
60378	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.2999999999999972	-76.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
60379	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.341700000000003	-76.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
60380	Salisbury, Wicomico River, Maryland	NOS	8571616	38.3650016784667969	-75.6066970825195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
60381	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.4283300000000025	-76.2366666666666646	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
60382	Vienna, Nanticoke River, Maryland	NOS	8571773	38.4833300000000023	-75.818333333333328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
60383	Cambridge, Choptank River, Maryland	NOS	8571892	38.5741666999999993	-76.0722221999999988	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
60384	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.7583333333333329	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
60386	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367000000000004	-76.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.769999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
60387	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9166999999999987	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
60388	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9566999999999979	-76.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
60389	Love Point, Chester River, Maryland	NOS	8572955	39.0317000000000007	-76.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
60390	Crumpton, Chester River, Maryland	NOS	8573349	39.2449999999999974	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
60391	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.2133299999999991	-76.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
60392	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.371699999999997	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
60393	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.503300000000003	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
60394	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5266999999999982	-75.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
60395	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367000000000033	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
60396	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.388300000000001	-76.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000782	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
60397	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.2666699999999977	-76.5783333333333331	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore, Fort McHenry, Patapsco River	MD
60398	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2616999999999976	-76.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.799999999999999822	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
60399	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.9832800000000006	-76.4815555551317061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
60400	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.4650000000000034	-76.4732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.679999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
60401	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917000000000002	-76.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
60402	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.3172222000000033	-76.4508332999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
60403	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.6550000000000011	-76.6833333333333371	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
60404	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333000000000027	-76.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
60405	Washington, Potomac River, DC	NOS	8594900	38.8733300000000028	-77.0216666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
60406	Jesters Island, Virginia	NOS	8630111	37.9817008972167969	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
60540	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.0799999999999983	-81.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.439999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
60407	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
60408	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
60409	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.6077777777777769	-75.6858333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28999999999999959	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
60410	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.1651900000000026	-75.9884444443384837	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
60412	Rappahannock Light, Virginia	NOS	8632837	37.5382999999999996	-76.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.939999999999997726	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
60413	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5566999999999993	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
60414	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8282999999999987	-75.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.849999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
60415	Saxis, Starling Creek, Virginia	NOS	8633777	37.9216995239257812	-75.728302001953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
60416	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.3197499999999991	-77.0366111111111138	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000001279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
60417	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2516999999999996	-76.9599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.969999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
60418	Rappahannock Bend, Virginia	NOS	8635257	38.2132999999999967	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
60419	Lewisetta, Potomac River, Virginia	NOS	8635750	37.9953888888888898	-76.4646111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000675	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
60420	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733000000000004	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
60421	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.6161111111111097	-76.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
60422	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833000000000013	-76.9899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.72999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
60423	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.4595555555555535	-77.4207777777777721	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
60426	Gloucester Point, York River, Virginia	NOS	8637624	37.246699999999997	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29000000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
60427	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265000000000015	-76.4788000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
60428	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.2201111111111089	-76.7914166666666631	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=02042770.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown Wharf	VA
60429	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.1382222222222325	-76.6227499999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27999999999999758	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
60430	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.8232222222222205	-76.399111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
60432	Kingsmill, James River, Virginia	NOS	8638424	37.2199999999999989	-76.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
60433	Scotland, James River, Virginia	NOS	8638433	37.1850000000000023	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
60434	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033000000000015	-76.9116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
60435	Tettington, James River, Virginia	NOS	8638450	37.240000000000002	-76.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
60436	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.3149999999999977	-77.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.30999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
60437	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3132999999999981	-77.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
60438	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667000000000002	-77.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.72000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
60439	Richmond River Locks, James River, Virginia	NOS	8638495	37.5249999999999986	-77.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92000000000000015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
60440	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.9466666666666725	-76.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
60441	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8216999999999999	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
60442	Lafayette River, Virginia	NOS	8638671	36.8842222222222205	-76.275858333333332	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
60443	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.966700000000003	-76.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
60444	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.0329017639160156	-76.0832977294921875	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
60445	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8316999999999979	-75.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.80000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
60446	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.778305555555562	-76.3016944444444505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
60447	FRF Pier, Duck, North Carolina	NOS	8651370	36.1833055555555632	-75.7466944444444437	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.77000000000000313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
60448	Manns Harbor, outer coast, North Carolina	NOS	8652247	35.9033000000000015	-75.769999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.219999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
60449	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.8449999999999989	-75.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
60450	Roanoke Marshes Light, outer coast, North Carolina	NOS	8652547	35.8117000000000019	-75.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
60451	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.7950000000000017	-75.5480555999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.580000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
60452	Oregon Inlet (USCG Station), North Carolina	NOS	8652678	35.7683000000000035	-75.5267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
60453	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.3501388888888926	-75.5120277777777744	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.289999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
60454	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233000000000018	-75.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
60455	Hatteras (USCG Station), North Carolina	NOS	8654467	35.2086388888888919	-75.7041666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.300000000000000711	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
60456	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115000000000002	-75.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
60457	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.390000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
60458	Davis, Core Sound, North Carolina	NOS	8656201	34.796750000000003	-76.4554722222222267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.630000000000002558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Core Sound	NC
60459	Spooner Creek, North Carolina	NOS	8656467	34.7250000000000014	-76.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.980000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
60460	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.7199999999999989	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.70999999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort, Duke Marine Lab	NC
60461	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933000000000007	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
60462	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133000000000024	-76.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
60463	Wilmington, North Carolina	NOS	8658120	34.2274999999999991	-77.9536111000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
60464	Wrightsville Beach, North Carolina	NOS	8658163	34.2133055555555572	-77.7866944444444499	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.15000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
60465	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.023299999999999	-77.946700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
60466	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.9500000000000028	-77.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
60467	Southport, Cape Fear River, North Carolina	NOS	8659084	33.9149999999999991	-78.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
60468	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9016999999999982	-78.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
60469	Sunset Beach Pier, North Carolina	NOS	8659897	33.865000000000002	-78.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
60470	Springmaid Pier, South Carolina	NOS	8661070	33.6550000000000011	-78.9183055555555626	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
60471	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467000000000027	-79.0949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
60472	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5782999999999987	-79.0032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2799999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
60473	Garden City Pier (ocean), South Carolina	NOS	8661437	33.5750000000000028	-78.9967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
60474	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5116999999999976	-79.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.51000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
60475	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067000000000021	-79.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
60476	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.4350000000000023	-79.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
60477	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4316999999999993	-79.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
60478	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117000000000033	-79.1350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.91999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
60479	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.351700000000001	-79.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
60480	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333000000000013	-79.1932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
60481	South Island Plantation (C.G. Station), Winyah Bay, South Carolina	NOS	8662746	33.2349999999999994	-79.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
60482	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.2549972534179688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9900000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
60483	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.4149999999999991	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.95999999999999952	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
60484	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0082999999999984	-79.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
60485	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9266999999999967	-79.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.54000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
60486	Army Depot, Cooper River, South Carolina	NOS	8664662	32.9099999999999966	-79.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
60487	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8566999999999965	-79.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57999999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
60488	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367000000000004	-80.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
60489	Charleston, Cooper River Entrance, South Carolina	NOS	8665530	32.7808332999999976	-79.9236111000000022	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.92000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston, Cooper River Entrance	SC
60490	Clarendon Plantation, South Carolina	NOS	8667633	32.5024999999999977	-80.7840999999999951	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
60491	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.4299999999999997	-80.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
60492	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
60493	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667000000000002	-80.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
60494	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.1433000000000035	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
60496	Fort Pulaski, Savannah River Entrance, Georgia	NOS	8670870	32.0367000000000033	-80.9017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
60498	Skidaway Institute, Skidaway River, Georgia	NOS	8671086	31.9899999999999984	-81.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SKIDAWAY INSTITUTE, SKIDAWAY RIVER	GA
60499	Halfmoon Reef, Halfmoon River, Georgia	NOS	8671314	31.9633000000000003	-80.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALFMOON REEF, HALFMOON RIVER	GA
60500	Priest Landing, Wilmington River, Georgia	NOS	8671315	31.9633000000000003	-81.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRIEST LANDING, WILMINGTON RIVER	GA
60501	Bear River, (Range 'A' Light), Georgia	NOS	8672667	31.7932999999999986	-81.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
60502	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667000000000002	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
60503	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
60504	South Newport River (Daymark 135), Georgia	NOS	8674301	31.5749999999999993	-81.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
60505	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.486699999999999	-81.3199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
60506	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.3738611111111112	-81.333944444444441	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
60507	Crispen Island, Turtle River, Georgia	NOS	8676808	31.2133000000000003	-81.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISPEN ISLAND,TURTLE RIVER	GA
60508	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1316999999999986	-81.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
60509	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.1445555555555593	-81.4968055555555537	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.00999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
60510	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.0148055555555509	-81.4559722222222291	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
60511	Bailey Cut, 0.8 mile west of, Satilla River, Georgia	NOS	8678322	30.9849999999999994	-81.591700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
60512	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967000000000013	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
60513	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.763300000000001	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
60514	St. Marys, St. Marys River, Georgia	NOS	8679964	30.7199999999999989	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
60515	Crandall, St. Marys River, Florida	NOS	8720004	30.7216999999999985	-81.6217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
60516	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083000000000013	-81.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
60518	Chester, Bells River, Florida	NOS	8720023	30.6832999999999991	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
60519	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.6713889000000002	-81.4658332999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
60520	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
60521	Vaughns Landing, Florida	NOS	8720059	30.629999999999999	-81.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.82999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
60522	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683000000000007	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
60523	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5016999999999996	-81.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
60524	Cedar Heights, Broward River, Florida	NOS	8720189	30.4366999999999983	-81.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
60525	Sisters Creek, Florida	NOS	8720196	30.4166999999999987	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38000000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
60526	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067000000000007	-81.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
60527	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida	NOS	8720211	30.3999999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
60528	Sherwood Forest, Trout River, Florida	NOS	8720213	30.4200000000000017	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
60529	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3966999999999992	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
60530	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.3981666666666683	-81.4278888888888872	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.46999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
60531	Dame Point, St. Johns River, Florida	NOS	8720219	30.3867000000000012	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
60532	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
60533	Mayport, St. Johns River, Florida	NOS	8720224	30.3949999999999996	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
60534	Phoenix Park, Florida	NOS	8720225	30.3832999999999984	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
60535	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.3200000000000003	-81.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
60536	Jacksonville, Long Branch, Florida	NOS	8720242	30.3599999999999994	-81.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longbranch	FL
60537	Jacksonville Beach, Florida	NOS	8720291	30.2833000000000006	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
60538	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.1917000000000009	-81.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.530000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Bridge, St Johns River	FL
60539	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.120000000000001	-81.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.419999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
60541	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.9816666666666691	-81.6341666666666725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999999916	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
60542	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9166999999999987	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
60543	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667000000000016	-81.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
60544	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
60545	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017000000000003	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.660000000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
60546	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
60547	State Road A1A Bridge, Florida	NOS	8720692	29.7045305555555608	-81.2278555555555499	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.93999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
60548	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.6149999999999984	-81.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
60549	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.5949999999999989	-81.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.580000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
60550	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.631699999999995	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.719999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
60573	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.3432998657226562	-80.0766983032226562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
60551	Welaka, St. Johns River, Florida	NOS	8720832	29.476700000000001	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
60553	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1466999999999992	-80.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
60554	Ponce De Leon Inlet South, Florida	NOS	8721147	29.0633000000000017	-80.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
60555	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.023299999999999	-80.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
60556	Packwood Place, Florida	NOS	8721222	28.9400000000000013	-80.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.540000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
60557	Turtle Mound, Florida	NOS	8721223	28.9267000000000003	-80.8250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
60558	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.4158332999999992	-80.5930555999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
60560	Cocoa Beach, Florida	NOS	8721649	28.3683000000000014	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
60561	Vero Beach, Indian River, Florida	NOS	8722125	27.6316999999999986	-80.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
60562	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4716999999999985	-80.3250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.950000000000000067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
60563	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.4682999999999993	-80.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
60564	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567000000000014	-80.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
60565	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8432999999999993	-80.0666999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
60566	Port of West Palm Beach, Florida	NOS	8722588	26.7699999999999996	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
60567	Lake Worth ICW, Florida	NOS	8722669	26.6132999999999988	-80.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
60568	Lake Worth Pier, Florida	NOS	8722670	26.6127777999999999	-80.0341667000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
60570	Ocean Ridge, ICWW, Florida	NOS	8722718	26.5266990661621094	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
60571	South Delray Beach, ICWW, Florida	NOS	8722761	26.4466999999999999	-80.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
60572	Lake Wyman, ICWW, Florida	NOS	8722802	26.370000000000001	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
60574	Hillsboro Inlet Marina, Florida	NOS	8722859	26.2600002288818359	-80.0849990844726562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
60575	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.1882991790771484	-80.0932998657226562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45999999999999952	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
60576	South Port Everglades, ICWW, Florida	NOS	8722956	26.0816993713378906	-80.11669921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port Everglades	FL
60577	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033000000000015	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
60578	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783000000000015	-80.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
60579	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
60580	Government Cut, Miami Harbor Entrance, Florida	NOS	8723178	25.763300000000001	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.30000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
60581	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.7314000000000007	-80.1617999999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key, Biscayne Bay	FL
60582	Cutler, Biscayne Bay, Florida	NOS	8723289	25.6149999999999984	-80.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
60583	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.523299999999999	-80.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
60584	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4532999999999987	-80.196700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
60585	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4366999999999983	-80.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.889999999999999902	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
60586	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733000000000004	-80.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.510000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
60587	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.3249999999999993	-80.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
60588	Little Card Sound bridge, Florida	NOS	8723534	25.2882999999999996	-80.3700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
60589	Key Colony Beach, Florida	NOS	8723962	24.7182999999999993	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
60590	Vaca Key, Florida Bay, Florida	NOS	8723970	24.7109999999999985	-81.1064999999999969	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
60591	Boca Chica Marina, Florida	NOS	8724493	24.5749999999999993	-81.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.649999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
60592	Fleming Key, north end, Florida	NOS	8724571	24.5916999999999994	-81.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.710000000000000853	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
60593	Key West, Florida	NOS	8724580	24.5558333333333287	-81.8077777777777726	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
60594	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4532999999999987	-81.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000000098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
60595	Smith Shoal Light, Florida	NOS	8724671	24.7182777777777787	-81.9215277777777828	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
60596	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6316999999999986	-82.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
60597	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.8949999999999996	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
60598	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8966999999999992	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
60599	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083000000000006	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67999999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
60600	Marco, Big Marco River, Florida	NOS	8724991	25.9716999999999985	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.50000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
60601	McIlvaine Bay, Florida	NOS	8724996	25.9849999999999994	-81.7017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.43999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
60602	Keewaydin Island (inside), Florida	NOS	8725019	26.0249999999999986	-81.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
60603	Naples, Gulf Of Mexico, Florida	NOS	8725110	26.1316666666666713	-81.8074722222222164	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
60604	Coconut Point, Estero Bay, Florida	NOS	8725319	26.3999999999999986	-81.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
60605	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383000000000017	-81.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
60606	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433000000000007	-82.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
60607	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.4699999999999989	-81.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
60608	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.4882999999999988	-82.013300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
60609	North Captiva Island, Florida	NOS	8725488	26.6050000000000004	-82.2182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04000000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
60610	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.6477000000000004	-81.8712000000000018	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers, Caloosahatchee River	FL
60611	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.7066993713378906	-82.163299560546875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.920000000000000373	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
60612	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.7199999999999989	-82.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999885	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
60613	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967000000000013	-82.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
60614	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.8550000000000004	-82.303299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.790000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
60615	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.9299999999999997	-82.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
60616	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9882999999999988	-81.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
60617	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117000000000012	-82.4099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
60618	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.0450000000000017	-82.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
60619	Venice Municipal Airport, Florida	NOS	8725858	27.0716999999999999	-82.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
60620	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.601700000000001	-82.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
60621	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.6149999999999984	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
60622	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.6383332999999993	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
60623	Little Manatee River, Florida	NOS	8726436	27.7049999999999983	-82.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
60624	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.7606000000000002	-82.6269000000000062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.20000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Petersburg, Tampa Bay	FL
60625	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833000000000006	-82.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.39999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
60626	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.8577778000000009	-82.5527778000000012	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
60627	Ballast Point, Tampa, Florida	NOS	8726639	27.8900000000000006	-82.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
60628	CSX Rockport, Mckay Bay Entrance, Florida	NOS	8726667	27.9133333333333304	-82.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
60629	Clearwater Beach, Gulf Of Mexico, Florida	NOS	8726724	27.9783000000000008	-82.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
60630	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9882999999999988	-82.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
60631	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.1649999999999991	-82.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.69999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
60632	Bayport, Florida	NOS	8727151	28.5333000000000006	-82.6500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
60633	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917000000000009	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
60634	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.7149999999999999	-82.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.259999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
60635	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617000000000012	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.59000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
60636	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7716999999999992	-82.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
60637	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8000000000000007	-82.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.329999999999999849	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
60638	Ozello, St. Martin's River, Florida	NOS	8727306	28.8249999999999993	-82.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.349999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
60639	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8632999999999988	-82.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.840000000000000302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
60640	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.870000000000001	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
60641	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8816999999999986	-82.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
60642	Crystal River, Kings Bay, Florida	NOS	8727343	28.898299999999999	-82.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
60643	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.9050000000000011	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.23999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
60644	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233000000000011	-82.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
60645	Cedar Key, Gulf Of Mexico, Florida	NOS	8727520	29.1336111111111116	-83.0308888888888958	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
60646	Horseshoe Point, Florida	NOS	8727648	29.4366999999999983	-83.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
60647	Spring Warrior Creek, Florida	NOS	8727843	29.9200000000000017	-83.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
60648	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0782999999999987	-84.178299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
60649	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.0599999999999987	-84.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
60650	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.9149999999999991	-84.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
60651	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.8099999999999987	-84.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
60652	Lanark, St. George Sound, Florida	NOS	8728412	29.8782997131347656	-84.595001220703125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
60653	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.8500000000000014	-84.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
60654	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.7667007446289062	-84.6999969482421875	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
60655	South Carrabelle Beach, Florida	NOS	8728488	29.8017005920410156	-84.7367019653320312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.40000000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
60656	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.7232999999999983	-84.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
60657	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533000000000015	-84.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
60658	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.6133003234863281	-84.9582977294921875	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
60659	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.726700000000001	-84.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.910000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
60660	White Beach, East Bay, Florida	NOS	8728694	29.7850000000000001	-84.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
60661	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.763300000000001	-85.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
60662	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.7700004577636719	-85.0849990844726562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.700000000000000067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
60663	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.7066993713378906	-85.1532974243164062	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
60664	White City, ICWW, Florida	NOS	8728853	29.8806944444444404	-85.2214444444444439	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
60665	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.8150000000000013	-85.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
60667	Overstreet, St. Andrew Bay, Florida	NOS	8728957	29.9967002868652344	-85.3700027465820312	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OVERSTREET	FL
60668	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.8733005523681641	-85.3899993896484375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
60669	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.1522777777777797	-85.6669444444444395	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.669999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
60670	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.2133007049560547	-85.8783035278320312	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.670000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
60671	Valparaiso, Florida	NOS	8729501	30.5032999999999994	-86.493300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.279999999999999361	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
60672	Navarre Beach, Florida	NOS	8729678	30.3766999999999996	-86.8649999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.660000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
60673	East Bay, Pensacola Bay, Florida	NOS	8729702	30.4499999999999993	-86.9183000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.739999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST BAY, HOLLEY	FL
60674	Woodlawn Beach, Florida	NOS	8729736	30.3867000000000012	-86.9916999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.65999999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WOODLAWN BEACH	FL
60676	Shield Point, Blackwater River, Florida	NOS	8729747	30.5817000000000014	-87.0150000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHIELD POINT, BLACKWATER RIVER	FL
60678	Hernandez Point North, Florida	NOS	8729791	30.4549999999999983	-87.0999999999999943	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.650000000000000355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERNANDEZ POINT NORTH	FL
60679	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.3367000000000004	-87.1400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.630000000000000338	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FISHING BEND, SANTA ROSA SOUND	FL
60680	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.5150000000000006	-87.1616999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LORA POINT, ESCAMBIA BAY	FL
60681	Floridatown, Escambia Bay, Florida	NOS	8729824	30.5817000000000014	-87.1800000000000068	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.709999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FLORIDATOWN, ESCAMBIA BAY	FL
60682	Pensacola, Florida	NOS	8729840	30.4043888888888887	-87.2111944444444447	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
60683	Millview, Perdido Bay, Florida	NOS	8729905	30.4182999999999986	-87.3567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
60684	Big Lagoon, Florida	NOS	8729909	30.3266999999999989	-87.3567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIG LAGOON	FL
60685	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.386944444444449	-87.4288055555555559	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
60686	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.2786111111111111	-87.5550003051757812	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
60687	Gulf Shores, ICWW, Alabama	NOS	8731439	30.2798888888888911	-87.6842777777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
60688	Weeks Bay, Vermilion Bay, Louisiana	NOS	8732828	30.4168888888888915	-87.8253888888888952	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.800000000000000711	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	LA
60689	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.4866388888888906	-87.9345277777777738	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
60690	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.6671666666666702	-87.9364444444444473	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
60691	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.0750000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.560000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
60692	Dauphin Island Hydro, Alabama	NOS	8735181	30.2513194444444409	-88.0794861111111089	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.590000000000000302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
60693	Dog River Bridge, Alabama	NOS	8735391	30.5651666666666699	-88.0879999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.809999999999998721	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
60694	East Fowl River Bridge, Alabama	NOS	8735523	30.4436110999999983	-88.1138889000000063	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
60695	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.6483055555555595	-88.0583055555555489	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
60696	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.7083000000000013	-88.0433000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
60697	Chickasaw Creek, Alabama	NOS	8737138	30.78188888888889	-88.0736111111111057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.839999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
60698	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783000000000008	-87.8733000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.930000000000003268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
60699	West Fowl River Bridge, Alabama	NOS	8738043	30.3766388888888912	-88.1585555555555516	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
60700	Bayou La Batre Bridge, Alabama	NOS	8739803	30.4056666666666686	-88.2476944444444484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.779999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
60701	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.4131944444444393	-88.4028888888888957	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.769999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
60702	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2032999999999987	-88.4416999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.709999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
60703	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477777999999994	-88.5058333000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000001563	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
60704	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.3399999999999999	-88.533299999999997	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
60705	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.3677777777777784	-88.5630555555555503	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
60706	Gautier, Mississippi	NOS	8741798	30.3832999999999984	-88.6099999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
60707	Graveline Bayou entrance, Mississippi	NOS	8742205	30.361699999999999	-88.6633000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
60708	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2382999999999988	-88.6667000000000058	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
60709	North Shore, Mississippi	NOS	8742523	30.3733000000000004	-88.7049999999999983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999662	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
60710	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867000000000012	-88.7733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.909999999999999698	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
60711	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217000000000013	-88.7883000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
60712	Ocean Springs, Mississippi	NOS	8743281	30.3917000000000002	-88.7982999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
60713	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.4299999999999997	-88.7999999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.859999999999999876	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
60714	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.4200000000000017	-88.8282999999999987	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.93000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
60715	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383000000000017	-88.8449999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.929999999999999938	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
60716	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.3900000000000006	-88.8567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
60717	Deer Island, Mississippi	NOS	8743812	30.3832999999999984	-88.8666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
60718	Langley Point, Mississippi	NOS	8743838	30.4250000000000007	-88.8700000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
60719	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4116999999999997	-88.9033000000000015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.900000000000002132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
60722	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4132999999999996	-88.9749999999999943	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
60723	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133000000000003	-88.9716999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
60724	Biloxi River, lower end, Mississippi	NOS	8744934	30.4349999999999987	-89.0083000000000055	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
60725	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067000000000007	-89.0267000000000053	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
60726	Landon, Mississippi	NOS	8745555	30.4316999999999993	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
60727	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.3599999999999994	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
60728	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.3099999999999987	-89.2450000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999885	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
60729	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.3249999999999993	-89.3250000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
60730	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817000000000007	-89.3666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.800000000000000711	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
60731	Devon Energy Facility, Louisiana	NOS	8760417	29.2007499999999993	-89.0444666666666649	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.590000000000003411	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
60732	South Pass, Louisiana	NOS	8760551	28.9899999999999984	-89.1400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.600000000000000533	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
60733	Grand Pass, Louisiana	NOS	8760668	30.1266994476318359	-89.2217025756835938	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
60734	Pilottown, Louisiana	NOS	8760721	29.1783055555555606	-89.2583055555555518	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.429999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
60736	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.3865555555555602	-89.3801388888888937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.670000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
60737	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322000000000017	-89.4074999999999989	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, S.W. Pass	LA
60738	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.9250000000000007	-89.4183000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.630000000000000782	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
60739	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.8681111111111086	-89.6732499999999959	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
60740	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.0687500000000014	-89.8020829999999961	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.579999999999998295	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
60741	The Rigolets, U.S. Highway 90, Louisiana	NOS	8761402	30.1666999999999987	-89.736699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
60742	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.9450000000000003	-89.8349999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.679999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
60744	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.2633333333333283	-89.9566666666666634	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.540000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
60745	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.3183002471923828	-89.9800033569335938	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
60746	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017000000000017	-90.0383000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.459999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
60747	Caminada Pass (bridge), Louisiana	NOS	8761826	29.2099990844726562	-90.0400009155273438	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.489999999999999769	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
60748	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6666999999999987	-90.111699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.170000000000000373	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
60749	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.0272222222222211	-90.1133333333333297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.270000000000000462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
60750	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.1142499999999984	-90.1992500000000064	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
60751	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483000000000004	-90.2116999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.470000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
60752	Golden Meadow, Plaisance Canal, Louisiana	NOS	8762184	29.3733000000000004	-90.2650000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.299999999999999822	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GOLDEN MEADOW, PLAISANCE CANAL	LA
60753	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0766999999999989	-90.2849999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
60754	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.0503333333333309	-90.367999999999995	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
60755	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.0678611111111103	-90.3899722222222266	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.270000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
60756	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0716999999999999	-90.6400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
60757	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245000000000001	-90.6616999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.559999999999999609	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
60758	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.1747777777777806	-90.9764444444444393	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
60759	Stouts Pass At Six Mile Lake, Louisiana	NOS	8764025	29.7433000000000014	-91.230000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.420000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
60760	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675000000000004	-91.2376111111111072	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.299999999999997158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
60761	Lawma, Amerada Pass, Louisiana	NOS	8764227	29.4496111111111105	-91.3381111111111181	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.859999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
60763	Eugene Island, north of, Louisiana	NOS	8764314	29.3674999999999997	-91.3838888888888903	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of , Gulf of Mexico	LA
60764	Weeks Bay, Louisiana	NOS	8765148	29.8372222222222199	-91.8375000000000057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
60765	Cypremort Point, Louisiana	NOS	8765251	29.7133611111111087	-91.8799999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
60766	Freshwater Canal Locks, Louisiana	NOS	8766072	29.5516944444444398	-92.3051944444444388	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
60767	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.2236388888888889	-93.221666666666664	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
60768	Bulk Terminal, Louisiana	NOS	8767961	30.1901944444444403	-93.3008055555555558	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
60769	Calcasieu Pass, East Jetty, Louisiana	NOS	8768094	29.7681666666666693	-93.3428888888888935	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.18999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
60770	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.8670833333333299	-93.9309999999999974	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.599999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
60771	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.9799995422363281	-93.8816986083984375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.550000000000000266	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge (TCOON)	TX
60772	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667000000000002	-93.894999999999996	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
60773	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133000000000003	-94.6899999999999977	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
60774	Sabine Pass (north), Texas	NOS	8770570	29.7284000000000006	-93.8700999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
60775	Orange (Old Navy Base), Texas	NOS	8770597	30.0982999999999983	-93.7216999999999985	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
60776	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.6816944444444495	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.709999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point, Barbours Cut	TX
60777	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.6799999999999997	-94.868300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.700000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
60778	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.7648611111111094	-95.0788611111111095	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
60779	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.7566999999999986	-95.0900000000000034	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
60780	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.7262222222222192	-95.265777777777771	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000782	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
60781	High Island (TCOON), Texas	NOS	8770808	29.5946998596191406	-94.3902969360351562	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.779999999999999361	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island (TCOON)	TX
60782	Texas Point, Sabine Pass, Texas	NOS	8770822	29.6893888888888888	-93.8419166666666626	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
60783	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633000000000017	-95.0666999999999973	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
60784	Rollover Pass, Texas	NOS	8770971	29.515555599999999	-94.5105556000000036	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.799999999999999822	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
60785	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.4800000000000004	-94.9183055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point, Galveston Bay	TX
60787	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.3649999999999984	-94.7800000000000011	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.840000000000000746	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
60788	Galveston Bay Entrance, North Jetty, Texas	NOS	8771341	29.3573333333333295	-94.7248333333333363	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
60789	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.3099999999999987	-94.7933055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
60790	Galveston Railroad Bridge, Texas	NOS	8771486	29.3026008605957031	-94.8971023559570312	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
60791	Galveston Pleasure Pier, Gulf Of Mexico, Texas	NOS	8771510	29.2852999999999994	-94.7894000000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.11000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
60792	San Luis Pass (TCOON), Texas	NOS	8771972	29.0809722222222184	-95.1313333333333304	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.719999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
60793	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9482999999999997	-95.3083000000000027	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.950000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
60794	USCG Freeport, Texas	NOS	8772447	28.9433055555555505	-95.3024999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000002416	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
60795	Freeport SPIP, Freeport Harbor, Texas	NOS	8772471	28.935699462890625	-95.2941970825195312	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.980000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport SPIP, Freeport Harbor	TX
60796	Sargent (TCOON), Texas	NOS	8772985	28.7714166666666706	-95.6171666666666624	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000001847	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
60797	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.4069004058837891	-96.71240234375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.199999999999999956	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
60798	Matagorda City (TCOON), Texas	NOS	8773146	28.7100555555555594	-95.9140000000000015	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
60799	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.6406002044677734	-96.60980224609375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
60825	Mission Bay, California	NOS	9410196	32.7937200000000004	-117.223799999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.81000000000000227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
60826	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.8668888888888873	-117.257138888888903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.72999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
60800	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.4458611111111104	-96.3955555555555605	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.400000000000000355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
60801	Matagorda Bay Entrance Channel, Texas	NOS	8773767	28.4269008636474609	-96.3301010131835938	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel, TX	TX
60802	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.2283000946044922	-96.7949981689453125	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.149999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge (TCOON)	TX
60803	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.1144008636474609	-97.0243988037109375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.209999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
60804	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216667000000008	-97.0466667000000029	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.189999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
60805	White Point Bay, Texas	NOS	8775188	27.8582999999999998	-97.4749999999999943	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
60806	Port Aransas, Texas	NOS	8775237	27.8397006988525391	-97.0725021362304688	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.650000000000000355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
60807	Aransas, Aransas Pass, Texas	NOS	8775241	27.8365993499755859	-97.0391006469726562	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.829999999999998295	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
60808	Nueces Bay (TCOON), Texas	NOS	8775244	27.8327500000000008	-97.4859444444444421	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.359999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
60809	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.8267002105712891	-97.0500030517578125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.919999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
60810	Port Ingleside, Corpus Christi Bay, Texas	NOS	8775283	27.8216999999999999	-97.2032999999999987	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Ingleside	TX
61047	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783000000000015	-148.664999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
60811	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.8148994445800781	-97.3891983032226562	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington, Corpus Christi Bay	TX
60812	Corpus Christi Naval Air Station, Texas	NOS	8775421	27.7049999999999983	-97.2800000000000011	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
60813	Packery Channel, Texas	NOS	8775792	27.6333055555555589	-97.2366944444444385	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.189999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
60814	Corpus Christi, Gulf Of Mexico, Texas	NOS	8775870	27.5799999999999983	-97.216700000000003	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.929999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
60815	Realitos Peninsula, Texas	NOS	8779280	26.2624439999999986	-97.2853329999999943	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
60816	Coast Guard Station, South Padre Island, Texas	NOS	8779748	26.0730991363525391	-97.1675033569335938	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
60817	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.0673888888888889	-97.154777777777781	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
60818	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683000000000007	-97.1567000000000007	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.879999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
60819	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.0611666666666686	-97.2155277777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
60820	Wilson Cove, San Clemente Island, California	NOS	9410032	33.0050010681152344	-118.556999206542969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILSON COVE, SAN CLEMENTE IS.	CA
60821	Avalon, Santa Catalina Island, California	NOS	9410079	33.3449999999999989	-118.325000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
60822	South San Diego Bay, California	NOS	9410135	32.6291390000000021	-117.108000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
60823	Ballast Point, California	NOS	9410155	32.6867000000000019	-117.233000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
60824	San Diego, San Diego Bay, California	NOS	9410170	32.7141944444444519	-117.173583333333298	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego, San Diego Bay	CA
60827	Newport Beach, Newport Bay Entrance, Corona del Mar, California	NOS	9410580	33.6032999999999973	-117.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
60828	Los Angeles (outer harbor), California	NOS	9410660	33.7199444444444367	-118.272861111111098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
60829	Long Beach, Terminal Island, California	NOS	9410680	33.7516999999999996	-118.227000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
60830	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0082999999999984	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
60831	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483000000000018	-119.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
60832	Santa Barbara, California	NOS	9411340	34.4031111111111088	-119.692805555555594	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
60833	Gaviota State Park, California	NOS	9411399	34.4693888888888935	-120.228305555555593	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
60834	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.4691666666666734	-120.681944444444397	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
60835	Port San Luis, California	NOS	9412110	35.1688055555555579	-120.754194444444494	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
60836	Mansfield Cone, California	NOS	9412802	35.9495277777777673	-121.481944444444494	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.73999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
60837	Monterey, Monterey Harbor, California	NOS	9413450	36.6049995422363281	-121.888053894042969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
60838	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.81829833984375	-121.747001647949219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough at Elkhorn	CA
60839	Tidal Creek, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413643	36.8333015441894531	-121.745002746582031	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tidal Creek, Elkhorn Slough	CA
60840	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.8413009643554688	-121.74530029296875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.95000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kirby Park, Elkhorn Slough	CA
60841	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.8566700000000012	-121.754999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.93000000000000327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
60842	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5024999999999977	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.98999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
60843	San Francisco, San Francisco Bay, California	NOS	9414290	37.8063055555555465	-122.465888888888898	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
60845	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.7899999999999991	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
60846	Hunters Point, San Francisco Bay, California	NOS	9414358	37.7299999999999969	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
60847	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.6649999999999991	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.77000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
60848	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.5799999999999983	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.10999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
60850	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067000000000021	-122.114999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
60851	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.5067777777777778	-122.211527777777803	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
60852	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.4650000000000034	-122.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.86999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
60853	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.6950000000000003	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92000000000000082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
60854	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717000000000027	-122.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38000000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
60855	Alameda, San Francisco Bay, California	NOS	9414750	37.7717000000000027	-122.299999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
60856	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.7950000000000017	-122.281999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
60857	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933000000000021	-122.314999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
60858	Sausalito, San Francisco Bay, California	NOS	9414806	37.8466999999999985	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
60859	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833000000000027	-121.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
60860	Berkeley, San Francisco Bay, California	NOS	9414816	37.8650016784667969	-122.306999206542969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BERKELEY,S.F.BAY	CA
60861	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865000000000002	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
60862	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.9230000000000018	-122.409583333333302	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
60863	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.9077796936035156	-122.678611755371094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
60864	Drakes Bay, Point Reyes, California	NOS	9415020	37.9961128234863281	-122.976669311523438	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
60865	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.9946944444444412	-121.419044444444395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.84000000000003183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
60866	Pinole Point, San Pablo Bay, California	NOS	9415056	38.0150000000000006	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
60867	Antioch, San Joaquin River, California	NOS	9415064	38.0200000000000031	-121.814999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
60868	Martinez-Amorco Pier, California	NOS	9415102	38.0346388888888924	-122.125194444444503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
60869	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.0500252777777774	-121.496855555555598	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
60870	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433000000000021	-121.918000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
60871	Crockett, Carquinez Strait, California	NOS	9415143	38.0583000000000027	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
60872	Port Chicago, Suisun Bay, California	NOS	9415144	38.0559999999999974	-122.039500000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
60873	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.0867000000000004	-121.685000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.75999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
60874	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.0700000000000003	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
60875	Korths Harbor, San Joaquin River, California	NOS	9415229	38.0976100000000031	-121.568382999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
60876	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.1153055555555582	-122.505666666666698	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
60877	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.128300000000003	-122.072999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.60999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
60878	Rio Vista, Sacramento River, California	NOS	9415316	38.1450000000000031	-121.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
60879	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567000000000007	-122.406999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
60880	Lakeville, Petaluma River, California	NOS	9415423	38.1983000000000033	-122.546999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
60881	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2282999999999973	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
60882	Green Cove, California	NOS	9416409	38.7043333333333308	-123.449388888888905	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
60883	Arena Cove, California	NOS	9416841	38.9145555555555589	-123.711083333333306	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.13999999999999702	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
60884	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.4257777777777818	-123.805111111111103	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2799999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
60885	Shelter Cove, California	NOS	9418024	40.0250015258789062	-124.057998657226562	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.30000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
60886	Cockrobin Island Bridge, Eel River, San Francisco, California	NOS	9418637	40.6371994018554688	-124.282203674316406	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.36999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cockrobin Island Bridge	CA
60887	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233000000000018	-124.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
60888	North Spit, Humboldt Bay, California	NOS	9418767	40.7663000000000011	-124.217200000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
60889	Samoa, Humboldt Bay, California	NOS	9418817	40.8267000000000024	-124.180000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
60891	Crescent City, California	NOS	9419750	41.7449999999999974	-124.183000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
60892	Pyramid Point, Smith River, California	NOS	9419945	41.9452500000000015	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.41999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
60893	Gold Beach, Rogue River, Oregon	NOS	9431011	42.4216388888888929	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.90999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
60894	Port Orford, Oregon	NOS	9431647	42.7389700000000019	-124.498277777565846	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
60895	Rink Creek Entrance, Coquille River, Oregon	NOS	9432436	43.1579017639160156	-124.181800842285156	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coquille River	OR
60896	Charleston, Coos Bay, Oregon	NOS	9432780	43.3449999999999989	-124.322000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
60897	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.6749999999999972	-124.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
60898	Reedsport, Umpqua River, Oregon	NOS	9433501	43.7083015441894531	-124.097999572753906	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.95000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEDSPORT	OR
60900	Florence USCG Pier, Suislaw River, Oregon	NOS	9434098	44.0021111111111125	-124.123000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Suislaw River	OR
60901	Waldport, Alsea Bay, Oregon	NOS	9434939	44.4343611111111088	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
60902	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5932999999999993	-124.007999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
60903	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.625	-124.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
60904	Depoe Bay, Oregon	NOS	9435827	44.8100000000000023	-124.058000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
60905	Chinook Bend, Siletz River, Oregon	NOS	9435992	44.8800010681152344	-123.963600158691406	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chinook Bend	OR
60906	Cascade Head, Salmon River, Oregon	NOS	9436381	45.0479444444444468	-124.007305555555604	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.60000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
60907	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4816999999999965	-123.902000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.30999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
60908	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.5545299999999997	-123.918944444391457	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
60909	North Jetty, Tillamook Bay, Oregon	NOS	9437585	45.5699996948242188	-123.964996337890625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27000000000000313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
60910	North Fork, Nehalem River, Oregon	NOS	9437954	45.7337989807128906	-123.87640380859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.44000000000000128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Fork	OR
60911	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.1242500000000035	-123.804333333333304	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
60912	Hammond, Oregon	NOS	9439011	46.2017000000000024	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
60913	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.2073099999999997	-123.768305555582046	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
60914	Wauna, Columbia River, Oregon	NOS	9439099	46.1616668701171875	-123.408889770507812	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
60915	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6966999999999999	-122.867999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.41999999999999971	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
60916	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8633000000000024	-122.796199999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
60917	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.509999999999998	-122.673000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
60918	Washougal, Columbia River, Washington	NOS	9440047	45.5783004760742188	-122.382003784179688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
60919	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.020301818847656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
60920	Vancouver, Columbia River, Washington	NOS	9440083	45.6316944444444417	-122.697000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.34999999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
60921	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.754997253417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
60922	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.9866981506347656	-122.836700439453125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
60923	Longview, Columbia River, Washington	NOS	9440422	46.1061388888888928	-122.954194444444397	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
60924	Cape Horn, Columbia River, Washington	NOS	9440482	46.1516990661621094	-123.290000915527344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.98999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
60925	Barlow Point, Columbia River, Washington	NOS	9440483	46.1521987915039062	-123.039199829101562	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
60926	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.2667000000000002	-123.451999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
60927	Cape Disappointment, Washington	NOS	9440581	46.2999992370605469	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
60928	Greenhead Slough, Washington	NOS	9440650	46.3722000122070312	-123.950302124023438	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
60929	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5016999999999996	-124.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
60930	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6632999999999996	-123.798000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
60931	Toke Point, Willapa Bay, Washington	NOS	9440910	46.7074700000000007	-123.96691666666004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.78000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
60932	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.9043100000000024	-124.105083333121399	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
60933	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9682999999999993	-123.852999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.60000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
60935	La Push, Quillayute River, Washington	NOS	9442396	47.9133333333333269	-124.636944444444396	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push, Quillayute River	WA
60936	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.1711006164550781	-124.736900329589844	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
60937	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.3702777999999967	-124.601944399999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
60938	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.263300000000001	-124.296999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
60939	Jim Creek, Washington	NOS	9443551	48.1871986389160156	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
60940	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.1247222222222319	-123.441138888888901	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
60941	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.1129000000000033	-122.759500000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
60942	Foulweather Bluff, Washington	NOS	9445016	47.9266999999999967	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
60943	Bangor Wharf, Washington	NOS	9445133	47.7483000000000004	-122.727000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
60944	Union, Hood Canal, Washington	NOS	9445478	47.3582999999999998	-123.097999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
60945	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.5616989135742188	-122.623001098632812	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BREMERTON	WA
60946	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.3782997131347656	-122.634002685546875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
60947	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.2666699999999977	-122.413333333333327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
60948	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.1799999999999997	-122.674999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
60949	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.1529998779296875	-122.675102233886719	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.61999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
60950	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983000000000018	-122.894999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
60951	Seattle, Puget Sound, Washington	NOS	9447130	47.602640000000001	-122.339305555555597	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
60952	Everett, Washington	NOS	9447659	47.9799999999999969	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
60953	Priest Point, Washington	NOS	9447717	48.0349444444444416	-122.227194444444507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
60954	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.0649999999999977	-122.287999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
60955	Greenbank, Whidbey Island, Washington	NOS	9447883	48.1049999999999969	-122.569999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
60956	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.3428001403808594	-122.685798645019531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.43999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
60957	Spee-Bi-Dah, Washington	NOS	9448009	48.0882500000000022	-122.322333333333304	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
60958	Tulare Beach, Port Susan, Washington	NOS	9448043	48.1068055555555532	-122.347277777777805	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4599999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
60959	Sneeoosh Point, Washington	NOS	9448576	48.3999999999999986	-122.548000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
60961	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.4150009155273438	-122.652000427246094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.63000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
60962	Turner Bay, Similk Bay, Washington	NOS	9448657	48.4450000000000003	-122.555000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
60963	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.4583015441894531	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.0400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
60964	Village Point, Lummi Island, Washington	NOS	9449161	48.716700000000003	-122.707999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.01000000000000068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
60965	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.8633000000000024	-122.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
60966	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.9749984741210938	-123.083000183105469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
60967	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917000000000016	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
60968	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
60969	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.6467018127441406	-122.870002746582031	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
60970	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5816999999999979	-123.170000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
60971	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.4850006103515625	-123.083000183105469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
60972	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.5453055555555579	-123.012888888888895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.55000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
60973	Upright Head, Lopez Island, Washington	NOS	9449911	48.5717010498046875	-122.885002136230469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
60974	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.5349999999999966	-122.796999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66000000000000103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
60975	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4466999999999999	-122.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
60976	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.805000305175781	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
60977	Windy Cove entrance, Alaska	NOS	9450251	55.0354000000000028	-133.023799999999994	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
60998	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2766999999999982	-132.985000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
61048	Seward, Resurrection Bay, Alaska	NOS	9455090	60.1199999999999974	-149.426666699999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
60978	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0878999999999976	-132.815830000000005	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
60979	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1000000000000014	-131.217000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
60980	Metlakatla, Port Chester, Alaska	NOS	9450314	55.128300000000003	-131.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
60981	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.2016983032226562	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
60982	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.3318299999999965	-131.62619444423251	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
60983	Trocadero Bay, Alaska	NOS	9450463	55.3516666666666666	-132.938055555555593	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
60984	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883000000000024	-133.141999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
60986	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.601700000000001	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.20999999999999908	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
60987	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.6289999999999978	-131.362694000000005	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.14999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
60988	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.7216666666666569	-133.349999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
60989	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.7882833333333323	-132.190883333333403	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
60990	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0382999999999996	-131.094999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
60991	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1182999999999979	-132.078000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
60992	El Capitan Passage, Alaska	NOS	9450997	56.1632999999999996	-133.330000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
60993	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1632999999999996	-133.413000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
60994	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783000000000001	-132.697000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
60995	Bradfield Canal, Alaska	NOS	9451012	56.1833000000000027	-131.572000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
60996	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.2199999999999989	-132.296999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
60997	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.246699999999997	-134.646999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
60999	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3532999999999973	-132.552999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
61000	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922000000000025	-132.169000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
61001	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.4699999999999989	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
61002	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.5349999999999966	-133.766999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
61003	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583000000000027	-132.962999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.72999999999999865	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
61004	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.5949999999999989	-132.986999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.90000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
61005	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.638300000000001	-132.926999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.19999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
61006	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6766999999999967	-132.932999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.54000000000000092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
61007	The Summit, Keku Strait, Alaska	NOS	9451349	56.6824222222222218	-133.736908333333304	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
61008	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867000000000033	-135.393000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
61009	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7882999999999996	-132.50200000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
61010	Turn Point, Alaska	NOS	9451434	56.7999999999999972	-132.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
61011	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117000000000019	-133.787000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
61012	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8566999999999965	-134.723000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.78999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
61013	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.9033333333333431	-134.303055555555602	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
61014	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.9483055555555566	-133.894722222222214	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.50999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
61015	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.0516944444444434	-135.342000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29000000000000092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
61016	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.0883333333333312	-134.824999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
61017	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.31999999999999673	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
61018	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.2950000000000017	-133.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
61019	Scraggy Island, Alaska	NOS	9451805	57.3400000000000034	-135.706999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
61020	Sergius Narrows, Alaska	NOS	9451853	57.4099999999999966	-135.62700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
61021	Provorotni Island, Alaska	NOS	9451936	57.5150000000000006	-135.555000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
61022	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.533299999999997	-134.417000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
61023	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2982999999999976	-134.412000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
61024	Hawk Inlet Entrance, Alaska	NOS	9452294	58.0850000000000009	-134.776999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
61025	False Bay, Chatham Strait, Alaska	NOS	9452328	57.966700000000003	-134.935000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
61026	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.4500000000000028	-135.326999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway, Taiya Inlet	AK
61027	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.1700000000000017	-135.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
61028	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.1075555555555567	-135.444194444444406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.91000000000000369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
61030	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.9577777777777783	-136.226777777777812	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
61031	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.1947199999999967	-136.346944444444432	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
61032	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.9647777777777833	-136.877583333333291	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.78000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
61033	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5484999999999971	-139.733399999999989	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.30000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
61034	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5583000000000027	-145.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.73999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
61035	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.361999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
61036	Perch Point, Montague Island, Alaska	NOS	9454561	60.1266999999999996	-147.39500000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
61037	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.402999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
61038	Seal Island, Alaska	NOS	9454564	60.4249999999999972	-147.409999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
61040	Montague Island, Alaska	NOS	9454616	60.0249999999999986	-147.592000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
61041	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667000000000016	-147.699999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
61042	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
61043	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.4750000000000014	-147.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
61044	South Bay, Perry Island, Alaska	NOS	9454721	60.6717000000000013	-147.931999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
61045	Guguak, Alaska	NOS	9454751	60.1000000000000014	-148.038000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
61046	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9382999999999981	-148.227000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6800000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
61049	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.773299999999999	-149.587999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
61050	Aialik Bay, north end, Alaska	NOS	9455145	59.9532999999999987	-149.715000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.53000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
61051	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.884999999999998	-149.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
61052	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933000000000007	-149.74799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
61053	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7132999999999967	-149.787000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
61054	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.7899999999999991	-150.032000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
61055	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.4405277777777812	-151.719944444444508	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
61056	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.4683055555555526	-151.564999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.61999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
61057	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.7250000000000014	-151.022999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
61058	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.7719722222222316	-151.867027777777793	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
61059	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.0549999999999997	-151.681999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.2799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
61060	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367000000000004	-151.379999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
61061	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.5116996765136719	-151.951995849609375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.1699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
61062	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.503300000000003	-151.282999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
61063	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.6833055555555632	-151.397999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.2900000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
61064	Point Possession, Alaska	NOS	9455866	61.0367000000000033	-150.413000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.2600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
61065	North Foreland, Alaska	NOS	9455869	61.0433055555555626	-151.163000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.5000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
61066	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1732999999999976	-150.212999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
61067	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2374999999999972	-149.8904	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.4699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
61068	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2682991027832031	-149.917007446289062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
61069	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933000000000035	-149.847000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
61070	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917000000000002	-153.957999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
61071	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.2899999999999991	-154.27000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
61072	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217000000000013	-152.49799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
61073	Kodiak, Women's Bay, Alaska	NOS	9457292	57.7302777777777791	-152.513888888888914	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
61074	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283000000000001	-152.812000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
61075	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.8734722222222189	-152.867111111111086	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.78999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
61077	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9782999999999973	-152.925000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
61078	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.7440277777777808	-153.195472222222207	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
61079	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.9657199999999975	-153.252194000000003	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.34000000000000341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
61080	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.2027777777777828	-153.303888888888906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.43000000000000327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
61081	West Raspberry Island, Alaska	NOS	9457535	58.1071666666666573	-153.340111111111099	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.35000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
61082	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.9600000000000009	-153.687000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
61083	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.533299999999997	-153.990000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.14000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
61084	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.5946939999999969	-153.996027999999995	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
61086	Alitak, Lazy Bay, Alaska	NOS	9457804	56.8973999999999975	-154.24799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.17999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
61087	Puale Bay, Alaska	NOS	9458209	57.7066999999999979	-155.393000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
61088	Chirikof Island, Alaska	NOS	9458293	55.8083000000000027	-155.740000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
61089	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0516999999999967	-156.698000000000008	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
61091	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2316999999999965	-158.347000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
61092	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133000000000024	-158.598000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
61093	Mitrofania Island, Alaska	NOS	9459016	55.8900000000000006	-158.819999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
61094	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.0655555555555623	-159.418666666666695	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
61095	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.835222222222221	-159.759555555555607	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
61096	Sand Point, Popof Island, Alaska	NOS	9459450	55.3366944444444471	-160.50200000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
61097	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.3349990844726562	-160.61700439453125	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.96999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
61098	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.1217002868652344	-161.792007446289062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
61099	King Cove, Deer Passage, Alaska	NOS	9459881	55.0598888888888922	-162.326111111111089	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
61100	Cold Bay, Alaska	NOS	9459949	55.2083000000000013	-162.698000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
61101	Attu, Massacre Bay, Alaska	NOS	9460150	52.8400000000000034	173.194999999999993	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Station 9460150 Massacre Bay, Attu Island is a historic station with tidal\nharmonic constants and tidal datums based upon a 06/1943 - 06/1944\ninstallation. Due to the remote nature of this area, there are no plans to\ncollect updated water level values in the vicinity of Attu Island, AK.  During\nthe 1943-1944 installation of this station NOAA was able to obtain and compute\na full suite of harmonic constants.  Therefore, this station is used as a\ncontrol station for predictions at other subordinate harmonic stations in the\nfar western Aleutian Islands.In order to provide tidal predictions\n(http://tidesandcurrents.noaa.gov/tide_predictions.shtml) for this station and\nits subordinate stations, it is necessary to provide the separation between\nMean Sea Level (MSL) and Mean Lower Low Water (MLLW) only.Therefore, MSL has\nbeen held fixed as station datum and MLLW referenced to MSL in order to remove\nany reference to the terrestrial system.  The removal of a terrestrial\nreference frame enables the relationship between MSL and MLLW to remain\nconsistent over time and not require a periodic National Tidal Datum Epoch\n(NTDE) update to accountant for sea level rise.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.93999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
61102	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.8633055555555629	-176.632000000000005	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
61103	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.2319999999999993	-174.172599999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.96999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
61104	Nikolski, Umnak Island, Alaska	NOS	9462450	52.9406099999999995	-168.871305555767492	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
61105	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.8791944444444368	-166.540305555555591	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07999999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
61106	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.8289166666666716	-166.216250000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
61107	Reef Bight, Alaska	NOS	9462662	54.1307222222222322	-166.099333333333306	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
61108	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.0645833333333314	-165.937055555555588	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.17999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
61109	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.1332777777777778	-165.777305555555614	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.15999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
61110	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.1102777777777817	-165.661388888888894	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
61111	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.1508333333333312	-165.615000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
61112	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2332999999999998	-165.532999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
61113	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.1400000000000006	-165.526999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
61114	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.0522222222222197	-165.514166666666711	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
61115	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.1199999999999974	-164.977000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
61116	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.1018055555555577	-164.941583333333313	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.96000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
61117	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6000000000000014	-164.927999999999997	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.97999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
61118	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.3936388888888871	-164.745722222222213	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
61119	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.0642777777777823	-163.534166666666692	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.28999999999999204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
61120	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.966700000000003	-163.439999999999998	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
61121	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8582999999999998	-163.407000000000011	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.44000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
61122	Isanotski Strait Entrance, Aleutian Islands, Alaska	NOS	9462961	54.7784444444444532	-163.364277777777801	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
61123	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.985694444444448	-160.573888888888888	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.83000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
61125	Village Cove, St. Paul Island, Bering Sea, Alaska	NOS	9464212	57.1253055555555633	-170.285166666666697	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.96000000000000019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
61127	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.711999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
61170	Point Hope, Alaska	NOS	9491873	68.341700000000003	-166.807999999999993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.329999999999999627	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
61133	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483000000000018	-158.551999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
61136	Snag Point, Dillingham, Alaska	NOS	9465374	59.0399999999999991	-158.447000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
61137	Platinum, Alaska	NOS	9465396	59.0467000000000013	-161.818000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83999999999999631	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum, AK	AK
61138	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.3780166666666673	-162.029333333333312	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
61139	Quinhagak (Kwinak), Kushkokwin River, Alaska	NOS	9465831	59.7505527777777772	-161.915436111111092	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.44999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
61140	Kinak Bay, Alaska	NOS	9465953	59.9475279999999984	-164.210700000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
61141	Eastern Nunivak Island, Alaska	NOS	9466012	60.0429400000000015	-165.680583000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.77000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
61142	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.1232777777777798	-162.50036111111109	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
61143	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.2703018188476562	-162.410202026367188	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
61144	Mekoryuk, Mekoryuk River Entrance, Alaska	NOS	9466217	60.4166999999999987	-166.167000000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.86999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
61145	Tooksook Bay, Nelson Island, Alaska	NOS	9466298	60.5167000000000002	-165.13300000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
61146	Lomavik, Alaska	NOS	9466328	60.5542984008789062	-162.297103881835938	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
61147	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.7999999999999972	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
61148	Dall Point, Hooper Bay, Alaska	NOS	9466931	61.5317000000000007	-166.147999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.83999999999999631	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
61149	Nunam Iqua (Sheldon Point), Alaska	NOS	9467551	62.5329444444444533	-164.845277777777795	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
61150	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3166999999999973	-168.967000000000013	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
61131	Hagemeister Island (north end), Alaska	NOS	9465234	58.7766999999999982	-160.776999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
61152	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.679083333333331	-170.537111111111102	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
61154	Unalakleet, Alaska	NOS	9468333	63.875	-160.788000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
61155	Shaktoolik, Alaska	NOS	9468691	64.3802222222222156	-161.235138888888912	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
61156	Nome, Norton Sound, Alaska	NOS	9468756	64.4946111111111122	-165.439638888888908	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
61157	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.256699999999995	-166.847000000000008	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.729999999999999538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
61158	Teller, Port Clarence, Alaska	NOS	9469239	65.2667000000000002	-166.353000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.599999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
61159	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.3900000000000006	-167.14500000000001	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
61160	Tin City, Bering Sea, Alaska	NOS	9469439	65.5583333333333371	-167.974999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.469999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
61161	Outside Lopp Lagoon, Alaska	NOS	9469515	65.7288060000000058	-168.032139000000001	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000003979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
61162	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.0971666666666664	-162.740472222222195	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.949999999999999289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
61163	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.2303009033203125	-163.904098510742188	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000002558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
61164	Shishmaref Inlet 2, Alaska	NOS	9469854	66.263300000000001	-166.02000000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.510000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
61165	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.5856944444444423	-164.250833333333304	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.530000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
61166	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017000000000053	-162.581999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
61167	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.0541944444444482	-163.321277777777794	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.230000000000003979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
61168	Red Dog Dock, Alaska	NOS	9491094	67.5758055555555615	-164.064388888888914	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.439999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
61169	Kivalina, Alaska	NOS	9491253	67.7266999999999939	-164.592000000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.440000000000000391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
61171	Barrow (offshore), Alaska	NOS	9494935	71.3601111111111095	-156.729861111111092	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000002274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
61172	Prudhoe Bay, Alaska	NOS	9497645	70.4114166666666677	-148.531777777777791	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999996305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
61175	Barter Island, Alaska	NOS	9499176	70.1285555555555504	-143.611027777777792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.280000000000000249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
61176	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.3676111111111098	-64.7207222222222214	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
61177	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.75	-64.7049999999999983	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
61178	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.3482999999999983	-64.716700000000003	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.419999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
61179	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.318249999947021	-64.7242222224341504	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.399999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
61180	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.6947222222222216	-64.7538055555555587	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000004547	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lime Tree Bay. St. Croix	VI
61181	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.3606666666666705	-64.8035277777777736	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.489999999999998437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
61182	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.2971388888888917	-64.8177500000000038	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
61184	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.3489444444444487	-64.8641666666666623	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.559999999999998721	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
61185	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133000000000003	-64.8833000000000055	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
61186	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.3358333333333299	-64.9200000000000017	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
61187	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.3712499999999999	-64.9634722222222223	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.579999999999998295	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
61188	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3632999999999988	-65.0349999999999966	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.59000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
61189	Culebra, Puerto Rico	NOS	9752235	18.3008611111111108	-65.3024722222222209	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
61190	Isabel Segunda, Vieques Island, Puerto Rico	NOS	9752619	18.1525277777777809	-65.4438055555555565	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
61217	Waianae, Oahu Island, Hawaii	NOS	1612482	21.4450000000000003	-158.192000000000007	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:18:00	\N	1	00:20:00	\N	0.930000000000000049	\N	\N	Waianae	HI
61218	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5982999999999983	-158.108000000000004	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-02:05:00	\N	0.800000000000000044	-01:02:00	\N	0.800000000000000044	\N	\N	Haleiwa, Waialua Bay	HI
61219	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483000000000011	-156.87700000000001	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:16:00	0	\N	-00:37:00	0.100000000000000006	\N	\N	\N	Kamalo Harbor	HI
61220	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0716999999999999	-156.800000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:48:00	0	\N	-01:03:00	0.100000000000000006	\N	\N	\N	Pukoo Harbor	HI
61191	Esperanza, Vieques Island, Puerto Rico	NOS	9752695	18.0938611111111101	-65.4713611111111078	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.390000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
61192	Isla Palominos, Puerto Rico	NOS	9752962	18.3449722222222213	-65.569500000000005	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
61193	Fajardo, Puerto Rico	NOS	9753216	18.335222222222221	-65.6311111111111103	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
61194	Naguabo, Puerto Rico	NOS	9753641	18.1870555555555597	-65.7113888888888908	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
61195	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.0550833333333287	-65.8329999999999984	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.349999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
61196	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.4591666666666683	-66.116388888888892	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
61197	Las Mareas, Puerto Rico	NOS	9755679	17.9283000000000001	-66.158299999999997	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
61198	Santa Isabel, Puerto Rico	NOS	9756639	17.9549999999999983	-66.4067000000000007	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.359999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
61199	Arecibo, Puerto Rico	NOS	9757809	18.4805277777777803	-66.7023611111111165	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
61200	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.9725277777777812	-66.7617777777777803	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.350000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
61201	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.9699999999999989	-67.0463888999999966	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
61202	Puerto Real, Puerto Rico	NOS	9759189	18.0748055555555602	-67.1887777777777728	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.420000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
61203	Baha Salinas, Puerto Rico	NOS	9759197	17.9514444444444408	-67.1965833333333364	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.320000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
61204	Mayagez, Puerto Rico	NOS	9759394	18.2188888888888911	-67.1624999999999943	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
61205	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.4566388888888895	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla, Crashboat Beach	PR
61206	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.1649999999999991	-67.1817000000000064	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999999805	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJABO, MAYAGUES	PR
61207	Mona Island, Puerto Rico	NOS	9759938	18.0899166668785902	-67.9385000001059609	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
60677	Hawkins Recreational Park, Blackwater River, Florida	NOS	8729753	30.6367000000000012	-87.0283000000000015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000515	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAWKINS REC. PARK, BLACKWATER RIVER	FL
60899	Cushman, Suislaw River, Oregon	NOS	9434068	43.9850006103515625	-124.044998168945312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.93999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cushman	OR
60175	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.3200000000000003	-69.7702799999999996	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.900000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
60249	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2282999999999973	-71.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
60263	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0716999999999999	-71.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
60267	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.0349999999999966	-72.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
60305	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.783299999999997	-73.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
60317	Spuyten Duyvil Creek Entrance, Hudson River, New York	NOS	8518903	40.878300000000003	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
60318	Riverdale, Hudson River, New York	NOS	8518905	40.9033000000000015	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
60385	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867000000000033	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.869999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
60411	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia	NOS	8632366	37.263300000000001	-76.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
60424	New Point, Virginia	NOS	8637289	37.3466999999999985	-76.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.849999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
60425	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567000000000021	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
60431	Burwell Bay, James River, Virginia	NOS	8638421	37.0566999999999993	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
60495	Savannah (Bull Street), Georgia	NOS	8670681	32.0816999999999979	-81.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.30999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
60517	Cut 2N front range, St. Marys River, Florida	NOS	8720012	30.7166999999999994	-81.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.97999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	FL
60552	Daytona Beach (ocean), Florida	NOS	8721020	29.2283000000000008	-81.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
60559	Canaveral Harbor Entrance, Florida	NOS	8721608	28.4083000000000006	-80.6016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
60569	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.5482997894287109	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.30000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
60666	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.6900000000000013	-85.3632999999999953	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
60675	Upper Blackwater River, Florida	NOS	8729738	30.6583000000000006	-86.9882999999999953	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.569999999999999951	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER BLACKWATER RIVER	FL
60720	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4182999999999986	-88.9249999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.729999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
60721	Tchoutacabouffa River Entrance, Mississippi	NOS	8744663	30.4417000000000009	-88.9732999999999947	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.790000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
60735	Venice, Grand Pass, Louisiana	NOS	8760849	29.273299999999999	-89.3516999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.330000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
60743	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.254999999999999	-89.9682999999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.510000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
60762	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717000000000006	-91.3850000000000051	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
60786	Sabine (offshore), Texas	NOS	8771081	29.4983000000000004	-93.6400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.28000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	TX
60844	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.8100000000000023	-122.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.2200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT [PIER 41] S.F.BAY	CA
60849	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.533299999999997	-122.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
60890	Requa Dock, California	NOS	9419551	41.5450000000000017	-124.069999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Requa Dock	CA
60934	Taholah, Washington	NOS	9441644	47.3481700000000032	-124.284750000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
60960	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4132999999999996	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.95000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
60985	Big Salt Lake, Alaska	NOS	9450623	55.6000000000000014	-132.949999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.44999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Salt Lake	AK
61029	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9132999999999996	-136.108000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
61039	Storey Island (north side), Alaska	NOS	9454571	60.7316999999999965	-147.437000000000012	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
61076	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394000000000034	-152.874719999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
61085	Uyak, Uyak Bay, Alaska	NOS	9457728	57.634999999999998	-154.007000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
61090	Sutwik Island, West End, Alaska	NOS	9458665	56.5399999999999991	-157.326999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
61124	Zapadni Bay, St. George Island, Alaska	NOS	9463885	56.5700000000000003	-169.699999999999989	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZAPADNI BAY, ST. GEORGE ISLAND	AK
61126	Cape Constantine, Nushagak Peninsula, Alaska	NOS	9464961	58.5216939999999965	-159.151999999999987	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.65000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CONSTANTINE, NUSHAGAK PENINSULA	AK
61128	Pyrite Point, Bristol Bay, Alaska	NOS	9465123	58.6199999999999974	-161.542000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PYRITE POINT, BRISTOL BAY	AK
61129	High Island, Bristol Bay, Alaska	NOS	9465173	58.7216939999999994	-160.426999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HIGH ISLAND, BRISTOL BAY	AK
61130	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.7083000000000013	-160.187999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK ROCK, WALRUS IS BRISTOL B	AK
61132	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083000000000027	-161.099999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.95000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
61134	Kulukak Point, Alaska	NOS	9465265	58.8400000000000034	-159.646999999999991	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.53000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KULUKAK POINT	AK
61151	St. Michael, Norton Sound, Alaska	NOS	9468132	63.4750000000000014	-162.026999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.6399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
61153	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7184999999999988	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
61173	Prudhoe Bay #2, Alaska	NOS	9497649	70.388300000000001	-148.509999999999991	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.349999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
61174	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4916999999999945	-147.949999999999989	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
61183	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.3200000000000003	-64.8700000000000045	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.369999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
60497	Palmer Johnson Shipyard, Wilmington River, Georgia	NOS	8670893	32.023299999999999	-81.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.97999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PALMER JOHNSON SHIPYARD, WILMINGTON R.	GA
61135	Summit Island, NE side, Togiak Bay, Alaska	NOS	9465283	58.8466999999999985	-160.210000000000008	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE SIDE SUMMIT ISLAND, TOGIAK BAY A	AK
61208	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.870000000000001	-160.235000000000014	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:11:00	\N	0.770000000000000018	-00:16:00	\N	0.770000000000000018	\N	\N	Nonopapa, Niihau Island	HI
61209	Port Allen, Hanapepe Bay, Kauai Island, Hawaii (sub)	NOS	1611347	21.9033000000000015	-159.592000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	-00:10:00	\N	1	-00:15:00	\N	1.01000000000000001	\N	\N	Port Allen, Hanapepe Bay	HI
61210	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567000000000014	-159.673000000000002	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	00:18:00	\N	0.910000000000000031	00:07:00	\N	0.859999999999999987	\N	\N	Waimea Bay	HI
61211	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995000000000001	-159.335000000000008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	00:04:00	\N	0.910000000000000031	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
61212	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.2149999999999999	-159.50200000000001	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60136	-01:22:00	\N	0.910000000000000031	-01:01:00	\N	1.07000000000000006	\N	\N	Hanalei Bay	HI
61213	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.2749999999999986	-157.697000000000003	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
61214	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii (sub)	NOS	1612366	21.3299999999999983	-157.967000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:06:00	\N	0.880000000000000004	00:15:00	\N	1	\N	\N	Pearl Harbor Entrance, Bishop Point	HI
61215	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.3350000000000009	-157.693000000000012	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	00:05:00	\N	0.75	00:11:00	\N	0.880000000000000004	\N	\N	Waimanalo	HI
61216	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii (sub)	NOS	1612404	21.3683000000000014	-157.939999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:08:00	\N	0.880000000000000004	00:16:00	\N	1.03000000000000003	\N	\N	Pearl Harbor, Ford Island Ferry	HI
61221	Kaunakakai Harbor, Molokai Island, Hawaii (sub)	NOS	1613198	21.0850000000000009	-157.032000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:14:00	\N	1.25	-00:10:00	\N	1.12999999999999989	\N	\N	Kaunakakai	HI
61222	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0932999999999993	-157.197000000000003	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
61223	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.7899999999999991	-156.995000000000005	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:03:00	0	\N	00:02:00	0.200000000000000011	\N	\N	\N	Kaumalapau, Lanai Island	HI
61224	Makena, Maui Island, Hawaii	NOS	1615202	20.6567000000000007	-156.444999999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:09:00	\N	0.540000000000000036	01:21:00	\N	0.729999999999999982	\N	\N	Makena	HI
61225	Hana, Maui Island, Hawaii	NOS	1615395	20.7617000000000012	-155.986999999999995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	00:18:00	\N	0.540000000000000036	00:40:00	\N	1.05000000000000004	\N	\N	Hana	HI
61226	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.5949999999999989	-156.606999999999999	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	-00:09:00	0	\N	-00:09:00	0.200000000000000011	\N	\N	\N	Kuheia Bay	HI
61227	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1866999999999983	-155.902999999999992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:42:00	\N	0.67000000000000004	00:38:00	\N	0.800000000000000044	\N	\N	Mahukona	HI
61228	Kawaihae, Hawaii Island, Hawaii (sub)	NOS	1617433	20.0366	-155.829399999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:57:00	\N	0.599999999999999978	01:01:00	\N	0.82999999999999996	\N	\N	Kawaihae	HI
61229	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:37:00	\N	0.67000000000000004	00:38:00	\N	0.800000000000000044	\N	\N	Kailua Kona	HI
61230	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.476700000000001	-155.921999999999997	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:47:00	\N	0.67000000000000004	00:48:00	\N	0.800000000000000044	\N	\N	Napoopoo, Kealakekua Bay	HI
61231	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883000000000003	-155.552999999999997	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60144	00:33:00	\N	1	00:38:00	\N	1.01000000000000001	\N	\N	Honuapo	HI
61232	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.7833000000000006	-166.207999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:08:00	\N	0.729999999999999982	00:03:00	\N	0.729999999999999982	\N	\N	East Island, French Frigate Shoals	HI
61233	Laysan Island, Hawaii	NOS	1619645	25.7667000000000002	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	01:12:00	\N	0.5	01:02:00	\N	0.530000000000000027	\N	\N	Laysan Island	HI
61234	Coffin Point, Coffin Neck, Maine (sub)	NOS	8410714	44.8699999999999974	-67.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	00:33:00	\N	0.770000000000000018	00:31:00	\N	0.939999999999999947	\N	\N	Coffins Point	ME
61235	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine (sub)	NOS	8410715	44.9232999999999976	-67.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	00:14:00	\N	1	00:11:00	\N	1.04000000000000004	\N	\N	Garnet Point, Pennamquan River	ME
61236	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	01:13:00	\N	0.75	00:59:00	\N	0.939999999999999947	\N	\N	Birch Islands	ME
61237	Cutler (Farris Wharf), Little River, Maine (sub)	NOS	8411060	44.6570281982421875	-67.2046661376953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:19:00	\N	0.739999999999999991	-00:10:00	\N	0.739999999999999991	\N	\N	Cutler, Little River	ME
61238	Cutler Naval Base, Machias Bay, Maine (sub)	NOS	8411250	44.6417000000000002	-67.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:15:00	\N	0.699999999999999956	-00:06:00	\N	0.699999999999999956	\N	\N	Cutler, Naval Radio Station	ME
61239	Stone Island, Machias Bay, Maine	NOS	8411411	44.6032999999999973	-67.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:28:00	\N	0.680000000000000049	-00:11:00	\N	0.680000000000000049	\N	\N	Stone Island, Machias Bay	ME
61240	Machiasport, Machias River, Maine	NOS	8411467	44.6983000000000033	-67.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:09:00	\N	0.689999999999999947	00:01:00	\N	0.689999999999999947	\N	\N	Machiasport, Machias River	ME
61241	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615000000000002	-67.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60154	-00:13:00	\N	0.660000000000000031	-00:05:00	\N	0.660000000000000031	\N	\N	Shoppee Point, Englishman Bay	ME
61242	Steele Harbor Island, Maine	NOS	8411801	44.4932999999999979	-67.5433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:20:00	\N	1.27000000000000002	-00:28:00	\N	1.27000000000000002	\N	\N	Steele Harbor Island	ME
61243	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.371699999999997	-67.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:24:00	\N	1.15999999999999992	-00:28:00	\N	1.15999999999999992	\N	\N	Green Island, Petit Manan Bar	ME
61244	Milbridge, Narraguagus River, Maine (sub)	NOS	8412581	44.5399999999999991	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:05:00	\N	1.09000000000000008	-00:15:00	\N	1.22999999999999998	\N	\N	Millbridge, Narraguagus River, Maine	ME
61245	Prospect Harbor, Maine	NOS	8412932	44.3999999999999986	-68.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:15:00	\N	1.14999999999999991	-00:24:00	\N	1.14999999999999991	\N	\N	Prospect Harbor	ME
61246	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.388300000000001	-68.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.949999999999999956	-00:01:00	\N	0.949999999999999956	\N	\N	Winter Harbor, Frenchman Bay	ME
61247	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.2749999999999986	-68.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.949999999999999956	00:00:00	\N	0.959999999999999964	\N	\N	Southwest Harbor	ME
61248	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417000000000016	-68.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.930000000000000049	00:04:00	\N	0.930000000000000049	\N	\N	Bass Harbor	ME
61249	Ellsworth, Union River, Blue Hill Bay, Maine (sub)	NOS	8413801	44.5349999999999966	-68.4217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:16:00	\N	0.969999999999999973	00:15:00	\N	1	\N	\N	Ellsworth, Union River	ME
61250	Mackerel Cove, Swans Island, Blue Hill Bay, Maine (sub)	NOS	8413825	44.1700000000000017	-68.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.930000000000000049	00:02:00	\N	0.939999999999999947	\N	\N	Mackerel Cove	ME
61251	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.1450000000000031	-68.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	0.880000000000000004	-00:01:00	\N	0.890000000000000013	\N	\N	Burnt Coat Harbor, Swans Island	ME
61252	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.408299999999997	-68.5632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	0.949999999999999956	00:09:00	\N	0.949999999999999956	\N	\N	Blue Hill Harbor	ME
61253	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.263300000000001	-68.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:12:00	\N	0.949999999999999956	00:09:00	\N	0.949999999999999956	\N	\N	Center Harbor	ME
61254	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733000000000033	-68.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.880000000000000004	-00:01:00	\N	0.869999999999999996	\N	\N	Isle Au Haut	ME
61255	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533000000000015	-68.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	0.900000000000000022	00:08:00	\N	0.910000000000000031	\N	\N	Stonington, Deer Isle	ME
61256	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2916999999999987	-68.6932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:14:00	\N	0.930000000000000049	00:16:00	\N	0.939999999999999947	\N	\N	Little Deer Isle	ME
61257	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367000000000033	-68.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.979999999999999982	-00:06:00	\N	0.989999999999999991	\N	\N	Gross Point, Eastern Channel	ME
61258	Bangor, Penobscot River, Maine (sub)	NOS	8414612	44.7849999999999966	-68.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:18:00	\N	0.869999999999999996	-00:06:00	\N	1.25	\N	\N	Bangor	ME
61259	Castine, Penobscot Bay, Maine	NOS	8414672	44.3866999999999976	-68.7967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	1	00:15:00	\N	0.949999999999999956	\N	\N	Castine	ME
61260	Bucksport, Penobscot River, Maine	NOS	8414684	44.5716999999999999	-68.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:11:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Bucksport	ME
61261	Sandy Point, Penobscot River, Maine	NOS	8414692	44.5050000000000026	-68.8050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:08:00	\N	0.979999999999999982	00:06:00	\N	0.989999999999999991	\N	\N	Sandy Point	ME
61262	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433000000000021	-68.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.880000000000000004	00:09:00	\N	0.869999999999999996	\N	\N	Vinalhaven, Vinalhaven Island	ME
61263	Winterport, Penobscot River, Maine	NOS	8414781	44.6366999999999976	-68.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:04:00	\N	0.92000000000000004	-00:09:00	\N	1.1100000000000001	\N	\N	Winterport	ME
61264	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1266999999999996	-68.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:10:00	\N	0.900000000000000022	00:13:00	\N	0.910000000000000031	\N	\N	North Haven	ME
61265	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.861699999999999	-68.881699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	-00:27:00	\N	0.849999999999999978	00:05:00	\N	0.849999999999999978	\N	\N	Matinicus Harbor, Wheaton Island	ME
61266	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4266999999999967	-69.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:04:00	\N	1.03000000000000003	00:09:00	\N	0.969999999999999973	\N	\N	Belfast	ME
61267	Rockland, Penobscot River, Maine (sub)	NOS	8415490	44.1049999999999969	-69.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60162	00:06:00	\N	1.03000000000000003	00:09:00	\N	0.930000000000000049	\N	\N	Rockland	ME
61268	Thomaston, St. George River, Maine (sub)	NOS	8415709	44.0716999999999999	-69.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	1.03000000000000003	-00:04:00	\N	1.03000000000000003	\N	\N	Thomaston	ME
61269	Tenants Harbor, Maine	NOS	8415809	43.9650000000000034	-69.216700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:11:00	\N	1.02000000000000002	-00:11:00	\N	1.02000000000000002	\N	\N	Tenants Harbor	ME
61270	Otis Cove, St. George River, Maine	NOS	8415867	43.986699999999999	-69.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
61271	Port Clyde, St. George River, Maine	NOS	8415933	43.9249999999999972	-69.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:07:00	\N	0.979999999999999982	-00:11:00	\N	0.979999999999999982	\N	\N	Port Clyde	ME
61272	Burnt Island, Georges Islands, Maine	NOS	8416028	43.871699999999997	-69.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:12:00	\N	0.979999999999999982	-00:13:00	\N	0.979999999999999982	\N	\N	Burnt Island, Georges Islands	ME
61273	Monhegan Island, Maine	NOS	8416092	43.7650000000000006	-69.321700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:09:00	\N	0.969999999999999973	-00:13:00	\N	0.969999999999999973	\N	\N	Monhegan Island	ME
61274	Friendship Harbor, Maine	NOS	8416141	43.9699999999999989	-69.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:11:00	\N	0.989999999999999991	-00:18:00	\N	0.989999999999999991	\N	\N	Friendship Harbor	ME
61275	Waldoboro, Medomak River, Maine	NOS	8416224	44.0932999999999993	-69.3766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	1.04000000000000004	-00:16:00	\N	1.04000000000000004	\N	\N	Waldoboro	ME
61276	Jones Neck, Medomak River, Maine	NOS	8416232	44.0150000000000006	-69.3799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
61277	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.966700000000003	-69.4416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.989999999999999991	-00:09:00	\N	0.989999999999999991	\N	\N	Muscongus Harbor, Muscongus Sound	ME
61278	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.969999999999999973	-00:10:00	\N	0.969999999999999973	\N	\N	New Harbor, Muscongus Bay	ME
61279	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8766999999999996	-69.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.969999999999999973	-00:05:00	\N	0.969999999999999973	\N	\N	Pemaquid Harbor, Johns Bay	ME
61280	Newcastle, Damariscotta River, Maine	NOS	8416608	44.033299999999997	-69.5366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:25:00	\N	1.02000000000000002	00:16:00	\N	1.02000000000000002	\N	\N	Newcastle	ME
61281	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865000000000002	-69.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	East Boothbay	ME
61282	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7582999999999984	-69.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:10:00	\N	0.969999999999999973	-00:09:00	\N	0.969999999999999973	\N	\N	Damariscove Harbor, Damariscove Island	ME
61283	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.0499999999999972	-69.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:20:00	\N	1.05000000000000004	00:20:00	\N	1.05000000000000004	\N	\N	Sheepscot (below rapids)	ME
61284	Boothbay Harbor, Maine	NOS	8416828	43.8500000000000014	-69.6282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.969999999999999973	-00:06:00	\N	0.969999999999999973	\N	\N	Boothbay Harbor	ME
61285	Southport, Townsend Gut, Maine	NOS	8416908	43.8466999999999985	-69.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.979999999999999982	00:01:00	\N	0.979999999999999982	\N	\N	Southport, Townsend Gut	ME
61286	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1.03000000000000003	00:16:00	\N	1.03000000000000003	\N	\N	Wiscasset	ME
61287	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.9249999999999972	-69.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
61288	Back River, Sheepscot River, Maine	NOS	8416961	43.9583000000000013	-69.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
61289	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.8599999999999994	-69.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	Isle of Springs	ME
61313	Cow Island, Casco Bay, Maine	NOS	8418009	43.6899999999999977	-70.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
61290	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8532999999999973	-69.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:14:00	\N	0.969999999999999973	00:14:00	\N	0.969999999999999973	\N	\N	Robinhood, Sasanoa River	ME
61291	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8866999999999976	-69.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:43:00	\N	0.969999999999999973	00:35:00	\N	0.969999999999999973	\N	\N	Mill Point, Sasanoa River	ME
61292	Fort Popham, Hunniwell Point, Kennebec River, Maine (sub)	NOS	8417177	43.7550000000000026	-69.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	0.92000000000000004	00:09:00	\N	0.92000000000000004	\N	\N	Fort Popham, Hunniwell Point	ME
61293	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183000000000007	-69.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:28:00	\N	0.880000000000000004	00:26:00	\N	0.880000000000000004	\N	\N	Phippsburg	ME
61294	Bath, Kennebec River, Maine (sub)	NOS	8417227	43.9249999999999972	-69.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:17:00	\N	0.699999999999999956	01:01:00	\N	0.699999999999999956	\N	\N	Bath	ME
61295	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9816999999999965	-69.8349999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:04:00	\N	0.57999999999999996	02:00:00	\N	0.57999999999999996	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
61296	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.8900000000000006	-69.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.989999999999999991	-00:05:00	\N	0.989999999999999991	\N	\N	Howard Point, New Meadows River	ME
61297	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.9500000000000028	-69.888300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	03:26:00	\N	0.520000000000000018	02:24:00	\N	0.520000000000000018	\N	\N	Androscoggin River entrance	ME
61298	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7882999999999996	-69.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	0.979999999999999982	-00:01:00	\N	0.979999999999999982	\N	\N	Cundy Harbor, New Meadows River	ME
61299	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0082999999999984	-69.894999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:42:00	\N	0.630000000000000004	02:34:00	\N	0.630000000000000004	\N	\N	Bowdoinham, Cathance River	ME
61300	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217000000000013	-69.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	04:36:00	\N	0.419999999999999984	02:35:00	\N	0.419999999999999984	\N	\N	Brunswick, Androscoggin River	ME
61301	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.8250000000000028	-69.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
61302	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383000000000024	-70.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.979999999999999982	00:02:00	\N	0.979999999999999982	\N	\N	South Harpswell, Potts Harbor	ME
61303	South Freeport, Casco Bay, Maine	NOS	8417801	43.8200000000000003	-70.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	0.989999999999999991	00:12:00	\N	0.989999999999999991	\N	\N	South Freeport	ME
61304	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.6950000000000003	-70.1099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
61305	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7516999999999996	-70.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.880000000000000004	-00:02:00	\N	1	\N	\N	Doyle Point	ME
61306	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7216999999999985	-70.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1.03000000000000003	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
61307	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6766999999999967	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	1.03000000000000003	00:05:00	\N	0.979999999999999982	\N	\N	Vaill Island	ME
61308	Long Island, Casco Bay, Maine	NOS	8417941	43.6899999999999977	-70.1700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
61309	Prince Point, Casco Bay, Maine	NOS	8417948	43.7616999999999976	-70.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.989999999999999991	00:00:00	\N	1	\N	\N	Prince Point	ME
61310	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.6700000000000017	-70.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:00:00	\N	1.03000000000000003	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
61311	Cushing Island, Casco Bay, Maine	NOS	8417997	43.6450000000000031	-70.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	1.03000000000000003	00:01:00	\N	0.989999999999999991	\N	\N	Cushing Island	ME
61312	Peak Island, Casco Bay, Maine	NOS	8418001	43.6550000000000011	-70.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:08:00	\N	0.989999999999999991	-00:04:00	\N	0.989999999999999991	\N	\N	Peak Island	ME
61314	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7316999999999965	-70.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.969999999999999973	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
61315	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233000000000004	-70.2066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:01:00	\N	1	-00:02:00	\N	0.969999999999999973	\N	\N	Portland Head Light	ME
61316	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867000000000019	-70.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:04:00	\N	1.06000000000000005	00:01:00	\N	1.01000000000000001	\N	\N	Presumpscot River Bridge	ME
61317	Back Cove, Casco Bay, Maine	NOS	8418175	43.6766999999999967	-70.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:06:00	\N	0.969999999999999973	00:02:00	\N	0.969999999999999973	\N	\N	Back Cove	ME
61318	Fore River, Casco Bay, Maine	NOS	8418268	43.6417000000000002	-70.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	1.03000000000000003	00:02:00	\N	1	\N	\N	Fore River	ME
61319	Old Orchard Beach, Maine	NOS	8418557	43.5167000000000002	-70.3666999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:06:00	\N	0.969999999999999973	00:00:00	\N	0.969999999999999973	\N	\N	Old Orchard Beach	ME
61320	Camp Ellis, Saco River Entrance, Maine (sub)	NOS	8418606	43.4617000000000004	-70.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	1	00:03:00	\N	0.969999999999999973	\N	\N	Camp Ellis, Saco River Entrance	ME
61321	Cape Porpoise, Maine	NOS	8418772	43.3667000000000016	-70.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:14:00	\N	0.949999999999999956	00:12:00	\N	0.949999999999999956	\N	\N	Cape Porpoise	ME
61322	Biddeford, Saco River, Maine (sub)	NOS	8418828	43.4917000000000016	-70.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:26:00	\N	0.969999999999999973	00:12:00	\N	0.989999999999999991	\N	\N	Biddeford, Saco River	ME
61323	Kennebunkport, Kennebunk River, Maine (sub)	NOS	8418911	43.3582999999999998	-70.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:05:00	\N	1	00:07:00	\N	0.969999999999999973	\N	\N	Kennebunkport	ME
61324	Wells, Webhannet River, Maine (sub)	NOS	8419317	43.3200000000000003	-70.5633055555555586	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:02:00	\N	0.969999999999999973	00:06:00	\N	0.959999999999999964	\N	\N	Wells, Webhannet River	ME
61325	Cape Neddick, Maine	NOS	8419399	43.1666999999999987	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:08:00	\N	1	00:02:00	\N	0.949999999999999956	\N	\N	Cape Neddick	ME
61326	York Harbor, Maine	NOS	8419518	43.1317000000000021	-70.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:13:00	\N	0.949999999999999956	00:03:00	\N	0.949999999999999956	\N	\N	York Harbor	ME
61327	Fort Point, York Harbor, Maine	NOS	8419528	43.1300000000000026	-70.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:10:00	\N	0.939999999999999947	-00:04:00	\N	0.949999999999999956	\N	\N	Fort Point, York Harbor	ME
61328	Seapoint, Cutts Island, Maine	NOS	8419590	43.0850000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:04:00	\N	0.959999999999999964	00:01:00	\N	0.959999999999999964	\N	\N	Seapoint, Cutts Island	ME
61329	Gerrish Island, Portsmouth Harbor, New Hampshire	NOS	8419688	43.0666999999999973	-70.696700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:03:00	\N	0.949999999999999956	-00:02:00	\N	0.949999999999999956	\N	\N	Gerrish Island	NH
61330	Kittery Point, Portsmouth Harbor, New Hampshire	NOS	8419807	43.0816999999999979	-70.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:01:00	\N	0.959999999999999964	-00:07:00	\N	0.959999999999999964	\N	\N	Kittery Point	NH
61331	Seavey Island, Portsmouth Harbor, New Hampshire (sub)	NOS	8419870	43.0799999999999983	-70.7416999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:18:00	\N	0.890000000000000013	00:20:00	\N	0.890000000000000013	\N	\N	Seavey Island	NH
61332	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1916999999999973	-70.8250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
61333	Dover, Cocheco River, Piscataqua River, New Hampshire (sub)	NOS	8420411	43.1983000000000033	-70.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:39:00	\N	0.760000000000000009	01:45:00	\N	0.770000000000000018	\N	\N	Dover, Cocheco River	NH
61334	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.121699999999997	-70.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:27:00	\N	0.699999999999999956	01:33:00	\N	0.699999999999999956	\N	\N	Dover Point	NH
61335	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533000000000001	-70.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
61336	Atlantic Heights, Piscataqua River, New Hampshire	NOS	8423635	43.0900000000000034	-70.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:28:00	\N	0.819999999999999951	00:37:00	\N	0.819999999999999951	\N	\N	Atlantic Heights	NH
61337	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0782999999999987	-70.7516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:17:00	\N	0.859999999999999987	00:22:00	\N	0.859999999999999987	\N	\N	Portsmouth	NH
61338	Fort Point, Portsmouth Harbor, New Hampshire (sub)	NOS	8423898	43.0713882446289062	-70.7105560302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:07:00	\N	0.939999999999999947	00:03:00	\N	0.939999999999999947	\N	\N	Fort Point	NH
61339	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0566999999999993	-70.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:05:00	\N	0.949999999999999956	-00:03:00	\N	0.949999999999999956	\N	\N	Jaffrey Point	NH
61340	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9782999999999973	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	-00:02:00	\N	0.930000000000000049	00:02:00	\N	0.930000000000000049	\N	\N	Gosport Harbor, Isles of Shoals	NH
61341	Hampton Harbor, New Hampshire	NOS	8429489	42.8950000000000031	-70.8166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:32:00	\N	0.910000000000000031	00:14:00	\N	0.910000000000000031	\N	\N	Hampton Harbor	NH
61342	Salisbury Point, Merrimack River, Massachusetts (sub)	NOS	8440273	42.8382999999999967	-70.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:18:00	\N	0.560000000000000053	00:55:00	\N	0.82999999999999996	\N	\N	Salisbury Point	MA
61343	Merrimacport, Merrimack River, Massachusetts (sub)	NOS	8440369	42.8250000000000028	-70.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	02:08:00	\N	0.5	01:26:00	\N	0.760000000000000009	\N	\N	Merrimacport	MA
61344	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts (sub)	NOS	8440452	42.8166999999999973	-70.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:29:00	\N	0.880000000000000004	00:06:00	\N	0.880000000000000004	\N	\N	Plum Island, Merrimack River Entrance	MA
61345	Newburyport, Merrimack River, Massachusetts (sub)	NOS	8440466	42.8149999999999977	-70.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	01:11:00	\N	0.859999999999999987	00:31:00	\N	0.859999999999999987	\N	\N	Newburyport	MA
61346	Riverside, Merrimack River, Massachusetts (sub)	NOS	8440889	42.763300000000001	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	03:30:00	\N	0.349999999999999978	01:56:00	\N	0.619999999999999996	\N	\N	Riverside	MA
61347	Plum Island Sound (south end), Massachusetts (sub)	NOS	8441241	42.710138888888892	-70.7886111111111092	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:37:00	\N	0.939999999999999947	00:12:00	\N	0.939999999999999947	\N	\N	Plum Island Sound (south end)	MA
61348	Rockport Harbor, Massachusetts (sub)	NOS	8441551	42.658299999999997	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:06:00	\N	0.969999999999999973	00:06:00	\N	0.949999999999999956	\N	\N	Rockport	MA
61349	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.6550000000000011	-70.6766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:03:00	\N	0.969999999999999973	00:11:00	\N	0.969999999999999973	\N	\N	Annisquam, Lobster Cove	MA
61350	Essex, Essex River, Massachusetts (sub)	NOS	8441771	42.6317000000000021	-70.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60179	00:31:00	\N	0.939999999999999947	00:22:00	\N	1	\N	\N	Essex	MA
61351	Gloucester Harbor, Massachusetts	NOS	8441841	42.6099999999999994	-70.6599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:04:00	\N	0.969999999999999973	00:00:00	\N	0.930000000000000049	\N	\N	Gloucester Harbor	MA
61352	Salem, Salem Harbor, Massachusetts (sub)	NOS	8442645	42.523299999999999	-70.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:05:00	\N	0.969999999999999973	-00:02:00	\N	0.939999999999999947	\N	\N	Salem, Salem Harbor	MA
61353	Lynn, Lynn Harbor, Massachusetts (sub)	NOS	8443187	42.4583000000000013	-70.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:03:00	\N	1	00:01:00	\N	0.969999999999999973	\N	\N	Lynn, Lynn Harbor	MA
61354	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts (sub)	NOS	8443662	42.3950000000000031	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:02:00	\N	0.969999999999999973	00:01:00	\N	1.01000000000000001	\N	\N	Amelia Earhart Dam, Mystic River	MA
61355	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts (sub)	NOS	8443725	42.3866999999999976	-71.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:06:00	\N	1.01000000000000001	00:01:00	\N	1.01000000000000001	\N	\N	Chelsea St. Bridge, Chelsea River	MA
61356	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.371699999999997	-71.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
61357	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483000000000018	-70.9599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:00:00	\N	0.969999999999999973	00:01:00	\N	0.969999999999999973	\N	\N	Deer Island (south end)	MA
61358	Boston Light, Boston Harbor, Massachusetts (sub)	NOS	8444162	42.3282999999999987	-70.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:02:00	\N	0.969999999999999973	-00:01:00	\N	0.949999999999999956	\N	\N	Boston Light	MA
61359	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083000000000027	-70.9916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:04:00	\N	0.989999999999999991	00:01:00	\N	0.989999999999999991	\N	\N	Moon Head	MA
61360	Hull, Massachusetts	NOS	8444351	42.3033000000000001	-70.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.969999999999999973	00:05:00	\N	0.969999999999999973	\N	\N	Hull	MA
61361	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.2849999999999966	-71.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
61362	Nut Island, Quincy Bay, Massachusetts (sub)	NOS	8444525	42.2800000000000011	-70.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:01:00	\N	1	00:01:00	\N	0.989999999999999991	\N	\N	Nut Island, Quincy Bay	MA
61363	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.2700000000000031	-70.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.989999999999999991	00:06:00	\N	0.989999999999999991	\N	\N	Nantasket Beach, Weir River	MA
61364	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2616999999999976	-70.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:05:00	\N	0.989999999999999991	00:02:00	\N	0.989999999999999991	\N	\N	Crow Point, Hingham Harbor entrance	MA
61365	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483000000000004	-70.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:02:00	\N	0.92000000000000004	00:04:00	\N	0.92000000000000004	\N	\N	Cohasset Harbor (White Head)	MA
61366	Hingham, Massachusetts	NOS	8444775	42.246699999999997	-70.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
61367	Shipyard Point, Weymouth Fore River, Massachusetts (sub)	NOS	8444788	42.2483000000000004	-70.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:06:00	\N	1	00:09:00	\N	1	\N	\N	Weymouth Fore River Bridge	MA
61368	Scituate, Scituate Harbor, Massachusetts (sub)	NOS	8445138	42.2017000000000024	-70.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:01:00	\N	1.03000000000000003	00:03:00	\N	0.949999999999999956	\N	\N	Scituate, Scituate Harbor	MA
61369	Damons Point, North River, Massachusetts	NOS	8445425	42.1599999999999966	-70.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:36:00	\N	0.890000000000000013	00:20:00	\N	0.890000000000000013	\N	\N	Damons Point, North River	MA
61370	Brant Rock, Green Harbor River, Massachusetts (sub)	NOS	8446009	42.0833000000000013	-70.6466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:03:00	\N	1.03000000000000003	00:05:00	\N	0.959999999999999964	\N	\N	Brant Rock, Green Harbor River	MA
61371	Provincetown, Cape Cod, Massachusetts (sub)	NOS	8446121	42.0495916666666574	-70.1821583333333336	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	0.949999999999999956	00:16:00	\N	0.949999999999999956	\N	\N	Provincetown	MA
61372	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts (sub)	NOS	8446166	42.0382999999999996	-70.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:33:00	\N	1.03000000000000003	00:06:00	\N	1.04000000000000004	\N	\N	Duxbury, Duxbury Harbor	MA
61373	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts (sub)	NOS	8446493	41.9600000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	1	00:04:00	\N	1.03000000000000003	\N	\N	Plymouth	MA
61374	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.9299999999999997	-70.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:30:00	\N	1.05000000000000004	00:14:00	\N	1.05000000000000004	\N	\N	Wellfleet	MA
61375	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts (sub)	NOS	8447173	41.7749999999999986	-70.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:06:00	\N	0.880000000000000004	-00:15:00	\N	0.82999999999999996	\N	\N	Cape Cod Canal, Sagamore	MA
61376	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts (sub)	NOS	8447180	41.7717000000000027	-70.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:03:00	\N	0.680000000000000049	-00:01:00	\N	0.910000000000000031	\N	\N	Sandwich Marina, Cape Cod Canal, east entrance	MA
61377	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts (sub)	NOS	8447191	41.7700000000000031	-70.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:21:00	\N	0.790000000000000036	-00:29:00	\N	0.660000000000000031	\N	\N	Cape Cod Canal, Bournedale	MA
61378	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts (sub)	NOS	8447241	41.7516999999999996	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:01:00	\N	0.819999999999999951	00:02:00	\N	1.02000000000000002	\N	\N	Sesuit Harbor, East Dennis	MA
61379	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts (sub)	NOS	8447259	41.7449999999999974	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:24:00	\N	0.790000000000000036	-01:13:00	\N	0.46000000000000002	\N	\N	Cape Cod Canal, Bourne Bridge	MA
61380	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts (sub)	NOS	8447270	41.7417000000000016	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:50:00	\N	1.01000000000000001	01:17:00	\N	1.01000000000000001	\N	\N	Cape Cod Canal, RR. bridge	MA
61381	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417000000000016	-70.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:25:00	\N	1.03000000000000003	00:41:00	\N	1.03000000000000003	\N	\N	Onset Beach, Onset Bay	MA
61382	Steep Brook, Taunton River, Narragansett Bay, Rhode Island	NOS	8447281	41.740000000000002	-71.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:05:00	\N	1.29000000000000004	00:26:00	\N	1.30000000000000004	\N	\N	Steep Brook, Taunton River	RI
61383	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.736699999999999	-69.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	03:27:00	\N	0.340000000000000024	02:28:00	\N	0.340000000000000024	\N	\N	Pleasant Bay	MA
61384	Gray Gables, Buzzards Bay, Massachusetts (sub)	NOS	8447295	41.7349999999999994	-70.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:16:00	\N	1.20999999999999996	00:37:00	\N	1.05000000000000004	\N	\N	Gray Gables	MA
61385	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7216999999999985	-70.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
61386	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.7150000000000034	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:30:00	\N	1.14999999999999991	00:16:00	\N	1.14999999999999991	\N	\N	Monument Beach	MA
61387	Great Hill, Buzzards Bay, Massachusetts (sub)	NOS	8447368	41.7117000000000004	-70.7150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:12:00	\N	1.20999999999999996	00:12:00	\N	1.1399999999999999	\N	\N	Great Hill	MA
61388	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.7049999999999983	-70.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:12:00	\N	1.29000000000000004	00:10:00	\N	1.12999999999999989	\N	\N	Marion, Sippican Harbor	MA
61389	Fall River, Narragansett Bay, Massachusetts (sub)	NOS	8447386	41.7043055555555569	-71.1641111111111115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:03:00	\N	1.20999999999999996	00:18:00	\N	1.25	\N	\N	Fall River, Massachusetts	MA
61390	Piney Point, Buzzards Bay, Massachusetts (sub)	NOS	8447416	41.6950000000000003	-70.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:10:00	\N	1.20999999999999996	00:10:00	\N	1.12999999999999989	\N	\N	Piney Point	MA
61391	Chatham, Cape Cod, Massachusetts (sub)	NOS	8447435	41.6884722222222166	-69.9510833333333295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:57:00	\N	0.349999999999999978	01:08:00	\N	0.479999999999999982	\N	\N	Chatham Harbor, Aunt Lydias Cove	MA
61392	Texas Tower, Georges Shoal	NOS	8447436	41.6882999999999981	-67.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:43:00	\N	0.440000000000000002	-00:47:00	\N	0.440000000000000002	\N	\N	Georges Shoal, Texas Tower	\N
61393	Saquatucket Harbor, Nantucket Sound, Massachusetts (sub)	NOS	8447495	41.6683000000000021	-70.0567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:16:00	\N	0.409999999999999976	00:46:00	\N	0.409999999999999976	\N	\N	Saquatucket Harbor	MA
61394	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.6649999999999991	-70.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:46:00	\N	0.28999999999999998	01:48:00	\N	0.28999999999999998	\N	\N	South Yarmouth, Bass River	MA
61395	Chatham, Stage Harbor, Cape Cod, Massachusetts (sub)	NOS	8447505	41.6666999999999987	-69.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:19:00	\N	0.429999999999999993	00:46:00	\N	0.429999999999999993	\N	\N	Chatham, Stage Harbor	MA
61396	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.6649999999999991	-70.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:25:00	\N	0.390000000000000013	00:52:00	\N	0.390000000000000013	\N	\N	Wychmere Harbor	MA
61397	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.658299999999997	-70.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:38:00	\N	0.359999999999999987	01:03:00	\N	0.359999999999999987	\N	\N	Dennisport	MA
61398	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567000000000007	-70.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:20:00	\N	1	00:11:00	\N	1.09000000000000008	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
61399	New Bedford, Buzzards Bay, Massachusetts	NOS	8447584	41.6400000000000006	-70.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:07:00	\N	1.05000000000000004	00:07:00	\N	1.05000000000000004	\N	\N	New Bedford	MA
61400	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6082999999999998	-70.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:47:00	\N	0.260000000000000009	01:17:00	\N	0.260000000000000009	\N	\N	Cotuit Highlands	MA
61401	Clarks Point, New Bedford, Buzzards Bay, Massachusetts (sub)	NOS	8447712	41.5932999999999993	-70.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:23:00	\N	1.07000000000000006	00:14:00	\N	1.03000000000000003	\N	\N	Clarks Point	MA
61402	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867000000000004	-70.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	01:52:00	\N	0.239999999999999991	02:03:00	\N	0.239999999999999991	\N	\N	Poponesset Island, Poponesset Bay	MA
61403	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.5700000000000003	-71.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:30:00	\N	0.770000000000000018	01:40:00	\N	0.770000000000000018	\N	\N	Hix Bridge, East Branch	MA
61404	Round Hill Point, Buzzards Bay, Massachusetts (sub)	NOS	8447842	41.5382999999999996	-70.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:22:00	\N	1	00:14:00	\N	0.989999999999999991	\N	\N	Round Hill Point	MA
61405	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.5450000000000017	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	-00:09:00	\N	0.140000000000000013	-00:16:00	\N	0.140000000000000013	\N	\N	Falmouth Heights	MA
61406	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.5200000000000031	-70.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	02:21:00	\N	0.400000000000000022	00:32:00	\N	0.400000000000000022	\N	\N	Little Harbor	MA
61407	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.5200000000000031	-70.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:22:00	\N	1.02000000000000002	00:12:00	\N	1.02000000000000002	\N	\N	Uncatena Island (south side)	MA
61408	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5082999999999984	-71.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:33:00	\N	0.849999999999999978	00:09:00	\N	0.849999999999999978	\N	\N	Westport Harbor	MA
61409	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583000000000013	-70.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	03:47:00	\N	0.709999999999999964	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
61410	Penikese Island, Buzzards Bay, Massachusetts (sub)	NOS	8448248	41.4500000000000028	-70.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:16:00	\N	0.969999999999999973	-00:17:00	\N	0.969999999999999973	\N	\N	Penikese Island	MA
61411	Quicks Hole, North side, Massachusetts	NOS	8448251	41.4483000000000033	-70.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:08:00	\N	0.989999999999999991	-00:08:00	\N	0.989999999999999991	\N	\N	Quicks Hole, North side	MA
61412	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.4350000000000023	-70.696700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:32:00	\N	0.619999999999999996	00:10:00	\N	0.619999999999999996	\N	\N	Cedar Tree Neck	MA
61413	Cuttyhunk, Massachusetts	NOS	8448376	41.4249999999999972	-70.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:15:00	\N	0.930000000000000049	01:20:00	\N	0.969999999999999973	\N	\N	Cuttyhunk	MA
61414	Edgartown, Martha's Vineyard, Massachusetts (sub)	NOS	8448558	41.388300000000001	-70.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:18:00	\N	0.200000000000000011	00:57:00	\N	0.200000000000000011	\N	\N	Edgartown	MA
61415	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3866999999999976	-70.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:28:00	\N	0.320000000000000007	00:43:00	\N	0.320000000000000007	\N	\N	Great Point	MA
61416	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633000000000024	-70.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	03:20:00	\N	0.309999999999999998	02:02:00	\N	0.309999999999999998	\N	\N	Wasque Point, Chappaquiddick Island	MA
61417	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3532999999999973	-70.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:45:00	\N	0.819999999999999951	-00:06:00	\N	0.819999999999999951	\N	\N	Gay Head	MA
61418	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367000000000004	-70.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:15:00	\N	0.209999999999999992	00:25:00	\N	0.209999999999999992	\N	\N	Muskeget Island, north side	MA
61419	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117000000000019	-70.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:02:00	\N	0.819999999999999951	-00:45:00	\N	0.819999999999999951	\N	\N	Squibnocket Point	MA
61420	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2916999999999987	-70.2082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60201	00:07:00	\N	0.239999999999999991	00:39:00	\N	0.239999999999999991	\N	\N	Eel Point	MA
61421	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2616999999999976	-70.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:18:00	\N	0.849999999999999978	-00:19:00	\N	0.849999999999999978	\N	\N	Nomans Land	MA
61422	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6516999999999982	-71.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:01:00	\N	1.07000000000000006	00:20:00	\N	1.19999999999999996	\N	\N	North End, Bay Oil pier	RI
61423	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.638300000000001	-71.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:01:00	\N	1.09000000000000008	00:00:00	\N	1.09000000000000008	\N	\N	Anthony Point	RI
61424	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6182999999999979	-71.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:13:00	\N	1.01000000000000001	-00:12:00	\N	1.01000000000000001	\N	\N	Nannaquaket Neck	RI
61425	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583000000000027	-71.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:03:00	\N	1	-00:13:00	\N	0.979999999999999982	\N	\N	The Glen	RI
61426	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.486699999999999	-71.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:15:00	\N	0.930000000000000049	-00:05:00	\N	0.900000000000000022	\N	\N	Sachuest, Flint Point	RI
61427	Bristol Ferry, Narragansett Bay, Rhode Island (sub)	NOS	8451552	41.6366999999999976	-71.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.1399999999999999	00:15:00	\N	1.16999999999999993	\N	\N	Bristol Ferry	RI
61428	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683000000000021	-71.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.1399999999999999	00:13:00	\N	1.15999999999999992	\N	\N	Bristol, Bristol Harbor	RI
61429	Prudence Island, (south end), Narragansett Bay, Rhode Island	NOS	8452555	41.5799999999999983	-71.321700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:03:00	\N	1.1399999999999999	00:08:00	\N	1.08000000000000007	\N	\N	Prudence Island, (south end)	RI
61430	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.7516999999999996	-71.3516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:01:00	\N	1.20999999999999996	00:12:00	\N	1.21999999999999997	\N	\N	Bay Spring, Bullock Cove	RI
61431	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4632999999999967	-71.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:13:00	\N	1	-00:05:00	\N	0.939999999999999947	\N	\N	Castle Hill	RI
61432	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.8400000000000034	-71.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:06:00	\N	1.29000000000000004	00:12:00	\N	1.34000000000000008	\N	\N	Rumford, Seekonk River	RI
61433	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733000000000033	-71.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:06:00	\N	1.07000000000000006	00:07:00	\N	1.07000000000000006	\N	\N	Conanicut Point	RI
61434	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8682999999999979	-71.3799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:09:00	\N	1.29000000000000004	00:18:00	\N	1.31000000000000005	\N	\N	Pawtucket, Seekonk River	RI
61435	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island (sub)	NOS	8453742	41.496699999999997	-71.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:04:00	\N	1	00:05:00	\N	1	\N	\N	West Jamestown, Dutch Island Harbor	RI
61436	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.7616999999999976	-71.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:11:00	\N	1.29000000000000004	00:06:00	\N	1.25	\N	\N	Pawtuxet, Pawtuxet Cove	RI
61437	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517000000000024	-71.4017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:04:00	\N	0.979999999999999982	-00:05:00	\N	0.979999999999999982	\N	\N	Beavertail Point	RI
61438	Providence, State Pier no.1, Narragansett Bay, Rhode Island (sub)	NOS	8454000	41.806666700000001	-71.4005556000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:00:00	\N	1.29000000000000004	00:13:00	\N	1.27000000000000002	\N	\N	Providence, State Pier no.1	RI
61439	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.4600000000000009	-71.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:16:00	\N	0.930000000000000049	-00:03:00	\N	0.959999999999999964	\N	\N	Watson Pier, Boston Neck	RI
61440	Wickford, Narragansett Bay, Rhode Island (sub)	NOS	8454538	41.5716999999999999	-71.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	-00:06:00	\N	1.07000000000000006	00:03:00	\N	1.07000000000000006	\N	\N	Wickford	RI
61441	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217000000000013	-71.4549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:11:00	\N	0.930000000000000049	-00:11:00	\N	0.910000000000000031	\N	\N	Narragansett Pier	RI
61442	Point Judith, Harbor of Refuge, Rhode Island (sub)	NOS	8455083	41.3633000000000024	-71.4899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:33:00	\N	0.930000000000000049	00:00:00	\N	0.869999999999999996	\N	\N	Point Judith, Harbor of Refuge	RI
61443	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817000000000021	-71.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:03:00	\N	1	-00:21:00	\N	1.02000000000000002	\N	\N	Westerly, Pawcatuck River	RI
61444	Weekapaug Point, Block Island Sound, Rhode Island (sub)	NOS	8458022	41.3282999999999987	-71.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:06:00	\N	0.930000000000000049	00:41:00	\N	0.739999999999999991	\N	\N	Weekapaug Point, Block Island Sound	RI
61445	Watch Hill Point, Rhode Island	NOS	8458694	41.3049999999999997	-71.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	01:16:00	\N	0.709999999999999964	00:41:00	\N	0.739999999999999991	\N	\N	Watch Hill Point	RI
61446	Block Island (Old Harbor), Rhode Island (sub)	NOS	8459338	41.1732999999999976	-71.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:15:00	\N	0.859999999999999987	-00:13:00	\N	0.819999999999999951	\N	\N	Block Island (Old Harbor)	RI
61447	Block Island (SW end), Block Island Sound, Rhode Island (sub)	NOS	8459681	41.1632999999999996	-71.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60237	00:42:00	\N	0.790000000000000036	00:05:00	\N	0.75	\N	\N	Southwest Point, Block Island	RI
61448	Norwich, Thames River, Connecticut	NOS	8461392	41.523299999999999	-72.0782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:19:00	\N	1.20999999999999996	00:24:00	\N	1.17999999999999994	\N	\N	Norwich	CT
61449	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.4299999999999997	-72.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:10:00	\N	1.1100000000000001	00:14:00	\N	1.07000000000000006	\N	\N	Yale boathouse	CT
61450	Niantic, Niantic River, Connecticut	NOS	8461925	41.3250000000000028	-72.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:57:00	\N	0.839999999999999969	00:52:00	\N	0.989999999999999991	\N	\N	Niantic, Niantic River	CT
61451	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.263300000000001	-72.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:45:00	\N	1.35000000000000009	01:11:00	\N	1.3600000000000001	\N	\N	Saybrook Jetty	CT
61452	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.283299999999997	-72.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:53:00	\N	1.25	01:11:00	\N	1.23999999999999999	\N	\N	Saybrook Point	CT
61453	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3216999999999999	-72.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:09:00	\N	0.949999999999999956	01:36:00	\N	1.26000000000000001	\N	\N	Lyme, highway bridge	CT
61454	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483000000000018	-72.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:38:00	\N	1.14999999999999991	01:39:00	\N	1.15999999999999992	\N	\N	Essex	CT
61455	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.4200000000000017	-72.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:23:00	\N	1.05000000000000004	02:19:00	\N	1.05000000000000004	\N	\N	Hadlyme	CT
61456	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517000000000024	-72.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:51:00	\N	1.02000000000000002	02:38:00	\N	1.02000000000000002	\N	\N	Tylerville	CT
61457	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.273299999999999	-72.4749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:32:00	\N	0.599999999999999978	-00:24:00	\N	0.609999999999999987	\N	\N	Westbrook, Duck Island Roads	CT
61458	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4816999999999965	-72.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	03:08:00	\N	0.949999999999999956	02:48:00	\N	0.969999999999999973	\N	\N	Haddam	CT
61459	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5416999999999987	-72.5516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	04:01:00	\N	0.910000000000000031	03:25:00	\N	0.910000000000000031	\N	\N	Maromas	CT
61460	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.503300000000003	-72.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	03:40:00	\N	0.910000000000000031	03:08:00	\N	0.910000000000000031	\N	\N	Higganum Creek	CT
61461	Madison, Connecticut	NOS	8464041	41.2700000000000031	-72.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:30:00	\N	0.719999999999999973	-00:21:00	\N	0.729999999999999982	\N	\N	Madison	CT
61462	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6632999999999996	-72.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	05:36:00	\N	0.630000000000000004	04:30:00	\N	0.719999999999999973	\N	\N	Rocky Hill	CT
61463	Middletown, Connecticut River, Connecticut	NOS	8464336	41.5600000000000023	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	04:39:00	\N	0.82999999999999996	03:54:00	\N	0.82999999999999996	\N	\N	Middletown	CT
61464	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.7550000000000026	-72.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	06:54:00	\N	0.57999999999999996	05:24:00	\N	0.739999999999999991	\N	\N	South Hartford	CT
61465	Guilford Harbor, Connecticut	NOS	8464445	41.2717000000000027	-72.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:21:00	\N	0.959999999999999964	-00:11:00	\N	0.770000000000000018	\N	\N	Guilford Harbor	CT
61466	Hartford, Connecticut River, Connecticut	NOS	8464464	41.7700000000000031	-72.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	06:52:00	\N	0.75	05:30:00	\N	0.739999999999999991	\N	\N	Hartford	CT
61467	Sachem Head, Connecticut	NOS	8464687	41.2449999999999974	-72.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:15:00	\N	0.800000000000000044	-00:11:00	\N	0.800000000000000044	\N	\N	Sachem Head	CT
61468	Branford, Branford River, Connecticut	NOS	8465233	41.2616999999999976	-72.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:13:00	\N	0.959999999999999964	-00:05:00	\N	0.869999999999999996	\N	\N	Branford, Branford River	CT
61469	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2516999999999996	-72.9050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:07:00	\N	0.959999999999999964	-00:04:00	\N	0.910000000000000031	\N	\N	Lighthouse Point, New Haven Harbor	CT
61470	New Haven Harbor, New Haven Reach, Connecticut (sub)	NOS	8465705	41.283299999999997	-72.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:06:00	\N	1	-00:01:00	\N	0.92000000000000004	\N	\N	New Haven Harbor, New Haven Reach	CT
61471	Gulf Beach, Connecticut	NOS	8466375	41.2049999999999983	-73.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:08:00	\N	1.04000000000000004	-00:05:00	\N	0.939999999999999947	\N	\N	Gulf Beach	CT
61472	Milford Harbor, Connecticut	NOS	8466442	41.2182999999999993	-73.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:03:00	\N	1.04000000000000004	-00:02:00	\N	0.939999999999999947	\N	\N	Milford Harbor	CT
61473	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3016999999999967	-73.071700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	01:19:00	\N	0.959999999999999964	00:46:00	\N	1.04000000000000004	\N	\N	Shelton	CT
61474	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.2749999999999986	-73.0883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	01:13:00	\N	1.04000000000000004	00:43:00	\N	1.02000000000000002	\N	\N	Long Hill	CT
61475	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867000000000019	-73.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:09:00	\N	1	00:10:00	\N	0.959999999999999964	\N	\N	Sniffens Point	CT
61476	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2032999999999987	-73.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:23:00	\N	1	00:23:00	\N	0.979999999999999982	\N	\N	Stratford, I-95 bridge	CT
61477	South Norwalk, Norwalk River, Connecticut (sub)	NOS	8468448	41.0966999999999985	-73.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:15:00	\N	1.04000000000000004	00:09:00	\N	1.05000000000000004	\N	\N	South Norwalk	CT
61478	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.0649999999999977	-73.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	1.08000000000000007	00:00:00	\N	1.05000000000000004	\N	\N	Rowayton, Fivemile River	CT
61479	Long Neck Point, Long Island Sound, Connecticut (sub)	NOS	8468799	41.0382999999999996	-73.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:01:00	\N	0.959999999999999964	-00:09:00	\N	1.06000000000000005	\N	\N	Long Neck Point	CT
61480	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167000000000002	-73.5966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:11:00	\N	1.08000000000000007	00:05:00	\N	1.07000000000000006	\N	\N	Cos Cob Harbor	CT
61481	Lake Montauk, Long Island, New York (sub)	NOS	8510448	41.0733000000000033	-71.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:22:00	\N	0.890000000000000013	-00:26:00	\N	0.770000000000000018	\N	\N	Lake Montauk	NY
61482	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.0750000000000028	-71.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:16:00	\N	0.75	-00:24:00	\N	0.739999999999999991	\N	\N	Montauk Harbor entrance	NY
61483	Silver Eel Pond, Fishers Island, New York (sub)	NOS	8510719	41.2567000000000021	-72.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:04:00	\N	1	-00:04:00	\N	0.910000000000000031	\N	\N	Silver Eel Pond, Fishers Island, N.Y.	NY
61484	Little Gull Island, Long Island, New York	NOS	8510884	41.2066999999999979	-72.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	-00:22:00	\N	0.849999999999999978	00:13:00	\N	0.849999999999999978	\N	\N	Little Gull Island	NY
61485	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.0349999999999966	-72.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:19:00	\N	1	00:39:00	\N	0.959999999999999964	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
61486	Plum Gut Harbor, Plum Island, Long Island, New York (sub)	NOS	8511236	41.1717000000000013	-72.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:16:00	\N	1.01000000000000001	00:28:00	\N	1.01000000000000001	\N	\N	Plum Gut Harbor, Plum Island	NY
61487	Orient Harbor, Orient, Shelter Island Sound, New York (sub)	NOS	8511671	41.1366999999999976	-72.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	00:36:00	\N	0.969999999999999973	00:37:00	\N	0.969999999999999973	\N	\N	Orient	NY
61488	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.9949999999999974	-72.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:44:00	\N	0.890000000000000013	02:06:00	\N	0.890000000000000013	\N	\N	Noyack Bay	NY
61489	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.0949999999999989	-72.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:13:00	\N	0.640000000000000013	00:03:00	\N	0.640000000000000013	\N	\N	Hashamomuck Beach	NY
61490	Southold, Shelter Island Sound, New York	NOS	8512114	41.0600000000000023	-72.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	01:33:00	\N	0.890000000000000013	01:44:00	\N	0.890000000000000013	\N	\N	Southold	NY
61491	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917000000000016	-72.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:11:00	\N	1	02:27:00	\N	1.01000000000000001	\N	\N	New Suffolk	NY
61492	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.8200000000000003	-72.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:51:00	\N	0.369999999999999996	01:12:00	\N	0.510000000000000009	\N	\N	Shinnecock Bay entrance	NY
61493	South Jamesport, Great Peconic Bay, New York (sub)	NOS	8512735	40.9350000000000023	-72.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60252	02:43:00	\N	0.949999999999999956	02:34:00	\N	1.07000000000000006	\N	\N	South Jamesport	NY
61494	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York (sub)	NOS	8512769	40.8185555555555624	-72.586611111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:45:00	\N	0.550000000000000044	01:01:00	\N	0.550000000000000044	\N	\N	Shinnecock Yacht Club, Penniman Creek	NY
61495	Northville, Long Island, New York (sub)	NOS	8512987	40.9816999999999965	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	-00:03:00	\N	0.92000000000000004	00:05:00	\N	0.800000000000000044	\N	\N	Northville	NY
61496	Smith Point Bridge, Narrow Bay, Long Island, New York (sub)	NOS	8513825	40.7383000000000024	-72.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:34:00	\N	0.599999999999999978	01:58:00	\N	0.270000000000000018	\N	\N	Smith Point Bridge, Narrow Bay	NY
61497	Patchogue, Patchogue River, Great South Bay, New York (sub)	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.530000000000000027	03:14:00	\N	0.25	\N	\N	Patchogue	NY
61498	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9632999999999967	-73.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:18:00	\N	0.880000000000000004	00:04:00	\N	0.890000000000000013	\N	\N	Mount Sinai Harbor	NY
61499	Cedar Beach, Long Island, New York (sub)	NOS	8514422	40.9650000000000034	-73.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	1	00:07:00	\N	0.959999999999999964	\N	\N	Cedar Beach	NY
61500	Port Jefferson, Long Island, New York	NOS	8514560	40.9500000000000028	-73.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:05:00	\N	0.92000000000000004	00:04:00	\N	0.979999999999999982	\N	\N	Port Jefferson	NY
61501	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9716999999999985	-73.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:01:00	\N	0.979999999999999982	00:02:00	\N	0.979999999999999982	\N	\N	Port Jefferson Harbor entrance	NY
61502	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233000000000018	-73.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:32:00	\N	0.149999999999999994	03:19:00	\N	0.149999999999999994	\N	\N	Great River, Connetquot River	NY
61503	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567000000000007	-73.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:18:00	\N	0.130000000000000004	02:10:00	\N	0.130000000000000004	\N	\N	West Fire Island	NY
61504	Fire Island Light, Great South Bay, New York	NOS	8515014	40.634999999999998	-73.2199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:22:00	\N	0.149999999999999994	00:46:00	\N	0.149999999999999994	\N	\N	Fire Island Light	NY
61505	Bay Shore, Watchogue Creek Entrance, Great South Bay, New York	NOS	8515102	40.716700000000003	-73.2399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:27:00	\N	0.369999999999999996	02:15:00	\N	0.220000000000000001	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
61506	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6332999999999984	-73.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:27:00	\N	0.550000000000000044	-00:39:00	\N	0.560000000000000053	\N	\N	Democrat Point, Fire Island Inlet	NY
61507	Oak Beach, Great South Bay, New York	NOS	8515336	40.6400000000000006	-73.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:58:00	\N	0.149999999999999994	02:23:00	\N	0.149999999999999994	\N	\N	Oak Beach	NY
61508	Babylon, Great South Bay, New York	NOS	8515421	40.6850000000000023	-73.3149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.149999999999999994	02:11:00	\N	0.130000000000000004	\N	\N	Babylon	NY
61509	Northport, Northport Bay, Long Island, New York (sub)	NOS	8515586	40.8999999999999986	-73.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:04:00	\N	0.92000000000000004	-00:05:00	\N	1.07000000000000006	\N	\N	Northport, Northport Bay	NY
61510	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.6199999999999974	-73.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:58:00	\N	0.25	02:22:00	\N	0.239999999999999991	\N	\N	Gilgo Heading	NY
61511	Eatons Neck Point, Long Island, New York (sub)	NOS	8515786	40.9532999999999987	-73.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:08:00	\N	1.04000000000000004	00:02:00	\N	1.05000000000000004	\N	\N	Eatons Neck Point	NY
61512	Amityville, Great South Bay, New York	NOS	8515864	40.6550000000000011	-73.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:05:00	\N	0.25	02:20:00	\N	0.260000000000000009	\N	\N	Amityville	NY
61513	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York (sub)	NOS	8515921	40.9099999999999966	-73.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:07:00	\N	0.880000000000000004	-00:01:00	\N	1.04000000000000004	\N	\N	Lloyd Harbor, Huntington Bay	NY
61514	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6666999999999987	-73.4682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:32:00	\N	0.299999999999999989	02:04:00	\N	0.299999999999999989	\N	\N	Biltmore Shores, South Oyster Bay	NY
61515	Cold Spring Harbor, Oyster Bay, New York (sub)	NOS	8516061	40.8733000000000004	-73.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:02:00	\N	0.92000000000000004	-00:07:00	\N	1.07000000000000006	\N	\N	Cold Spring Harbor	NY
61516	Green Island, Hempstead Bay, New York (sub)	NOS	8516155	40.6233000000000004	-73.5016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:31:00	\N	0.400000000000000022	01:21:00	\N	0.409999999999999976	\N	\N	Green Island	NY
61517	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667000000000016	-73.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:13:00	\N	1.08000000000000007	00:07:00	\N	1.08000000000000007	\N	\N	Oyster Bay Harbor	NY
61518	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6632999999999996	-73.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:58:00	\N	0.450000000000000011	01:28:00	\N	0.429999999999999993	\N	\N	Bellmore, Bellmore Creek	NY
61519	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.6199999999999974	-73.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:22:00	\N	0.5	01:07:00	\N	0.489999999999999991	\N	\N	Cuba Island	NY
61520	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6032999999999973	-73.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:11:00	\N	0.5	01:01:00	\N	0.510000000000000009	\N	\N	Deep Creek Meadow	NY
61521	Bayville Bridge, Oyster Bay, New York (sub)	NOS	8516299	40.9033000000000015	-73.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60255	00:04:00	\N	1.04000000000000004	-00:06:00	\N	1.09000000000000008	\N	\N	Bayville Bridge	NY
61522	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233000000000004	-73.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:54:00	\N	0.599999999999999978	00:49:00	\N	0.57999999999999996	\N	\N	Neds Creek	NY
61523	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867000000000004	-73.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:25:00	\N	0.75	-00:20:00	\N	0.770000000000000018	\N	\N	Jones Inlet (Point Lookout)	NY
61524	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6332999999999984	-73.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:55:00	\N	0.650000000000000022	00:37:00	\N	0.640000000000000013	\N	\N	Freeport, Baldwin Bay	NY
61525	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6000000000000014	-73.6500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:02:00	\N	0.849999999999999978	00:18:00	\N	0.839999999999999969	\N	\N	Long Beach (Inside)	NY
61526	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York (sub)	NOS	8516614	40.8633000000000024	-73.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:26:00	\N	0.819999999999999951	-00:22:00	\N	1.01000000000000001	\N	\N	Glen Cove, Hempstead Harbor	NY
61527	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.6199999999999974	-73.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:50:00	\N	0.849999999999999978	00:34:00	\N	0.839999999999999969	\N	\N	Woodmere, Brosewere Bay	NY
61528	Port Washington, Manhasset Bay, Long Island, New York (sub)	NOS	8516761	40.8316999999999979	-73.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:12:00	\N	0.959999999999999964	-00:12:00	\N	1.02000000000000002	\N	\N	Port Washington, Manhasset Bay	NY
61529	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167000000000016	-73.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:48:00	\N	1.14999999999999991	00:39:00	\N	1.15999999999999992	\N	\N	Motts Basin	NY
61530	Willets Point, Little Bay, East River, New York (sub)	NOS	8516990	40.7933000000000021	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:00:00	\N	1.04000000000000004	-00:01:00	\N	1	\N	\N	Willets Point	NY
61531	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233000000000004	-73.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:45:00	\N	1.14999999999999991	00:25:00	\N	1.1399999999999999	\N	\N	J.F.K. International Airport	NY
61532	Whitestone, East River, New York	NOS	8517125	40.7982999999999976	-73.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:09:00	\N	1.04000000000000004	00:07:00	\N	1	\N	\N	Whitestone	NY
61533	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5882999999999967	-73.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:24:00	\N	1.10000000000000009	00:37:00	\N	1.09000000000000008	\N	\N	Beach Channel (bridge)	NY
61534	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.783299999999997	-73.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:16:00	\N	1.04000000000000004	00:17:00	\N	0.949999999999999956	\N	\N	College Point, Flushing Bay	NY
61535	Canarsie, Jamaica Bay, New York	NOS	8517381	40.6300000000000026	-73.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:08:00	\N	1.10000000000000009	00:27:00	\N	1.12000000000000011	\N	\N	Canarsie	NY
61536	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5782999999999987	-73.888300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:04:00	\N	1.05000000000000004	-00:01:00	\N	1.07000000000000006	\N	\N	Barren Island, Rockaway Inlet	NY
61537	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867000000000033	-73.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	03:45:00	\N	1.59000000000000008	02:58:00	\N	1.33000000000000007	\N	\N	Hell Gate, Wards Island	NY
61538	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6082999999999998	-73.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:04:00	\N	1.10000000000000009	00:28:00	\N	1.12000000000000011	\N	\N	Mill Basin	NY
61539	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.5850000000000009	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:03:00	\N	1.05000000000000004	00:02:00	\N	1.05000000000000004	\N	\N	Plumb Beach Channel	NY
61540	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.740000000000002	-73.9616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:56:00	\N	0.900000000000000022	01:22:00	\N	0.890000000000000013	\N	\N	Hunters Point, Newtown Creek	NY
61541	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7066999999999979	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.05000000000000004	00:32:00	\N	0.939999999999999947	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
61542	Coney Island, New York	NOS	8517741	40.5700000000000003	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:17:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Coney Island	NY
61543	Norton Point, Gravesend Bay, New York	NOS	8517811	40.5900000000000034	-73.9983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:03:00	\N	1.14999999999999991	-00:01:00	\N	1.02000000000000002	\N	\N	Norton Point, Gravesend Bay	NY
61544	Brooklyn Bridge, East River, New York (sub)	NOS	8517847	40.7032999999999987	-73.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:04:00	\N	1	00:24:00	\N	0.989999999999999991	\N	\N	Brooklyn Bridge	NY
61545	Gowanus Bay, New York	NOS	8517921	40.6649999999999991	-74.013300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:12:00	\N	0.949999999999999956	-00:18:00	\N	1.03000000000000003	\N	\N	Gowanus Bay	NY
61546	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6082999999999998	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:07:00	\N	1	00:02:00	\N	1.01000000000000001	\N	\N	Fort Hamilton, The Narrows	NY
61547	Rye Beach (Amusement Park), New York (sub)	NOS	8518091	40.9617000000000004	-73.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:27:00	\N	0.859999999999999987	-00:20:00	\N	1	\N	\N	Rye Beach	NY
61548	New Rochelle, New York	NOS	8518490	40.8933000000000035	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	-00:18:00	\N	0.930000000000000049	-00:16:00	\N	1.01000000000000001	\N	\N	New Rochelle	NY
61549	Hunts Point, East River, New York	NOS	8518621	40.7999999999999972	-73.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:10:00	\N	1.07000000000000006	00:12:00	\N	0.969999999999999973	\N	\N	Hunts Point	NY
61550	North Brother Island, East River, New York	NOS	8518635	40.7982999999999976	-73.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:18:00	\N	1.1100000000000001	00:18:00	\N	0.930000000000000049	\N	\N	North Brother Island	NY
61551	Port Morris (Stony Point), East River, New York (sub)	NOS	8518639	40.8016999999999967	-73.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60300	00:10:00	\N	0.959999999999999964	00:07:00	\N	0.869999999999999996	\N	\N	Port Morris (Stony Point)	NY
61552	Horns Hook, East 90th Street, East River, New York, New York (sub)	NOS	8518668	40.7766999999999982	-73.9416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:34:00	\N	0.900000000000000022	01:54:00	\N	1.03000000000000003	\N	\N	Horns Hook, East 90th Street	NY
61553	Queensboro Bridge, East River, New York (sub)	NOS	8518687	40.7582999999999984	-73.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:57:00	\N	1	01:23:00	\N	0.959999999999999964	\N	\N	Queensboro Bridge	NY
61554	East 41st Street, New York City, East River, New York	NOS	8518695	40.746699999999997	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:46:00	\N	1.09000000000000008	01:03:00	\N	0.949999999999999956	\N	\N	East 41st Street, New York City	NY
61555	Williamsburg Bridge, East River, New York (sub)	NOS	8518699	40.7117000000000004	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:28:00	\N	0.949999999999999956	00:45:00	\N	0.930000000000000049	\N	\N	Williamsburg Bridge	NY
61556	Spuyten Duyvil Creek Entrance, Hudson River, New York (sub)	NOS	8518903	40.878300000000003	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:48:00	\N	0.839999999999999969	00:52:00	\N	0.839999999999999969	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
61557	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033000000000015	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:49:00	\N	0.849999999999999978	00:48:00	\N	0.849999999999999978	\N	\N	Riverdale, N.Y.	NY
61558	Tarrytown, Hudson River, New York	NOS	8518919	41.0782999999999987	-73.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:57:00	\N	0.699999999999999956	01:49:00	\N	0.699999999999999956	\N	\N	Tarrytown	NY
61559	Haverstraw Bay, Hudson River, New York (sub)	NOS	8518924	41.2182999999999993	-73.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	02:42:00	\N	0.810000000000000053	02:15:00	\N	0.719999999999999973	\N	\N	Haverstraw	NY
61560	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:03:00	\N	0.640000000000000013	03:46:00	\N	0.619999999999999996	\N	\N	Newburgh	NY
61561	New Hamburg, Hudson River, New York	NOS	8518939	41.5833000000000013	-73.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:28:00	\N	0.640000000000000013	04:04:00	\N	0.640000000000000013	\N	\N	New Hamburg	NY
61562	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7000000000000028	-73.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	04:46:00	\N	0.680000000000000049	04:34:00	\N	0.680000000000000049	\N	\N	Poughkeepsie	NY
61563	Peekskill, Hudson River, New York	NOS	8518949	41.2882999999999996	-73.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	03:03:00	\N	0.640000000000000013	02:28:00	\N	0.640000000000000013	\N	\N	Peekskill	NY
61564	Tivoli, Hudson River, New York	NOS	8518964	42.0583000000000027	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	06:04:00	\N	0.859999999999999987	05:50:00	\N	0.859999999999999987	\N	\N	Tivoli	NY
61565	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.7999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	07:12:00	\N	0.859999999999999987	06:58:00	\N	0.880000000000000004	\N	\N	Hudson	NY
61566	Castleton, Hudson River, New York	NOS	8518989	42.533299999999997	-73.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60323	-00:29:00	0.100000000000000006	\N	-00:17:00	-0.200000000000000011	\N	\N	\N	Castleton	NY
61567	Kingston, Hudson River, New York	NOS	8518993	41.9183000000000021	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	05:34:00	\N	0.819999999999999951	05:20:00	\N	0.810000000000000053	\N	\N	Kingston	NY
61568	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6066999999999965	-74.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.05000000000000004	00:06:00	\N	0.979999999999999982	\N	\N	Fort Wadsworth, The Narrows	NY
61569	St. George, Staten Island, New York	NOS	8519112	40.6433000000000035	-74.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:15:00	\N	0.989999999999999991	-00:17:00	\N	0.989999999999999991	\N	\N	St. George, Staten Island	NY
61570	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.6450000000000031	-74.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:39:00	\N	1.09000000000000008	00:27:00	\N	1.09000000000000008	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
61571	Princes Bay, New Jersey	NOS	8519726	40.5116999999999976	-74.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.05000000000000004	00:00:00	\N	1.05000000000000004	\N	\N	Princes Bay	NJ
61572	Rossville, Arthur Kill, New York	NOS	8519789	40.5566999999999993	-74.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:29:00	\N	1.12000000000000011	00:20:00	\N	1.12000000000000011	\N	\N	Rossville, N.Y.	NY
61573	Alpine, Hudson River, New Jersey	NOS	8530095	40.9450000000000003	-73.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:02:00	\N	0.900000000000000022	01:05:00	\N	0.82999999999999996	\N	\N	Alpine, N.J.	NJ
61574	New Millford, Hackensack River, New Jersey	NOS	8530186	40.9350000000000023	-74.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	02:49:00	\N	1.02000000000000002	01:17:00	\N	1.02000000000000002	\N	\N	New Millford	NJ
61575	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.8800000000000026	-74.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1.37999999999999989	01:06:00	\N	1.33000000000000007	\N	\N	Hackensack	NJ
61576	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.8500000000000014	-74.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1.26000000000000001	01:00:00	\N	1.26000000000000001	\N	\N	Ridgefield Park	NJ
61577	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8466999999999985	-74.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:06:00	\N	1.29000000000000004	00:09:00	\N	1.29000000000000004	\N	\N	East Rutherford	NJ
61578	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8132999999999981	-73.9783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:28:00	\N	0.930000000000000049	00:31:00	\N	0.930000000000000049	\N	\N	Edgewater, N.J.	NJ
61579	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8066999999999993	-74.0600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:45:00	\N	1.29000000000000004	00:59:00	\N	1.26000000000000001	\N	\N	Carlstadt, Garretts Reach	NJ
61580	North Secaucus, Garretts Reach, Hackensack River, New York	NOS	8530531	40.8049999999999997	-74.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:57:00	\N	1.22999999999999998	00:57:00	\N	1.22999999999999998	\N	\N	North Secaucus, Garretts Reach	NY
61581	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933000000000021	-74.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	01:00:00	\N	1	01:02:00	\N	1.15999999999999992	\N	\N	Fish Creek, Berrys Creek	NJ
61582	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867000000000033	-74.1466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:49:00	\N	1.18999999999999995	00:09:00	\N	1.22999999999999998	\N	\N	Belleville	NJ
61583	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.7650000000000006	-74.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:15:00	\N	0.959999999999999964	00:13:00	\N	0.959999999999999964	\N	\N	Weehawken, Union City, N.J.	NJ
61584	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7516999999999996	-74.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:39:00	\N	1.10000000000000009	00:33:00	\N	1.15999999999999992	\N	\N	Amtrak RR. swing bridge	NJ
61585	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7316999999999965	-74.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.04000000000000004	00:00:00	\N	1.14999999999999991	\N	\N	Point No Point	NJ
61586	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7282999999999973	-74.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:22:00	\N	1.1399999999999999	00:11:00	\N	1.14999999999999991	\N	\N	Kearny Point	NJ
61587	Port Elizabeth, New Jersey	NOS	8530882	40.6732999999999976	-74.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:13:00	\N	0.949999999999999956	-00:02:00	\N	1.1100000000000001	\N	\N	Port Elizabeth	NJ
61588	Port Newark Terminal, New Jersey	NOS	8530884	40.6899999999999977	-74.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	00:21:00	\N	1.12000000000000011	00:03:00	\N	1.12000000000000011	\N	\N	Port Newark Terminal	NJ
61589	Constable Hook, Kill Van Kull, New York	NOS	8530985	40.6550000000000011	-74.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60315	-00:08:00	\N	1.02000000000000002	-00:18:00	\N	1.02000000000000002	\N	\N	Constable Hook	NY
61590	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983000000000018	-74.2317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:30:00	\N	1.15999999999999992	00:17:00	\N	1.1399999999999999	\N	\N	Rahway River, RR. Bridge	NJ
61591	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867000000000004	-74.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:33:00	\N	1.09000000000000008	00:22:00	\N	1.09000000000000008	\N	\N	Carteret	NJ
61592	Woodbridge Creek, 0.8 n.mi. above entrance, Arthur Kill, New Jersey	NOS	8531156	40.5450000000000017	-74.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:21:00	\N	1	00:09:00	\N	1.10000000000000009	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
61593	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917000000000016	-74.2817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:08:00	\N	1.09000000000000008	-00:04:00	\N	1.09000000000000008	\N	\N	South Amboy	NJ
61594	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333000000000027	-74.2182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:07:00	\N	1.08000000000000007	-00:01:00	\N	1.08000000000000007	\N	\N	Matawan Creek, Route 35 bridge	NJ
61595	Keyport, New Jersey	NOS	8531545	40.4399999999999977	-74.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:06:00	\N	1.10000000000000009	-00:04:00	\N	1.08000000000000007	\N	\N	Keyport	NJ
61596	Waackaack Creek, New Jersey	NOS	8531592	40.4483000000000033	-74.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:21:00	\N	0.989999999999999991	-00:06:00	\N	0.989999999999999991	\N	\N	Waackaack Creek	NJ
61597	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183000000000021	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:10:00	\N	1.01000000000000001	-00:10:00	\N	1.01000000000000001	\N	\N	Atlantic Highlands	NJ
61598	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967000000000027	-73.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:14:00	\N	0.900000000000000022	00:17:00	\N	0.900000000000000022	\N	\N	Highlands, Route 36 bridge	NJ
61599	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3766999999999996	-74.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:45:00	\N	0.630000000000000004	01:13:00	\N	0.719999999999999973	\N	\N	Oceanic Bridge, Navesink River	NJ
61600	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365000000000002	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:07:00	\N	0.680000000000000049	01:15:00	\N	0.680000000000000049	\N	\N	Sea Bright	NJ
61601	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.3549999999999969	-74.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:57:00	\N	0.630000000000000004	01:17:00	\N	0.739999999999999991	\N	\N	Red Bank, Navesink River	NJ
61602	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267000000000024	-74.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.550000000000000044	02:18:00	\N	0.550000000000000044	\N	\N	Gooseneck Point, bridge	NJ
61603	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.3250000000000028	-73.9967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:41:00	\N	0.630000000000000004	02:18:00	\N	0.560000000000000053	\N	\N	Long Branch Reach	NJ
61604	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033000000000001	-73.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:36:00	\N	1	-00:26:00	\N	0.939999999999999947	\N	\N	Long Branch (fishing pier)	NJ
61605	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1916999999999973	-74.0383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:09:00	\N	0.939999999999999947	-00:13:00	\N	0.939999999999999947	\N	\N	Shark River Hills	NJ
61606	Belmar (ocean), New Jersey	NOS	8532337	40.1850000000000023	-74.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:45:00	\N	0.949999999999999956	-00:35:00	\N	0.949999999999999956	\N	\N	Belmar, Atlantic Ocean	NJ
61607	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867000000000019	-74.0267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:08:00	\N	0.930000000000000049	-00:13:00	\N	0.930000000000000049	\N	\N	Shark River Island, fixed RR. bridge	NJ
61608	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783000000000001	-74.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:07:00	\N	0.949999999999999956	-00:13:00	\N	0.949999999999999956	\N	\N	New Bedford	NJ
61609	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.1049999999999969	-74.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:20:00	\N	0.82999999999999996	-00:06:00	\N	0.82999999999999996	\N	\N	Brielle, Route 35 bridge	NJ
61610	Manasquan Inlet, USCG Station, New Jersey	NOS	8532591	40.101700000000001	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:24:00	\N	0.949999999999999956	-00:12:00	\N	0.859999999999999987	\N	\N	Manasquan Inlet, USCG Station	NJ
61611	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0966999999999985	-74.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:38:00	\N	0.729999999999999982	00:08:00	\N	0.729999999999999982	\N	\N	Riviera Beach	NJ
61612	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.0649999999999977	-74.1350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:07:00	\N	0.0700000000000000067	02:17:00	\N	0.0700000000000000067	\N	\N	Forge Pond	NJ
61613	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617000000000019	-74.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.369999999999999996	02:41:00	\N	0.0700000000000000067	\N	\N	Beaverdam Creek entrance	NJ
61614	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617000000000019	-74.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:47:00	\N	0.0599999999999999978	02:49:00	\N	0.0599999999999999978	\N	\N	Beaverdam Creek, inside	NJ
61615	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583000000000027	-74.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:24:00	\N	0.0599999999999999978	02:23:00	\N	0.0599999999999999978	\N	\N	Tall Pines Camp	NJ
61616	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367000000000033	-74.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:39:00	\N	0.0700000000000000067	04:28:00	\N	0.0700000000000000067	\N	\N	Mantoloking	NJ
61617	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.013300000000001	-74.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:41:00	\N	0.0800000000000000017	04:23:00	\N	0.0800000000000000017	\N	\N	Kettle Creek, Green Island	NJ
61618	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883000000000024	-74.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:36:00	\N	0.0800000000000000017	04:17:00	\N	0.0800000000000000017	\N	\N	Ocean Beach	NJ
61619	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.996699999999997	-74.1483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:39:00	\N	0.0800000000000000017	04:26:00	\N	0.0800000000000000017	\N	\N	Silver Bay, Silver Bay Marina	NJ
61620	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9632999999999967	-74.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:29:00	\N	0.0800000000000000017	04:06:00	\N	0.0800000000000000017	\N	\N	Goose Creek entrance	NJ
61621	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483000000000033	-74.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:21:00	\N	0.0800000000000000017	04:00:00	\N	0.0800000000000000017	\N	\N	Coates Point	NJ
61622	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433000000000007	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	-00:32:00	\N	0.92000000000000004	-00:30:00	\N	0.92000000000000004	\N	\N	Seaside Heights, ocean	NJ
61623	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217000000000013	-74.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:05:00	\N	0.0800000000000000017	03:40:00	\N	0.0800000000000000017	\N	\N	Seaside Park	NJ
61624	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183000000000021	-74.1099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:55:00	\N	0.0800000000000000017	03:35:00	\N	0.0800000000000000017	\N	\N	Barnegat Pier	NJ
61625	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.9050000000000011	-74.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:01:00	\N	0.0800000000000000017	03:38:00	\N	0.0800000000000000017	\N	\N	Sloop Creek	NJ
61626	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.8699999999999974	-74.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:45:00	\N	0.0800000000000000017	03:23:00	\N	0.0800000000000000017	\N	\N	Cedar Creek	NJ
61627	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.851700000000001	-74.0883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:28:00	\N	0.0800000000000000017	03:04:00	\N	0.0800000000000000017	\N	\N	Island Beach	NJ
61628	Stouts Creek, Barnegat Bay, New Jersey (sub)	NOS	8533365	39.8449999999999989	-74.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.0599999999999999978	03:16:00	\N	0.0599999999999999978	\N	\N	Stouts Creek	NJ
61629	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.8250000000000028	-74.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:20:00	\N	0.0700000000000000067	03:08:00	\N	0.0700000000000000067	\N	\N	Forked River	NJ
61630	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083000000000027	-74.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:36:00	\N	0.0599999999999999978	03:30:00	\N	0.0599999999999999978	\N	\N	Oyster Creek	NJ
61631	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7882999999999996	-74.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:56:00	\N	0.0700000000000000067	03:00:00	\N	0.0700000000000000067	\N	\N	Island Beach, Sedge Islands	NJ
61632	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7916999999999987	-74.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:00:00	\N	0.0700000000000000067	02:43:00	\N	0.0700000000000000067	\N	\N	Waretown	NJ
61633	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567000000000021	-74.1282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:55:00	\N	0.119999999999999996	01:04:00	\N	0.119999999999999996	\N	\N	High Bar	NJ
61634	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.7449999999999974	-74.2017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.0700000000000000067	03:03:00	\N	0.0700000000000000067	\N	\N	Double Creek	NJ
61635	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.7250000000000014	-74.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:39:00	\N	0.100000000000000006	03:02:00	\N	0.100000000000000006	\N	\N	Loveladies Harbor	NJ
61636	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7066999999999979	-74.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:35:00	\N	0.179999999999999993	03:33:00	\N	0.179999999999999993	\N	\N	Flat Creek	NJ
61637	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.6749999999999972	-74.1599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:07:00	\N	0.220000000000000001	03:02:00	\N	0.220000000000000001	\N	\N	North Beach	NJ
61638	Mill Creek, 1 n.mi. above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.6649999999999991	-74.2317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:33:00	\N	0.349999999999999978	02:32:00	\N	0.349999999999999978	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
61639	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6666999999999987	-74.2150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:51:00	\N	0.270000000000000018	02:50:00	\N	0.270000000000000018	\N	\N	Manahawkin Creek	NJ
61640	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533000000000015	-74.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:39:00	\N	0.270000000000000018	02:47:00	\N	0.270000000000000018	\N	\N	Manahawkin Drawbridge	NJ
61641	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533000000000015	-74.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:56:00	\N	0.400000000000000022	02:10:00	\N	0.400000000000000022	\N	\N	Cedar Run	NJ
61642	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567000000000007	-74.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:17:00	\N	0.400000000000000022	02:41:00	\N	0.400000000000000022	\N	\N	Dinner Point Creek, upper end	NJ
61643	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317000000000021	-74.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.469999999999999973	02:10:00	\N	0.440000000000000002	\N	\N	West Creek, Westecunk Creek	NJ
61644	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	04:21:00	\N	0.560000000000000053	03:23:00	\N	0.560000000000000053	\N	\N	Sweetwater, Mullica River Marina	NJ
61645	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6182999999999979	-74.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:44:00	\N	0.790000000000000036	02:48:00	\N	0.640000000000000013	\N	\N	Wading River (town), Wading River	NJ
61646	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133000000000024	-74.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:40:00	\N	0.469999999999999973	02:00:00	\N	0.419999999999999984	\N	\N	Westecunk Creek entrance	NJ
61647	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133000000000024	-74.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:59:00	\N	0.320000000000000007	02:13:00	\N	0.380000000000000004	\N	\N	Beach Haven Crest	NJ
61648	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167000000000016	-74.3100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:39:00	\N	0.469999999999999973	02:05:00	\N	0.450000000000000011	\N	\N	Parker Run, upper end	NJ
61649	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.601700000000001	-74.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:15:00	\N	0.469999999999999973	01:45:00	\N	0.450000000000000011	\N	\N	Tuckerton, Tuckerton Creek	NJ
61650	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.591700000000003	-74.4416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:06:00	\N	0.739999999999999991	01:52:00	\N	0.660000000000000031	\N	\N	New Gretna, Bass River	NJ
61651	Green Bank, Mullica River, New Jersey	NOS	8534117	39.611699999999999	-74.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	03:16:00	\N	0.660000000000000031	02:59:00	\N	0.660000000000000031	\N	\N	Green Bank	NJ
61652	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767000000000024	-74.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:59:00	\N	0.450000000000000011	01:32:00	\N	0.450000000000000011	\N	\N	Tuckerton Creek entrance	NJ
61653	Beach Haven Coast Guard Station, Little Egg Harbor, New Jersey	NOS	8534208	39.5482999999999976	-74.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:23:00	\N	0.57999999999999996	01:18:00	\N	0.46000000000000002	\N	\N	Beach Haven Coast Guard Station	NJ
61654	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5482999999999976	-74.4616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	02:01:00	\N	0.790000000000000036	01:27:00	\N	0.630000000000000004	\N	\N	Chestnut Neck Boat Yard	NJ
61655	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.5399999999999991	-74.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:14:00	\N	0.680000000000000049	00:44:00	\N	0.680000000000000049	\N	\N	Graveling Point	NJ
61656	Nacote Creek, U.S. Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.5349999999999966	-74.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	01:55:00	\N	0.680000000000000049	01:34:00	\N	0.660000000000000031	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
61657	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217000000000027	-74.3199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:44:00	\N	0.680000000000000049	00:35:00	\N	0.660000000000000031	\N	\N	Little Sheepshead Creek	NJ
61658	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167000000000002	-74.3366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:28:00	\N	0.729999999999999982	00:32:00	\N	0.729999999999999982	\N	\N	Seven Island, Newmans Thorofare	NJ
61659	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4782999999999973	-74.3833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:52:00	\N	0.760000000000000009	01:10:00	\N	0.800000000000000044	\N	\N	Main Marsh Thorofare	NJ
61660	Mays Landing, Great Egg Harbor River, New Jersey (sub)	NOS	8534468	39.4483000000000033	-74.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	03:10:00	\N	1.12000000000000011	02:50:00	\N	1.01000000000000001	\N	\N	Mays Landing, Great Egg Harbor River	NJ
61661	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.4350000000000023	-74.3632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:58:00	\N	0.880000000000000004	00:59:00	\N	0.900000000000000022	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
61662	Absecon, Absecon Creek, U.S. Hwy. 30 bridge, New Jersey	NOS	8534540	39.4232999999999976	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:37:00	\N	0.939999999999999947	01:28:00	\N	0.959999999999999964	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
61663	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.384999999999998	-74.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:26:00	\N	1.12999999999999989	00:38:00	\N	0.959999999999999964	\N	\N	Absecon Channel, State Route 87 bridge	NJ
61664	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817000000000021	-74.5182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:37:00	\N	0.819999999999999951	01:00:00	\N	0.979999999999999982	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
61665	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3682999999999979	-74.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	02:25:00	\N	1	02:12:00	\N	0.869999999999999996	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
61666	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.351700000000001	-74.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:00:00	\N	0.939999999999999947	00:55:00	\N	0.979999999999999982	\N	\N	Dock Thorofare, Risley Channel	NJ
61667	Ventnor City, ocean pier, New Jersey (sub)	NOS	8534770	39.3350000000000009	-74.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Ventnor City, ocean pier	NJ
61668	Steelmanville, Patcong Ck., 2.5 n.mi. above ent, Great Egg Harbor Bay, New Jersey	NOS	8534778	39.3350000000000009	-74.5966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:50:00	\N	0.939999999999999947	01:28:00	\N	0.92000000000000004	\N	\N	Steelmanville, Patcong Ck., 2.5 nm above ent.	NJ
61669	Longport, Risely Channel, New Jersey (sub)	NOS	8534836	39.3083000000000027	-74.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:32:00	\N	0.880000000000000004	00:26:00	\N	0.939999999999999947	\N	\N	Longport (inside), Great Egg Harbor Inlet	NJ
61670	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey (sub)	NOS	8534883	39.2950000000000017	-74.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	02:40:00	\N	1.25	02:12:00	\N	0.859999999999999987	\N	\N	Tuckahoe, Tuckahoe River	NJ
61671	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2882999999999996	-74.6282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:32:00	\N	1	00:55:00	\N	0.869999999999999996	\N	\N	Beesleys Point	NJ
61672	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.246699999999997	-74.7182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	03:03:00	\N	1.53000000000000003	03:14:00	\N	0.780000000000000027	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
61673	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.2150000000000034	-74.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:30:00	\N	0.939999999999999947	00:31:00	\N	0.949999999999999956	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
61674	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2000000000000028	-74.6567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:38:00	\N	1	00:31:00	\N	0.949999999999999956	\N	\N	Strathmere, Strathmere Bay	NJ
61675	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1766999999999967	-74.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:12:00	\N	0.939999999999999947	00:56:00	\N	0.979999999999999982	\N	\N	Ludlam Bay, west side	NJ
61676	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467000000000027	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:39:00	\N	0.589999999999999969	01:08:00	\N	0.900000000000000022	\N	\N	Townsend Sound	NJ
61677	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.1199999999999974	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:04:00	\N	1	00:49:00	\N	0.969999999999999973	\N	\N	Stites Sound	NJ
61678	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.1099999999999994	-74.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:50:00	\N	1	00:44:00	\N	0.959999999999999964	\N	\N	Ingram Thorofare	NJ
61679	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.101700000000001	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:11:00	\N	1.06000000000000005	01:06:00	\N	0.979999999999999982	\N	\N	Long Reach, Ingram Thorofare	NJ
61680	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283000000000015	-74.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
61681	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183000000000035	-74.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:10:00	\N	1	00:56:00	\N	1.06000000000000005	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
61682	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.0050000000000026	-74.8267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	01:11:00	\N	1	00:57:00	\N	1.04000000000000004	\N	\N	West Wildwood, Grassy Sound	NJ
61683	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.9799999999999969	-74.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:40:00	\N	1.06000000000000005	00:55:00	\N	1.09000000000000008	\N	\N	Swain Channel, Taylor Sound	NJ
61684	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9782999999999973	-74.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:47:00	\N	1.06000000000000005	00:52:00	\N	1.10000000000000009	\N	\N	Wildwood Crest, Sunset Lake	NJ
61685	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483000000000033	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:19:00	\N	1.06000000000000005	00:33:00	\N	1.10000000000000009	\N	\N	Cape May Harbor	NJ
61686	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9466999999999999	-74.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:20:00	\N	1.18999999999999995	00:40:00	\N	1.1100000000000001	\N	\N	Cape Island Creek, Cape May	NJ
61687	Cape May (ocean), New Jersey	NOS	8535962	38.9299999999999997	-74.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60340	00:21:00	\N	1.06000000000000005	00:34:00	\N	1.12000000000000011	\N	\N	Cape May, Atlantic Ocean	NJ
61688	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9466999999999999	-74.9716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	-00:08:00	\N	1.15999999999999992	-00:05:00	\N	1.15999999999999992	\N	\N	Cape May Point, Sunset Beach	NJ
61689	Cape May Canal, Cape May, Delaware Bay, New Jersey (sub)	NOS	8536110	38.9677777777777834	-74.9597222222222257	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	-00:05:00	\N	1	-00:06:00	\N	1.17999999999999994	\N	\N	Cape May, ferry terminal	NJ
61690	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183000000000035	-74.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:14:00	\N	1.26000000000000001	00:04:00	\N	1.26000000000000001	\N	\N	North Highlands Beach	NJ
61691	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833000000000013	-74.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:18:00	\N	0.46000000000000002	01:09:00	\N	0.46000000000000002	\N	\N	Dias Creek, Route 47 bridge	NJ
61692	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1182999999999979	-74.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:48:00	\N	1.3600000000000001	00:36:00	\N	1.3600000000000001	\N	\N	Bidwell Creek, Route 47 bridge	NJ
61693	Bidwell Creek entrance, Delaware Bay, New Jersey (sub)	NOS	8536581	39.128300000000003	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:46:00	\N	1.18999999999999995	00:15:00	\N	1.3899999999999999	\N	\N	Bidwell Creek entrance	NJ
61694	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617000000000033	-74.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:36:00	\N	1.21999999999999997	01:49:00	\N	1.21999999999999997	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
61695	Dennis Creek, 2.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783000000000001	-74.8516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:17:00	\N	1.26000000000000001	00:55:00	\N	1.26000000000000001	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
61696	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833000000000027	-74.821700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:30:00	\N	1.19999999999999996	02:01:00	\N	1.19999999999999996	\N	\N	Dennis Creek, Route 47 bridge	NJ
61697	West Creek, 0.7 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1882999999999981	-74.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:31:00	\N	1.14999999999999991	00:20:00	\N	1.14999999999999991	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
61698	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2000000000000028	-75.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:08:00	\N	1.3899999999999999	00:40:00	\N	1.3899999999999999	\N	\N	East Point, Maurice River Cove	NJ
61699	Riggins Ditch, 0.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2000000000000028	-74.9699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:29:00	\N	1.23999999999999999	00:29:00	\N	1.23999999999999999	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
61700	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083000000000013	-74.9017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:24:00	\N	0.939999999999999947	01:46:00	\N	0.939999999999999947	\N	\N	East Creek, Route 47 bridge	NJ
61701	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.216700000000003	-75.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-02:10:00	\N	1.02000000000000002	-01:51:00	\N	1.02000000000000002	\N	\N	Fishing Creek entrance	NJ
61702	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.216700000000003	-75.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:05:00	\N	1.35000000000000009	00:29:00	\N	1.35000000000000009	\N	\N	Dividing Creek entrance	NJ
61703	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.216700000000003	-74.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:17:00	\N	0.57999999999999996	02:20:00	\N	0.57999999999999996	\N	\N	West Creek, Route 47 bridge	NJ
61704	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2182999999999993	-74.980000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:40:00	\N	1.12000000000000011	01:36:00	\N	1.12000000000000011	\N	\N	Riggins Ditch, Heislerville	NJ
61705	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:33:00	\N	0.709999999999999964	01:38:00	\N	0.709999999999999964	\N	\N	Weir Creek bridge, Dividing Creek	NJ
61706	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.2749999999999986	-75.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:13:00	\N	0.209999999999999992	01:45:00	\N	0.209999999999999992	\N	\N	Hollywood Beach, The Glades	NJ
61707	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.2849999999999966	-75.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:58:00	\N	1.10000000000000009	-01:43:00	\N	1.10000000000000009	\N	\N	Money Island, Nantuxent Creek entrance	NJ
61708	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.2849999999999966	-74.9916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:30:00	\N	1.05000000000000004	02:17:00	\N	1.05000000000000004	\N	\N	Mauricetown	NJ
61709	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2916999999999987	-75.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:28:00	\N	0.739999999999999991	-00:03:00	\N	0.739999999999999991	\N	\N	Newport Landing, Nantuxent Creek	NJ
61710	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2982999999999976	-75.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:51:00	\N	1.08000000000000007	-01:37:00	\N	1.08000000000000007	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
61711	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.3049999999999997	-75.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:34:00	\N	1.07000000000000006	-01:29:00	\N	1.07000000000000006	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
61712	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3132999999999981	-74.9849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	02:58:00	\N	1.05000000000000004	02:52:00	\N	1.05000000000000004	\N	\N	Port Elizabeth, Manumuskin River	NJ
61713	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3432999999999993	-75.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:09:00	\N	1.10000000000000009	03:06:00	\N	1.10000000000000009	\N	\N	Menantico Creek entrance	NJ
61714	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.378300000000003	-75.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:02:00	\N	1.09000000000000008	01:01:00	\N	1.09000000000000008	\N	\N	Tindalls Wharf, Cohansey River	NJ
61715	Millville, Maurice River, New Jersey	NOS	8537359	39.3917000000000002	-75.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:36:00	\N	1.20999999999999996	03:33:00	\N	1.20999999999999996	\N	\N	Millville	NJ
61716	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3832999999999984	-75.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:54:00	\N	0.989999999999999991	-00:42:00	\N	0.989999999999999991	\N	\N	Greenwich Pier, Cohansey River	NJ
61717	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:37:00	\N	0.880000000000000004	-00:22:00	\N	0.880000000000000004	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
61718	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217000000000013	-75.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:18:00	\N	0.92000000000000004	00:21:00	\N	0.92000000000000004	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
61719	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217000000000013	-75.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:33:00	\N	0.760000000000000009	01:08:00	\N	0.760000000000000009	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
61969	Haxall, James River, Virginia	NOS	8638478	37.3733000000000004	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:53:00	\N	1.33000000000000007	-04:10:00	\N	0.989999999999999991	\N	\N	Haxall	VA
61720	1 n.mi. above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4316999999999993	-75.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:47:00	\N	1.07000000000000006	-00:20:00	\N	1.07000000000000006	\N	\N	1 n.mi. above entrance, N.J.	NJ
61721	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617000000000004	-75.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:45:00	\N	0.800000000000000044	01:36:00	\N	0.800000000000000044	\N	\N	Canton, Stow Creek, N.J.	NJ
61722	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.4600000000000009	-75.5317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:33:00	\N	1.08000000000000007	-00:35:00	\N	1.08000000000000007	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
61723	Hope Creek, 0.6 n.mi. above entrance, Delaware River, New Jersey	NOS	8537667	39.4583000000000013	-75.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:36:00	\N	1.05000000000000004	-00:25:00	\N	1.05000000000000004	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
61724	0.8 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537731	39.496699999999997	-75.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:10:00	\N	0.989999999999999991	00:21:00	\N	0.989999999999999991	\N	\N	0.8 n.mi. above entrance	NJ
61725	2.5 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537753	39.5050000000000026	-75.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:15:00	\N	0.900000000000000022	00:51:00	\N	0.900000000000000022	\N	\N	2.5 n.mi. above entrance	NJ
61726	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5116999999999976	-75.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:12:00	\N	0.939999999999999947	00:44:00	\N	0.939999999999999947	\N	\N	Abbots Meadow	NJ
61727	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.513300000000001	-75.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:00:00	\N	0.780000000000000027	01:51:00	\N	0.780000000000000027	\N	\N	Coopers Creek bridge	NJ
61728	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5482999999999976	-75.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:30:00	\N	0.689999999999999947	02:24:00	\N	0.689999999999999947	\N	\N	Quinton	NJ
61729	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.5700000000000003	-75.4983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:19:00	\N	0.969999999999999973	00:04:00	\N	0.969999999999999973	\N	\N	Sinnickson Landing	NJ
61730	Salem, Salem River, New Jersey	NOS	8537979	39.5767000000000024	-75.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:41:00	\N	0.760000000000000009	00:49:00	\N	0.760000000000000009	\N	\N	Salem	NJ
61731	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833000000000027	-75.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
61732	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.7150000000000034	-75.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	03:30:00	\N	0.550000000000000044	04:12:00	\N	0.550000000000000044	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
61733	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7616999999999976	-75.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
61734	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.7950000000000017	-75.1766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:56:00	\N	0.709999999999999964	01:28:00	\N	0.709999999999999964	\N	\N	Mantua, Mantua Creek, N.J.	NJ
61735	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8066999999999993	-75.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:50:00	\N	1	-01:11:00	\N	0.910000000000000031	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
61736	Woodbury Creek, New Jersey	NOS	8538548	39.8599999999999994	-75.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:14:00	\N	0.949999999999999956	-00:13:00	\N	0.959999999999999964	\N	\N	Woodbury Creek, N.J.	NJ
61737	Billingsport, New Jersey	NOS	8538552	39.8500000000000014	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:28:00	\N	0.949999999999999956	-00:35:00	\N	0.930000000000000049	\N	\N	Billingsport, N.J.	NJ
61738	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733000000000004	-75.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:03:00	\N	1	00:02:00	\N	0.969999999999999973	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
61739	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9466999999999999	-75.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:23:00	\N	1	00:14:00	\N	1.04000000000000004	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
61740	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9782999999999973	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	03:05:00	\N	0.619999999999999996	02:58:00	\N	0.619999999999999996	\N	\N	Hainesport, South Branch	NJ
61741	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983000000000004	-74.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	03:29:00	\N	0.599999999999999978	02:58:00	\N	0.479999999999999982	\N	\N	North Branch	NJ
61742	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9932999999999979	-75.0283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:03:00	\N	0.890000000000000013	00:51:00	\N	0.890000000000000013	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
61743	Pompeston Creek, New Jersey	NOS	8538875	40.013300000000001	-75.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:43:00	\N	1.05000000000000004	00:21:00	\N	1.05000000000000004	\N	\N	Pompeston Creek, N.J.	NJ
61744	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283000000000015	-74.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:18:00	\N	1	01:15:00	\N	1.06000000000000005	\N	\N	Bridgeboro	NJ
61745	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733000000000033	-74.8482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:31:00	\N	0.849999999999999978	01:04:00	\N	1.12000000000000011	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
61746	Burlington, Delaware River, New Jersey (sub)	NOS	8539094	40.0799999999999983	-74.8733333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:07:00	\N	1	00:53:00	\N	1.19999999999999996	\N	\N	Burlington, N.J.	NJ
61747	Fieldsboro, Delaware River, New Jersey (sub)	NOS	8539487	40.1366999999999976	-74.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:39:00	\N	1.10000000000000009	01:07:00	\N	1.29000000000000004	\N	\N	Fieldsboro, N.J.	NJ
61748	Trenton Marine Terminal, Trenton, New Jersey (sub)	NOS	8539993	40.1882999999999981	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:54:00	\N	1	01:13:00	\N	1.35000000000000009	\N	\N	Trenton, N.J.	NJ
61749	Marcus Hook, Pennsylvania (sub)	NOS	8540433	39.8116667000000035	-75.4094443999999982	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-01:07:00	\N	0.949999999999999956	-01:23:00	\N	0.92000000000000004	\N	\N	Marcus Hook, Pa.	PA
61750	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8766999999999996	-75.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:34:00	\N	0.949999999999999956	-00:46:00	\N	0.949999999999999956	\N	\N	Wanamaker Bridge	PA
61751	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.8800000000000026	-75.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:35:00	\N	1	-00:42:00	\N	0.969999999999999973	\N	\N	Norwood City	PA
61752	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.878300000000003	-75.2767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:08:00	\N	0.900000000000000022	-00:22:00	\N	0.910000000000000031	\N	\N	Tinicum National Wildlife Refuge	PA
61753	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8866999999999976	-75.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:27:00	\N	0.739999999999999991	-00:24:00	\N	0.739999999999999991	\N	\N	Tinicum National Wildlife Refuge	PA
61754	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.898299999999999	-75.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	-00:11:00	\N	0.849999999999999978	-00:22:00	\N	0.959999999999999964	\N	\N	Penrose Avenue Bridge	PA
61755	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.9549999999999983	-75.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:00:00	\N	0.800000000000000044	-00:20:00	\N	0.989999999999999991	\N	\N	Market Street Bridge	PA
61756	Philadelphia, Municipal Pier 11, Pennsylvania (sub)	NOS	8545530	39.9532999999999987	-75.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:05:00	\N	0.949999999999999956	00:02:00	\N	1.04000000000000004	\N	\N	Philadelphia, Municipal Pier 11, Pa.	PA
61757	Bridesburg, Philadelphia, Pennsylvania (sub)	NOS	8546252	39.9833333333333272	-75.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:15:00	\N	0.900000000000000022	00:12:00	\N	1.06000000000000005	\N	\N	Bridesburg, Philadelphia, Pa.	PA
61758	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683000000000007	-74.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	00:58:00	\N	1	00:46:00	\N	1.16999999999999993	\N	\N	Cornwells Heights, Pa.	PA
61759	Newbold, Delaware River, Pennsylvania (sub)	NOS	8548989	40.1373055555555567	-74.7518888888888853	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:31:00	\N	1	01:10:00	\N	1.30000000000000004	\N	\N	Newbold, Pa.	PA
61760	Edgely, Pennsylvania	NOS	8549424	40.128300000000003	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60359	01:28:00	\N	1.14999999999999991	01:08:00	\N	1.27000000000000002	\N	\N	Edgely, Pa.	PA
61761	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:11:00	\N	1.16999999999999993	00:52:00	\N	1.02000000000000002	\N	\N	Edgemoor, Del.	DE
61762	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.7250000000000014	-75.5600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:19:00	\N	1.06000000000000005	01:08:00	\N	0.989999999999999991	\N	\N	Millside, RR. bridge	DE
61763	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7182999999999993	-75.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	01:06:00	\N	1.1100000000000001	00:50:00	\N	0.989999999999999991	\N	\N	Wilmington Marine Terminal	DE
61764	New Castle, Delaware River, Delaware	NOS	8551201	39.6567000000000007	-75.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:40:00	\N	1	00:29:00	\N	0.979999999999999982	\N	\N	New Castle, Delaware	DE
61765	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833000000000013	-75.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:00:00	\N	1	00:03:00	\N	1.05000000000000004	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
61766	Delaware City, Delaware River, Delaware (sub)	NOS	8551762	39.5816999999999979	-75.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:14:00	\N	1	00:11:00	\N	0.989999999999999991	\N	\N	Delaware City	DE
61767	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.5700000000000003	-75.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:05:00	\N	0.890000000000000013	00:00:00	\N	1.02000000000000002	\N	\N	Delaware City Branch Channel bridge	DE
61768	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.5549999999999997	-75.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:17:00	\N	1	-00:16:00	\N	0.82999999999999996	\N	\N	St. Georges, Delaware	DE
61769	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.533299999999997	-75.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-00:52:00	\N	0.560000000000000053	-00:28:00	\N	0.650000000000000022	\N	\N	Summit Bridge, Delaware	DE
61770	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.4050000000000011	-75.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	00:57:00	\N	0.560000000000000053	01:53:00	\N	0.540000000000000036	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
61771	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333000000000013	-75.466700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:10:00	\N	1.1100000000000001	-01:07:00	\N	1.1100000000000001	\N	\N	Woodland Beach, Del.	DE
61772	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.2449999999999974	-75.5182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	03:49:00	\N	0.630000000000000004	03:35:00	\N	0.849999999999999978	\N	\N	Leipsic, Leipsic River	DE
61773	Mahon River entrance, Delaware Bay, Delaware (sub)	NOS	8554399	39.1850000000000023	-75.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:29:00	\N	1.12999999999999989	00:58:00	\N	1.30000000000000004	\N	\N	Mahon River entrance	DE
61774	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583000000000027	-75.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	01:11:00	\N	0.939999999999999947	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
61775	Brandywine Shoal Light, Delaware Bay, New Jersey (sub)	NOS	8555889	38.9866699999999966	-75.1133333333333297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:23:00	\N	1.06000000000000005	-00:01:00	\N	1.15999999999999992	\N	\N	Brandywine Shoal Light	NJ
61776	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.9450000000000003	-75.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60367	00:50:00	\N	1	00:22:00	\N	1.12999999999999989	\N	\N	Mispillion River entrance	DE
61777	Rehoboth Beach, Delaware	NOS	8557863	38.7199999999999989	-75.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:08:00	\N	1.33000000000000007	00:15:00	\N	1.12999999999999989	\N	\N	Rehoboth Beach	DE
61778	Inlet (Coast Guard Station), Indian River, Delaware (sub)	NOS	8558690	38.6099999999999994	-75.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:45:00	\N	1	01:14:00	\N	0.760000000000000009	\N	\N	Indian River Inlet (Coast Guard Station)	DE
61779	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.341700000000003	-75.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:54:00	\N	0.810000000000000053	-00:57:00	\N	0.469999999999999973	\N	\N	Keydash, Isle of Wight Bay	MD
61780	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3316999999999979	-75.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:23:00	\N	0.939999999999999947	00:25:00	\N	0.67000000000000004	\N	\N	Ocean City (Isle of Wight Bay)	MD
61781	Ocean City Inlet, Maryland (sub)	NOS	8570283	38.3283300000000011	-75.0916666666666686	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:14:00	\N	1	00:28:00	\N	0.650000000000000022	\N	\N	Ocean City Inlet	MD
61782	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland (sub)	NOS	8570536	38.2150000000000034	-75.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	05:02:00	\N	0.160000000000000003	05:16:00	\N	0.160000000000000003	\N	\N	South Point, Sinepuxent Neck	MD
61783	Public Landing, Chincoteague Bay, Maryland (sub)	NOS	8570649	38.148299999999999	-75.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	05:21:00	\N	0.179999999999999993	04:41:00	\N	0.179999999999999993	\N	\N	Public Landing	MD
61784	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.9617000000000004	-75.821700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:58:00	\N	0.82999999999999996	04:27:00	\N	0.900000000000000022	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
61785	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland (sub)	NOS	8571091	37.976700000000001	-75.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:51:00	\N	1	04:34:00	\N	0.75	\N	\N	Crisfield, Little Annemessex River	MD
61786	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.9799999999999969	-75.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:16:00	\N	1	04:32:00	\N	0.939999999999999947	\N	\N	Shelltown	MD
61787	Ewell, Smith Island, Chesapeake Bay, Maryland (sub)	NOS	8571117	37.9949999999999974	-76.0317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:19:00	\N	1	04:56:00	\N	0.609999999999999987	\N	\N	Ewell, Smith Island	MD
61788	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0482999999999976	-75.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:30:00	\N	1.16999999999999993	04:59:00	\N	0.780000000000000027	\N	\N	Colburn Creek, Big Annemessex River	MD
61789	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0566999999999993	-75.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:47:00	\N	0.82999999999999996	05:19:00	\N	0.819999999999999951	\N	\N	Long Point, Big Annemessex River	MD
61790	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683000000000007	-76.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:30:00	\N	0.57999999999999996	05:16:00	\N	0.560000000000000053	\N	\N	Holland Island Bar Light	MD
61791	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1082999999999998	-75.8383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:05:00	\N	0.82999999999999996	05:38:00	\N	0.819999999999999951	\N	\N	Teague Creek, Manokin River	MD
61792	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717000000000013	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:57:00	\N	1.16999999999999993	05:29:00	\N	0.780000000000000027	\N	\N	Chance	MD
61793	Snow Hill, city park, Pocomoke River, Maryland (sub)	NOS	8571359	38.1783300000000025	-75.3966666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	08:54:00	\N	1.33000000000000007	08:44:00	\N	0.57999999999999996	\N	\N	Snowhill, city park	MD
61794	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017000000000024	-75.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:06:00	\N	0.92000000000000004	05:46:00	\N	0.859999999999999987	\N	\N	Sharkfin Shoal Light	MD
61795	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.226700000000001	-76.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	05:51:00	\N	1.16999999999999993	05:26:00	\N	0.609999999999999987	\N	\N	Hooper Strait Light	MD
61796	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.216700000000003	-75.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:22:00	\N	0.92000000000000004	06:00:00	\N	0.900000000000000022	\N	\N	Great Shoals Light, Monie Bay	MD
61797	Bishops Head, Hooper Strait, Maryland (sub)	NOS	8571421	38.2203888888888912	-76.0386666666666713	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:04:00	\N	1.08000000000000007	05:32:00	\N	0.699999999999999956	\N	\N	Bishops Head, Hooper Strait	MD
61798	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2616999999999976	-75.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:35:00	\N	0.92000000000000004	06:00:00	\N	0.900000000000000022	\N	\N	Roaring Point	MD
61799	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683000000000035	-75.7883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:46:00	\N	1	06:26:00	\N	0.939999999999999947	\N	\N	Whitehaven	MD
61800	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967000000000013	-76.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:39:00	\N	1.5	-04:40:00	\N	1.32000000000000006	\N	\N	Middle Hooper Island	MD
61801	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland (sub)	NOS	8571559	38.2999999999999972	-76.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:22:00	\N	1.16999999999999993	05:49:00	\N	0.819999999999999951	\N	\N	McCreedy's Creek, Fishing Bay	MD
61802	Barren Island, Chesapeake Bay, Maryland (sub)	NOS	8571579	38.341700000000003	-76.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:56:00	\N	0.680000000000000049	-04:45:00	\N	1.01000000000000001	\N	\N	Barren Island	MD
61803	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland (sub)	NOS	8571702	38.4283300000000025	-76.2366666666666646	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:49:00	\N	0.819999999999999951	-02:26:00	\N	1.01000000000000001	\N	\N	Smithville Road Bridge, Beaverdam Creek	MD
61804	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.466700000000003	-76.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:00:00	\N	1.17999999999999994	-03:15:00	\N	1.10000000000000009	\N	\N	Taylors Island, Slaughter Creek	MD
61805	Vienna, Nanticoke River, Maryland (sub)	NOS	8571773	38.4833300000000023	-75.818333333333328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	08:32:00	\N	1.33000000000000007	08:25:00	\N	0.790000000000000036	\N	\N	Vienna	MD
61806	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067000000000021	-76.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:55:00	\N	1.40999999999999992	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
61807	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.5450000000000017	-75.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	09:28:00	\N	1	09:19:00	\N	0.969999999999999973	\N	\N	Sharptown	MD
61808	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617000000000019	-76.2082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:57:00	\N	1.27000000000000002	-03:07:00	\N	1.17999999999999994	\N	\N	Cherry Island, Beckwiths Creek	MD
61809	Cambridge, Choptank River, Maryland (sub)	NOS	8571892	38.5741666999999993	-76.0722221999999988	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:28:00	\N	0.949999999999999956	-02:42:00	\N	1.22999999999999998	\N	\N	Cambridge	MD
61810	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.7100000000000009	-76.3349999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:48:00	\N	1.3600000000000001	-02:54:00	\N	1.17999999999999994	\N	\N	Avalon, Dogwood Harbor	MD
61811	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567000000000021	-75.9983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:41:00	\N	1.67999999999999994	-00:18:00	\N	1.54000000000000004	\N	\N	Dover Bridge	MD
61812	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.7650000000000006	-76.3282999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:42:00	\N	1	-02:33:00	\N	0.979999999999999982	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
61813	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933000000000007	-76.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:45:00	\N	1.40999999999999992	-02:50:00	\N	1.25	\N	\N	Oxford	MD
61814	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7316999999999965	-76.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:47:00	\N	1.40999999999999992	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
61815	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683000000000035	-76.0949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:35:00	\N	1.59000000000000008	-02:45:00	\N	1.46999999999999997	\N	\N	Easton Point	MD
61816	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.7749999999999986	-76.2332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:52:00	\N	1.40999999999999992	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
61817	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867000000000033	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:02:00	\N	1.17999999999999994	-02:12:00	\N	1.21999999999999997	\N	\N	St. Michaels, Miles River	MD
61818	Kent Point Marina, Chesapeake Bay, Maryland (sub)	NOS	8572467	38.8367000000000004	-76.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:29:00	\N	0.949999999999999956	-02:21:00	\N	0.969999999999999973	\N	\N	Kent Point Marina	MD
61819	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367000000000004	-76.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:28:00	\N	1.09000000000000008	-02:26:00	\N	0.959999999999999964	\N	\N	Claiborne, Eastern Bay	MD
61820	Hillsboro, Tuckahoe Creek, Maryland (sub)	NOS	8572669	38.9166999999999987	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:18:00	\N	0.859999999999999987	01:21:00	\N	1.83000000000000007	\N	\N	Hillsboro, Tuckahoe Creek	MD
61821	Matapeake, Kent Island, Chesapeake Bay, Maryland (sub)	NOS	8572770	38.9566999999999979	-76.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:49:00	\N	0.949999999999999956	-01:30:00	\N	0.900000000000000022	\N	\N	Matapeake, Kent Island	MD
61822	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.966700000000003	-76.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:23:00	\N	1.17999999999999994	-01:30:00	\N	1.10000000000000009	\N	\N	Kent Island Narrows	MD
61823	Queenstown, Chester River, Maryland	NOS	8572867	38.996699999999997	-76.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:08:00	\N	1.27000000000000002	00:05:00	\N	1.17999999999999994	\N	\N	Queenstown	MD
61824	Love Point, Chester River, Maryland (sub)	NOS	8572955	39.0317000000000007	-76.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:41:00	\N	0.949999999999999956	-00:25:00	\N	1.03000000000000003	\N	\N	Love Point	MD
61825	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533000000000001	-76.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:14:00	\N	1.8899999999999999	00:20:00	\N	1.46999999999999997	\N	\N	Centreville Landing, Corsica River	MD
61826	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1066999999999965	-76.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:02:00	\N	1.5	00:12:00	\N	1.32000000000000006	\N	\N	Cliffs Point	MD
61827	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.1099999999999994	-76.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:08:00	\N	1.27000000000000002	00:09:00	\N	1.33000000000000007	\N	\N	Cliffs Wharf	MD
61828	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.1450000000000031	-76.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:04:00	\N	1.09000000000000008	00:02:00	\N	0.959999999999999964	\N	\N	Deep Landing, Swan Creek	MD
61829	Chestertown, Chester River, Maryland	NOS	8573343	39.2066999999999979	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:36:00	\N	1.77000000000000002	01:03:00	\N	1.62000000000000011	\N	\N	Chestertown	MD
61830	Crumpton, Chester River, Maryland (sub)	NOS	8573349	39.2449999999999974	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:04:00	\N	0.910000000000000031	01:10:00	\N	1.82000000000000006	\N	\N	Crumpton	MD
61831	Tolchester Beach, Chesapeake Bay, Maryland (sub)	NOS	8573364	39.2133299999999991	-76.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:11:00	\N	0.949999999999999956	00:18:00	\N	1.04000000000000004	\N	\N	Tolchester Beach	MD
61832	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967000000000013	-76.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:19:00	\N	1.27000000000000002	01:22:00	\N	1.17999999999999994	\N	\N	Worton Creek entrance	MD
61833	Sassafras River, Betterton, Chesapeake Bay, Maryland (sub)	NOS	8573704	39.371699999999997	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	02:15:00	\N	1	02:35:00	\N	1.34000000000000008	\N	\N	Sassafras River, Betterton	MD
61834	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8573777	37.9216666666670079	-75.7283333333329978	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:36:00	\N	1.16999999999999993	03:52:00	\N	0.890000000000000013	\N	\N	Saxis, Starling Creek, Pocomoke Sound	MD
61835	Town Point Wharf, Elk River, Maryland (sub)	NOS	8573903	39.503300000000003	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	02:59:00	\N	0.859999999999999987	03:18:00	\N	1.73999999999999999	\N	\N	Town Point Wharf	MD
61836	Chesapeake City, Chesapeake and Delaware Canal, Maryland (sub)	NOS	8573927	39.5266999999999982	-75.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60364	-01:12:00	\N	1.28000000000000003	-00:45:00	\N	0.560000000000000053	\N	\N	Chesapeake City, Maryland	MD
61837	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733000000000033	-75.9699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	04:03:00	\N	1.8600000000000001	03:52:00	\N	1.68999999999999995	\N	\N	Charlestown, Northeast River	MD
61838	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.5750000000000028	-75.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:00:00	\N	2.27000000000000002	03:13:00	\N	2.06000000000000005	\N	\N	Old Frenchtown Wharf	MD
61839	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6032999999999973	-76.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:49:00	\N	1.1399999999999999	03:24:00	\N	1.51000000000000001	\N	\N	Port Deposit	MD
61840	Havre de Grace, Susquehanna River, Maryland (sub)	NOS	8574070	39.5367000000000033	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	03:27:00	\N	0.949999999999999956	03:13:00	\N	1.55000000000000004	\N	\N	Havre de Grace	MD
61841	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland (sub)	NOS	8574459	39.388300000000001	-76.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	01:31:00	\N	0.859999999999999987	01:52:00	\N	1.06000000000000005	\N	\N	Pond Point, Bush River	MD
61842	Fort McHenry Marsh, Patapsco River, Maryland (sub)	NOS	8574683	39.2616999999999976	-76.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Fort McHenry Marsh	MD
61843	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083000000000013	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:06:00	\N	0.949999999999999956	00:00:00	\N	1.03000000000000003	\N	\N	Hawkins Point	MD
61844	North Point, Patapsco River, Maryland	NOS	8574857	39.1966999999999999	-76.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	00:04:00	\N	1.09000000000000008	00:12:00	\N	0.930000000000000049	\N	\N	North Point	MD
61845	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1632999999999996	-76.5267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:05:00	\N	0.910000000000000031	00:03:00	\N	0.949999999999999956	\N	\N	Stony Creek	MD
61846	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1000000000000014	-76.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:38:00	\N	0.949999999999999956	-00:29:00	\N	0.890000000000000013	\N	\N	Cornfield Creek, Magothy River	MD
61847	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617000000000019	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:04:00	\N	0.770000000000000018	-00:04:00	\N	0.739999999999999991	\N	\N	Mountain Point, Magothy River	MD
61848	Brewer Point, Severn River, Maryland	NOS	8575331	39.0266999999999982	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-00:54:00	\N	0.910000000000000031	-00:45:00	\N	0.739999999999999991	\N	\N	Brewer Point	MD
61849	Annapolis (US Naval Academy), Severn River, Maryland (sub)	NOS	8575512	38.9832800000000006	-76.4815555551317061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:44:00	\N	1	-01:30:00	\N	0.880000000000000004	\N	\N	Annapolis (US Naval Academy)	MD
61850	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583000000000013	-76.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:06:00	\N	1	-02:01:00	\N	0.92000000000000004	\N	\N	Gingerville Creek, South River	MD
61851	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.9500000000000028	-76.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:07:00	\N	0.910000000000000031	-01:51:00	\N	0.810000000000000053	\N	\N	Edgewater, South River	MD
61852	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.8999999999999986	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:11:00	\N	0.910000000000000031	-01:56:00	\N	0.810000000000000053	\N	\N	Thomas Point Shoal Light	MD
61853	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8866999999999976	-76.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:17:00	\N	1	-02:07:00	\N	0.880000000000000004	\N	\N	Rhode River (County Wharf)	MD
61854	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.841700000000003	-76.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-01:34:00	\N	0.910000000000000031	-01:39:00	\N	0.810000000000000053	\N	\N	Galesville, West River	MD
61855	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.7250000000000014	-76.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:44:00	\N	0.910000000000000031	-02:37:00	\N	0.810000000000000053	\N	\N	Rose Haven	MD
61856	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7000000000000028	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:05:00	\N	1	-02:47:00	\N	0.880000000000000004	\N	\N	Chesapeake Beach	MD
61857	Long Beach, Chesapeake Bay, Maryland (sub)	NOS	8577004	38.4650000000000034	-76.4732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:04:00	\N	0.770000000000000018	-03:47:00	\N	0.869999999999999996	\N	\N	Long Beach	MD
61858	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.4149999999999991	-76.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:19:00	\N	1.3600000000000001	-04:13:00	\N	1.17999999999999994	\N	\N	Broomes Island	MD
61859	Cove Point, Chesapeake Bay, Maryland (sub)	NOS	8577188	38.3917000000000002	-76.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:25:00	\N	0.82999999999999996	-04:10:00	\N	0.82999999999999996	\N	\N	Cove Point	MD
61860	Solomons Island, Patuxent River, Maryland (sub)	NOS	8577330	38.3172222000000033	-76.4508332999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-04:46:00	\N	0.729999999999999982	-04:38:00	\N	0.979999999999999982	\N	\N	Solomons Island	MD
61861	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.0600000000000023	-76.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:35:00	\N	0.530000000000000027	-06:16:00	\N	0.479999999999999982	\N	\N	Cornfield Harbor, Md.	MD
61862	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.0399999999999991	-76.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-05:37:00	\N	0.770000000000000018	-05:28:00	\N	1.02000000000000002	\N	\N	Point Lookout	MD
61863	Piney Point, Potomac River, Maryland	NOS	8578240	38.1332999999999984	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:16:00	\N	0.599999999999999978	-05:54:00	\N	0.510000000000000009	\N	\N	Piney Point, Md.	MD
61864	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233000000000018	-76.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:43:00	\N	0.729999999999999982	-05:18:00	\N	0.650000000000000022	\N	\N	Colton Point, Md.	MD
61865	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267000000000024	-76.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:05:00	\N	0.729999999999999982	-05:05:00	\N	0.650000000000000022	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
61866	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.341700000000003	-76.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-05:56:00	\N	0.599999999999999978	-04:48:00	\N	0.540000000000000036	\N	\N	Lower Cedar Point, Md.	MD
61867	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4532999999999987	-77.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-05:07:00	\N	0.599999999999999978	-04:08:00	\N	0.540000000000000036	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
61868	Riverside, Potomac River, Maryland	NOS	8578853	38.3866999999999976	-77.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:24:00	\N	0.530000000000000027	-03:23:00	\N	0.479999999999999982	\N	\N	Riverside, Md.	MD
61869	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.4133333333329929	-77.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:46:00	\N	0.67000000000000004	-01:42:00	\N	0.409999999999999976	\N	\N	Clifton Beach, Smith Point, Md.	MD
61870	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.4600000000000009	-77.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:58:00	\N	0.67000000000000004	-00:39:00	\N	0.440000000000000002	\N	\N	Liverpool Point, Md.	MD
61871	Benedict, Patuxent River, Maryland	NOS	8579135	38.513300000000001	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-03:54:00	\N	1.82000000000000006	-03:54:00	\N	1.46999999999999997	\N	\N	Benedict	MD
61872	Indian Head, Potomac River, Maryland	NOS	8579381	38.601700000000001	-77.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:33:00	\N	0.729999999999999982	-00:14:00	\N	0.650000000000000022	\N	\N	Indian Head, Md.	MD
61873	Lower Marlboro, Patuxent River, Maryland (sub)	NOS	8579542	38.6550000000000011	-76.6833333333333371	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60397	-02:51:00	\N	0.770000000000000018	-02:44:00	\N	1.43999999999999995	\N	\N	Lower Marlboro	MD
61874	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867000000000019	-77.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:55:00	\N	0.930000000000000049	00:10:00	\N	0.819999999999999951	\N	\N	Marshall Hall, Md.	MD
61875	Bladensburg, Anacostia River, Maryland (sub)	NOS	8579997	38.9333000000000027	-76.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:25:00	\N	1.12999999999999989	00:31:00	\N	1.06000000000000005	\N	\N	Bladensburg, Md.	MD
61876	Bellevue, Potomac River, DC	NOS	8590111	38.8267000000000024	-77.0267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:11:00	\N	1.33000000000000007	00:34:00	\N	1.02000000000000002	\N	\N	Bellevue, D.C.	DC
61877	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.871699999999997	-76.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:06:00	\N	1.19999999999999996	00:18:00	\N	1.01000000000000001	\N	\N	Washington Naval Yard	DC
61878	Kingman Lake, Anacostia River, DC	NOS	8593545	38.8950000000000031	-76.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:04:00	\N	1.19999999999999996	00:22:00	\N	1.03000000000000003	\N	\N	Kingman Lake	DC
61879	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.9099999999999966	-76.9549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	00:10:00	\N	1.07000000000000006	00:29:00	\N	1.05000000000000004	\N	\N	Kenilworth Aquatic Garden	DC
61880	Franklin City, Virginia	NOS	8630055	38.0067000000000021	-75.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	03:00:00	\N	0.630000000000000004	02:20:00	\N	0.220000000000000001	\N	\N	Franklin City	VA
61881	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517000000000024	-75.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	02:32:00	\N	0.560000000000000053	01:51:00	\N	0.280000000000000027	\N	\N	Chincoteague Island, Blake Cove	VA
61882	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9416999999999973	-75.3466999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	02:05:00	\N	0.560000000000000053	01:44:00	\N	0.46000000000000002	\N	\N	Chincoteague Island, Oyster Bay	VA
61883	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9382999999999981	-75.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:38:00	\N	0.630000000000000004	01:17:00	\N	0.400000000000000022	\N	\N	Chincoteague Island, Lewis Creek	VA
61884	Chincoteague Channel (south end), Chincoteague Bay, Virginia (sub)	NOS	8630308	37.9067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:47:00	\N	0.689999999999999947	00:39:00	\N	0.640000000000000013	\N	\N	Chincoteague Channel (south end)	VA
61885	Harbor of Refuge, Virginia	NOS	8630316	37.9033000000000015	-75.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:35:00	\N	0.880000000000000004	00:31:00	\N	0.729999999999999982	\N	\N	Harbor of Refuge	VA
61886	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817000000000021	-75.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:13:00	\N	0.630000000000000004	00:52:00	\N	0.770000000000000018	\N	\N	Wishart Point, Bogues Bay	VA
61887	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865000000000002	-75.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:48:00	\N	1.25	00:35:00	\N	1.08000000000000007	\N	\N	Assateague Beach, Toms Cove	VA
61888	Wallops Island, Virginia	NOS	8630440	37.841700000000003	-75.4783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	-00:04:00	\N	0.309999999999999998	00:04:00	\N	1.06000000000000005	\N	\N	Wallops Island	VA
61889	Gargathy Neck, Virginia	NOS	8630637	37.7766999999999982	-75.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:27:00	\N	0.630000000000000004	01:31:00	\N	0.880000000000000004	\N	\N	Gargathy Neck	VA
61890	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6966999999999999	-75.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:12:00	\N	0.630000000000000004	01:24:00	\N	0.969999999999999973	\N	\N	Folly Creek, Metompkin Inlet	VA
61891	Metompkin Inlet, Virginia	NOS	8630901	37.6717000000000013	-75.5949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:44:00	\N	1.25	01:01:00	\N	1.08000000000000007	\N	\N	Metompkin Inlet	VA
61892	Wachapreague, Wachapreague Channel, Virginia (sub)	NOS	8631044	37.6077777777777769	-75.6858333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:56:00	\N	1.06000000000000005	01:10:00	\N	1.18999999999999995	\N	\N	Wachapreague, Wachapreague Channel	VA
61893	Revel Island, Revel Creek, Virginia	NOS	8631234	37.496699999999997	-75.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:27:00	\N	1	00:35:00	\N	1.18999999999999995	\N	\N	Revel Creek, Revel Island	VA
61894	Upshur Neck, south end, Virginia	NOS	8631287	37.466700000000003	-75.7999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:14:00	\N	1.25	01:09:00	\N	1.31000000000000005	\N	\N	Upshur Neck, south end	VA
61895	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933000000000035	-75.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:56:00	\N	1.25	01:05:00	\N	1.15999999999999992	\N	\N	Great Machipongo Inlet (inside)	VA
61896	Sand Shoal Inlet (Coast Guard Station), Virginia	NOS	8631542	37.3016999999999967	-75.7783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:17:00	\N	1	00:32:00	\N	1.17999999999999994	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
61897	Oyster Harbor, Virginia	NOS	8631591	37.2882999999999996	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	00:36:00	\N	1.12999999999999989	01:00:00	\N	1.34000000000000008	\N	\N	Oyster Harbor	VA
61898	Smith Island (Coast Guard Station), Virginia	NOS	8631874	37.1233000000000004	-75.9116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60369	01:29:00	\N	1.25	00:52:00	\N	1.05000000000000004	\N	\N	Smith Island (Coast Guard Station)	VA
61899	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0966999999999985	-75.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:11:00	\N	1.25	00:02:00	\N	1.18999999999999995	\N	\N	Fishermans Island	VA
61900	Kiptopeke Beach, Chesapeake Bay, Virginia (sub)	NOS	8632200	37.1651900000000026	-75.9884444443384837	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:32:00	\N	0.92000000000000004	00:23:00	\N	1.01000000000000001	\N	\N	Kiptopeke Beach	VA
61901	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2332999999999998	-76.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:52:00	\N	0.82999999999999996	00:33:00	\N	0.92000000000000004	\N	\N	Old Plantation Light	VA
61902	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.263300000000001	-76.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	01:03:00	\N	0.92000000000000004	00:45:00	\N	0.900000000000000022	\N	\N	Cape Charles Harbor	VA
61903	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia (sub)	NOS	8632869	37.5566999999999993	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:13:00	\N	0.82999999999999996	02:35:00	\N	0.660000000000000031	\N	\N	Gaskins Point, Occohannock Creek	VA
61904	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6666999999999987	-75.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:33:00	\N	0.82999999999999996	03:11:00	\N	0.699999999999999956	\N	\N	Harborton, Pungoteague Creek	VA
61905	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117000000000004	-75.756699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:19:00	\N	0.82999999999999996	03:55:00	\N	0.709999999999999964	\N	\N	Onancock, Onancock Creek	VA
61906	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.763300000000001	-75.7733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:59:00	\N	1.25	03:41:00	\N	0.780000000000000027	\N	\N	Chesconessex Creek, Schooner Bay	VA
61907	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7982999999999976	-75.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:12:00	\N	0.82999999999999996	04:02:00	\N	0.640000000000000013	\N	\N	Watts Island	VA
61908	Tangier Island, Chesapeake Bay, Virginia (sub)	NOS	8633532	37.8282999999999987	-75.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:16:00	\N	0.75	03:58:00	\N	0.599999999999999978	\N	\N	Tangier Island	VA
61909	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.8500000000000014	-75.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:47:00	\N	0.82999999999999996	04:06:00	\N	0.900000000000000022	\N	\N	Guard Shore	VA
61910	Muddy Creek Entrance, Chesapeake Bay, Virginia	NOS	8633604	37.8549999999999969	-75.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:51:00	\N	0.82999999999999996	04:14:00	\N	0.859999999999999987	\N	\N	Muddy Creek Entrance	VA
61911	Alexandria, Potomac River, Virginia	NOS	8634214	38.8049999999999997	-77.0383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:11:00	\N	1.33000000000000007	00:18:00	\N	0.959999999999999964	\N	\N	Alexandria, Va.	VA
61912	Quantico, Potomac River, Virginia	NOS	8634689	38.5200000000000031	-77.2866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:04:00	\N	0.67000000000000004	-00:52:00	\N	0.510000000000000009	\N	\N	Quantico, Va.	VA
61913	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183000000000021	-77.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:32:00	\N	0.67000000000000004	-01:28:00	\N	0.479999999999999982	\N	\N	Aquia Creek, Va.	VA
61914	Mathias Point, Potomac River, Virginia	NOS	8634892	38.398299999999999	-77.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:56:00	\N	0.67000000000000004	-04:00:00	\N	0.440000000000000002	\N	\N	Mathias Point, Va.	VA
61915	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.2550000000000026	-77.4099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-00:41:00	\N	1.33000000000000007	-00:39:00	\N	0.880000000000000004	\N	\N	Massaponax	VA
61916	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2432999999999979	-77.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-01:57:00	\N	0.67000000000000004	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
61917	Rappahannock Bend, Virginia (sub)	NOS	8635257	38.2132999999999967	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-02:30:00	\N	0.200000000000000011	-01:35:00	\N	0.729999999999999982	\N	\N	Park Turn	VA
61918	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1732999999999976	-77.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:02:00	\N	0.67000000000000004	-02:19:00	\N	0.680000000000000049	\N	\N	Port Royal	VA
61919	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983000000000018	-76.7349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:14:00	\N	0.67000000000000004	-04:51:00	\N	0.540000000000000036	\N	\N	Mount Holly, Nomini Creek, Va.	VA
61920	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417000000000002	-76.6132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:03:00	\N	0.67000000000000004	-05:35:00	\N	0.540000000000000036	\N	\N	Ragged Point, Coles Neck, Va.	VA
61921	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.0900000000000034	-77.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:41:00	\N	0.660000000000000031	-03:53:00	\N	0.540000000000000036	\N	\N	Saunders Wharf	VA
61922	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317000000000007	-76.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-06:53:00	\N	0.67000000000000004	-05:46:00	\N	0.440000000000000002	\N	\N	Kinsale, Yeocomico River, Va.	VA
61923	Lewisetta, Potomac River, Virginia (sub)	NOS	8635750	37.9953888888888898	-76.4646111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:31:00	\N	0.800000000000000044	-06:19:00	\N	0.46000000000000002	\N	\N	Lewisetta, Va.	VA
61924	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.996699999999997	-76.466700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-07:05:00	\N	0.67000000000000004	-06:00:00	\N	0.440000000000000002	\N	\N	Travis Point, Coan River, Va.	VA
61925	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.9299999999999997	-76.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:18:00	\N	0.82999999999999996	04:40:00	\N	0.709999999999999964	\N	\N	Tappahannock	VA
61926	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8866999999999976	-76.2667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	06:45:00	\N	0.299999999999999989	06:41:00	\N	0.299999999999999989	\N	\N	Sunnybank, Little Wicomico River	VA
61927	Wares Wharf, Rappahannock River, Virginia (sub)	NOS	8635985	37.8733000000000004	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:34:00	\N	0.330000000000000016	04:04:00	\N	0.75	\N	\N	Wares Wharf	VA
61928	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8466999999999985	-76.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:37:00	\N	0.82999999999999996	04:15:00	\N	0.489999999999999991	\N	\N	Glebe Point, Great Wicomico River	VA
61929	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8132999999999981	-76.2750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:14:00	\N	0.409999999999999976	03:58:00	\N	0.409999999999999976	\N	\N	Fleeton Point	VA
61930	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.8049999999999997	-76.2682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	04:11:00	\N	0.409999999999999976	03:58:00	\N	0.409999999999999976	\N	\N	Great Wicomico River Light	VA
61931	Bayport, Rappahannock River, Virginia	NOS	8636261	37.7550000000000026	-76.6732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:51:00	\N	0.82999999999999996	03:22:00	\N	0.67000000000000004	\N	\N	Bayport	VA
61932	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683000000000021	-76.486699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:05:00	\N	0.82999999999999996	02:37:00	\N	0.550000000000000044	\N	\N	Millenbeck, Corrotoman River	VA
61933	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.6499999999999986	-76.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:57:00	\N	1.66999999999999993	03:34:00	\N	1.40999999999999992	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
61934	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.6499999999999986	-76.5750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:09:00	\N	0.82999999999999996	02:50:00	\N	0.589999999999999969	\N	\N	Urbanna	VA
61935	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	06:18:00	\N	1.66999999999999993	06:03:00	\N	1.37000000000000011	\N	\N	Northbury	VA
61936	Windmill Point, Rappahannock River, Virginia (sub)	NOS	8636580	37.6161111111111097	-76.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:14:00	\N	0.82999999999999996	01:55:00	\N	0.489999999999999991	\N	\N	Windmill Point	VA
61937	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5966999999999985	-76.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	03:12:00	\N	0.409999999999999976	02:48:00	\N	0.409999999999999976	\N	\N	Windmill Point Light	VA
61938	Lester Manor, Pamunkey River, Virginia (sub)	NOS	8636653	37.5833000000000013	-76.9899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:00:00	\N	0.82999999999999996	04:45:00	\N	1.05000000000000004	\N	\N	Lester Manor	VA
61939	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833000000000013	-76.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:42:00	\N	0.82999999999999996	02:28:00	\N	0.550000000000000044	\N	\N	Mill Creek (Grey Point)	VA
61940	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5482999999999976	-76.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:04:00	\N	0.82999999999999996	01:36:00	\N	0.510000000000000009	\N	\N	Jackson Creek, Deltaville	VA
61941	West Point, York River, Virginia	NOS	8636769	37.5349999999999966	-76.7933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:38:00	\N	0.82999999999999996	02:12:00	\N	1.1399999999999999	\N	\N	West Point	VA
61942	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067000000000021	-76.4167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:14:00	\N	0.82999999999999996	01:34:00	\N	0.550000000000000044	\N	\N	Dixie	VA
61943	Roane Point, York River, Virginia	NOS	8636969	37.4466999999999999	-76.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:50:00	\N	0.82999999999999996	01:47:00	\N	1.1399999999999999	\N	\N	Roane Point	VA
61944	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117000000000033	-76.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:00:00	\N	0.82999999999999996	-00:06:00	\N	1.02000000000000002	\N	\N	Belleville	VA
61945	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.3900000000000006	-76.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:32:00	\N	0.82999999999999996	-00:02:00	\N	0.67000000000000004	\N	\N	Wolf Trap Light	VA
61946	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733000000000004	-76.3466999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:02:00	\N	0.82999999999999996	-00:17:00	\N	0.979999999999999982	\N	\N	Mobjack, East River	VA
61947	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.2999999999999972	-76.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	-00:03:00	\N	1.58000000000000007	-00:11:00	\N	0.979999999999999982	\N	\N	Browns Bay	VA
61948	Cheatham Annex, York River, Virginia	NOS	8637472	37.2916999999999987	-76.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:40:00	\N	0.82999999999999996	00:48:00	\N	1.02000000000000002	\N	\N	Cheatham Annex	VA
61949	Gloucester Point, York River, Virginia (sub)	NOS	8637624	37.246699999999997	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:11:00	\N	1	00:10:00	\N	0.979999999999999982	\N	\N	Gloucester Point	VA
61950	Tue Marshes Light, York River, Virginia	NOS	8637663	37.2349999999999994	-76.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:03:00	\N	0.82999999999999996	00:03:00	\N	0.900000000000000022	\N	\N	Tue Marshes Light	VA
61951	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.2299999999999969	-76.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:15:00	\N	0.82999999999999996	00:18:00	\N	0.900000000000000022	\N	\N	Yorktown, Goodwin Neck	VA
61952	Yorktown USCG Training Center, York River, Virginia (sub)	NOS	8637689	37.2265000000000015	-76.4788000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:15:00	\N	1.08000000000000007	00:10:00	\N	0.949999999999999956	\N	\N	Yorktown, USCG Training Center	VA
61953	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1082999999999998	-76.3182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:02:00	\N	0.969999999999999973	-00:07:00	\N	0.969999999999999973	\N	\N	Messick Point, Back River	VA
61954	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.003300000000003	-76.3149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:09:00	\N	0.82999999999999996	00:01:00	\N	1.02000000000000002	\N	\N	Old Point Comfort	VA
61955	Newport News, James River, Virginia	NOS	8638379	36.9733000000000018	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:28:00	\N	0.82999999999999996	00:29:00	\N	1.08000000000000007	\N	\N	Newport News	VA
61956	Huntington Park, James River, Virginia	NOS	8638401	37.013300000000001	-76.4582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:39:00	\N	0.92000000000000004	00:38:00	\N	1.07000000000000006	\N	\N	Huntington Park	VA
61957	Town Point, Nansemond River, Virginia	NOS	8638406	36.8832999999999984	-76.5083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:44:00	\N	0.82999999999999996	00:37:00	\N	1.21999999999999997	\N	\N	Town Point	VA
61958	Menchville, James River, Virginia	NOS	8638407	37.0816999999999979	-76.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:19:00	\N	0.82999999999999996	01:03:00	\N	1.06000000000000005	\N	\N	Menchville	VA
61959	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8382999999999967	-76.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:03:00	\N	1.66999999999999993	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
61960	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9832999999999998	-76.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:38:00	\N	0.82999999999999996	01:34:00	\N	1.1399999999999999	\N	\N	Smithfield, Pagan River	VA
61961	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0566999999999993	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	01:39:00	\N	1.16999999999999993	01:17:00	\N	1	\N	\N	Burwell Bay	VA
61962	Kingsmill, James River, Virginia (sub)	NOS	8638424	37.2199999999999989	-76.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	02:26:00	\N	1.33000000000000007	02:05:00	\N	0.939999999999999947	\N	\N	Kingsmill	VA
61963	Scotland, James River, Virginia (sub)	NOS	8638433	37.1850000000000023	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	03:13:00	\N	1.08000000000000007	02:44:00	\N	0.780000000000000027	\N	\N	Scotland	VA
61964	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.3449999999999989	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:03:00	\N	0.82999999999999996	04:44:00	\N	0.900000000000000022	\N	\N	Wright Island Landing	VA
61965	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.263300000000001	-76.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:26:00	\N	0.82999999999999996	04:01:00	\N	0.780000000000000027	\N	\N	Ferry Point (bridge)	VA
61966	Claremont, James River, Virginia	NOS	8638449	37.2316999999999965	-76.9483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	04:25:00	\N	1.16999999999999993	03:51:00	\N	0.760000000000000009	\N	\N	Claremont	VA
61967	Sturgeon Point, James River, Virginia	NOS	8638455	37.3066999999999993	-77.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	05:09:00	\N	0.82999999999999996	04:37:00	\N	0.859999999999999987	\N	\N	Sturgeon Point	VA
61968	Jordan Point, James River, Virginia	NOS	8638476	37.3132999999999981	-77.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	06:39:00	\N	0.82999999999999996	06:16:00	\N	1.02000000000000002	\N	\N	Jordan Point	VA
61970	Meadowville, James River, Virginia	NOS	8638486	37.378300000000003	-77.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:17:00	\N	1.33000000000000007	-03:46:00	\N	1.05000000000000004	\N	\N	Meadowville	VA
61971	Puddledock Sand & Gravel, Appomattox River, Virginia (sub)	NOS	8638489	37.2667000000000002	-77.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-04:32:00	\N	1.07000000000000006	-03:49:00	\N	1	\N	\N	Puddledock, Appomattox River	VA
61972	Chester, James River, Virginia	NOS	8638491	37.3832999999999984	-77.3782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:59:00	\N	0.67000000000000004	-03:39:00	\N	1.02000000000000002	\N	\N	Chester	VA
61973	Richmond River Locks, James River, Virginia (sub)	NOS	8638495	37.5249999999999986	-77.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60405	-03:26:00	\N	1.33000000000000007	-03:16:00	\N	1.15999999999999992	\N	\N	Richmond (river locks)	VA
61974	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9166999999999987	-76.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:40:00	\N	0.82999999999999996	00:42:00	\N	1.05000000000000004	\N	\N	Pig Point	VA
61975	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917000000000002	-76.3383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:04:00	\N	0.82999999999999996	00:18:00	\N	1.06000000000000005	\N	\N	Craney Island Light	VA
61976	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.851700000000001	-76.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:20:00	\N	0.82999999999999996	00:23:00	\N	1.1399999999999999	\N	\N	Norfolk	VA
61977	Portsmouth, Naval Shipyard, Elizabeth River, Virginia (sub)	NOS	8638660	36.8216999999999999	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:10:00	\N	1.16999999999999993	00:08:00	\N	1.12999999999999989	\N	\N	Portsmouth, Naval Shipyard	VA
61978	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117000000000033	-76.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:09:00	\N	1.16999999999999993	00:08:00	\N	1.01000000000000001	\N	\N	Little Creek, NAB	VA
61979	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.861699999999999	-76.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:56:00	\N	0.82999999999999996	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
61980	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933000000000035	-76.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:48:00	\N	0.82999999999999996	01:52:00	\N	0.67000000000000004	\N	\N	Bayville	VA
61981	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067000000000007	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	00:38:00	\N	1.08000000000000007	00:40:00	\N	0.880000000000000004	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
61982	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033000000000015	-76.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	01:15:00	\N	1.08000000000000007	01:15:00	\N	0.680000000000000049	\N	\N	Long Creek	VA
61983	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:43:00	\N	0.82999999999999996	02:05:00	\N	0.650000000000000022	\N	\N	Brown Cove	VA
61984	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9016999999999982	-76.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60443	02:00:00	\N	0.92000000000000004	02:05:00	\N	0.560000000000000053	\N	\N	Broad Bay Canal	VA
61985	Cape Henry, Virginia	NOS	8638999	36.9299999999999997	-76.0066944444444488	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:36:00	\N	0.930000000000000049	00:31:00	\N	0.959999999999999964	\N	\N	Cape Henry	VA
61986	Virginia Beach, Virginia	NOS	8639168	36.8432999999999993	-75.9716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1.07000000000000006	00:15:00	\N	1.07000000000000006	\N	\N	Virginia Beach	VA
61987	Inside channel, Rudee Inlet, Virginia (sub)	NOS	8639207	36.8316999999999979	-75.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1	00:17:00	\N	1.02000000000000002	\N	\N	Rudee Inlet, interior channel	VA
61988	Rudee Inlet entrance, Virginia	NOS	8639208	36.8316999999999979	-75.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:02:00	\N	0.859999999999999987	00:02:00	\N	1.01000000000000001	\N	\N	Rudee Inlet entrance	VA
61989	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.8250000000000028	-75.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:16:00	\N	1	00:18:00	\N	1.03000000000000003	\N	\N	Rudee Heights, Lake Wesley	VA
61990	Lake Rudee, south end, Virginia	NOS	8639219	36.8250000000000028	-75.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:19:00	\N	1.07000000000000006	00:20:00	\N	1.05000000000000004	\N	\N	Lake Rudee, south end	VA
61991	Money Point, South Bridge, Elizabeth River, Virginia (sub)	NOS	8639348	36.778305555555562	-76.3016944444444505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:12:00	\N	1.16999999999999993	00:16:00	\N	1.17999999999999994	\N	\N	Money Point	VA
61992	Deep Creek Entrance, Elizabeth River, Virginia	NOS	8639414	36.7550000000000026	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60440	00:18:00	\N	1.25	00:22:00	\N	1.20999999999999996	\N	\N	Deep Creek Entrance	VA
61993	Sandbridge, Virginia	NOS	8639428	36.6916999999999973	-75.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:07:00	\N	1.04000000000000004	00:07:00	\N	1.04000000000000004	\N	\N	Sandbridge	VA
61994	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.101700000000001	-75.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:02:00	\N	1.42999999999999994	-00:01:00	\N	1.01000000000000001	\N	\N	Kitty Hawk (ocean)	NC
61995	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.9099999999999966	-75.591700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60447	00:01:00	\N	1.42999999999999994	-00:05:00	\N	1.04000000000000004	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
61996	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7982999999999976	-75.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	01:17:00	\N	0.140000000000000013	01:37:00	\N	0.469999999999999973	\N	\N	Roanoke Sound Channel	NC
61997	Old House Channel, North Carolina	NOS	8652648	35.7766999999999982	-75.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	00:28:00	\N	0.209999999999999992	00:34:00	\N	0.660000000000000031	\N	\N	Old House Channel	NC
61998	Oregon Inlet Channel, North Carolina	NOS	8652657	35.773299999999999	-75.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:34:00	\N	0.429999999999999993	-00:09:00	\N	1.22999999999999998	\N	\N	Oregon Inlet Channel	NC
61999	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.773299999999999	-75.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:55:00	\N	0.640000000000000013	-00:17:00	\N	1.8899999999999999	\N	\N	Oregon Inlet Bridge	NC
62000	Davis Slough, North Carolina	NOS	8652737	35.7483000000000004	-75.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:01:00	\N	0.28999999999999998	00:09:00	\N	0.849999999999999978	\N	\N	Davis Slough	NC
62001	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.5949999999999989	-75.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	01:36:00	\N	0.689999999999999947	02:03:00	\N	0.790000000000000036	\N	\N	Rodanthe, Pamlico Sound	NC
62002	Hatteras (USCG Station), North Carolina (sub)	NOS	8654467	35.2086388888888919	-75.7041666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:13:00	\N	1.66999999999999993	-00:15:00	\N	1.1399999999999999	\N	\N	Hatteras (ocean)	NC
62003	Ocracoke, Ocracoke Island, North Carolina (sub)	NOS	8654792	35.115000000000002	-75.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:47:00	\N	0.5	00:15:00	\N	0.340000000000000024	\N	\N	Ocracoke, Ocracoke Island	NC
62004	Core Creek Bridge, North Carolina	NOS	8656084	34.8250000000000028	-76.6899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:46:00	\N	0.82999999999999996	01:26:00	\N	0.680000000000000049	\N	\N	Core Creek Bridge	NC
62005	North River Bridge, North Carolina	NOS	8656225	34.7916999999999987	-76.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	03:08:00	\N	0.67000000000000004	02:25:00	\N	0.589999999999999969	\N	\N	North River Bridge	NC
62006	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683000000000035	-76.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:13:00	\N	1	01:03:00	\N	1.03000000000000003	\N	\N	Newport River (Yacht Club)	NC
62007	Gallant Channel, North Carolina	NOS	8656451	34.7282999999999973	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:44:00	\N	1.25	00:49:00	\N	1.01000000000000001	\N	\N	Gallant Channel	NC
62008	Duke Marine Lab, Beaufort, North Carolina (sub)	NOS	8656483	34.7199999999999989	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:36:00	\N	1.16999999999999993	00:39:00	\N	1.05000000000000004	\N	\N	Beaufort, Duke Marine Lab	NC
62009	Morehead City, North Carolina	NOS	8656496	34.7182999999999993	-76.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:27:00	\N	1.25	00:26:00	\N	1.04000000000000004	\N	\N	Morehead City	NC
62010	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7182999999999993	-76.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:02:00	\N	0.82999999999999996	00:48:00	\N	0.790000000000000036	\N	\N	Atlantic Beach Bridge	NC
62011	Morehead City Harbor, North Carolina	NOS	8656502	34.7199999999999989	-76.7108333333333263	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:37:00	\N	1.16999999999999993	00:35:00	\N	1.04000000000000004	\N	\N	Morehead City Harbor	NC
62012	Harkers Island Bridge, North Carolina	NOS	8656503	34.7150000000000034	-76.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:31:00	\N	0.67000000000000004	02:08:00	\N	0.520000000000000018	\N	\N	Harkers Island Bridge	NC
62013	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117000000000004	-76.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:48:00	\N	1.16999999999999993	00:52:00	\N	0.949999999999999956	\N	\N	Beaufort, Taylor Creek	NC
62014	Lenoxville Point, North Carolina	NOS	8656539	34.7083000000000013	-76.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:11:00	\N	1	01:18:00	\N	0.800000000000000044	\N	\N	Lenoxville Point	NC
62015	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7032999999999987	-76.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:27:00	\N	0.82999999999999996	01:25:00	\N	0.660000000000000031	\N	\N	Channel Marker Lt. 59	NC
62016	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7000000000000028	-76.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:14:00	\N	0.82999999999999996	01:47:00	\N	0.530000000000000027	\N	\N	Coral Bay, Atlantic Beach	NC
62017	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983000000000033	-76.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:11:00	\N	1.66999999999999993	00:07:00	\N	1.07000000000000006	\N	\N	Beaufort Inlet Channel Range	NC
62018	Fort Macon, USCG Station, North Carolina	NOS	8656571	34.6983000000000033	-76.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:18:00	\N	1.25	00:17:00	\N	1.03000000000000003	\N	\N	Fort Macon, USCG Station	NC
62019	Triple S Marina, Bogue Sd., North Carolina	NOS	8656583	34.6950000000000003	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:28:00	\N	1.16999999999999993	00:35:00	\N	0.930000000000000049	\N	\N	Triple ESS Marina, Bogue Sd.	NC
62020	Triple S Pier, Atlantic Beach, North Carolina (sub)	NOS	8656590	34.6933000000000007	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:01:00	\N	1.25	-00:02:00	\N	1.22999999999999998	\N	\N	Atlantic Beach	NC
62021	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6082999999999998	-76.5283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:22:00	\N	1.25	-00:22:00	\N	1.14999999999999991	\N	\N	Cape Lookout (ocean)	NC
62022	New River Inlet, North Carolina	NOS	8657167	34.533299999999997	-77.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:17:00	\N	0.82999999999999996	00:16:00	\N	0.979999999999999982	\N	\N	New River Inlet	NC
62023	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517000000000024	-77.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	-00:01:00	\N	1.33000000000000007	00:03:00	\N	1.39999999999999991	\N	\N	Ocean City Beach (fishing pier)	NC
62024	Wrightsville Beach, North Carolina (sub)	NOS	8658163	34.2133055555555572	-77.7866944444444499	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:23:00	\N	1.25	00:18:00	\N	1.27000000000000002	\N	\N	Wrightsville Beach	NC
62025	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0566999999999993	-77.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-00:58:00	\N	1	-00:36:00	\N	0.979999999999999982	\N	\N	Orton Point	NC
62026	Wilmington Beach, North Carolina	NOS	8658559	34.0317000000000007	-77.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:10:00	\N	1.25	00:18:00	\N	1.39999999999999991	\N	\N	Wilmington Beach	NC
62027	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.003300000000003	-77.9549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:18:00	\N	1.07000000000000006	-00:54:00	\N	0.959999999999999964	\N	\N	Reaves Point	NC
62028	Sunny Point Army Base, Wharf no.1, Cape Fear River, North Carolina	NOS	8658654	33.990000000000002	-77.9566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:45:00	\N	0.930000000000000049	-01:03:00	\N	0.949999999999999956	\N	\N	Sunny Point Army Base, Wharf no.1	NC
62029	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617000000000004	-77.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-01:52:00	\N	0.930000000000000049	-01:17:00	\N	0.939999999999999947	\N	\N	Federal Point	NC
62030	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.8800000000000026	-78.0016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:43:00	\N	1.12999999999999989	-02:06:00	\N	1.05000000000000004	\N	\N	Bald Head	NC
62031	Southport, Cape Fear River, North Carolina (sub)	NOS	8659084	33.9149999999999991	-78.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:22:00	\N	1	-01:49:00	\N	0.989999999999999991	\N	\N	Southport	NC
62032	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967000000000027	-78.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	-02:45:00	\N	1.25	-02:02:00	\N	1.03000000000000003	\N	\N	Fort Caswell	NC
62033	Oak Island, Yaupon Beach, North Carolina (sub)	NOS	8659182	33.9016999999999982	-78.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:05:00	\N	0.839999999999999969	-00:05:00	\N	0.939999999999999947	\N	\N	Oak Island, Yaupon Beach	NC
62034	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.9149999999999991	-78.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:55:00	\N	1	00:43:00	\N	0.910000000000000031	\N	\N	Shallotte Inlet (Bowen Point)	NC
62035	Sunset Beach Pier, North Carolina (sub)	NOS	8659897	33.865000000000002	-78.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:03:00	\N	1.1100000000000001	00:02:00	\N	0.969999999999999973	\N	\N	Sunset Beach Pier	NC
62036	Sunset Beach Bridge, North Carolina	NOS	8659899	33.8816666666670088	-78.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:56:00	\N	0.839999999999999969	00:34:00	\N	0.939999999999999947	\N	\N	Sunset Beach Bridge	NC
62037	Little River Neck, north end, South Carolina	NOS	8660098	33.8699999999999974	-78.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:46:00	\N	0.839999999999999969	00:32:00	\N	0.92000000000000004	\N	\N	Little River Neck, north end	SC
62038	Little River (town), South Carolina	NOS	8660121	33.8699999999999974	-78.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:39:00	\N	0.790000000000000036	00:13:00	\N	0.839999999999999969	\N	\N	Little River (town)	SC
62039	Dunn Sound, north end, South Carolina	NOS	8660147	33.8599999999999994	-78.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:40:00	\N	0.839999999999999969	00:25:00	\N	0.930000000000000049	\N	\N	Dunn Sound, north end	SC
62040	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8582999999999998	-78.5699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:41:00	\N	0.800000000000000044	00:15:00	\N	0.910000000000000031	\N	\N	Dunn Sound, Little River Inlet	SC
62041	Nixon Crossroads, South Carolina	NOS	8660166	33.8549999999999969	-78.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:51:00	\N	0.680000000000000049	00:27:00	\N	0.780000000000000027	\N	\N	Nixon Crossroads	SC
62042	Dunn Sound, west end, South Carolina	NOS	8660195	33.851700000000001	-78.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:36:00	\N	1	00:29:00	\N	0.959999999999999964	\N	\N	Dunn Sound, west end	SC
62043	Cherry Grove (inside), South Carolina	NOS	8660265	33.8350000000000009	-78.6333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:44:00	\N	0.739999999999999991	00:40:00	\N	0.92000000000000004	\N	\N	Cherry Grove (inside)	SC
62044	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367000000000004	-78.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	-00:07:00	\N	0.900000000000000022	-00:06:00	\N	0.989999999999999991	\N	\N	Hog Inlet Pier	SC
62045	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.8350000000000009	-79.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	07:28:00	\N	0.739999999999999991	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
62046	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.8299999999999983	-78.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	08:32:00	\N	0.57999999999999996	08:17:00	\N	0.200000000000000011	\N	\N	Grahamville	SC
62047	Myrtle Beach Airport, South Carolina	NOS	8660401	33.8200000000000003	-78.7182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:47:00	\N	0.839999999999999969	01:09:00	\N	0.560000000000000053	\N	\N	Myrtle Beach Airport	SC
62048	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.7999999999999972	-79.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	07:30:00	\N	0.739999999999999991	07:25:00	\N	0.200000000000000011	\N	\N	Pitch Landing	SC
62049	North Myrtle Beach, South Carolina	NOS	8660642	33.7667007446289062	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:12:00	\N	0.839999999999999969	02:15:00	\N	0.359999999999999987	\N	\N	North Myrtle Beach, ICWW	SC
62050	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.7449999999999974	-79.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:20:00	\N	0.890000000000000013	06:09:00	\N	0.280000000000000027	\N	\N	Keysfield	SC
62051	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7132999999999967	-78.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:18:00	\N	0.890000000000000013	02:56:00	\N	0.349999999999999978	\N	\N	Myrtle Beach, Combination Bridge	SC
62052	Socastee Bridge, South Carolina	NOS	8660983	33.6867000000000019	-79.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:41:00	\N	0.739999999999999991	03:27:00	\N	0.409999999999999976	\N	\N	Socastee Bridge	SC
62053	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6666999999999987	-79.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:35:00	\N	0.369999999999999996	05:01:00	\N	0.380000000000000004	\N	\N	Enterprise Landing	SC
62054	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.6599999999999966	-79.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:24:00	\N	0.680000000000000049	04:33:00	\N	0.330000000000000016	\N	\N	Yauhannah Bridge	SC
62055	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.601700000000001	-79.118300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:43:00	\N	0.839999999999999969	03:59:00	\N	0.46000000000000002	\N	\N	Little Bull Creek entrance, Bull Creek	SC
62056	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6082999999999998	-79.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:20:00	\N	0.530000000000000027	04:48:00	\N	0.200000000000000011	\N	\N	Lower Topsaw Landing	SC
62057	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5966999999999985	-79.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:22:00	\N	0.790000000000000036	03:36:00	\N	0.479999999999999982	\N	\N	Bull Creek entrance	SC
62058	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6032999999999973	-79.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:13:00	\N	1.05000000000000004	06:00:00	\N	0.359999999999999987	\N	\N	Rhems, Black Mingo Creek, Black River	SC
62059	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.5600000000000023	-79.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:00:00	\N	0.839999999999999969	03:11:00	\N	0.530000000000000027	\N	\N	Wachesaw Landing	SC
62060	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5516999999999967	-79.0366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:28:00	\N	0.680000000000000049	00:57:00	\N	0.849999999999999978	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
62398	Great Pocket, Florida	NOS	8722381	27.1550000000000011	-80.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
62061	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5516999999999967	-79.1766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:12:00	\N	0.680000000000000049	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
62062	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.5450000000000017	-79.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:36:00	\N	0.949999999999999956	01:01:00	\N	0.859999999999999987	\N	\N	Smith's Dock	SC
62063	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5416999999999987	-79.0283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:18:00	\N	0.839999999999999969	00:40:00	\N	0.839999999999999969	\N	\N	Divine's Dock	SC
62064	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.5349999999999966	-79.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:39:00	\N	0.839999999999999969	04:23:00	\N	0.469999999999999973	\N	\N	Winea Plantation, Black River	SC
62065	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317000000000007	-79.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:32:00	\N	0.949999999999999956	00:52:00	\N	0.839999999999999969	\N	\N	Allston Creek	SC
62066	Oaks Creek, 0.5 mi. above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.5300000000000011	-79.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	01:03:00	\N	0.949999999999999956	00:38:00	\N	0.849999999999999978	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
62067	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5116999999999976	-79.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:09:00	\N	0.890000000000000013	03:29:00	\N	0.469999999999999973	\N	\N	Black River (south of Dunbar)	SC
62068	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.4949999999999974	-79.4616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:04:00	\N	1.05000000000000004	05:38:00	\N	0.369999999999999996	\N	\N	Mt. Pleasant Plantation, Black River	SC
62069	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4832999999999998	-79.178299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:39:00	\N	0.790000000000000036	02:38:00	\N	0.530000000000000027	\N	\N	Arundel Plantation	SC
62070	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4682999999999993	-79.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:06:00	\N	0.680000000000000049	02:21:00	\N	0.689999999999999947	\N	\N	South of Sam Worth Game Management Area	SC
62071	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4716999999999985	-79.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	03:02:00	\N	0.75	01:10:00	\N	0.57999999999999996	\N	\N	Litchfield Beach bridge	SC
62072	Carr Creek, 1 mile above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.4650000000000034	-79.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:00:00	\N	0.839999999999999969	02:13:00	\N	0.689999999999999947	\N	\N	Carr Creek, 1 mile above entrance	SC
62073	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.4549999999999983	-79.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:02:00	\N	0.890000000000000013	02:16:00	\N	0.680000000000000049	\N	\N	Weymouth Plantation	SC
62074	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483000000000033	-79.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:42:00	\N	1	00:16:00	\N	0.869999999999999996	\N	\N	Midway Inlet North, Pawleys Island	SC
62075	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.4350000000000023	-79.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:53:00	\N	0.790000000000000036	01:58:00	\N	0.67000000000000004	\N	\N	Hagley Landing	SC
62076	Cumberland, Sampit River, South Carolina	NOS	8662216	33.3699999999999974	-79.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:29:00	\N	0.739999999999999991	02:42:00	\N	0.770000000000000018	\N	\N	Cumberland	SC
62077	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633000000000024	-79.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:22:00	\N	0.739999999999999991	02:15:00	\N	0.729999999999999982	\N	\N	Jacobs Wharf	SC
62078	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.3049999999999997	-79.678299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	06:30:00	\N	0.369999999999999996	04:15:00	\N	0.220000000000000001	\N	\N	Jamestown Bridge, Santee River	SC
62079	South Island Ferry, Intracoastal Waterway, South Carolina	NOS	8662549	33.2516999999999996	-79.2682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:25:00	\N	0.739999999999999991	00:54:00	\N	0.709999999999999964	\N	\N	South Island Ferry, Intracoastal Waterway	SC
62080	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.2449999999999974	-79.5216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:47:00	\N	0.739999999999999991	02:28:00	\N	0.450000000000000011	\N	\N	Pleasant Hill Landing, Santee River	SC
62081	South Island Plantation (C.G. Station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.2349999999999994	-79.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:36:00	\N	0.839999999999999969	00:35:00	\N	0.739999999999999991	\N	\N	South Island Plantation (C.G. Station)	SC
62082	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233000000000018	-79.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:25:00	\N	1.05000000000000004	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
62083	North Santee Bridge, South Carolina	NOS	8662793	33.2100000000000009	-79.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:54:00	\N	0.739999999999999991	01:09:00	\N	0.719999999999999973	\N	\N	North Santee Bridge	SC
62084	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.1950000000000003	-79.2750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:00:00	\N	0.949999999999999956	00:16:00	\N	0.770000000000000018	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
62085	U.S. Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.1850000000000023	-79.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:43:00	\N	0.949999999999999956	00:43:00	\N	0.780000000000000027	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
62086	Georgetown, Sampit River, South Carolina	NOS	8662926	33.361699999999999	-79.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:09:00	\N	0.790000000000000036	01:25:00	\N	0.709999999999999964	\N	\N	Georgetown	SC
62087	Cape Romain, South Carolina	NOS	8663101	33.0249999999999986	-79.3482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:17:00	\N	0.890000000000000013	-00:22:00	\N	0.890000000000000013	\N	\N	Cape Romain	SC
62088	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.1400000000000006	-79.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	0.949999999999999956	-00:03:00	\N	0.800000000000000044	\N	\N	Cedar Island, North Santee Bay	SC
62089	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.1199999999999974	-79.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:08:00	\N	0.790000000000000036	-00:16:00	\N	0.780000000000000027	\N	\N	Cedar Island Point, South Santee River	SC
62090	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1082999999999998	-79.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:53:00	\N	0.790000000000000036	00:40:00	\N	0.869999999999999996	\N	\N	Casino Creek, ICWW	SC
62091	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.0949999999999989	-79.8083000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	04:12:00	\N	1.41999999999999993	04:37:00	\N	0.560000000000000053	\N	\N	Quinby Creek bridge, East Branch	SC
62092	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.0949999999999989	-79.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:53:00	\N	0.890000000000000013	03:19:00	\N	0.340000000000000024	\N	\N	Pimlico, West Branch	SC
62093	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0782999999999987	-79.4599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:24:00	\N	0.890000000000000013	00:31:00	\N	0.930000000000000049	\N	\N	McClellanville, Jeremy Creek	SC
62094	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0782999999999987	-79.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:51:00	\N	1.62999999999999989	02:56:00	\N	0.530000000000000027	\N	\N	Old Rice Mill, West Branch	SC
62095	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767000000000024	-79.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:43:00	\N	1.37000000000000011	03:43:00	\N	0.540000000000000036	\N	\N	Richmond Plantation, East Branch	SC
62096	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0716999999999999	-79.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:49:00	\N	1.79000000000000004	03:14:00	\N	0.630000000000000004	\N	\N	Bonneau Ferry, East Branch	SC
62097	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583000000000027	-79.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:07:00	\N	1.58000000000000007	02:21:00	\N	0.680000000000000049	\N	\N	Dupont, Dean Hall	SC
62098	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.0549999999999997	-79.8799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:20:00	\N	1.32000000000000006	03:24:00	\N	0.560000000000000053	\N	\N	Blessing Plantation, East Branch	SC
62099	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.0399999999999991	-79.5600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:37:00	\N	1	00:22:00	\N	0.949999999999999956	\N	\N	Buck Hall, Awendaw Creek	SC
62100	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.033299999999997	-79.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:36:00	\N	0.949999999999999956	00:03:00	\N	0.930000000000000049	\N	\N	Harbor River entrance	SC
62101	General Dynamics Pier, Cooper River, South Carolina (sub)	NOS	8664022	33.0082999999999984	-79.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:24:00	\N	1.1100000000000001	01:40:00	\N	0.839999999999999969	\N	\N	General Dynamics Pier	SC
62102	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:07:00	\N	0.949999999999999956	-00:06:00	\N	0.930000000000000049	\N	\N	Five Fathom Creek entrance	SC
62103	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.9949999999999974	-79.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	05:57:00	\N	0.790000000000000036	05:44:00	\N	0.170000000000000012	\N	\N	Back River Reservoir, West Branch	SC
62104	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367000000000019	-79.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:08:00	\N	1	00:11:00	\N	0.959999999999999964	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
62105	Snow Point, 0.4 mi. North of, Cooper River, South Carolina	NOS	8664515	32.9483000000000033	-79.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:45:00	\N	1.05000000000000004	00:59:00	\N	1.02000000000000002	\N	\N	Snow Point, 0.4 mi. North of	SC
62106	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583000000000013	-80.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	03:41:00	\N	0.160000000000000003	02:45:00	\N	0.390000000000000013	\N	\N	Bacon Bridge	SC
62107	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9316999999999993	-80.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:42:00	\N	1.15999999999999992	02:06:00	\N	1.14999999999999991	\N	\N	Greggs Landing, Mateeba Gardens	SC
62108	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.9249999999999972	-79.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:31:00	\N	1.37000000000000011	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
62109	Cainhoy, Wando River, South Carolina (sub)	NOS	8664545	32.9266999999999967	-79.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:31:00	\N	1	00:49:00	\N	1.14999999999999991	\N	\N	Cainhoy	SC
62110	Woodville, Wando River, South Carolina	NOS	8664582	32.9200000000000017	-79.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:22:00	\N	1.18999999999999995	02:07:00	\N	1.18999999999999995	\N	\N	Woodville	SC
62111	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183000000000021	-80.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:13:00	\N	0.790000000000000036	02:51:00	\N	0.900000000000000022	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
62112	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.9149999999999991	-79.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:52:00	\N	1.1100000000000001	01:24:00	\N	1.23999999999999999	\N	\N	Big Paradise Island	SC
62113	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9132999999999996	-79.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:08:00	\N	0.949999999999999956	00:12:00	\N	0.969999999999999973	\N	\N	Wharf Creek entrance	SC
62114	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067000000000007	-79.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:33:00	\N	1	00:45:00	\N	1.04000000000000004	\N	\N	Clouter Creek, north entrance	SC
62115	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.8999999999999986	-79.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:23:00	\N	1.05000000000000004	00:47:00	\N	1.12999999999999989	\N	\N	Nowell Creek	SC
62116	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.884999999999998	-79.8449999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:27:00	\N	1.1100000000000001	00:43:00	\N	1.09000000000000008	\N	\N	Parker Island, Horlbeck Creek	SC
62117	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817000000000021	-79.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:21:00	\N	0.890000000000000013	-00:01:00	\N	0.92000000000000004	\N	\N	Price Creek, North Capers Island	SC
62118	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8766999999999996	-80.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:54:00	\N	1.05000000000000004	01:02:00	\N	1.10000000000000009	\N	\N	Magnolia Gardens	SC
62119	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.8699999999999974	-79.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:09:00	\N	0.839999999999999969	00:21:00	\N	0.939999999999999947	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
62120	Capers Creek, South Capers Island, South Carolina (sub)	NOS	8664941	32.8566999999999965	-79.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:15:00	\N	0.949999999999999956	00:04:00	\N	0.939999999999999947	\N	\N	Capers Creek, South Capers Island	SC
62121	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.8599999999999994	-79.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:19:00	\N	1	00:25:00	\N	1.02000000000000002	\N	\N	Clouter Creek, south entrance	SC
62122	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.8500000000000014	-79.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:11:00	\N	0.949999999999999956	-00:02:00	\N	0.910000000000000031	\N	\N	North Dewees Island, Capers Inlet	SC
62123	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483000000000018	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:39:00	\N	1.05000000000000004	00:41:00	\N	1.09000000000000008	\N	\N	Drayton, Bee's Ferry	SC
62124	I-526 bridge, Ashley River, South Carolina (sub)	NOS	8665099	32.8367000000000004	-80.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:29:00	\N	1.1100000000000001	00:30:00	\N	1.08000000000000007	\N	\N	I-526 bridge	SC
62125	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.8350000000000009	-79.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	1.05000000000000004	00:25:00	\N	1.07000000000000006	\N	\N	Cosgrove Bridge	SC
62126	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333000000000013	-79.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:17:00	\N	0.890000000000000013	-00:01:00	\N	0.939999999999999947	\N	\N	South Dewees Island, Dewees Inlet	SC
62127	Duck Island, Ashley River, South Carolina	NOS	8665145	32.8299999999999983	-79.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:17:00	\N	1.06000000000000005	00:23:00	\N	1.06000000000000005	\N	\N	Duck Island	SC
62128	Hamlin Sound, South Carolina	NOS	8665167	32.8267000000000024	-79.7866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:13:00	\N	1	00:13:00	\N	0.989999999999999991	\N	\N	Hamlin Sound	SC
62129	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8216999999999999	-79.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:13:00	\N	0.949999999999999956	00:19:00	\N	1.03000000000000003	\N	\N	Hobcaw Point	SC
62130	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8132999999999981	-80.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	05:34:00	\N	0.320000000000000007	04:20:00	\N	0.130000000000000004	\N	\N	Canaday Landing, south of, Edisto River	SC
62131	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867000000000033	-79.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:06:00	\N	0.969999999999999973	\N	\N	Hamlin Creek, Isle of Palms	SC
62132	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.6749999999999972	-79.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:06:00	\N	1	00:25:00	\N	1.04000000000000004	\N	\N	Folly Creek, Hwy. 171 bridge	SC
62133	Shem Creek, South Carolina	NOS	8665426	32.7933000000000021	-79.881699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:03:00	\N	1	-00:02:00	\N	0.989999999999999991	\N	\N	Shem Creek	SC
62134	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867000000000033	-80.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:34:00	\N	1.08000000000000007	01:43:00	\N	1.08000000000000007	\N	\N	Limehouse Bridge	SC
62135	Isle of Palms Pier, South Carolina	NOS	8665494	32.783299999999997	-79.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:28:00	\N	0.890000000000000013	-00:25:00	\N	0.949999999999999956	\N	\N	Isle of Palms Pier	SC
62136	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.783299999999997	-79.9566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.05000000000000004	00:04:00	\N	1.01000000000000001	\N	\N	South Ashley Bridge	SC
62137	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7766999999999982	-79.8117000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:14:00	\N	1.05000000000000004	-00:05:00	\N	0.949999999999999956	\N	\N	Breach Inlet, Isle of Palms	SC
62138	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.773299999999999	-79.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:06:00	\N	0.969999999999999973	\N	\N	Ben Sawyer Bridge, ICWW	SC
62139	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.7700000000000031	-80.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:18:00	\N	1.02000000000000002	01:30:00	\N	1.02000000000000002	\N	\N	Sandblasters, Pennys Creek	SC
62140	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683000000000035	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:20:00	\N	1.32000000000000006	01:23:00	\N	1.03000000000000003	\N	\N	Pennys Creek, west entrance	SC
62141	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667000000000002	-79.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:22:00	\N	0.989999999999999991	00:22:00	\N	0.989999999999999991	\N	\N	Wappoo Creek, highway bridge	SC
62142	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.763300000000001	-79.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:10:00	\N	0.949999999999999956	-00:01:00	\N	0.969999999999999973	\N	\N	The Cove, Fort Moultrie	SC
62143	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.763300000000001	-80.0016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:52:00	\N	1.15999999999999992	00:48:00	\N	0.989999999999999991	\N	\N	Elliott Cut entrance	SC
62144	Fort Johnson, South Carolina	NOS	8665726	32.7516999999999996	-79.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:02:00	\N	1	-00:05:00	\N	0.969999999999999973	\N	\N	Fort Johnson	SC
62145	Fort Sumter, South Carolina	NOS	8665728	32.753300000000003	-79.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:01:00	\N	0.949999999999999956	00:02:00	\N	0.969999999999999973	\N	\N	Fort Sumter	SC
62146	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.753300000000003	-80.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:34:00	\N	0.859999999999999987	02:46:00	\N	0.589999999999999969	\N	\N	Jacksonboro Camp	SC
62147	Church Flats, Stono River, South Carolina	NOS	8665763	32.746699999999997	-80.1650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:14:00	\N	1.15999999999999992	01:51:00	\N	1.21999999999999997	\N	\N	Church Flats	SC
62148	James Island Creek, 1 mi. above ent., Ashley River, South Carolina	NOS	8665775	32.7449999999999974	-79.9483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.05000000000000004	00:17:00	\N	1.02000000000000002	\N	\N	James Island Creek, 1 mi. above ent.	SC
62149	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7432999999999979	-80.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:00:00	\N	1.05000000000000004	04:18:00	\N	0.340000000000000024	\N	\N	Ashepoo	SC
62150	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.7150000000000034	-80.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:43:00	\N	1.17999999999999994	02:10:00	\N	0.729999999999999982	\N	\N	Penny Creek, south of, Edisto River	SC
62151	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.7150000000000034	-80.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:58:00	\N	1	01:58:00	\N	1.30000000000000004	\N	\N	Church Creek bridge	SC
62152	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7066999999999979	-80.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:00:00	\N	1.15999999999999992	01:43:00	\N	1.30000000000000004	\N	\N	Johns Island, Church Creek	SC
62153	Lower Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666131	32.7032999999999987	-80.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:47:00	\N	1.26000000000000001	01:26:00	\N	1.29000000000000004	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
62154	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7132999999999967	-80.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:12:00	\N	1.72999999999999998	04:45:00	\N	0.510000000000000009	\N	\N	Cuckolds Creek	SC
62155	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7000000000000028	-80.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:13:00	\N	1.05000000000000004	01:46:00	\N	0.819999999999999951	\N	\N	Hope Creek, Edisto River	SC
62156	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.6950000000000003	-80.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:45:00	\N	1.15999999999999992	01:22:00	\N	1.23999999999999999	\N	\N	Yonges Island	SC
62157	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833000000000027	-80.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:57:00	\N	1.15999999999999992	01:39:00	\N	1.26000000000000001	\N	\N	Oak Branch, Bohicket Creek	SC
62158	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6766999999999967	-80.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:02:00	\N	0.949999999999999956	00:17:00	\N	1.01000000000000001	\N	\N	Abbapoola Creek entrance	SC
62159	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833000000000027	-80.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:51:00	\N	1.59000000000000008	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
62160	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6816999999999993	-80.4167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:03:00	\N	1	01:34:00	\N	0.82999999999999996	\N	\N	Willtown Bluff, Edisto River	SC
62161	Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683000000000021	-80.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:38:00	\N	1.05000000000000004	01:06:00	\N	1.20999999999999996	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
62162	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.6700000000000017	-79.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:05:00	\N	0.949999999999999956	00:24:00	\N	1.03000000000000003	\N	\N	Folly River, north, Folly Island	SC
62163	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.6649999999999991	-80.3166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:34:00	\N	1.20999999999999996	01:19:00	\N	1.20999999999999996	\N	\N	Park Island, Tom Point Creek	SC
62164	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567000000000007	-80.3917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:31:00	\N	0.949999999999999956	01:07:00	\N	0.890000000000000013	\N	\N	Dawho River	SC
62165	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617000000000033	-79.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:03:00	\N	0.949999999999999956	00:21:00	\N	1.01000000000000001	\N	\N	Folly River Bridge, Folly Island	SC
62166	U.S. 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6516999999999982	-80.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:29:00	\N	1.1399999999999999	03:00:00	\N	0.709999999999999964	\N	\N	U.S. 17 Bridge	SC
62167	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467000000000027	-80.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:31:00	\N	1.1100000000000001	00:58:00	\N	1.16999999999999993	\N	\N	Bluff Point	SC
62168	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317000000000021	-80.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:59:00	\N	1	01:57:00	\N	0.599999999999999978	\N	\N	Airy Hall Plantation	SC
62169	Snake Island, Stono River, South Carolina	NOS	8666767	32.6400000000000006	-80.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	00:01:00	\N	1.01000000000000001	\N	\N	Snake Island	SC
62170	Leadenwah Creek, 3 mi. above entrance, North Edisto River, South Carolina	NOS	8666775	32.6366999999999976	-80.2017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:23:00	\N	1.1100000000000001	00:54:00	\N	1.14999999999999991	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
62171	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6366999999999976	-80.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:47:00	\N	1.1100000000000001	00:56:00	\N	1.17999999999999994	\N	\N	Dawho Bridge, Dawho River	SC
62172	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:30:00	\N	1.1100000000000001	00:49:00	\N	1.12999999999999989	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
62173	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133000000000024	-80.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:34:00	\N	0.859999999999999987	01:27:00	\N	0.709999999999999964	\N	\N	Brickyard Ferry, swing bridge	SC
62174	Kiawah River Bridge, South Carolina	NOS	8667062	32.6032999999999973	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:06:00	\N	0.890000000000000013	00:14:00	\N	1.07000000000000006	\N	\N	Kiawah River Bridge	SC
62175	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6032999999999973	-80.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.949999999999999956	00:29:00	\N	0.92000000000000004	\N	\N	Pine Landing	SC
62176	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.601700000000001	-80.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:20:00	\N	1.17999999999999994	01:45:00	\N	0.880000000000000004	\N	\N	Wiggins, Chehaw River	SC
62177	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6032999999999973	-80.2866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:25:00	\N	1.1100000000000001	00:45:00	\N	1.14999999999999991	\N	\N	Steamboat Landing, Steamboat Creek	SC
62178	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.601700000000001	-80.9033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:31:00	\N	0.729999999999999982	03:24:00	\N	0.729999999999999982	\N	\N	Tulifiny River, I-95 bridge	SC
62179	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983000000000018	-80.1949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:07:00	\N	1.1100000000000001	00:19:00	\N	1.09000000000000008	\N	\N	Rockville, Bohicket Creek	SC
62180	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983000000000018	-80.3449999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:35:00	\N	1.1100000000000001	01:16:00	\N	1.20999999999999996	\N	\N	Windsor Plantation, Russel Creek	SC
62181	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617000000000019	-80.9099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:10:00	\N	1.1399999999999999	02:34:00	\N	1.12000000000000011	\N	\N	North Dawson Landing, Coosawhatchie River	SC
62182	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833000000000013	-80.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:52:00	\N	0.770000000000000018	02:11:00	\N	1.15999999999999992	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
62183	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.5850000000000009	-80.2283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:11:00	\N	1.05000000000000004	00:15:00	\N	1.08000000000000007	\N	\N	Point of Pines	SC
62184	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5782999999999987	-80.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	0.949999999999999956	02:06:00	\N	0.930000000000000049	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
62185	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5782999999999987	-80.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	0.910000000000000031	00:46:00	\N	0.839999999999999969	\N	\N	Bluff Islands	SC
62186	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5782999999999987	-80.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:57:00	\N	0.910000000000000031	01:21:00	\N	0.900000000000000022	\N	\N	Musselboro Island, Mosquito Creek	SC
62187	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683000000000007	-80.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:52:00	\N	0.910000000000000031	00:42:00	\N	0.910000000000000031	\N	\N	Fields Point	SC
62188	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.5649999999999977	-80.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1	01:02:00	\N	0.959999999999999964	\N	\N	Bowles Island, New Chehaw River	SC
62189	Ocella Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617000000000019	-80.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:09:00	\N	1.08000000000000007	00:32:00	\N	1.08000000000000007	\N	\N	Ocella Creek, 2 mi. above entrance	SC
62190	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.5600000000000023	-80.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	1.09000000000000008	00:15:00	\N	0.900000000000000022	\N	\N	Fenwick Island	SC
62191	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5516999999999967	-80.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:44:00	\N	0.910000000000000031	00:31:00	\N	0.869999999999999996	\N	\N	Hutchinson Island	SC
62192	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733000000000033	-80.7450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:28:00	\N	0.949999999999999956	01:40:00	\N	1.1100000000000001	\N	\N	Lobeco, Whale Branch	SC
62302	St. Simons Lighthouse, St. Simons Island, Georgia (sub)	NOS	8677344	31.1316999999999986	-81.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:16:00	\N	0.910000000000000031	00:14:00	\N	0.949999999999999956	\N	\N	St. Simons Light	GA
62193	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.5399999999999991	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:09:00	\N	0.949999999999999956	00:22:00	\N	0.880000000000000004	\N	\N	Peters Point, St. Pierre Creek	SC
62194	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.5249999999999986	-80.4517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	0.910000000000000031	00:15:00	\N	0.900000000000000022	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
62195	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.5249999999999986	-80.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:20:00	\N	0.949999999999999956	01:27:00	\N	1.06000000000000005	\N	\N	Whale Branch entrance	SC
62196	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5266999999999982	-80.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.949999999999999956	00:55:00	\N	0.959999999999999964	\N	\N	Summerhouse Point, Bull River	SC
62197	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217000000000027	-80.8383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	1.05000000000000004	01:39:00	\N	1.16999999999999993	\N	\N	RR. Bridge, Hall Island	SC
62198	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.523299999999999	-80.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:18:00	\N	0.910000000000000031	00:11:00	\N	0.900000000000000022	\N	\N	Seabrook	SC
62199	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.5050000000000026	-80.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:24:00	\N	0.910000000000000031	01:50:00	\N	1.14999999999999991	\N	\N	Pilot Island, West Branch Boyds Creek	SC
62200	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4932999999999979	-80.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:19:00	\N	0.949999999999999956	01:27:00	\N	1.08000000000000007	\N	\N	Brickyard Point, Brickyard Creek	SC
62201	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5016999999999996	-80.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:29:00	\N	0.949999999999999956	-00:21:00	\N	0.839999999999999969	\N	\N	Edisto Beach, Edisto Island	SC
62202	Clarendon Plantation, South Carolina (sub)	NOS	8667633	32.5024999999999977	-80.7840999999999951	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:25:00	\N	0.770000000000000018	01:37:00	\N	1.14999999999999991	\N	\N	Corning Landing, Whale Branch	SC
62203	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4932999999999979	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:13:00	\N	0.910000000000000031	-00:06:00	\N	0.859999999999999987	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
62204	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4932999999999979	-80.3267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:07:00	\N	0.910000000000000031	00:08:00	\N	0.869999999999999996	\N	\N	Carters Dock, Big Bay Creek	SC
62205	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4832999999999998	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.910000000000000031	00:55:00	\N	0.969999999999999973	\N	\N	Sams Point, Lucy Point Creek	SC
62206	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.476700000000001	-80.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:07:00	\N	0.949999999999999956	00:04:00	\N	0.869999999999999996	\N	\N	Otter Island	SC
62207	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.4650000000000034	-80.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:11:00	\N	0.949999999999999956	01:27:00	\N	1.10000000000000009	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
62208	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517000000000024	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	0.880000000000000004	00:53:00	\N	0.900000000000000022	\N	\N	Lucy Point Creek entrance	SC
62209	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.4500000000000028	-80.7317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:02:00	\N	0.450000000000000011	01:48:00	\N	0.979999999999999982	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
62210	Village Creek Entrance, Morgan River, South Carolina	NOS	8667927	32.4450000000000003	-80.5032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:07:00	\N	1	00:17:00	\N	0.930000000000000049	\N	\N	Village Creek Entrance	SC
62211	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4466999999999999	-80.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:14:00	\N	0.949999999999999956	00:31:00	\N	0.930000000000000049	\N	\N	Edding Point, Edding Creek	SC
62212	Jenkins Creek, 1 mi. above entrance, Morgan River, South Carolina	NOS	8667982	32.4399999999999977	-80.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	0.949999999999999956	00:41:00	\N	0.979999999999999982	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
62213	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4166999999999987	-80.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:15:00	\N	0.949999999999999956	00:36:00	\N	0.939999999999999947	\N	\N	Village Creek Cemetery	SC
62962	Fort Ross, California	NOS	9416024	38.513300000000001	-123.245000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:30:00	\N	0.959999999999999964	-00:51:00	\N	0.959999999999999964	\N	\N	Fort Ross	CA
62214	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.4200000000000017	-80.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05000000000000004	00:55:00	\N	1.01000000000000001	\N	\N	Jenkins Creek, Polawana Island	SC
62215	Battery Creek, 4 mi. above entrance, Beaufort River, South Carolina	NOS	8668092	32.4132999999999996	-80.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.910000000000000031	01:14:00	\N	1.10000000000000009	\N	\N	Battery Creek, 4 mi. above entrance	SC
62216	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.4099999999999966	-80.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:30:00	\N	0.819999999999999951	01:34:00	\N	1.10000000000000009	\N	\N	Broughton Point, Hazzard Creek	SC
62217	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033000000000015	-80.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:06:00	\N	0.949999999999999956	00:03:00	\N	0.880000000000000004	\N	\N	Harbor River Bridge	SC
62218	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4016999999999982	-80.6533000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:08:00	\N	0.359999999999999987	01:00:00	\N	0.979999999999999982	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
62219	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.398299999999999	-80.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:58:00	\N	0.550000000000000044	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
62220	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3866999999999976	-80.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	0.910000000000000031	00:51:00	\N	1.06000000000000005	\N	\N	Hwy. 170 bridge	SC
62221	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917000000000002	-80.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:03:00	\N	0.859999999999999987	00:03:00	\N	0.849999999999999978	\N	\N	Johnson Creek Bridge, Hunting Island	SC
62222	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.371699999999997	-80.605000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:34:00	\N	0.949999999999999956	00:58:00	\N	1.08000000000000007	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
62223	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.378300000000003	-80.6333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05000000000000004	00:43:00	\N	1.06000000000000005	\N	\N	Distant Island, Cowen Creek	SC
62224	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733000000000004	-80.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:48:00	\N	1	01:06:00	\N	1.10000000000000009	\N	\N	Chechessee Bluff, Chechessee River	SC
62225	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.3500000000000014	-80.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:26:00	\N	0.910000000000000031	00:37:00	\N	1.02000000000000002	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
62226	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3466999999999985	-80.8900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:57:00	\N	1.05000000000000004	01:25:00	\N	1.16999999999999993	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
62227	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina (sub)	NOS	8668498	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:22:00	\N	0.910000000000000031	-00:10:00	\N	0.880000000000000004	\N	\N	Fripps Inlet, Hunting Island Bridge	SC
62228	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.341700000000003	-80.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	1.1399999999999999	01:12:00	\N	1.12999999999999989	\N	\N	Callawassie Island Bridge, Colleton River	SC
62229	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.3350000000000009	-80.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:24:00	\N	1	00:15:00	\N	0.989999999999999991	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
62230	Station Creek, County Landing, South Carolina	NOS	8668601	32.3250000000000028	-80.6016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:16:00	\N	1	00:27:00	\N	0.989999999999999991	\N	\N	Station Creek, County Landing	SC
62231	Colleton River Entrance, South Carolina	NOS	8668619	32.3216999999999999	-80.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.05000000000000004	00:49:00	\N	1.05000000000000004	\N	\N	Colleton River Entrance	SC
62232	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3166999999999973	-80.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:53:00	\N	1.1399999999999999	01:15:00	\N	1.12999999999999989	\N	\N	Callawassie Creek, Colleton River	SC
62233	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3132999999999981	-80.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:40:00	\N	1.1100000000000001	01:09:00	\N	1.18999999999999995	\N	\N	Callawassie Island, south, Colleton River	SC
62234	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3066999999999993	-80.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	0.640000000000000013	00:19:00	\N	0.949999999999999956	\N	\N	Fort Fremont	SC
62235	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033000000000001	-81.1217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:38:00	\N	0.409999999999999976	02:14:00	\N	0.440000000000000002	\N	\N	Purrysburg Landing, S.C.	SC
62236	Station Creek, west end, South Carolina	NOS	8668836	32.2800000000000011	-80.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	0.910000000000000031	00:16:00	\N	0.959999999999999964	\N	\N	Station Creek, west end	SC
62237	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.273299999999999	-80.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:18:00	\N	0.949999999999999956	-00:01:00	\N	0.930000000000000049	\N	\N	Capers Island, Trenchards Inlet	SC
62238	Skull Creek, Ribaut Island, South Carolina (sub)	NOS	8668918	32.2667000000000002	-80.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:16:00	\N	0.910000000000000031	00:15:00	\N	0.989999999999999991	\N	\N	Skull Creek, north entrance, Hilton Head Island	SC
62239	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.259999999999998	-80.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	0.910000000000000031	00:36:00	\N	1.04000000000000004	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
62240	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.236699999999999	-81.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:53:00	\N	0.510000000000000009	04:12:00	\N	0.510000000000000009	\N	\N	Rt. 170 bridge	SC
62241	Bluffton, May River, South Carolina	NOS	8669103	32.2299999999999969	-80.861699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.05000000000000004	01:00:00	\N	1.15999999999999992	\N	\N	Bluffton	SC
62242	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233000000000018	-80.7716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	1.05000000000000004	00:34:00	\N	1.05000000000000004	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
62243	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.2199999999999989	-80.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:11:00	\N	1	00:01:00	\N	0.880000000000000004	\N	\N	Port Royal Plantation, Hilton Head Island	SC
62244	Bull Island North, May River, South Carolina	NOS	8669262	32.2000000000000028	-80.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:25:00	\N	1.05000000000000004	00:40:00	\N	1.09000000000000008	\N	\N	Bull Island North	SC
62245	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.1950000000000003	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:00:00	\N	1.40999999999999992	03:09:00	\N	0.689999999999999947	\N	\N	Cook Landing Cemetery	SC
62246	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.1850000000000023	-80.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	1	00:46:00	\N	1.10000000000000009	\N	\N	Savage I., Savage Creek, Bull Creek	SC
62247	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.1850000000000023	-80.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:17:00	\N	1.05000000000000004	00:33:00	\N	1.08000000000000007	\N	\N	Broad Creek, Hilton Head Island	SC
62248	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1766999999999967	-80.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:06:00	\N	1.55000000000000004	02:19:00	\N	0.849999999999999978	\N	\N	Good Hope Landing, south of	SC
62249	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.1749999999999972	-80.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:23:00	\N	0.770000000000000018	00:49:00	\N	1.1100000000000001	\N	\N	Moreland Cemetery	SC
62250	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.1649999999999991	-80.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:12:00	\N	1.05000000000000004	00:28:00	\N	1.05000000000000004	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
62251	Little Back River, Hwy. 17, Back River, Savannah River, South Carolina	NOS	8669415	32.1649999999999991	-81.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:41:00	\N	1.1399999999999999	01:28:00	\N	1.10000000000000009	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	SC
62252	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533000000000015	-80.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:09:00	\N	1	00:20:00	\N	1.04000000000000004	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
62253	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467000000000027	-80.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:10:00	\N	1	00:20:00	\N	1.02000000000000002	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
62254	Doughboy Island, New River, South Carolina	NOS	8669531	32.138300000000001	-80.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:06:00	\N	1.05000000000000004	01:04:00	\N	1.01000000000000001	\N	\N	Doughboy Island	SC
62255	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.128300000000003	-81.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:59:00	\N	1.09000000000000008	01:41:00	\N	1.06000000000000005	\N	\N	Turnbridge Landing, Salt Water Creek	SC
62256	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.121699999999997	-80.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:28:00	\N	0.910000000000000031	00:34:00	\N	1.03000000000000003	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
62257	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133000000000024	-80.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:02:00	\N	1	00:05:00	\N	0.979999999999999982	\N	\N	Braddock Point, Hilton Head Island	SC
62258	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1032999999999973	-80.894999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	0.949999999999999956	00:30:00	\N	1.01000000000000001	\N	\N	Daufuskie Landing, Daufuskie Island	SC
62259	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983000000000018	-80.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:27:00	\N	1.05000000000000004	00:19:00	\N	1.01000000000000001	\N	\N	Hargray Pier, Daufuskie Island	SC
62260	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0816999999999979	-80.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	0.910000000000000031	00:01:00	\N	0.979999999999999982	\N	\N	Bloody Point, Daufuskie Island	SC
62261	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867000000000004	-80.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:29:00	\N	1.05000000000000004	00:16:00	\N	1.02000000000000002	\N	\N	Fields Cut, Wright River	SC
62262	S.C.L. RR. bridge, Savannah River, Georgia	NOS	8670073	32.2316999999999965	-81.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	03:08:00	\N	0.910000000000000031	01:51:00	\N	0.900000000000000022	\N	\N	S.C.L. RR. bridge	GA
62263	Port Wentworth, Savannah River, Georgia (sub)	NOS	8670424	32.1433000000000035	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60495	-00:02:00	\N	0.839999999999999969	00:11:00	\N	1.03000000000000003	\N	\N	Port Wentworth	GA
62264	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0816999999999979	-81.0366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09000000000000008	00:29:00	\N	1.09000000000000008	\N	\N	Fort Jackson	GA
62265	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0816999999999979	-81.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:33:00	\N	1.1399999999999999	00:44:00	\N	1.1399999999999999	\N	\N	SAVANNAH	GA
62266	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283000000000015	-80.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:12:00	\N	0.989999999999999991	-00:10:00	\N	0.989999999999999991	\N	\N	Tybee Light	GA
62267	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267000000000003	-81.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1.09000000000000008	00:40:00	\N	1.09000000000000008	\N	\N	Vernon View, Burnside River	GA
62268	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533000000000008	-81.1466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:46:00	\N	0.910000000000000031	00:34:00	\N	1.05000000000000004	\N	\N	Florida Passage, Ogeechee River	GA
62269	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8216999999999999	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	0.949999999999999956	00:04:00	\N	1.02000000000000002	\N	\N	Bradley Point, Bradley River	GA
62270	Belfast, Belfast River, Georgia	NOS	8672462	31.8216999999999999	-81.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:10:00	\N	1.1399999999999999	01:23:00	\N	1.12999999999999989	\N	\N	Belfast, Belfast River	GA
62271	Bear River, (Range 'A' Light), Georgia (sub)	NOS	8672667	31.7932999999999986	-81.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:39:00	\N	0.949999999999999956	00:43:00	\N	1.09000000000000008	\N	\N	Bear River, (Range 'A' Light)	GA
62272	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7882999999999996	-81.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	0.910000000000000031	00:48:00	\N	1.09000000000000008	\N	\N	Kilkenny Club, Kilkenny Creek	GA
62273	Sunbury, Sunbury Channel, Georgia (sub)	NOS	8672875	31.7667000000000002	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:52:00	\N	0.729999999999999982	00:53:00	\N	1.05000000000000004	\N	\N	Sunbury, Medway River	GA
62274	Halfmoon, Timmons River, Georgia	NOS	8673381	31.6950000000000003	-81.2716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:09:00	\N	1.05000000000000004	01:21:00	\N	1.06000000000000005	\N	\N	Halfmoon, Timmons River	GA
62275	Walburg Creek entrance, Georgia	NOS	8673437	31.6900000000000013	-81.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:21:00	\N	1	00:16:00	\N	1.03000000000000003	\N	\N	Walburg Creek entrance	GA
62276	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6816999999999993	-81.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1	00:35:00	\N	1.05000000000000004	\N	\N	North Newport River (Daymark 119)	GA
62277	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:46:00	\N	0.949999999999999956	00:57:00	\N	1.06000000000000005	\N	\N	Thomas Landing, S. Newport River	GA
62278	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.6499999999999986	-81.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:06:00	\N	1	01:16:00	\N	1.09000000000000008	\N	\N	Eagle Neck, South Newport River	GA
62303	8 miles above mouth, Little Satilla River, Georgia	NOS	8677566	31.0982999999999983	-81.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:02:00	\N	1.19999999999999996	00:24:00	\N	1.19999999999999996	\N	\N	8 miles above mouth	GA
62279	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233000000000004	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:32:00	\N	1	00:54:00	\N	1.08000000000000007	\N	\N	Harris Neck, Barbour Island River	GA
62280	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5782999999999987	-81.2399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:24:00	\N	1	00:36:00	\N	1.06000000000000005	\N	\N	Barbour Island, Barbour Island River	GA
62281	South Newport River (Daymark 135), Georgia (sub)	NOS	8674301	31.5749999999999993	-81.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:20:00	\N	1.05000000000000004	00:27:00	\N	1.03000000000000003	\N	\N	South Newport River (Daymark 135)	GA
62282	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483000000000011	-81.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	1.05000000000000004	01:03:00	\N	1.05000000000000004	\N	\N	Pine Harbor, Sapelo River	GA
62283	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317000000000007	-81.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:22:00	\N	0.910000000000000031	00:33:00	\N	1.04000000000000004	\N	\N	Dog Hammock, Sapelo River	GA
62284	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317000000000007	-81.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:02:00	\N	0.859999999999999987	01:12:00	\N	1.08000000000000007	\N	\N	Bellville Point, Sapelo River	GA
62285	Eagle Creek, Mud River, Georgia	NOS	8674801	31.5100000000000016	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:19:00	\N	1.05000000000000004	00:21:00	\N	1.05000000000000004	\N	\N	Eagle Creek, Mud River	GA
62286	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983000000000004	-81.3250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:37:00	\N	1.09000000000000008	00:49:00	\N	1.08000000000000007	\N	\N	Creighton Narrows Entrance, Crescent River	GA
62287	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4882999999999988	-81.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:47:00	\N	0.949999999999999956	00:19:00	\N	0.939999999999999947	\N	\N	Blackbeard Creek, Blackbeard Island	GA
62288	Hudson Creek entrance, Georgia	NOS	8675245	31.4466999999999999	-81.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:31:00	\N	1.05000000000000004	00:37:00	\N	1.05000000000000004	\N	\N	Hudson Creek entrance	GA
62289	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4316999999999993	-81.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:39:00	\N	0.819999999999999951	00:39:00	\N	0.959999999999999964	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
62290	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.3900000000000006	-81.2883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:14:00	\N	0.949999999999999956	00:15:00	\N	0.989999999999999991	\N	\N	Old Tower, Sapelo Island	GA
62291	Rockdedundy River (Daymark 185), Georgia (sub)	NOS	8675761	31.3738611111111112	-81.333944444444441	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:41:00	\N	1.01000000000000001	00:29:00	\N	1	\N	\N	Rockdedundy River (Daymark 185)	GA
62292	Darien, Darien River, Georgia	NOS	8675779	31.3683000000000014	-81.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:15:00	\N	1.05000000000000004	01:08:00	\N	1.06000000000000005	\N	\N	Darien, Darien River	GA
62293	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:55:00	\N	1.05000000000000004	00:44:00	\N	1.03000000000000003	\N	\N	Threemile Cut entrance, Darien River	GA
62294	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317000000000014	-81.4599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	02:33:00	\N	0.770000000000000018	01:10:00	\N	0.760000000000000009	\N	\N	Champney Island, South Altamaha River	GA
62295	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.2850000000000001	-81.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:23:00	\N	1.09000000000000008	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
62296	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.2250000000000014	-81.571700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:02:00	\N	1.17999999999999994	01:32:00	\N	1.15999999999999992	\N	\N	Dillard Creek	GA
62297	Frederica River, Georgia	NOS	8676743	31.2216999999999985	-81.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:56:00	\N	1.05000000000000004	00:48:00	\N	1.05000000000000004	\N	\N	Frederica River	GA
62298	Mackay River (Daymark 239), Georgia	NOS	8676766	31.2100000000000009	-81.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:56:00	\N	1.09000000000000008	00:58:00	\N	1.03000000000000003	\N	\N	Mackay River (Daymark 239)	GA
62299	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.2149999999999999	-81.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:58:00	\N	1.17999999999999994	01:37:00	\N	1.15999999999999992	\N	\N	Buffalo River entrance	GA
62300	Crispen Island, Turtle River, Georgia (sub)	NOS	8676808	31.2133000000000003	-81.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:55:00	\N	1.05000000000000004	01:33:00	\N	1.14999999999999991	\N	\N	Crispen Island	GA
62301	Frederick River Bridge, Georgia	NOS	8677045	31.1682999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	1.09000000000000008	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
62304	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.0949999999999989	-81.5049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.17999999999999994	00:11:00	\N	1.17999999999999994	\N	\N	Jointer Island, Jointer Creek	GA
62305	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0566999999999993	-81.4232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:36:00	\N	1.15999999999999992	00:03:00	\N	1.12999999999999989	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
62306	2.5 miles above mouth, Little Satilla River, Georgia	NOS	8677833	31.0582999999999991	-81.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.12000000000000011	-00:04:00	\N	1.12000000000000011	\N	\N	2.5 miles above mouth	GA
62307	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167000000000002	-81.5283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	1.14999999999999991	00:06:00	\N	1.14999999999999991	\N	\N	Dover Bluff, Dover Creek	GA
62308	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9716999999999985	-81.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:41:00	\N	1.10000000000000009	-00:08:00	\N	1.10000000000000009	\N	\N	Todd Creek entrance	GA
62309	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633000000000003	-81.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:35:00	\N	1.09000000000000008	00:34:00	\N	1.09000000000000008	\N	\N	Ceylon	GA
62310	Floyd Creek, 2.8 miles above entrance, Georgia	NOS	8678642	30.9366999999999983	-81.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:21:00	\N	1.16999999999999993	00:08:00	\N	1.16999999999999993	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
62311	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.9299999999999997	-81.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:26:00	\N	1.12000000000000011	00:00:00	\N	1.12000000000000011	\N	\N	Cumberland Wharf, Cumberland River	GA
62312	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.870000000000001	-81.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:56:00	\N	1.05000000000000004	01:29:00	\N	1.05000000000000004	\N	\N	Harrietts Bluff, Crooked River	GA
62313	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8432999999999993	-81.486699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:56:00	\N	1.12000000000000011	00:44:00	\N	1.12000000000000011	\N	\N	Crooked River, Cumberland Dividings	GA
62314	Kings Bay, Navy Base, Georgia (sub)	NOS	8679511	30.7967000000000013	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:10:00	\N	1.05000000000000004	00:12:00	\N	1.09000000000000008	\N	\N	Kings Bay, Navy Base	GA
62315	Dungeness, Seacamp Dock, Georgia (sub)	NOS	8679758	30.763300000000001	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:16:00	\N	1.05000000000000004	00:12:00	\N	1.04000000000000004	\N	\N	Seacamp Dock, Cumberland Island	GA
62316	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.726700000000001	-81.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:04:00	\N	0.949999999999999956	00:00:00	\N	0.979999999999999982	\N	\N	Beach Creek ent., Cumberland Island	GA
62317	St. Marys, St. Marys River, Georgia (sub)	NOS	8679964	30.7199999999999989	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:45:00	\N	1.05000000000000004	00:38:00	\N	0.979999999999999982	\N	\N	St. Marys	GA
62318	St. Marys Entrance, North Jetty, Georgia	NOS	8679997	30.7199999999999989	-81.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:03:00	\N	0.959999999999999964	-00:36:00	\N	0.959999999999999964	\N	\N	St. Marys Entrance, North Jetty	GA
62319	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7866999999999997	-81.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	04:09:00	\N	1.15999999999999992	04:05:00	\N	0.489999999999999991	\N	\N	Kings Ferry	FL
62320	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:36:00	\N	0.790000000000000036	02:49:00	\N	0.709999999999999964	\N	\N	Little St. Marys River	FL
62321	Roses Bluff, Bells River, Florida	NOS	8720007	30.7032999999999987	-81.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:35:00	\N	0.949999999999999956	00:35:00	\N	1.03000000000000003	\N	\N	Roses Bluff, Bells River	FL
62322	Chester, Bells River, Florida (sub)	NOS	8720023	30.6832999999999991	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:19:00	\N	1.1100000000000001	00:27:00	\N	1.04000000000000004	\N	\N	Chester, Bells River	FL
62323	Lofton, Lanceford Creek, Florida (sub)	NOS	8720051	30.6433	-81.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:01:00	\N	1.05000000000000004	00:18:00	\N	1.05000000000000004	\N	\N	Lofton, Lanceford Creek	FL
62324	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6316999999999986	-81.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:25:00	\N	1	00:27:00	\N	0.989999999999999991	\N	\N	Kingsley Creek, RR. bridge	FL
62325	Boggy Creek, 2 mi. above entrance, Nassau River, Florida	NOS	8720084	30.5883000000000003	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	03:50:00	\N	0.890000000000000013	03:29:00	\N	0.489999999999999991	\N	\N	Boggy Creek, 2 mi. above entrance	FL
62326	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867000000000004	-81.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:42:00	\N	0.890000000000000013	00:21:00	\N	0.890000000000000013	\N	\N	Amelia City, South Amelia River	FL
62327	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5766999999999989	-81.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:39:00	\N	1.05000000000000004	02:00:00	\N	0.699999999999999956	\N	\N	Halfmoon Island, highway bridge	FL
62328	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5766999999999989	-81.571700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:48:00	\N	1.05000000000000004	02:14:00	\N	0.599999999999999978	\N	\N	Cuno, Lofton Creek	FL
62329	Nassauville, Nassau River East, Florida (sub)	NOS	8720098	30.5683000000000007	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:09:00	\N	1	00:24:00	\N	0.800000000000000044	\N	\N	Nassauville	FL
62330	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5366999999999997	-81.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:05:00	\N	1.05000000000000004	01:13:00	\N	0.719999999999999973	\N	\N	Mink Creek entrance	FL
62331	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:41:00	\N	1	-00:18:00	\N	0.859999999999999987	\N	\N	entrance	FL
62332	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.513300000000001	-81.4566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:21:00	\N	1	-00:14:00	\N	0.839999999999999969	\N	\N	Sawpit Creek entrance, bridge	FL
62333	Sawpit Creek, 1 mi. above entrance, Florida	NOS	8720143	30.5032999999999994	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:31:00	\N	0.739999999999999991	00:05:00	\N	0.839999999999999969	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
62334	Edwards Creek, Nassau River, Florida (sub)	NOS	8720145	30.5016999999999996	-81.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:51:00	\N	0.849999999999999978	01:24:00	\N	0.770000000000000018	\N	\N	Edwards Creek, 1 mi. above entrance	FL
62335	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5016999999999996	-81.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:46:00	\N	0.949999999999999956	01:22:00	\N	0.819999999999999951	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
62336	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.4649999999999999	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:17:00	\N	0.630000000000000004	00:04:00	\N	0.839999999999999969	\N	\N	Simpson Creek, A1A highway bridge	FL
62337	Fort George Island, Fort George River, Florida	NOS	8720186	30.4400000000000013	-81.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:33:00	\N	0.739999999999999991	00:10:00	\N	0.790000000000000036	\N	\N	Fort George Island, Fort George River	FL
62338	Little Talbot Island, ocean, Florida	NOS	8720194	30.4299999999999997	-81.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:13:00	\N	1	-00:36:00	\N	0.910000000000000031	\N	\N	Little Talbot Island, ocean	FL
62339	Sisters Creek, Florida (sub)	NOS	8720196	30.4166999999999987	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:50:00	\N	0.930000000000000049	00:32:00	\N	0.949999999999999956	\N	\N	Sisters Creek	FL
62340	Blount Island Bridge, Florida	NOS	8720203	30.4132999999999996	-81.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:05:00	\N	0.729999999999999982	00:42:00	\N	0.770000000000000018	\N	\N	Blount Island Bridge	FL
62341	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida (sub)	NOS	8720211	30.3999999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	-00:06:00	\N	1	-00:12:00	\N	1.03000000000000003	\N	\N	Mayport Naval Station, Water Treatment Dock	FL
62342	Sherwood Forest, Trout River, Florida (sub)	NOS	8720213	30.4200000000000017	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:13:00	\N	0.67000000000000004	01:42:00	\N	0.57999999999999996	\N	\N	Sherwood Forest	FL
62343	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.3999999999999986	-81.6266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:48:00	\N	0.530000000000000027	01:14:00	\N	0.560000000000000053	\N	\N	Jacksonville, Navy Fuel Depot	FL
62344	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.398299999999999	-81.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:10:00	\N	0.599999999999999978	01:13:00	\N	0.57999999999999996	\N	\N	Lake Forest, Ribault River	FL
62345	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917000000000002	-81.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:53:00	\N	0.530000000000000027	01:11:00	\N	0.550000000000000044	\N	\N	Moncrief Creek entrance	FL
62346	Dame Point, St. Johns River, Florida (sub)	NOS	8720219	30.3867000000000012	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:12:00	\N	0.67000000000000004	00:42:00	\N	0.699999999999999956	\N	\N	Dame Point	FL
62347	Fulton, Florida	NOS	8720221	30.3900000000000006	-81.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:40:00	\N	0.729999999999999982	00:24:00	\N	0.800000000000000044	\N	\N	Fulton	FL
62348	Phoenix Park, Florida (sub)	NOS	8720225	30.3832999999999984	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:47:00	\N	0.599999999999999978	01:02:00	\N	0.560000000000000053	\N	\N	Phoenix Park	FL
62349	Main Street Bridge, St. Johns River, Florida (sub)	NOS	8720226	30.3200000000000003	-81.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:09:00	\N	0.729999999999999982	01:39:00	\N	0.400000000000000022	\N	\N	Jacksonville, Main Street Bridge	FL
62350	Pablo Creek entrance, Florida	NOS	8720232	30.3766999999999996	-81.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	00:33:00	\N	0.729999999999999982	00:29:00	\N	0.849999999999999978	\N	\N	Pablo Creek entrance	FL
62351	Jacksonville, Long Branch, Florida (sub)	NOS	8720242	30.3599999999999994	-81.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:54:00	\N	0.729999999999999982	01:15:00	\N	0.550000000000000044	\N	\N	Jacksonville, Long Branch	FL
62352	Atlantic Beach, Florida	NOS	8720259	30.3350000000000009	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:23:00	\N	0.859999999999999987	-00:41:00	\N	0.859999999999999987	\N	\N	Atlantic Beach	FL
62353	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3232999999999997	-81.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	01:20:00	\N	1	01:14:00	\N	0.839999999999999969	\N	\N	Pablo Creek, ICWW bridge	FL
62354	Little Pottsburg Creek, Florida	NOS	8720274	30.3099999999999987	-81.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:09:00	\N	0.530000000000000027	01:31:00	\N	0.440000000000000002	\N	\N	Little Pottsburg Creek	FL
62355	Jacksonville Beach, Florida (sub)	NOS	8720291	30.2833000000000006	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:27:00	\N	0.839999999999999969	-00:50:00	\N	0.839999999999999969	\N	\N	Jacksonville Beach	FL
62356	Ortega River entrance, Florida	NOS	8720296	30.2783000000000015	-81.7049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	02:47:00	\N	0.469999999999999973	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
62357	Oak Landing, ICWW, Florida	NOS	8720305	30.2532999999999994	-81.4300000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	02:03:00	\N	0.800000000000000044	02:15:00	\N	0.680000000000000049	\N	\N	Oak Landing, ICWW	FL
62358	Piney Point, Florida	NOS	8720333	30.2283000000000008	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	03:36:00	\N	0.400000000000000022	02:39:00	\N	0.200000000000000011	\N	\N	Piney Point	FL
62359	I-295 Bridge (west end), St. Johns River, Florida (sub)	NOS	8720357	30.1917000000000009	-81.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	03:43:00	\N	0.599999999999999978	02:56:00	\N	0.209999999999999992	\N	\N	I-295 bridge (west end)	FL
62360	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.1683006286621094	-81.6949996948242188	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	04:44:00	\N	0.200000000000000011	03:24:00	\N	0.200000000000000011	\N	\N	Orange Park Landing, Orange Park	FL
62361	Palm Valley, ICWW, Florida	NOS	8720398	30.1332999999999984	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:49:00	\N	0.75	02:00:00	\N	0.790000000000000036	\N	\N	Palm Valley, ICWW	FL
62362	Julington Creek, Florida	NOS	8720409	30.1350002288818359	-81.6299972534179688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	05:13:00	\N	0.200000000000000011	03:58:00	\N	0.200000000000000011	\N	\N	Julington Creek	FL
62363	Green Cove Springs, Florida	NOS	8720496	29.9899999999999984	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	05:55:00	\N	0.270000000000000018	04:57:00	\N	0.170000000000000012	\N	\N	Green Cove Springs	FL
62364	Vilano Beach ICWW, Tolomato River, Florida (sub)	NOS	8720554	29.9166999999999987	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:05:00	\N	0.900000000000000022	-00:20:00	\N	0.739999999999999991	\N	\N	Vilano Beach, Tolomato River	FL
62365	St. Augustine, city dock, Florida	NOS	8720576	29.8917000000000002	-81.3100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:01:00	\N	0.890000000000000013	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
62366	St. Augustine Beach, Florida (sub)	NOS	8720587	29.8567	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:32:00	\N	0.839999999999999969	-00:51:00	\N	0.770000000000000018	\N	\N	St. Augustine Beach	FL
62367	Tocoi, Florida	NOS	8720596	29.8582999999999998	-81.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	07:03:00	\N	0.270000000000000018	06:02:00	\N	0.209999999999999992	\N	\N	Tocoi	FL
62368	Palmetto Bluff, Florida	NOS	8720653	29.763300000000001	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	07:36:00	\N	0.469999999999999973	06:35:00	\N	0.23000000000000001	\N	\N	Palmetto Bluff	FL
62369	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.7149999999999999	-81.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	00:49:00	\N	0.949999999999999956	00:03:00	\N	0.650000000000000022	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
62370	Buffalo Bluff, St. Johns River, Florida (sub)	NOS	8720767	29.5949999999999989	-81.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:58:00	\N	0.400000000000000022	07:27:00	\N	0.209999999999999992	\N	\N	Buffalo Bluff	FL
62371	Palatka, St. Johns River, Florida (sub)	NOS	8720774	29.6433	-81.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:38:00	\N	0.530000000000000027	07:11:00	\N	0.25	\N	\N	Palatka	FL
62372	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5716999999999999	-81.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	09:05:00	\N	0.200000000000000011	07:35:00	\N	0.179999999999999993	\N	\N	Sutherlands Still, Dunns Creek	FL
62373	Welaka, St. Johns River, Florida (sub)	NOS	8720832	29.476700000000001	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60530	08:07:00	\N	0.270000000000000018	07:16:00	\N	0.100000000000000006	\N	\N	Welaka	FL
62374	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783000000000008	-81.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	05:00:00	\N	0.299999999999999989	04:33:00	\N	0.149999999999999994	\N	\N	Smith Creek, Flagler Beach	FL
62375	Ormond Beach, Halifax River, Florida	NOS	8720954	29.2850000000000001	-81.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	04:31:00	\N	0.450000000000000011	03:17:00	\N	0.110000000000000001	\N	\N	Ormond Beach, Halifax River	FL
62376	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1466999999999992	-80.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	-00:42:00	\N	0.839999999999999969	-00:56:00	\N	0.650000000000000022	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
62377	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817000000000014	-80.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:33:00	\N	1	00:05:00	\N	1.17999999999999994	\N	\N	Ponce Inlet, Halifax River	FL
62378	Ponce De Leon Inlet South, Florida (sub)	NOS	8721147	29.0633000000000017	-80.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:19:00	\N	0.92000000000000004	-00:11:00	\N	1.16999999999999993	\N	\N	Ponce de Leon Inlet	FL
62379	Patrick Air Force Base, Florida	NOS	8721727	28.245000000000001	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:38:00	\N	1.42999999999999994	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
62380	Canova Beach, Florida	NOS	8721804	28.138300000000001	-80.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:26:00	\N	1.5	-00:53:00	\N	1.48999999999999999	\N	\N	Canova Beach	FL
62381	Micco, Indian River, Florida	NOS	8721994	27.8733000000000004	-80.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:19:00	\N	0.569999999999999951	01:14:00	\N	0.140000000000000013	\N	\N	Micco	FL
62382	Sebastian Inlet bridge, Florida	NOS	8722004	27.8599999999999994	-80.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:24:00	\N	1	-00:48:00	\N	0.930000000000000049	\N	\N	Sebastian Inlet bridge	FL
62383	Sebastian, Indian River, Florida	NOS	8722029	27.8116999999999983	-80.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:36:00	\N	0.5	01:32:00	\N	0.149999999999999994	\N	\N	Sebastian	FL
62384	Wabasso, Indian River, Florida	NOS	8722059	27.754999999999999	-80.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:24:00	\N	0.419999999999999984	02:20:00	\N	0.170000000000000012	\N	\N	Wabasso	FL
62385	Vero Beach (ocean), Florida	NOS	8722105	27.6700000000000017	-80.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:35:00	\N	1.3600000000000001	-00:55:00	\N	1.44999999999999996	\N	\N	Vero Beach (ocean)	FL
62386	Vero Beach, Indian River, Florida (sub)	NOS	8722125	27.6316999999999986	-80.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:41:00	\N	0.790000000000000036	02:56:00	\N	0.369999999999999996	\N	\N	Vero Beach	FL
62387	Oslo, Indian River, Florida	NOS	8722146	27.5932999999999993	-80.3567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:59:00	\N	0.5	03:00:00	\N	0.340000000000000024	\N	\N	Oslo	FL
62388	St. Lucie, Indian River, Florida	NOS	8722207	27.4800000000000004	-80.3332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	1	00:41:00	\N	0.479999999999999982	\N	\N	St. Lucie	FL
62389	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.4699999999999989	-80.2883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:18:00	\N	1.5	-00:31:00	\N	1.1399999999999999	\N	\N	Fort Pierce Inlet, south jetty	FL
62390	Ankona, Indian River, Florida	NOS	8722274	27.3550000000000004	-80.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:03:00	\N	0.849999999999999978	02:16:00	\N	0.520000000000000018	\N	\N	Ankona	FL
62391	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2866999999999997	-80.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:31:00	\N	0.92000000000000004	02:35:00	\N	0.450000000000000011	\N	\N	Eden, Nettles Island	FL
62392	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433000000000014	-80.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:28:00	\N	0.92000000000000004	02:28:00	\N	0.46000000000000002	\N	\N	North Fork	FL
62393	Jensen Beach, Indian River, Florida	NOS	8722338	27.2349999999999994	-80.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:04:00	\N	0.92000000000000004	02:17:00	\N	0.479999999999999982	\N	\N	Jensen Beach	FL
62394	Stuart, St. Lucie River, Florida	NOS	8722357	27.1999999999999993	-80.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:30:00	\N	0.859999999999999987	02:13:00	\N	0.400000000000000022	\N	\N	Stuart	FL
62395	Seminole Shores, Florida	NOS	8722366	27.1832999999999991	-80.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:35:00	\N	1.28000000000000003	-00:59:00	\N	1.29000000000000004	\N	\N	Seminole Shores	FL
62396	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.1750000000000007	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:10:00	\N	0.930000000000000049	01:13:00	\N	0.429999999999999993	\N	\N	Sewall Point	FL
62397	South Fork, St. Lucie River, Florida	NOS	8722376	27.1649999999999991	-80.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:32:00	\N	0.92000000000000004	02:35:00	\N	0.429999999999999993	\N	\N	South Fork	FL
62399	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517000000000017	-80.1949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	0.92000000000000004	00:51:00	\N	0.419999999999999984	\N	\N	Port Salerno, Manatee Pocket	FL
62400	Peck Lake, ICWW, Florida	NOS	8722404	27.1132999999999988	-80.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:10:00	\N	1	01:13:00	\N	0.57999999999999996	\N	\N	Peck Lake, ICWW	FL
62401	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0932999999999993	-80.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:37:00	\N	1.07000000000000006	01:33:00	\N	0.599999999999999978	\N	\N	Gomez, South Jupiter Narrows	FL
62402	Hobe Sound bridge, Florida	NOS	8722429	27.0650000000000013	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:25:00	\N	1	01:28:00	\N	0.680000000000000049	\N	\N	Hobe Sound bridge	FL
62403	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0366999999999997	-80.1067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
62404	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9882999999999988	-80.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:34:00	\N	1.07000000000000006	00:56:00	\N	0.739999999999999991	\N	\N	Conch Bar, Jupiter Sound	FL
62405	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.986699999999999	-80.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.3600000000000001	01:01:00	\N	0.92000000000000004	\N	\N	Boy Scout Dock	FL
62406	North Fork, 2 miles above entrance, Loxahatchee River, Florida	NOS	8722478	26.9750000000000014	-80.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:55:00	\N	1.1399999999999999	01:04:00	\N	0.859999999999999987	\N	\N	North Fork, 2 miles above entrance	FL
62407	3 miles above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.9699999999999989	-80.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	1.1399999999999999	00:56:00	\N	0.859999999999999987	\N	\N	3 miles above A1A highway bridge	FL
62408	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.9600000000000009	-80.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
62409	Jupiter Sound, south end, Florida	NOS	8722491	26.9516999999999989	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:45:00	\N	1.3600000000000001	00:22:00	\N	0.880000000000000004	\N	\N	Jupiter Sound, south end	FL
62410	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9466999999999999	-80.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:54:00	\N	1.1399999999999999	00:34:00	\N	0.869999999999999996	\N	\N	A1A highway bridge	FL
62411	Southwest Fork, 0.5 mile above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433000000000007	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:35:00	\N	1.41999999999999993	00:41:00	\N	0.890000000000000013	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
62412	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433000000000007	-80.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:09:00	\N	1.41999999999999993	-00:10:00	\N	1.08000000000000007	\N	\N	Jupiter Inlet, south jetty	FL
62413	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.9349999999999987	-80.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:45:00	\N	1.28000000000000003	00:52:00	\N	0.859999999999999987	\N	\N	Southwest Fork (spillway)	FL
62414	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.9349999999999987	-80.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:12:00	\N	1.28000000000000003	00:34:00	\N	0.910000000000000031	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
62415	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9116999999999997	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:08:00	\N	1.20999999999999996	00:29:00	\N	0.92000000000000004	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
62416	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8816999999999986	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:50:00	\N	1.20999999999999996	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
62417	PGA Boulevard Bridge, Palm Beach, Florida (sub)	NOS	8722548	26.8432999999999993	-80.0666999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:31:00	\N	1.3600000000000001	-00:02:00	\N	1.15999999999999992	\N	\N	PGA Boulevard Bridge, ICWW	FL
62418	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8266999999999989	-80.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:15:00	\N	1.29000000000000004	-00:17:00	\N	1.21999999999999997	\N	\N	North Palm Beach	FL
62419	Port of West Palm Beach, Florida (sub)	NOS	8722588	26.7699999999999996	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:04:00	\N	1.3600000000000001	-00:21:00	\N	1.17999999999999994	\N	\N	Port of Palm Beach	FL
62420	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7332999999999998	-80.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:16:00	\N	1.29000000000000004	-00:11:00	\N	1.16999999999999993	\N	\N	Palm Beach	FL
62421	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.7049999999999983	-80.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:40:00	\N	1.07000000000000006	00:18:00	\N	1.10000000000000009	\N	\N	Palm Beach, Highway 704 bridge	FL
62422	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.6449999999999996	-80.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:35:00	\N	1.1399999999999999	00:48:00	\N	1.07000000000000006	\N	\N	West Palm Beach Canal	FL
62423	Lake Worth Pier, Florida (sub)	NOS	8722670	26.6127777999999999	-80.0341667000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:19:00	\N	1	-00:45:00	\N	1.15999999999999992	\N	\N	Lake Worth Pier (ocean)	FL
62424	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.5482997894287109	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1.07000000000000006	01:05:00	\N	1.06000000000000005	\N	\N	Boynton Beach, Lake Worth	FL
62425	Delray Beach, ICWW, Florida	NOS	8722746	26.4732999999999983	-80.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1.1399999999999999	01:24:00	\N	1.07000000000000006	\N	\N	Delray Beach, ICWW	FL
62426	Yamato, ICWW, Florida	NOS	8722784	26.4033000000000015	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.1399999999999999	01:22:00	\N	1.02000000000000002	\N	\N	Yamato, ICWW	FL
62427	Lake Wyman, ICWW, Florida (sub)	NOS	8722802	26.370000000000001	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	1.1399999999999999	01:17:00	\N	0.959999999999999964	\N	\N	Lake Wyman, ICWW	FL
62428	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.3133000000000017	-80.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:03:00	\N	1.07000000000000006	00:28:00	\N	1.02000000000000002	\N	\N	Deerfield Beach, Hillsboro River	FL
62429	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.273299999999999	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:34:00	\N	1.07000000000000006	00:02:00	\N	1.06000000000000005	\N	\N	Hillsboro Beach, ICWW	FL
62430	Hillsboro Inlet, Coast Guard Light Station, Florida	NOS	8722861	26.2582999999999984	-80.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:03:00	\N	1.1399999999999999	-00:16:00	\N	1.08000000000000007	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
62431	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2566999999999986	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:00:00	\N	1.20999999999999996	-00:23:00	\N	1.12000000000000011	\N	\N	Hillsboro Inlet (ocean)	FL
62432	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183000000000014	-80.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	1.07000000000000006	00:15:00	\N	0.92000000000000004	\N	\N	Andrews Avenue bridge, New River	FL
62433	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1132999999999988	-80.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:33:00	\N	1.20999999999999996	-00:05:00	\N	1.05000000000000004	\N	\N	Bahia Mar Yacht Club	FL
62434	Mayan Lake, Florida	NOS	8722946	26.1000000000000014	-80.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:02:00	\N	1	00:20:00	\N	0.910000000000000031	\N	\N	Mayan Lake	FL
62435	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0916999999999994	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:09:00	\N	1.1399999999999999	-00:29:00	\N	1.09000000000000008	\N	\N	Port Everglades, Turning Basin	FL
62436	Whiskey Creek, north end, Florida	NOS	8722957	26.0799999999999983	-80.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:06:00	\N	1.28000000000000003	-00:23:00	\N	1.10000000000000009	\N	\N	Whiskey Creek, north end	FL
62437	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.0599999999999987	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:11:00	\N	1.20999999999999996	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
62438	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.0549999999999997	-80.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:31:00	\N	1.1399999999999999	00:04:00	\N	0.959999999999999964	\N	\N	Whiskey Creek, south entrance, ICWW	FL
62439	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0432999999999986	-80.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	1.07000000000000006	01:08:00	\N	0.849999999999999978	\N	\N	Hollywood Beach, West Lake, north end	FL
62440	Hollywood Beach, Florida	NOS	8722979	26.0399999999999991	-80.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:41:00	\N	1.1399999999999999	00:37:00	\N	0.910000000000000031	\N	\N	Hollywood Beach	FL
62441	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333000000000006	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:45:00	\N	1.1399999999999999	01:02:00	\N	0.880000000000000004	\N	\N	Hollywood Beach, West Lake, south end	FL
62442	Golden Beach, ICWW, Florida	NOS	8723026	25.9666999999999994	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:57:00	\N	1.07000000000000006	01:13:00	\N	0.910000000000000031	\N	\N	Golden Beach, ICWW	FL
62443	Dumfoundling Bay, Florida	NOS	8723044	25.9417000000000009	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:07:00	\N	1	01:17:00	\N	0.880000000000000004	\N	\N	Dumfoundling Bay	FL
62444	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.9299999999999997	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:00:00	\N	1.20999999999999996	-00:22:00	\N	1.08000000000000007	\N	\N	North Miami Beach, Newport Fishing Pier	FL
62445	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033000000000015	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:37:00	\N	0.92000000000000004	00:57:00	\N	0.869999999999999996	\N	\N	Bakers Haulover Inlet (inside)	FL
62446	Haulover Pier, N. Miami Beach, Florida (sub)	NOS	8723080	25.9033000000000015	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:06:00	\N	1	-00:29:00	\N	1.06000000000000005	\N	\N	Haulover Pier, N. Miami Beach	FL
62447	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283000000000001	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:24:00	\N	0.709999999999999964	02:00:00	\N	0.770000000000000018	\N	\N	Sunny Isles, Biscayne Creek	FL
62448	Biscayne Creek, ICWW, Florida	NOS	8723089	25.879999999999999	-80.1633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:39:00	\N	1	00:47:00	\N	0.930000000000000049	\N	\N	Biscayne Creek, ICWW	FL
62449	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:46:00	\N	0.92000000000000004	01:13:00	\N	0.92000000000000004	\N	\N	Indian Creek Golf Club, ICWW	FL
62450	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.7699999999999996	-80.1683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:10:00	\N	1	00:34:00	\N	0.910000000000000031	\N	\N	Dodge Island, Fishermans Channel	FL
62451	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7932999999999986	-80.1633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:58:00	\N	1	00:37:00	\N	0.92000000000000004	\N	\N	San Marino Island	FL
62452	Miami, Miamarina, Biscayne Bay, Florida (sub)	NOS	8723165	25.7783000000000015	-80.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:49:00	\N	0.92000000000000004	00:20:00	\N	0.939999999999999947	\N	\N	Miami Miamarina, Biscayne Bay	FL
62453	Miami Beach (city pier), Florida (sub)	NOS	8723170	25.7683	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:02:00	\N	1.1399999999999999	-00:22:00	\N	1.07000000000000006	\N	\N	Miami Harbor Entrance	FL
62454	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.726700000000001	-80.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:48:00	\N	0.92000000000000004	00:54:00	\N	0.839999999999999969	\N	\N	Dinner Key Marina	FL
62455	Virginia Key, Bear Cut, Biscayne Bay, Florida (sub)	NOS	8723214	25.7314000000000007	-80.1617999999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	0.859999999999999987	00:28:00	\N	0.880000000000000004	\N	\N	Bear Cut, Virginia Key	FL
62456	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6982999999999997	-80.1700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:31:00	\N	0.92000000000000004	00:44:00	\N	0.859999999999999987	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
62457	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517000000000017	-80.1599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:37:00	\N	0.92000000000000004	00:11:00	\N	0.880000000000000004	\N	\N	Coral Shoal, Biscayne Channel	FL
62458	Soldier Key, Florida	NOS	8723303	25.5899999999999999	-80.1616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:16:00	\N	0.709999999999999964	00:30:00	\N	0.810000000000000053	\N	\N	Soldier Key	FL
62459	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333000000000006	-80.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:18:00	\N	1	00:43:00	\N	0.729999999999999982	\N	\N	Ragged Keys, Biscayne Bay	FL
62460	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5066999999999986	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:26:00	\N	0.640000000000000013	01:25:00	\N	0.630000000000000004	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
62461	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.4800000000000004	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	02:56:00	\N	0.709999999999999964	01:55:00	\N	0.630000000000000004	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
62462	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.476700000000001	-80.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:05:00	\N	1.03000000000000003	-00:25:00	\N	1.03000000000000003	\N	\N	Sea Grape Point, Elliott Key	FL
62463	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.4149999999999991	-80.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:20:00	\N	0.640000000000000013	02:08:00	\N	0.630000000000000004	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
62464	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3966999999999992	-80.2332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:08:00	\N	1	01:01:00	\N	0.67000000000000004	\N	\N	Adams Key, south end, Biscayne Bay	FL
62465	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917000000000002	-80.230000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:37:00	\N	1.07000000000000006	00:13:00	\N	0.800000000000000044	\N	\N	Christmas Point, Elliott Key	FL
62466	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3782999999999994	-80.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:21:00	\N	0.569999999999999951	02:19:00	\N	0.540000000000000036	\N	\N	Totten Key, west side, Biscayne Bay	FL
62467	Card Sound, western side, Florida	NOS	8723491	25.3449999999999989	-80.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:40:00	\N	0.429999999999999993	02:51:00	\N	0.299999999999999989	\N	\N	Card Sound, western side	FL
62468	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.3099999999999987	-80.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:30:00	\N	0.569999999999999951	02:38:00	\N	0.340000000000000024	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
62469	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3082999999999991	-80.2767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:17:00	\N	1.5	-00:08:00	\N	1.02000000000000002	\N	\N	Ocean Reef Harbor, Key Largo	FL
62470	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.2899999999999991	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:01:00	\N	0.5	02:45:00	\N	0.320000000000000007	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
62471	Main Key, Barnes Sound, Florida	NOS	8723571	25.2399999999999984	-80.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	06:16:00	\N	0.359999999999999987	05:04:00	\N	0.190000000000000002	\N	\N	Main Key, Barnes Sound	FL
62472	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.2349999999999994	-80.4300000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	06:20:00	\N	0.359999999999999987	05:14:00	\N	0.179999999999999993	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
62473	Carysfort Reef, Florida	NOS	8723583	25.2216999999999985	-80.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:39:00	\N	1.3600000000000001	00:19:00	\N	1.03000000000000003	\N	\N	Carysfort Reef	FL
62474	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717000000000013	-80.3666999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:25:00	\N	1.1399999999999999	-00:01:00	\N	0.939999999999999947	\N	\N	Garden Cove, Key Largo	FL
62475	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417000000000002	-80.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	07:20:00	\N	1.08000000000000007	05:28:00	\N	1.46999999999999997	\N	\N	Flamingo, Florida Bay	FL
62476	Largo Sound, Key Largo, Florida	NOS	8723651	25.1400000000000006	-80.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	03:03:00	\N	0.5	02:13:00	\N	0.349999999999999978	\N	\N	Largo Sound, Key Largo	FL
62477	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.1133333333329922	-80.4166666666670125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:49:00	\N	0.640000000000000013	00:23:00	\N	0.660000000000000031	\N	\N	Key Largo, South Sound, Key Largo	FL
62478	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817000000000014	-80.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:36:00	\N	1.20999999999999996	00:22:00	\N	0.939999999999999947	\N	\N	Rock Harbor, Key Largo	FL
62479	Point Charles, Key Largo, Florida	NOS	8723691	25.0817000000000014	-80.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:53:00	\N	0.640000000000000013	00:25:00	\N	0.770000000000000018	\N	\N	Point Charles, Key Largo	FL
62480	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.004999999999999	-80.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:35:00	\N	0.209999999999999992	02:52:00	\N	0.170000000000000012	\N	\N	Crane Keys, north side, Florida Bay	FL
62481	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.004999999999999	-80.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:26:00	\N	1.3600000000000001	00:07:00	\N	0.900000000000000022	\N	\N	Tavernier Harbor, Hawk Channel	FL
62482	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0032999999999994	-80.5300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:52:00	\N	1.07000000000000006	00:25:00	\N	0.599999999999999978	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
62483	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967000000000006	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:06:00	\N	0.140000000000000013	02:43:00	\N	0.220000000000000001	\N	\N	East Key, southern end, Florida Bay	FL
62484	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9732999999999983	-80.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:12:00	\N	1.20999999999999996	00:05:00	\N	0.959999999999999964	\N	\N	Plantation Key, Hawk Channel	FL
62485	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.9649999999999999	-80.5682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	04:00:00	\N	0.28999999999999998	02:45:00	\N	0.23000000000000001	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
62486	Snake Creek, USCG Station, Plantation Key, Florida	NOS	8723786	24.9532999999999987	-80.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:56:00	\N	0.5	01:08:00	\N	0.359999999999999987	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
62487	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9516999999999989	-80.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:56:00	\N	0.5	00:49:00	\N	0.46000000000000002	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
62488	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.9400000000000013	-80.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:51:00	\N	0.359999999999999987	00:07:00	\N	0.650000000000000022	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
62489	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383000000000017	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:00:00	\N	0.709999999999999964	00:16:00	\N	0.589999999999999969	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
62490	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233000000000011	-80.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:57:00	\N	0.46000000000000002	00:31:00	\N	0.46000000000000002	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
62491	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.9250000000000007	-80.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:07:00	\N	0.369999999999999996	00:39:00	\N	0.369999999999999996	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
62492	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9132999999999996	-80.6599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:45:00	\N	0.780000000000000027	-00:20:00	\N	0.780000000000000027	\N	\N	Shell Key Channel, Florida Bay	FL
62493	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.9149999999999991	-80.6400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:15:00	\N	0.609999999999999987	00:08:00	\N	0.609999999999999987	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
62494	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.9149999999999991	-80.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:49:00	\N	1.20999999999999996	00:34:00	\N	0.869999999999999996	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
62495	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033000000000015	-80.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:31:00	\N	0.520000000000000018	00:09:00	\N	0.520000000000000018	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
62496	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.8999999999999986	-80.7049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:54:00	\N	0.469999999999999973	00:32:00	\N	0.469999999999999973	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
62497	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8966999999999992	-80.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:14:00	\N	0.330000000000000016	-01:00:00	\N	0.979999999999999982	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
62498	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8766999999999996	-80.6766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:35:00	\N	0.709999999999999964	-00:58:00	\N	1.30000000000000004	\N	\N	Indian Key, Hawk Channel	FL
62499	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683000000000014	-80.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.880000000000000004	-01:25:00	\N	1.37999999999999989	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
62500	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.8649999999999984	-80.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:33:00	\N	0.380000000000000004	-00:18:00	\N	0.550000000000000044	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
62501	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.8500000000000014	-80.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	00:24:00	\N	1.3600000000000001	00:08:00	\N	0.859999999999999987	\N	\N	Alligator Reef, Hawk Channel	FL
62502	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.851700000000001	-80.7399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:23:00	\N	0.330000000000000016	-00:25:00	\N	0.589999999999999969	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
62503	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.8449999999999989	-80.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:42:00	\N	0.540000000000000036	-00:49:00	\N	0.849999999999999978	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
62504	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8416999999999994	-80.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.75	-01:06:00	\N	1.12000000000000011	\N	\N	Channel Two, west side, Hawk Channel	FL
62505	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.8399999999999999	-80.7800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:41:00	\N	0.67000000000000004	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
62506	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.8383000000000003	-80.7982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:32:00	\N	0.380000000000000004	-00:11:00	\N	0.419999999999999984	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
62507	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367000000000004	-80.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:42:00	\N	0.57999999999999996	-00:54:00	\N	0.900000000000000022	\N	\N	Channel Five, east side, Hawk Channel	FL
62508	Long Key Bight, Long Key, Florida	NOS	8723879	24.8282999999999987	-80.8083000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:43:00	\N	0.619999999999999996	-00:59:00	\N	1.03000000000000003	\N	\N	Long Key Bight, Long Key	FL
62509	Long Key Lake, Long Key, Florida	NOS	8723887	24.8200000000000003	-80.8166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:57:00	\N	0.46000000000000002	00:33:00	\N	0.619999999999999996	\N	\N	Long Key Lake, Long Key	FL
62510	Long Key, western end, Florida	NOS	8723899	24.8033000000000001	-80.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:54:00	\N	0.330000000000000016	-01:01:00	\N	0.819999999999999951	\N	\N	Long Key, western end	FL
62511	Conch Key, eastern end, Florida	NOS	8723906	24.7916999999999987	-80.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:45:00	\N	0.540000000000000036	-01:09:00	\N	0.849999999999999978	\N	\N	Conch Key, eastern end	FL
62512	Toms Harbor Cut, Florida	NOS	8723912	24.7833000000000006	-80.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:30:00	\N	0.380000000000000004	-01:19:00	\N	0.369999999999999996	\N	\N	Toms Harbor Cut	FL
62513	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767000000000017	-80.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:49:00	\N	0.380000000000000004	05:07:00	\N	0.380000000000000004	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
62514	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7716999999999992	-80.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:48:00	\N	1.04000000000000004	05:40:00	\N	0.729999999999999982	\N	\N	Grassy Key, north side, Florida Bay	FL
62515	Duck Key, Hawk Channel, Florida	NOS	8723927	24.7650000000000006	-80.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:40:00	\N	0.550000000000000044	-01:11:00	\N	0.969999999999999973	\N	\N	Duck Key, Hawk Channel	FL
62516	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.754999999999999	-80.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:26:00	\N	0.709999999999999964	-00:52:00	\N	1.21999999999999997	\N	\N	Grassy Key, south side, Hawk Channel	FL
62517	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7332999999999998	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:26:00	\N	0.869999999999999996	05:09:00	\N	0.869999999999999996	\N	\N	Fat Deer Key, Florida Bay	FL
62518	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.7300000000000004	-81.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:36:00	\N	0.709999999999999964	-01:11:00	\N	0.949999999999999956	\N	\N	Vaca Key-Fat Deer Key bridge	FL
62519	Key Colony Beach, Florida (sub)	NOS	8723962	24.7182999999999993	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:53:00	\N	0.82999999999999996	-01:17:00	\N	1.21999999999999997	\N	\N	Key Colony Beach	FL
62520	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7032999999999987	-81.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:37:00	\N	0.75	-01:03:00	\N	1.12999999999999989	\N	\N	Boot Key Harbor bridge, Boot Key	FL
62521	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6266999999999996	-81.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:39:00	\N	0.790000000000000036	-01:03:00	\N	1.17999999999999994	\N	\N	Sombrero Key, Hawk Channel	FL
62522	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067000000000014	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:18:00	\N	0.5	-00:02:00	\N	0.540000000000000036	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
62523	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7032999999999987	-81.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:26:00	\N	0.5	-00:55:00	\N	0.810000000000000053	\N	\N	Pigeon Key, south side, Hawk Channel	FL
62524	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.7049999999999983	-81.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:45:00	\N	0.46000000000000002	-00:10:00	\N	0.46000000000000002	\N	\N	Pigeon Key, north side, Florida Bay	FL
62525	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6832999999999991	-81.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:16:00	\N	0.5	-00:56:00	\N	0.790000000000000036	\N	\N	Molasses Key Channel, Molasses Keys	FL
62526	Money Key, Florida	NOS	8724082	24.6832999999999991	-81.216700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:17:00	\N	0.57999999999999996	00:03:00	\N	0.57999999999999996	\N	\N	Money Key	FL
62527	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6816999999999993	-81.2283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:05:00	\N	0.67000000000000004	-00:49:00	\N	0.67000000000000004	\N	\N	Little Duck Key, east end, Hawk Channel	FL
62528	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.7749999999999986	-81.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:49:00	\N	0.689999999999999947	04:04:00	\N	0.689999999999999947	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
62529	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745000000000001	-81.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:50:00	\N	0.550000000000000044	03:52:00	\N	0.550000000000000044	\N	\N	Cocoanut Key, Florida Bay	FL
62530	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.6799999999999997	-81.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:36:00	\N	0.46000000000000002	-00:52:00	\N	0.699999999999999956	\N	\N	Missouri Key-Little Duck Key Channel	FL
62531	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733000000000011	-81.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:22:00	\N	0.5	-00:47:00	\N	0.770000000000000018	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
62532	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.6700000000000017	-81.2516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:14:00	\N	0.619999999999999996	-00:57:00	\N	0.810000000000000053	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
62533	West Bahia Honda Key, Florida	NOS	8724129	24.7800000000000011	-81.2716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:01:00	\N	1	03:59:00	\N	0.969999999999999973	\N	\N	West Bahia Honda Key	FL
62534	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.6550000000000011	-81.2817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:28:00	\N	0.630000000000000004	-00:46:00	\N	0.859999999999999987	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
62535	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667000000000002	-81.283299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:09:00	\N	1	03:54:00	\N	0.859999999999999987	\N	\N	Horseshoe Keys, south end	FL
62536	Johnson Keys, south end, Florida	NOS	8724153	24.7433000000000014	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:33:00	\N	0.959999999999999964	03:36:00	\N	0.719999999999999973	\N	\N	Johnson Keys, south end	FL
62537	Little Pine Key, south end, Florida	NOS	8724154	24.7133000000000003	-81.303299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:07:00	\N	0.790000000000000036	01:07:00	\N	0.560000000000000053	\N	\N	Little Pine Key, south end	FL
62538	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6982999999999997	-81.3182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:33:00	\N	0.82999999999999996	01:35:00	\N	0.57999999999999996	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
62539	Johnson Keys, north end, Florida	NOS	8724172	24.7667000000000002	-81.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:22:00	\N	1.37999999999999989	03:35:00	\N	1.31000000000000005	\N	\N	Johnson Keys, north end	FL
62540	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3282999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:28:00	\N	1.20999999999999996	03:38:00	\N	1.05000000000000004	\N	\N	Little Pine Key, north end	FL
62541	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.648299999999999	-81.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:03:00	\N	0.419999999999999984	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
62542	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.7399999999999984	-81.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:37:00	\N	1.04000000000000004	03:23:00	\N	0.810000000000000053	\N	\N	Water Key, west end, Big Spanish Channel	FL
62543	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517000000000017	-81.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:49:00	\N	0.5	-00:20:00	\N	0.869999999999999996	\N	\N	Big Pine Key, Coupon Bight	FL
62544	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6966999999999999	-81.3482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:11:00	\N	0.82999999999999996	02:10:00	\N	0.650000000000000022	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
62545	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7182999999999993	-81.3516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:29:00	\N	1	03:23:00	\N	0.719999999999999973	\N	\N	Porpoise Key, Big Spanish Channel	FL
62546	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7566999999999986	-81.3582999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:13:00	\N	1.33000000000000007	03:34:00	\N	1.33000000000000007	\N	\N	Crawl Key, Big Spanish Channel	FL
62547	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.6900000000000013	-81.3567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:47:00	\N	0.709999999999999964	00:41:00	\N	0.630000000000000004	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
62548	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7332999999999998	-81.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:01:00	\N	1.08000000000000007	03:35:00	\N	0.92000000000000004	\N	\N	Mayo Key, Big Spanish Channel	FL
62549	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.773299999999999	-81.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:30:00	\N	1.62000000000000011	03:25:00	\N	1.73999999999999999	\N	\N	Little Spanish Key, Spanish Banks	FL
62550	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.6700000000000017	-81.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:43:00	\N	0.330000000000000016	00:03:00	\N	0.569999999999999951	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
62551	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6682999999999986	-81.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:03:00	\N	0.330000000000000016	-00:13:00	\N	0.67000000000000004	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
62552	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517000000000017	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:44:00	\N	0.46000000000000002	-00:09:00	\N	0.819999999999999951	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
62553	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.6649999999999991	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:57:00	\N	0.330000000000000016	-00:15:00	\N	0.680000000000000049	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
62554	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.6649999999999991	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:54:00	\N	0.380000000000000004	-00:13:00	\N	0.689999999999999947	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
62555	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283000000000008	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:30:00	\N	1.08000000000000007	03:19:00	\N	0.859999999999999987	\N	\N	Big Pine Key, northeast shore	FL
62556	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.6900000000000013	-81.3833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:52:00	\N	0.419999999999999984	00:21:00	\N	0.520000000000000018	\N	\N	Big Pine Key, west side, Pine Channel	FL
62557	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7582999999999984	-81.3900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:33:00	\N	1.29000000000000004	03:30:00	\N	1.43999999999999995	\N	\N	Annette Key, north end, Big Spanish Channel	FL
62558	Big Pine Key, north end, Florida	NOS	8724231	24.745000000000001	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:56:00	\N	0.82999999999999996	04:24:00	\N	0.959999999999999964	\N	\N	Big Pine Key, north end	FL
62559	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.6649999999999991	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:45:00	\N	0.330000000000000016	00:11:00	\N	0.569999999999999951	\N	\N	Little Torch Key, Torch Channel	FL
62560	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6616999999999997	-81.4017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:29:00	\N	0.380000000000000004	-00:16:00	\N	0.689999999999999947	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
62561	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233000000000004	-81.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:12:00	\N	0.67000000000000004	-00:40:00	\N	0.979999999999999982	\N	\N	Munson Island, Newfound Harbor Channel	FL
62562	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.6499999999999986	-81.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:05:00	\N	0.5	-00:41:00	\N	0.900000000000000022	\N	\N	Ramrod Key, Newfound Harbor	FL
62563	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.7250000000000014	-81.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:49:00	\N	0.619999999999999996	04:43:00	\N	0.719999999999999973	\N	\N	Howe Key, south end, Harbor Channel	FL
62564	Big Spanish Key, Florida	NOS	8724246	24.7882999999999996	-81.4116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:29:00	\N	1.5	03:19:00	\N	1.96999999999999997	\N	\N	Big Spanish Key	FL
62565	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.6600000000000001	-81.4232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:12:00	\N	0.46000000000000002	-00:13:00	\N	0.67000000000000004	\N	\N	Ramrod Key, Niles Channel Bridge	FL
62566	Howe Key, northwest end, Florida	NOS	8724257	24.7582999999999984	-81.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:22:00	\N	1.33000000000000007	03:29:00	\N	1.67999999999999994	\N	\N	Howe Key, northwest end	FL
62567	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.7049999999999983	-81.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:05:00	\N	0.709999999999999964	03:15:00	\N	0.609999999999999987	\N	\N	Big Torch Key, Niles Channel	FL
62568	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517000000000017	-81.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:11:00	\N	0.709999999999999964	-00:36:00	\N	0.849999999999999978	\N	\N	Summerland Key, Niles Channel South	FL
62569	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.6600000000000001	-81.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:56:00	\N	0.57999999999999996	-00:10:00	\N	0.67000000000000004	\N	\N	Summerland Key, Niles Channel Bridge	FL
62570	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467000000000006	-81.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:41:00	\N	1	03:42:00	\N	1.52000000000000002	\N	\N	Water Keys, south end, Harbor Channel	FL
62571	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.736699999999999	-81.4432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:51:00	\N	1.29000000000000004	03:47:00	\N	1.58000000000000007	\N	\N	Big Torch Key, Harbor Channel	FL
62572	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.6499999999999986	-81.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:50:00	\N	0.540000000000000036	-00:26:00	\N	0.810000000000000053	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
62573	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6616999999999997	-81.4682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:04:00	\N	0.46000000000000002	00:47:00	\N	0.57999999999999996	\N	\N	Kemp Channel Viaduct	FL
62574	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:45:00	\N	0.75	-01:15:00	\N	1.06000000000000005	\N	\N	Key Lois, southeast end	FL
62575	Knockemdown Key, north end, Florida	NOS	8724302	24.7149999999999999	-81.4783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:54:00	\N	1.20999999999999996	03:30:00	\N	1.35000000000000009	\N	\N	Knockemdown Key, north end	FL
62576	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417000000000002	-81.4849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:17:00	\N	0.709999999999999964	-00:46:00	\N	0.900000000000000022	\N	\N	Gopher Key, Cudjoe Bay	FL
62577	Content Keys, Content Passage, Florida	NOS	8724307	24.7899999999999991	-81.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:49:00	\N	1.83000000000000007	02:46:00	\N	2.12999999999999989	\N	\N	Content Keys, Content Passage	FL
62578	Raccoon Key, east side, Florida	NOS	8724311	24.7417000000000016	-81.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:09:00	\N	1.20999999999999996	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
62579	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.6600000000000001	-81.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:41:00	\N	0.709999999999999964	-00:38:00	\N	0.869999999999999996	\N	\N	Cudjoe Key, Cudjoe Bay	FL
62580	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533000000000015	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:41:00	\N	0.75	-00:48:00	\N	0.589999999999999969	\N	\N	Sugarloaf Key, Pirates Cove	FL
62581	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6282999999999994	-81.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:15:00	\N	0.57999999999999996	-00:41:00	\N	0.890000000000000013	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
62582	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.6999999999999993	-81.5049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:40:00	\N	1.45999999999999996	03:33:00	\N	1.6100000000000001	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
62583	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6616999999999997	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:54:00	\N	0.790000000000000036	03:50:00	\N	0.770000000000000018	\N	\N	Cudjoe Key, Pirates Cove	FL
62584	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.629999999999999	-81.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:17:00	\N	0.380000000000000004	-00:29:00	\N	0.349999999999999978	\N	\N	Tarpon Creek	FL
62585	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717000000000013	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:24:00	\N	0.709999999999999964	03:47:00	\N	1.01000000000000001	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
62586	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.6550000000000011	-81.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:33:00	\N	0.28999999999999998	05:47:00	\N	0.260000000000000009	\N	\N	Park Channel Bridge	FL
62587	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533000000000015	-81.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
62588	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933000000000007	-81.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:20:00	\N	0.75	03:37:00	\N	1.29000000000000004	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
62589	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7582999999999984	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:19:00	\N	0.5	02:37:00	\N	1.42999999999999994	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
62590	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7582999999999984	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:24:00	\N	0.5	02:45:00	\N	1.57000000000000006	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
62591	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7166999999999994	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:39:00	\N	1.16999999999999993	03:17:00	\N	1.56000000000000005	\N	\N	Pumpkin Key, Bow Channel	FL
62592	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.648299999999999	-81.5699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	08:25:00	\N	0.0800000000000000017	05:37:00	\N	0.280000000000000027	\N	\N	Perky	FL
62593	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.7100000000000009	-81.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:38:00	\N	0.5	03:26:00	\N	1.10000000000000009	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
62594	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233000000000004	-81.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:10:00	\N	0.209999999999999992	01:44:00	\N	0.429999999999999993	\N	\N	Saddlebunch Keys, Channel No. 3	FL
62595	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583000000000006	-81.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:39:00	\N	0.82999999999999996	03:25:00	\N	1.28000000000000003	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
62596	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.6149999999999984	-81.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:36:00	\N	0.28999999999999998	04:35:00	\N	0.540000000000000036	\N	\N	Saddlebunch Keys, Channel No. 4	FL
62597	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6000000000000014	-81.6217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:41:00	\N	0.209999999999999992	00:39:00	\N	0.369999999999999996	\N	\N	Saddlebunch Keys, Similar Sound	FL
62598	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.611699999999999	-81.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:58:00	\N	1.12000000000000011	04:32:00	\N	0.660000000000000031	\N	\N	Saddlebunch Keys, Channel No. 5	FL
62599	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6666999999999987	-81.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:54:00	\N	0.67000000000000004	03:44:00	\N	1.02000000000000002	\N	\N	Snipe Keys, Middle Narrows	FL
62600	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883000000000003	-81.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:03:00	\N	0.419999999999999984	-00:21:00	\N	0.589999999999999969	\N	\N	Bird Key, Similar Sound	FL
62601	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033000000000008	-81.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:51:00	\N	0.46000000000000002	00:18:00	\N	0.520000000000000018	\N	\N	Shark Key, southeast end, Similar Sound	FL
62602	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167000000000016	-81.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:39:00	\N	0.82999999999999996	03:53:00	\N	1.03000000000000003	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
62603	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6466999999999992	-81.6533000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:33:00	\N	0.959999999999999964	03:53:00	\N	1.03000000000000003	\N	\N	Waltz Key, Waltz Key Basin	FL
62604	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5916999999999994	-81.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:06:00	\N	0.880000000000000004	05:02:00	\N	0.760000000000000009	\N	\N	Rockland Key, Rockland Channel Bridge	FL
62605	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917000000000009	-81.6732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:33:00	\N	1.29000000000000004	02:15:00	\N	1.68999999999999995	\N	\N	Snipe Keys, Snipe Point	FL
62606	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233000000000004	-81.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	04:57:00	\N	0.959999999999999964	03:27:00	\N	1.18999999999999995	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
62607	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033000000000008	-81.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	05:22:00	\N	0.709999999999999964	03:54:00	\N	0.939999999999999947	\N	\N	Boca Chica Key, Long Point	FL
62608	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.601700000000001	-81.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	06:54:00	\N	0.330000000000000016	04:21:00	\N	0.839999999999999969	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
62609	Boca Chica Key, Southwest end, Florida	NOS	8724499	24.5633000000000017	-81.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:16:00	\N	0.630000000000000004	-00:14:00	\N	0.660000000000000031	\N	\N	Boca Chica Key, Southwest end	FL
62610	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5766999999999989	-81.7216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:29:00	\N	0.67000000000000004	01:23:00	\N	0.569999999999999951	\N	\N	Boca Chica Channel Bridge	FL
62611	Channel Key, west side, Florida	NOS	8724507	24.6033000000000008	-81.7249999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	03:07:00	\N	0.709999999999999964	03:09:00	\N	0.699999999999999956	\N	\N	Channel Key, west side	FL
62612	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.5799999999999983	-81.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:57:00	\N	0.790000000000000036	02:25:00	\N	0.729999999999999982	\N	\N	Key Haven - Stock Island Channel	FL
62613	Cow Key Channel, Florida	NOS	8724527	24.5700000000000003	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:05:00	\N	0.709999999999999964	01:55:00	\N	0.650000000000000022	\N	\N	Cow Key Channel	FL
62614	Riviera Canal, Key West, Florida	NOS	8724529	24.5650000000000013	-81.7516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	01:00:00	\N	0.630000000000000004	-00:12:00	\N	0.650000000000000022	\N	\N	Riveria Canal, Key West	FL
62615	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.5850000000000009	-81.7750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	02:06:00	\N	0.880000000000000004	01:59:00	\N	0.810000000000000053	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
62616	Key West, south side, White Street Pier, Florida	NOS	8724557	24.5450000000000017	-81.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:31:00	\N	0.92000000000000004	-00:53:00	\N	1.07000000000000006	\N	\N	Key West, south side, White Street Pier	FL
62617	Sand Key Lighthouse, Sand Key Channel, Florida (sub)	NOS	8724635	24.4532999999999987	-81.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	-00:32:00	\N	0.880000000000000004	-00:43:00	\N	0.949999999999999956	\N	\N	Sand Key Lighthouse, Sand Key Channel	FL
62618	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6266999999999996	-82.8717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60593	00:33:00	\N	1.33000000000000007	00:29:00	\N	0.939999999999999947	\N	\N	Garden Key, Dry Tortugas	FL
62619	Shark River entrance, Florida	NOS	8724769	25.3449999999999989	-81.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:45:00	\N	0.979999999999999982	00:57:00	\N	1.42999999999999994	\N	\N	Shark River entrance	FL
62620	Lostmans River entrance, Florida	NOS	8724842	25.5533000000000001	-81.2133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:59:00	\N	0.979999999999999982	01:09:00	\N	1.33000000000000007	\N	\N	Lostmans River entrance	FL
62621	Onion Key, Lostmans River, Florida	NOS	8724863	25.611699999999999	-81.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	04:53:00	\N	0.160000000000000003	03:09:00	\N	0.260000000000000009	\N	\N	Onion Key, Lostmans River	FL
62622	Chatham River entrance, Florida	NOS	8724891	25.6900000000000013	-81.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:53:00	\N	0.660000000000000031	00:59:00	\N	1.42999999999999994	\N	\N	Chatham River entrance	FL
62623	Chokoloskee, Florida	NOS	8724919	25.8133000000000017	-81.3632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:14:00	\N	0.619999999999999996	02:15:00	\N	1.1100000000000001	\N	\N	Chokoloskee	FL
62624	Cape Romano, Florida	NOS	8724947	25.8533000000000008	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:04:00	\N	0.979999999999999982	00:43:00	\N	1.18999999999999995	\N	\N	Cape Romano	FL
62625	Everglades City, Barron River, Florida	NOS	8724948	25.8582999999999998	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:26:00	\N	0.569999999999999951	02:25:00	\N	0.989999999999999991	\N	\N	Everglades City, Barron River	FL
62626	Dismal Key, Pumpkin Bay, Florida (sub)	NOS	8724963	25.8949999999999996	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	03:07:00	\N	0.489999999999999991	02:39:00	\N	0.890000000000000013	\N	\N	Pumpkin Bay	FL
62627	Coon Key Pass, Gullivan Bay, Florida (sub)	NOS	8724964	25.8966999999999992	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:31:00	\N	0.979999999999999982	01:15:00	\N	1.18999999999999995	\N	\N	Coon Key	FL
62628	Naples, Naples Bay, north end, Florida	NOS	8725114	26.1367000000000012	-81.7883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	00:56:00	\N	0.900000000000000022	00:43:00	\N	0.969999999999999973	\N	\N	Naples, Naples Bay, north end	FL
62629	Cocohatchee River, U.S. 41 bridge, Florida	NOS	8725228	26.2817000000000007	-81.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:28:00	\N	0.650000000000000022	01:10:00	\N	0.739999999999999991	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
62630	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.2899999999999991	-81.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	00:59:00	\N	0.729999999999999982	00:44:00	\N	0.770000000000000018	\N	\N	Wiggins Pass, Cocohatchee River	FL
62631	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.3533000000000008	-81.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:05:00	\N	1.09000000000000008	-00:58:00	\N	1.09000000000000008	\N	\N	Little Hickory Island	FL
62632	Carlos Point, Estero Bay, Florida	NOS	8725325	26.4050000000000011	-81.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:28:00	\N	1.16999999999999993	-01:08:00	\N	1.16999999999999993	\N	\N	Carlos Point	FL
62633	Estero River, Estero Bay, Florida	NOS	8725346	26.4299999999999997	-81.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:10:00	\N	1.1100000000000001	-00:45:00	\N	1.09000000000000008	\N	\N	Estero River	FL
62634	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567000000000014	-81.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:34:00	\N	1.21999999999999997	-01:10:00	\N	1.21999999999999997	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
62635	Captiva Island (outside), Florida	NOS	8725383	26.4783000000000008	-82.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:28:00	\N	1.12999999999999989	-02:20:00	\N	1.12999999999999989	\N	\N	Captiva Island (outside)	FL
62636	St. James City, Pine Island, Florida	NOS	8725393	26.4917000000000016	-82.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:44:00	\N	1.04000000000000004	-00:30:00	\N	1.04000000000000004	\N	\N	St. James City, Pine Island	FL
62637	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.513300000000001	-82.1067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:16:00	\N	0.910000000000000031	-00:25:00	\N	0.910000000000000031	\N	\N	Galt Island, Pine Island Sound	FL
62638	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5216999999999992	-82.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:20:00	\N	0.910000000000000031	-00:46:00	\N	0.910000000000000031	\N	\N	Captiva Island, Pine Island Sound	FL
62639	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5216999999999992	-81.9650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:40:00	\N	0.429999999999999993	01:08:00	\N	0.429999999999999993	\N	\N	Iona Shores	FL
62640	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483000000000011	-82.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:22:00	\N	0.869999999999999996	-00:08:00	\N	0.869999999999999996	\N	\N	Tropical Homesites Landing, Pine Island	FL
62641	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.5500000000000007	-82.196700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:14:00	\N	0.910000000000000031	-00:55:00	\N	0.910000000000000031	\N	\N	Redfish Pass, Captiva Island (north end)	FL
62642	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.5633000000000017	-81.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:02:00	\N	0.429999999999999993	01:15:00	\N	0.429999999999999993	\N	\N	Cape Coral Bridge	FL
62643	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.6316999999999986	-82.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:28:00	\N	0.82999999999999996	00:43:00	\N	0.82999999999999996	\N	\N	Matlacha Pass (bascule bridge)	FL
62644	Fort Myers, Caloosahatchee River, Florida (sub)	NOS	8725520	26.6477000000000004	-81.8712000000000018	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:23:00	\N	0.390000000000000013	01:56:00	\N	0.560000000000000053	\N	\N	Fort Myers	FL
62645	Pineland, Pine Island, Florida	NOS	8725528	26.6600000000000001	-82.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:26:00	\N	0.82999999999999996	-00:19:00	\N	0.82999999999999996	\N	\N	Pineland, Pine Island	FL
62646	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333000000000013	-82.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:56:00	\N	0.939999999999999947	-00:43:00	\N	0.589999999999999969	\N	\N	Placida, Gasparilla Sound	FL
62647	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283000000000001	-82.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:27:00	\N	0.82999999999999996	01:06:00	\N	0.82999999999999996	\N	\N	Punta Gorda, Charlotte Harbor	FL
62648	Englewood, Lemon Bay, Florida	NOS	8725747	26.9332999999999991	-82.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:17:00	\N	0.819999999999999951	-00:17:00	\N	0.660000000000000031	\N	\N	Englewood, Lemon Bay	FL
62649	El Jobean, Myakka River, Florida	NOS	8725769	26.9617000000000004	-82.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:56:00	\N	0.82999999999999996	01:38:00	\N	0.82999999999999996	\N	\N	El Jobean, Myakka River	FL
62650	Venice Inlet (inside), Florida	NOS	8725889	27.111699999999999	-82.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:38:00	\N	0.910000000000000031	-02:02:00	\N	0.910000000000000031	\N	\N	Venice Inlet (inside)	FL
62651	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317000000000014	-82.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:58:00	\N	0.910000000000000031	-01:38:00	\N	0.910000000000000031	\N	\N	Sarasota, Sarasota Bay	FL
62652	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4666999999999994	-82.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:25:00	\N	0.959999999999999964	-02:00:00	\N	0.959999999999999964	\N	\N	Cortez, Sarasota Bay	FL
62653	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967000000000006	-82.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-03:32:00	\N	1	-02:27:00	\N	0.989999999999999991	\N	\N	Anna Maria Key, Bradenton Beach	FL
62654	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:55:00	\N	0.949999999999999956	-01:24:00	\N	0.969999999999999973	\N	\N	Bradenton, Manatee River	FL
62655	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267000000000017	-82.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:14:00	\N	1	-00:30:00	\N	0.92000000000000004	\N	\N	Redfish Point, Manatee River	FL
62656	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333000000000006	-82.730000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:19:00	\N	0.989999999999999991	-02:10:00	\N	0.989999999999999991	\N	\N	Anna Maria Key, city pier	FL
62657	Egmont Key, Egmont Channel, Tampa Bay, Florida (sub)	NOS	8726347	27.601700000000001	-82.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-03:20:00	\N	1	-02:15:00	\N	0.959999999999999964	\N	\N	Egmont Key, Egmont Channel	FL
62658	Mullet Key Channel (Skyway), Tampa Bay, Florida (sub)	NOS	8726364	27.6149999999999984	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:01:00	\N	0.92000000000000004	-02:03:00	\N	0.92000000000000004	\N	\N	Mullet Key Channel (Skyway)	FL
62659	Port Manatee, Tampa Bay, Florida (sub)	NOS	8726384	27.6383332999999993	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:48:00	\N	0.949999999999999956	-01:00:00	\N	0.969999999999999973	\N	\N	Port Manatee	FL
62660	Point Pinellas, Florida	NOS	8726454	27.7016999999999989	-82.6400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:29:00	\N	0.859999999999999987	-00:22:00	\N	0.859999999999999987	\N	\N	Point Pinellas	FL
62661	Shell Point, Florida	NOS	8726468	27.7182999999999993	-82.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:17:00	\N	0.910000000000000031	00:08:00	\N	0.910000000000000031	\N	\N	Shell Point	FL
62662	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.736699999999999	-82.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:05:00	\N	0.959999999999999964	-01:32:00	\N	0.959999999999999964	\N	\N	Gulfport	FL
62663	Long Key, 0.5mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7516999999999996	-82.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-00:44:00	\N	1	-01:18:00	\N	0.92000000000000004	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
62664	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.7850000000000001	-82.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-02:04:00	\N	1.02000000000000002	-02:14:00	\N	0.969999999999999973	\N	\N	Johns Pass	FL
62665	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.7866992950439453	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:32:00	\N	1.19999999999999996	00:53:00	\N	1.10000000000000009	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
62666	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8082999999999991	-82.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:45:00	\N	1.17999999999999994	-01:32:00	\N	1.08000000000000007	\N	\N	Madeira Beach Causeway	FL
62667	Port Tampa, Old Tampa Bay, Florida (sub)	NOS	8726607	27.8577778000000009	-82.5527778000000012	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:39:00	\N	1.17999999999999994	00:25:00	\N	1.10000000000000009	\N	\N	Old Port Tampa	FL
62668	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8766999999999996	-82.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:53:00	\N	0.630000000000000004	-00:57:00	\N	0.650000000000000022	\N	\N	Indian Rocks Beach (inside)	FL
62669	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:57:00	\N	1.23999999999999999	00:59:00	\N	1.12000000000000011	\N	\N	Gandy Bridge, Old Tampa Bay	FL
62670	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.898299999999999	-82.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:05:00	\N	1.17999999999999994	00:21:00	\N	1.1399999999999999	\N	\N	Pendola Point, Hillsborough Bay	FL
62671	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083000000000006	-82.4517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:32:00	\N	1.23999999999999999	00:03:00	\N	1.15999999999999992	\N	\N	Davis Island, Hillsborough Bay	FL
62672	CSX Rockport, Mckay Bay Entrance, Florida (sub)	NOS	8726667	27.9133333333333304	-82.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	00:28:00	\N	1.26000000000000001	00:02:00	\N	1.18999999999999995	\N	\N	McKay Bay entrance	FL
62673	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417000000000009	-82.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:32:00	\N	1.37000000000000011	01:01:00	\N	1.23999999999999999	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
62674	Clearwater, Florida	NOS	8726706	27.9549999999999983	-82.8067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:35:00	\N	0.630000000000000004	-01:48:00	\N	0.650000000000000022	\N	\N	Clearwater	FL
62675	Clearwater Beach, Gulf Of Mexico, Florida (sub)	NOS	8726724	27.9783000000000008	-82.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-02:19:00	\N	0.839999999999999969	-02:07:00	\N	0.689999999999999947	\N	\N	Clearwater Beach	FL
62676	Safety Harbor, Old Tampa Bay, Florida (sub)	NOS	8726738	27.9882999999999988	-82.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	01:34:00	\N	1.3899999999999999	01:32:00	\N	1.22999999999999998	\N	\N	Safety Harbor, Old Tampa Bay	FL
62677	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.013300000000001	-82.7933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:45:00	\N	0.790000000000000036	-01:50:00	\N	0.699999999999999956	\N	\N	Dunedin, St. Joseph Sound	FL
62678	Mobbly Bayou, Florida	NOS	8726769	28.0216999999999992	-82.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	02:54:00	\N	0.450000000000000011	02:38:00	\N	0.709999999999999964	\N	\N	Mobbly Bayou	FL
62679	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.1600000000000001	-82.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:03:00	\N	0.82999999999999996	-01:16:00	\N	0.770000000000000018	\N	\N	Tarpon Springs, Anclote River	FL
62680	Anclote, Anclote River, Florida	NOS	8726924	28.1717000000000013	-82.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:24:00	\N	0.869999999999999996	-01:28:00	\N	0.780000000000000027	\N	\N	Anclote, Anclote River	FL
62681	North Anclote Key, Florida	NOS	8726942	28.2100000000000009	-82.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:38:00	\N	0.859999999999999987	-01:55:00	\N	0.800000000000000044	\N	\N	North Anclote Key	FL
62682	Gulf Harbors, Florida	NOS	8726995	28.2433000000000014	-82.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:52:00	\N	0.900000000000000022	-01:15:00	\N	0.839999999999999969	\N	\N	Gulf Harbors	FL
62683	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483000000000004	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:11:00	\N	0.869999999999999996	-00:58:00	\N	0.880000000000000004	\N	\N	New Port Richey, Pithlachascotee River	FL
62684	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-00:40:00	\N	0.839999999999999969	-01:16:00	\N	0.849999999999999978	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
62685	Hudson, Hudson Creek, Florida	NOS	8727061	28.361699999999999	-82.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	-01:02:00	\N	0.890000000000000013	-01:12:00	\N	0.910000000000000031	\N	\N	Hudson, Hudson Creek	FL
62686	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4332999999999991	-82.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:23:00	\N	0.630000000000000004	-00:37:00	\N	0.810000000000000053	\N	\N	Aripeka, Hammock Creek	FL
62687	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.486699999999999	-82.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:58:00	\N	0.82999999999999996	-00:20:00	\N	0.82999999999999996	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
62688	Johns Island, Chassahowitzka Bay, Florida (sub)	NOS	8727235	28.6917000000000009	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:14:00	\N	0.489999999999999991	01:09:00	\N	0.619999999999999996	\N	\N	Johns Island, Chassahowitzka Bay	FL
62689	Chassahowitzka, Chassahowitzka River, Florida (sub)	NOS	8727246	28.7149999999999999	-82.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:45:00	\N	0.160000000000000003	03:59:00	\N	0.140000000000000013	\N	\N	Chassahowitzka, Chassahowitzka River	FL
62690	Mason Creek, Homosassa Bay, Florida (sub)	NOS	8727274	28.7617000000000012	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	04:44:00	\N	0.25	03:09:00	\N	0.320000000000000007	\N	\N	Mason Creek, Homosassa Bay	FL
62691	Tuckers Island, Homosassa River, Florida (sub)	NOS	8727277	28.7716999999999992	-82.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:23:00	\N	0.330000000000000016	01:26:00	\N	0.469999999999999973	\N	\N	Tuckers Island, Homosassa River	FL
62692	Halls River bridge, Homosassa River, Florida (sub)	NOS	8727293	28.8000000000000007	-82.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:41:00	\N	0.130000000000000004	04:30:00	\N	0.160000000000000003	\N	\N	Halls River bridge, Homosassa River	FL
62693	Ozello, St. Martin's River, Florida (sub)	NOS	8727306	28.8249999999999993	-82.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	05:21:00	\N	0.140000000000000013	04:25:00	\N	0.170000000000000012	\N	\N	Ozello, St. Martins River	FL
62694	Ozello North, Crystal Bay, Florida (sub)	NOS	8727328	28.8632999999999988	-82.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:17:00	\N	0.25	01:25:00	\N	0.5	\N	\N	Ozello north, Crystal Bay	FL
62695	Mangrove Pt., Crystal Bay, Florida (sub)	NOS	8727333	28.870000000000001	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:41:00	\N	0.760000000000000009	00:22:00	\N	0.949999999999999956	\N	\N	Mangrove Pt., Crystal Bay	FL
62696	Dixie Bay, Salt River, Crystal Bay, Florida (sub)	NOS	8727336	28.8816999999999986	-82.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:06:00	\N	0.330000000000000016	02:00:00	\N	0.550000000000000044	\N	\N	Dixie Bay, Salt River, Crystal Bay	FL
62697	Crystal River, Kings Bay, Florida (sub)	NOS	8727343	28.898299999999999	-82.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	03:07:00	\N	0.409999999999999976	02:20:00	\N	0.589999999999999969	\N	\N	Kings Bay	FL
62698	Twin Rivers Marina, Crystal River, Florida (sub)	NOS	8727348	28.9050000000000011	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	02:30:00	\N	0.489999999999999991	01:46:00	\N	0.640000000000000013	\N	\N	Twin Rivers Marina	FL
62699	Shell Island, north end, Crystal River, Florida (sub)	NOS	8727359	28.9233000000000011	-82.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	01:30:00	\N	0.589999999999999969	00:36:00	\N	0.790000000000000036	\N	\N	Shell Island, north end	FL
62700	Florida Power, Crystal River, Florida	NOS	8727386	28.9600000000000009	-82.7249999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:30:00	\N	0.890000000000000013	-00:03:00	\N	1.04000000000000004	\N	\N	Florida Power	FL
62701	Withlacoochee River entrance, Florida	NOS	8727395	29.0016999999999996	-82.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:55:00	\N	0.949999999999999956	00:07:00	\N	0.910000000000000031	\N	\N	Withlacoochee River entrance	FL
62702	Suwannee, Salt Creek, Florida	NOS	8727577	29.3282999999999987	-83.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:24:00	\N	0.82999999999999996	-00:07:00	\N	0.910000000000000031	\N	\N	Suwannee, Salt Creek	FL
62703	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717000000000013	-83.3900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:00:00	\N	1.08000000000000007	00:02:00	\N	1.03000000000000003	\N	\N	Steinhatchee River ent., Deadman Bay	FL
62704	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1266999999999996	-83.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:57:00	\N	0.550000000000000044	00:25:00	\N	0.689999999999999947	\N	\N	Mandalay, Aucilla River	FL
62705	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533000000000015	-84.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	01:04:00	\N	0.910000000000000031	00:36:00	\N	0.930000000000000049	\N	\N	St. Marks, St. Marks River	FL
62706	Shell Point, Walker Creek, Apalachee Bay, Florida (sub)	NOS	8728229	30.0599999999999987	-84.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:03:00	\N	1.08000000000000007	-00:03:00	\N	1.02000000000000002	\N	\N	Shell Point, Walker Creek	FL
62707	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9482999999999997	-84.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:19:00	\N	0.699999999999999956	00:33:00	\N	0.849999999999999978	\N	\N	Bald Point, Ochlockonee Bay	FL
62708	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.0283000000000015	-84.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:20:00	\N	0.819999999999999951	00:16:00	\N	1.01000000000000001	\N	\N	Panacea, Dickerson Bay	FL
62709	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033000000000015	-84.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:11:00	\N	0.729999999999999982	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
62710	Turkey Point, Apalachee Bay, St. James Island, Florida (sub)	NOS	8728360	29.9149999999999991	-84.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:21:00	\N	0.979999999999999982	-00:16:00	\N	0.780000000000000027	\N	\N	Turkey Point, St. James Island	FL
62711	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.8500000000000014	-84.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:13:00	\N	1.60000000000000009	-01:25:00	\N	1.60000000000000009	\N	\N	Carrabelle, Carrabelle River	FL
62712	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.7850000000000001	-84.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:38:00	\N	1.39999999999999991	-01:53:00	\N	1.72999999999999998	\N	\N	Dog Island, west end	FL
62713	St. George Island, East End, St. George Sound, Florida	NOS	8728548	29.6866999999999983	-84.7866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-02:48:00	\N	1	-02:02:00	\N	1.12999999999999989	\N	\N	St. George Island, East End	FL
62714	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917000000000009	-84.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:35:00	\N	1.19999999999999996	-01:00:00	\N	1.33000000000000007	\N	\N	St. George Island, Rattlesnake Cove	FL
62715	Cat Point, Apalachicola Bay, Florida (sub)	NOS	8728619	29.7232999999999983	-84.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:17:00	\N	0.599999999999999978	-00:40:00	\N	1.07000000000000006	\N	\N	Cat Point	FL
62716	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533000000000015	-84.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-01:08:00	\N	1.26000000000000001	-00:55:00	\N	1.26000000000000001	\N	\N	St. George Island, 12th St. W (Bayside)	FL
62717	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.763300000000001	-85.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	00:35:00	\N	0.82999999999999996	00:28:00	\N	0.849999999999999978	\N	\N	Apalachicola River (A&N RR bridge)	FL
62718	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6332999999999984	-85.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-00:27:00	\N	1	-00:27:00	\N	0.869999999999999996	\N	\N	West Pass	FL
62719	Port Saint Joe, St. Joseph Bay, Florida (sub)	NOS	8728912	29.8150000000000013	-85.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	Reference is in time zone :America/Chicago; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-02:45:00	\N	1.1100000000000001	-02:06:00	\N	1.1100000000000001	\N	\N	Port Saint Joe, St. Joseph Bay	FL
62720	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0382999999999996	-85.3932999999999964	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:40:00	\N	1.10000000000000009	01:01:00	\N	1.10000000000000009	\N	\N	Wetappo Creek, East Bay	FL
62721	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.0300000000000011	-85.4650000000000034	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:01:00	\N	1.14999999999999991	-00:16:00	\N	1.14999999999999991	\N	\N	Allanton, East Bay	FL
62722	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167000000000002	-85.4699999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:59:00	\N	1.16999999999999993	-00:16:00	\N	1.16999999999999993	\N	\N	Farmdale, East Bay	FL
62723	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217000000000006	-85.5283000000000015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:05:00	\N	1.12999999999999989	-00:28:00	\N	1.12999999999999989	\N	\N	Laird Bayou, East Bay	FL
62724	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1266999999999996	-85.611699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	00:22:00	\N	1.19999999999999996	-00:05:00	\N	1.19999999999999996	\N	\N	Parker	FL
62725	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.254999999999999	-85.6483000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:01:00	\N	1.10000000000000009	-00:31:00	\N	1.10000000000000009	\N	\N	Lynn Haven, North Bay	FL
62726	Panama City, St. Andrew Bay, Florida (sub)	NOS	8729108	30.1522777777777797	-85.6669444444444395	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:11:00	\N	1.65999999999999992	-00:57:00	\N	1.05000000000000004	\N	\N	Panama City	FL
62727	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.730000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:50:00	\N	1.02000000000000002	-01:39:00	\N	1.02000000000000002	\N	\N	Channel entrance	FL
62728	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.1700000000000017	-85.7549999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-01:10:00	\N	1.07000000000000006	-00:47:00	\N	1.07000000000000006	\N	\N	Alligator Bayou	FL
62729	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.2932999999999986	-85.8582999999999998	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:47:00	\N	1.12999999999999989	-00:10:00	\N	1.12999999999999989	\N	\N	West Bay Creek, West Bay	FL
62730	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.3949999999999996	-86.513300000000001	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:34:00	\N	0.330000000000000016	-00:33:00	\N	0.489999999999999991	\N	\N	East Pass (Destin)	FL
62731	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.4349999999999987	-86.5866999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	03:03:00	\N	0.320000000000000007	03:33:00	\N	0.320000000000000007	\N	\N	Shalimar, Garnier Bayou	FL
62732	Harris, The Narrows, Florida	NOS	8729613	30.4083000000000006	-86.7317000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	02:51:00	\N	1.10000000000000009	01:37:00	\N	1.10000000000000009	\N	\N	Harris, The Narrows	FL
62733	Navarre Beach, Florida (sub)	NOS	8729678	30.3766999999999996	-86.8649999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-02:26:00	\N	1.66999999999999993	-02:07:00	\N	1.07000000000000006	\N	\N	Navarre Beach	FL
62734	East Bay, Pensacola Bay, Florida (sub)	NOS	8729702	30.4499999999999993	-86.9183000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:17:00	\N	1.19999999999999996	00:44:00	\N	1.19999999999999996	\N	\N	East Bay	FL
62735	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5716999999999999	-87.0049999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:27:00	\N	1.19999999999999996	01:23:00	\N	1.19999999999999996	\N	\N	Bay Point, Blackwater River	FL
62736	Fishing Bend, Santa Rosa Sound, Florida (sub)	NOS	8729806	30.3367000000000004	-87.1400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	00:51:00	\N	1.10000000000000009	00:41:00	\N	1.10000000000000009	\N	\N	Fishing Bend, Santa Rosa Sound	FL
62737	Lora Point, Escambia Bay, Pensacola Bay, Florida (sub)	NOS	8729816	30.5150000000000006	-87.1616999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:03:00	\N	1.19999999999999996	00:36:00	\N	1.19999999999999996	\N	\N	Lora Point, Escambia Bay	FL
62738	Warrington, 2 miles south of, Pensacola Bay, Florida	NOS	8729868	30.3449999999999989	-87.2733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
62739	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3266999999999989	-87.3117000000000019	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	-00:34:00	\N	0.800000000000000044	-01:23:00	\N	0.800000000000000044	\N	\N	Fort McRee Breakwater	FL
62740	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.4249999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	03:37:00	\N	0.330000000000000016	02:29:00	\N	0.569999999999999951	\N	\N	Nix Point, Perdido Bay	FL
62741	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033000000000001	-87.7349999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	-01:17:00	\N	1.07000000000000006	-01:13:00	\N	1.07000000000000006	\N	\N	Bon Secour, Bon Secour River	AL
62742	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2332999999999998	-88.019999999999996	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	-01:32:00	\N	0.800000000000000044	-01:46:00	\N	0.800000000000000044	\N	\N	Mobile Point (Fort Morgan)	AL
62743	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183000000000007	-87.9150000000000063	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60696	03:05:00	\N	0.869999999999999996	02:16:00	\N	0.869999999999999996	\N	\N	Lower Hall Landing, Tensaw River	AL
62744	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717000000000006	-88.2750000000000057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:14:00	\N	1.22999999999999998	01:52:00	\N	1.22999999999999998	\N	\N	Bayou La Batre, Mississippi Sound	AL
62745	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867000000000012	-88.4399999999999977	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
62746	Pascagoula Point, Mississippi Sound, Mississippi (sub)	NOS	8741196	30.3399999999999999	-88.533299999999997	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:48:00	\N	1.20999999999999996	01:20:00	\N	1.20999999999999996	\N	\N	Pascagoula, Mississippi Sound	MS
62747	Horn Island, Mississippi Sound, Mississippi (sub)	NOS	8742221	30.2382999999999988	-88.6667000000000058	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:59:00	\N	1.25	01:34:00	\N	1.25	\N	\N	Horn Island, Mississippi Sound	MS
62748	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867000000000012	-88.7733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:52:00	\N	1.41999999999999993	02:24:00	\N	1.41999999999999993	\N	\N	Hollingsworth Point, Davis Bayou	MS
62749	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.3900000000000006	-88.8567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:30:00	\N	1.37999999999999989	02:04:00	\N	1.37999999999999989	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
62750	Ship Island, Mississippi Sound, Mississippi (sub)	NOS	8744756	30.2133000000000003	-88.9716999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:22:00	\N	1.30000000000000004	01:52:00	\N	1.30000000000000004	\N	\N	Ship Island, Mississippi Sound	MS
62751	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267000000000003	-89.053299999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:27:00	\N	1.54000000000000004	03:23:00	\N	1.54000000000000004	\N	\N	Turkey Creek, Bernard Bayou	MS
62752	Gulfport, Gulfport Harbor, Mississippi (sub)	NOS	8745557	30.3599999999999994	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:09:00	\N	1.29000000000000004	02:09:00	\N	1.29000000000000004	\N	\N	Gulfport Harbor, Mississippi Sound	MS
62753	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1166999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:00:00	\N	1.22999999999999998	02:13:00	\N	1.22999999999999998	\N	\N	Cat Island	MS
62754	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.3099999999999987	-89.2450000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:04:00	\N	1.37000000000000011	02:36:00	\N	1.37000000000000011	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
62755	Bay Waveland Yacht Club, Bay St. Louis, Mississippi (sub)	NOS	8747437	30.3249999999999993	-89.3250000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:57:00	\N	1.3600000000000001	03:17:00	\N	1.3600000000000001	\N	\N	St. Louis Bay entrance	MS
62756	Waveland, Mississipi Sound, Mississippi (sub)	NOS	8747766	30.2817000000000007	-89.3666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:49:00	\N	1.28000000000000003	03:09:00	\N	1.28000000000000003	\N	\N	Waveland	MS
62757	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.3583333333329932	-89.2733333333329853	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:51:00	\N	1.3600000000000001	03:18:00	\N	1.3600000000000001	\N	\N	Wolf River, Henderson Avenue bridge	MS
62758	Pearlington, Pearl River, Mississippi	NOS	8749704	30.2399999999999984	-89.6149999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	05:31:00	\N	0.989999999999999991	05:51:00	\N	0.989999999999999991	\N	\N	Pearlington, Pearl River	MS
62759	Chandeleur Light, Louisiana	NOS	8760172	30.0483000000000011	-88.8717000000000041	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	01:54:00	\N	0.979999999999999982	01:50:00	\N	0.979999999999999982	\N	\N	Chandeleur Light	LA
62760	North Pass, Mississippi River, Louisiana	NOS	8760412	29.2049999999999983	-89.0366999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	00:43:00	\N	0.910000000000000031	00:42:00	\N	0.910000000000000031	\N	\N	North Pass, Pass a Loutre	LA
62761	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167000000000016	-89.0450000000000017	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:28:00	\N	0.979999999999999982	00:37:00	\N	0.979999999999999982	\N	\N	Southeast Pass	LA
62762	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283000000000008	-89.0499999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:29:00	\N	0.900000000000000022	00:34:00	\N	0.900000000000000022	\N	\N	Lonesome Bayou (Thomasin)	LA
62763	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.0150000000000006	-89.1599999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:17:00	\N	0.900000000000000022	00:56:00	\N	0.900000000000000022	\N	\N	Port Eads, South Pass	LA
62764	Breton Islands, Louisiana	NOS	8760595	29.4933000000000014	-89.1732999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:08:00	\N	1.1399999999999999	02:07:00	\N	1.1399999999999999	\N	\N	Breton Islands	LA
62765	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0582999999999991	-89.2716999999999956	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:17:00	\N	1.14999999999999991	00:37:00	\N	1.14999999999999991	\N	\N	Joseph Bayou	LA
62766	Comfort Island, Louisiana	NOS	8760742	29.8232999999999997	-89.269999999999996	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:14:00	\N	1.28000000000000003	02:47:00	\N	1.28000000000000003	\N	\N	Comfort Island	LA
62767	Jack Bay, Louisiana	NOS	8760841	29.3667000000000016	-89.3449999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
62768	Olga Compressor Station, Grand Bay, Louisiana (sub)	NOS	8760889	29.3865555555555602	-89.3801388888888937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	02:56:00	\N	1.08000000000000007	02:54:00	\N	1.08000000000000007	\N	\N	Grand Bay	LA
62769	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9316999999999993	-89.428299999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	-00:13:00	\N	1.07000000000000006	00:35:00	\N	1.07000000000000006	\N	\N	Southwest Pass	LA
62770	Bay Gardene, Louisiana	NOS	8761108	29.5982999999999983	-89.618300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	04:04:00	\N	1.15999999999999992	04:04:00	\N	1.15999999999999992	\N	\N	Bay Gardene	LA
62771	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6082999999999998	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-01:45:00	\N	1.22999999999999998	-01:03:00	\N	1.22999999999999998	\N	\N	Empire Jetty	LA
62772	Bastian Island, Louisiana	NOS	8761289	29.2866999999999997	-89.6633000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:12:00	\N	1.12999999999999989	00:41:00	\N	1.12999999999999989	\N	\N	Bastian Island	LA
62773	Shell Beach, Lake Borgne, Louisiana (sub)	NOS	8761305	29.8681111111111086	-89.6732499999999959	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	05:45:00	\N	1.12999999999999989	05:45:00	\N	1.12999999999999989	\N	\N	Shell Beach, Lake Borgne	LA
62774	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2716999999999992	-89.7933000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	11:31:00	\N	0.429999999999999993	11:12:00	\N	0.429999999999999993	\N	\N	Bayou BonFouca, Route 433	LA
62775	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.0650000000000013	-89.7999999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	06:27:00	\N	0.880000000000000004	06:25:00	\N	0.880000000000000004	\N	\N	Chef Menteur, Chef Menteur Pass	LA
62776	Quatre Bayous Pass, Louisiana	NOS	8761557	29.3099999999999987	-89.8533000000000044	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:17:00	\N	1.22999999999999998	02:18:00	\N	1.22999999999999998	\N	\N	Quatre Bayous Pass	LA
62777	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.3099999999999987	-89.9382999999999981	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	01:59:00	\N	0.849999999999999978	02:29:00	\N	0.849999999999999978	\N	\N	Independence Island	LA
62778	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0066999999999986	-89.9367000000000019	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	06:22:00	\N	1.09000000000000008	06:37:00	\N	1.09000000000000008	\N	\N	Michoud Substation, ICWW	LA
62779	Barataria Pass, Louisiana	NOS	8761687	29.2749999999999986	-89.9449999999999932	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-00:10:00	\N	1.12999999999999989	01:00:00	\N	1.12999999999999989	\N	\N	Barataria Pass	LA
62780	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267000000000003	-89.9766999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	03:13:00	\N	0.939999999999999947	02:32:00	\N	0.939999999999999947	\N	\N	Manilla	LA
62781	New Canal USCG station, Lake Pontchartrain, Louisiana (sub)	NOS	8761927	30.0272222222222211	-90.1133333333333297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	12:09:00	\N	0.429999999999999993	11:47:00	\N	0.429999999999999993	\N	\N	New Canal USCG station, Lake Pontchartrain	LA
62782	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3782999999999994	-90.1599999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60732	12:21:00	\N	0.479999999999999982	11:36:00	\N	0.479999999999999982	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
62783	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1282999999999994	-90.4232999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	02:26:00	\N	1.12999999999999989	02:26:00	\N	1.12999999999999989	\N	\N	Pelican Islands, Timbalier Bay	LA
62784	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867000000000004	-90.5267000000000053	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:23:00	\N	1.12999999999999989	00:19:00	\N	1.12999999999999989	\N	\N	Timbalier Island, Timbalier Bay	LA
62785	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0782999999999987	-90.5866999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	01:02:00	\N	1.22999999999999998	01:08:00	\N	1.22999999999999998	\N	\N	Wine Island, Terrebonne Bay	LA
62786	Caillou Boca, Louisiana	NOS	8763206	29.0633000000000017	-90.8067000000000064	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:48:00	\N	1.32000000000000006	00:40:00	\N	1.32000000000000006	\N	\N	Caillou Boca	LA
62787	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633000000000017	-90.9616999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-00:20:00	\N	1.60000000000000009	-00:03:00	\N	1.60000000000000009	\N	\N	Raccoon Point, Caillou Bay	LA
62788	Ship Shoal Light, Louisiana	NOS	8763719	28.9149999999999991	-91.071700000000007	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	-01:50:00	\N	1.51000000000000001	-01:54:00	\N	1.51000000000000001	\N	\N	Ship Shoal Light	LA
62789	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4732999999999983	-91.3050000000000068	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:39:00	\N	1.07000000000000006	00:54:00	\N	1.07000000000000006	\N	\N	Shell Island	LA
62790	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333000000000013	-91.3533000000000044	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:26:00	\N	1.39999999999999991	-00:21:00	\N	1.39999999999999991	\N	\N	Point Au Fer	LA
62791	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.5550000000000068	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:54:00	\N	1.07000000000000006	01:02:00	\N	1.07000000000000006	\N	\N	Point Chevreuil	LA
62792	Rabbit Island, 5 miles south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.4200000000000017	-91.5932999999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:00:00	\N	1.39999999999999991	-00:13:00	\N	1.39999999999999991	\N	\N	Rabbit Island, 5 miles south of	LA
62793	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.7349999999999994	-91.7133000000000038	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
62794	South Point, Marsh Island, Atchafalaya Bay, Louisiana	NOS	8765026	29.4849999999999994	-91.763300000000001	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:57:00	\N	1.30000000000000004	-00:19:00	\N	1.30000000000000004	\N	\N	South Point, Marsh Island	LA
62795	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.5799999999999983	-92.0349999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:33:00	\N	1.1399999999999999	-00:32:00	\N	1.1399999999999999	\N	\N	Southwest Pass, Vermilion Bay	LA
62796	Lighthouse Point, Atchafalaya Bay, Louisiana	NOS	8765568	29.523299999999999	-92.0433000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-02:17:00	\N	1.39999999999999991	-01:16:00	\N	1.39999999999999991	\N	\N	Lighthouse Point	LA
62797	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.7399999999999984	-94.8316999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:43:00	\N	0.790000000000000036	05:48:00	\N	0.790000000000000036	\N	\N	Point Barrow, Trinity Bay	TX
62798	Round Point, Trinity Bay, Galveston Bay, Texas (sub)	NOS	8770559	29.7133000000000003	-94.6899999999999977	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:15:00	\N	0.709999999999999964	10:39:00	\N	0.709999999999999964	\N	\N	Round Point, Trinity Bay	TX
62799	Sabine Pass (north), Texas (sub)	NOS	8770570	29.7284000000000006	-93.8700999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:38:00	\N	1.1399999999999999	-01:18:00	\N	1.1399999999999999	\N	\N	Sabine Pass	TX
62800	Barbours Cut, Morgans Point, Galveston Bay, Texas (sub)	NOS	8770613	29.6816944444444495	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:17:00	\N	0.400000000000000022	05:11:00	\N	0.949999999999999956	\N	\N	Morgans Point, Barbours Cut	TX
62801	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas (sub)	NOS	8770733	29.7648611111111094	-95.0788611111111095	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:51:00	\N	0.569999999999999951	04:55:00	\N	1.05000000000000004	\N	\N	Lynchburg Landing, San Jacinto River	TX
62802	Houston Ship Channel, Galveston Bay, Manchester, Texas (sub)	NOS	8770777	29.7262222222222192	-95.265777777777771	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:05:00	\N	0.82999999999999996	04:55:00	\N	1.14999999999999991	\N	\N	Manchester, Houston Ship Channel	TX
62803	Clear Lake, Galveston Bay, Texas (sub)	NOS	8770933	29.5633000000000017	-95.0666999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	05:19:00	\N	0.82999999999999996	06:57:00	\N	0.82999999999999996	\N	\N	Clear Lake	TX
62804	Eagle Point, Galveston Bay, Texas (sub)	NOS	8771013	29.4800000000000004	-94.9183055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:38:00	\N	0.800000000000000044	05:34:00	\N	0.800000000000000044	\N	\N	Eagle Point	TX
62805	Port Bolivar, Galveston Bay, Texas (sub)	NOS	8771328	29.3649999999999984	-94.7800000000000011	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	00:09:00	\N	0.630000000000000004	00:57:00	\N	1	\N	\N	Port Bolivar	TX
62806	Galveston Pleasure Pier, Gulf Of Mexico, Texas (sub)	NOS	8771510	29.2852999999999994	-94.7894000000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:03:00	\N	1.30000000000000004	-01:33:00	\N	1.39999999999999991	\N	\N	Galveston Pleasure Pier	TX
62807	Jamaica Beach, West Bay, Galveston Bay, Texas	NOS	8771721	29.1999999999999993	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	03:31:00	\N	0.709999999999999964	02:38:00	\N	0.709999999999999964	\N	\N	Jamaica Beach, West Bay	TX
62808	Alligator Point, West Bay, Texas	NOS	8771801	29.1666999999999987	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:33:00	\N	0.640000000000000013	02:39:00	\N	0.640000000000000013	\N	\N	Alligator Point, West Bay	TX
62809	Christmas Bay, Texas	NOS	8772132	29.0416999999999987	-95.1749999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	02:37:00	\N	0.23000000000000001	04:47:00	\N	0.57999999999999996	\N	\N	Christmas Bay	TX
62810	Freeport, DOW Barge Canal, Texas (sub)	NOS	8772440	28.9482999999999997	-95.3083000000000027	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:08:00	\N	0.900000000000000022	-01:17:00	\N	1.22999999999999998	\N	\N	Freeport Harbor	TX
62811	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0782999999999987	-97.1700000000000017	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:21:00	\N	0.75	00:24:00	\N	0.869999999999999996	\N	\N	Queen Isabella Causeway (east end)	TX
62812	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0716999999999999	-97.1916999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:30:00	\N	0.630000000000000004	00:52:00	\N	0.810000000000000053	\N	\N	Queen Isabella Causeway (west end)	TX
62813	South Bay entrance, Texas	NOS	8779768	26.0517000000000003	-97.1817000000000064	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:21:00	\N	0.939999999999999947	00:14:00	\N	0.910000000000000031	\N	\N	South Bay entrance	TX
62814	Port Isabel, Laguna Madre, Texas (sub)	NOS	8779770	26.0611666666666686	-97.2155277777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60818	00:26:00	\N	1	00:10:00	\N	0.92000000000000004	\N	\N	Port Isabel	TX
62815	San Nicolas Island, California	NOS	9410068	33.2667000000000002	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:21:00	\N	0.880000000000000004	00:10:00	\N	0.880000000000000004	\N	\N	San Nicolas Island	CA
62816	Avalon, Santa Catalina Island, California (sub)	NOS	9410079	33.3449999999999989	-118.325000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:09:00	\N	0.959999999999999964	00:06:00	\N	0.959999999999999964	\N	\N	Avalon, Santa Catalina Island	CA
62817	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4316999999999993	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:17:00	\N	0.939999999999999947	00:11:00	\N	0.939999999999999947	\N	\N	Catalina Harbor, Santa Catalina Island	CA
62818	Imperial Beach, California	NOS	9410120	32.5782999999999987	-117.135000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:03:00	\N	0.959999999999999964	00:00:00	\N	0.930000000000000049	\N	\N	Imperial Beach	CA
62819	National City, San Diego Bay, California	NOS	9410152	32.6649999999999991	-117.117999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:10:00	0	\N	00:04:00	0.200000000000000011	\N	\N	\N	National City, San Diego Bay	CA
62820	San Diego, Quarantine Station, California	NOS	9410166	32.7032999999999987	-117.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:02:00	\N	0.959999999999999964	-00:04:00	\N	0.959999999999999964	\N	\N	San Diego, Quarantine Station	CA
62821	Crown Point, Mission Bay, California	NOS	9410191	32.7749999999999986	-117.233000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:16:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Crown Point, Mission Bay	CA
62822	La Jolla (Scripps Institution Wharf), California (sub)	NOS	9410230	32.8668888888888873	-117.257138888888903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:04:00	\N	0.969999999999999973	00:00:00	\N	0.92000000000000004	\N	\N	La Jolla (Scripps Institution Wharf)	CA
62823	Newport Beach, Newport Bay Entrance, Corona del Mar, California (sub)	NOS	9410580	33.6032999999999973	-117.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	-00:04:00	\N	0.979999999999999982	-00:03:00	\N	0.979999999999999982	\N	\N	Newport Bay Entrance, Corona del Mar	CA
62824	Balboa Pier, Newport Beach, California	NOS	9410583	33.6000000000000014	-117.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	0.959999999999999964	-00:09:00	\N	0.959999999999999964	\N	\N	Balboa Pier, Newport Beach	CA
62825	Santa Ana River entrance (inside), California	NOS	9410599	33.6300000000000026	-117.957999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	01:47:00	\N	0.200000000000000011	00:23:00	\N	0.540000000000000036	\N	\N	Santa Ana River entrance (inside)	CA
62826	Cabrillo Beach, California	NOS	9410650	33.7066999999999979	-118.272999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
62827	Long Beach, Terminal Island, California (sub)	NOS	9410680	33.7516999999999996	-118.227000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:00:00	\N	1.01000000000000001	-00:01:00	\N	1.01000000000000001	\N	\N	Long Beach, Terminal Island	CA
62828	Long Beach, Inner Harbor, California	NOS	9410686	33.7717000000000027	-118.209999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:05:00	\N	0.959999999999999964	00:04:00	\N	0.959999999999999964	\N	\N	Long Beach, Inner Harbor	CA
62829	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8466999999999985	-118.397999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:07:00	\N	1	00:08:00	\N	0.959999999999999964	\N	\N	King Harbor, Santa Monica Bay	CA
62830	El Segundo, Santa Monica Bay, California	NOS	9410777	33.908299999999997	-118.433000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:13:00	\N	0.959999999999999964	00:13:00	\N	0.959999999999999964	\N	\N	El Segundo, Santa Monica Bay	CA
62831	Santa Monica, Municipal Pier, San Pedro Channel, California (sub)	NOS	9410840	34.0082999999999984	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:03:00	\N	0.989999999999999991	00:03:00	\N	0.989999999999999991	\N	\N	Santa Monica, Municipal Pier	CA
62832	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0082999999999984	-120.046999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:27:00	\N	1.03000000000000003	00:27:00	\N	0.930000000000000049	\N	\N	Bechers Bay, Santa Rosa Island	CA
62833	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.0200000000000031	-119.683000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:18:00	\N	1.01000000000000001	00:19:00	\N	0.939999999999999947	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
62834	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0566999999999993	-120.355000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:34:00	\N	0.939999999999999947	00:33:00	\N	0.939999999999999947	\N	\N	Cuyler Harbor, San Miguel Island	CA
62835	Port Hueneme, California	NOS	9411065	34.148299999999999	-119.203000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:13:00	0	\N	00:10:00	-0.100000000000000006	\N	\N	\N	Port Hueneme	CA
62836	Ventura, California	NOS	9411189	34.2667000000000002	-119.283000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:16:00	0	\N	00:09:00	-0.100000000000000006	\N	\N	\N	Ventura	CA
62837	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483000000000018	-119.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:18:00	\N	1.05000000000000004	00:20:00	\N	0.989999999999999991	\N	\N	Rincon Island, Mussel Shoals	CA
62838	Santa Barbara, California (sub)	NOS	9411340	34.4031111111111088	-119.692805555555594	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:21:00	\N	1.04000000000000004	00:23:00	\N	0.979999999999999982	\N	\N	Santa Barbara	CA
62839	San Simeon, California	NOS	9412553	35.6417000000000002	-121.188000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60835	00:07:00	\N	1	00:08:00	\N	0.989999999999999991	\N	\N	San Simeon	CA
62840	Carmel Cove, Carmel Bay, California	NOS	9413375	36.5200000000000031	-121.939999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:04:00	\N	0.989999999999999991	-00:03:00	\N	0.969999999999999973	\N	\N	Carmel Cove, Carmel Bay	CA
62841	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8016999999999967	-121.790000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:01:00	\N	0.900000000000000022	-00:01:00	\N	0.949999999999999956	\N	\N	Moss Landing, Ocean Pier	CA
62842	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8016999999999967	-121.787000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:01:00	\N	0.949999999999999956	00:01:00	\N	0.979999999999999982	\N	\N	General Fish Company Pier	CA
62843	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.8100000000000023	-121.784999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:02:00	\N	0.900000000000000022	00:03:00	\N	0.949999999999999956	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
62844	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8132999999999981	-121.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:07:00	\N	0.979999999999999982	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
62845	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8132999999999981	-121.787000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	00:02:00	\N	0.949999999999999956	00:00:00	\N	0.969999999999999973	\N	\N	Elkhorn Yacht Club	CA
62846	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583000000000013	-122.016999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60837	-00:11:00	\N	0.989999999999999991	-00:06:00	\N	0.969999999999999973	\N	\N	Santa Cruz, Monterey Bay	CA
62847	Ano Nuevo Island, California	NOS	9413878	37.1082999999999998	-122.337999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-01:04:00	-0.100000000000000006	\N	-01:24:00	-0.699999999999999956	\N	\N	\N	Ano Nuevo Island	CA
62848	Southeast Farallon Island, California	NOS	9414262	37.7000000000000028	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:19:00	0	\N	-00:39:00	-0.299999999999999989	\N	\N	\N	Southeast Farallon Island	CA
62849	Ocean Beach, outer coast, California	NOS	9414275	37.7749999999999986	-122.513000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:35:00	0	\N	-00:49:00	0.100000000000000006	\N	\N	\N	Ocean Beach, outer coast	CA
62850	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.8100000000000023	-122.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:11:00	0	\N	00:13:00	0.200000000000000011	\N	\N	\N	San Francisco, North Point, Pier 41	CA
62851	Rincon Point, Pier 22, San Francisco Bay, California (sub)	NOS	9414317	37.7899999999999991	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:25:00	0	\N	00:23:00	0.400000000000000022	\N	\N	\N	Rincon Point, Pier 22 1/2	CA
62852	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7582999999999984	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
62853	Hunters Point, San Francisco Bay, California (sub)	NOS	9414358	37.7299999999999969	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:39:00	0	\N	00:25:00	0.900000000000000022	\N	\N	\N	Hunters Point	CA
62854	Borden Highway Bridge, San Joaquin River, San Joaquin River, California	NOS	9414367	37.9366666666670085	-121.333333333330046	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:48:00	\N	0.640000000000000013	04:28:00	\N	0.780000000000000027	\N	\N	Borden Highway Bridge, San Joaquin River	CA
62855	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6666999999999987	-122.390000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:56:00	0	\N	00:38:00	1.19999999999999996	\N	\N	\N	South San Francisco	CA
62856	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.6649999999999991	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:00:00	\N	1	00:41:00	\N	1.22999999999999998	\N	\N	Oyster Point Marina	CA
62857	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.6499999999999986	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:10:00	0.100000000000000006	\N	00:38:00	1.10000000000000009	\N	\N	\N	Point San Bruno	CA
62858	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6366999999999976	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:03:00	0	\N	00:42:00	1.39999999999999991	\N	\N	\N	Seaplane Harbor	CA
62859	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.591700000000003	-122.313000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:08:00	\N	1.01000000000000001	00:42:00	\N	1.29000000000000004	\N	\N	Coyote Point Marina	CA
62860	San Mateo Bridge (west end), San Francisco Bay, California (sub)	NOS	9414458	37.5799999999999983	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:11:00	\N	1.04000000000000004	00:44:00	\N	1.3600000000000001	\N	\N	San Mateo Bridge (west end)	CA
62861	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5516999999999967	-122.242999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	\N	1	00:48:00	\N	1.35000000000000009	\N	\N	Bay Slough, west end	CA
62862	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.5450000000000017	-122.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:52:00	\N	0.770000000000000018	00:49:00	\N	1.27000000000000002	\N	\N	Bay Slough, east end	CA
62863	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.533299999999997	-122.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	\N	1.05000000000000004	00:53:00	\N	1.40999999999999992	\N	\N	Redwood Creek Marker 8	CA
62864	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5082999999999984	-122.209999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:42:00	0.100000000000000006	\N	01:03:00	2.20000000000000018	\N	\N	\N	Corkscrew Slough	CA
62865	Newark Slough, San Francisco Bay, California	NOS	9414506	37.513300000000001	-122.079999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	0.100000000000000006	\N	01:11:00	2.60000000000000009	\N	\N	\N	Newark Slough	CA
62866	West Point Slough, San Francisco Bay, California	NOS	9414507	37.5050000000000026	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:30:00	\N	1.04000000000000004	00:56:00	\N	1.43999999999999995	\N	\N	West Point Slough	CA
62867	Dumbarton Highway Bridge, San Francisco Bay, California (sub)	NOS	9414509	37.5067000000000021	-122.114999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	1.05000000000000004	00:50:00	\N	1.51000000000000001	\N	\N	Dumbarton Highway Bridge	CA
62868	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5016999999999996	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	0	\N	01:15:00	2.10000000000000009	\N	\N	\N	Smith Slough	CA
62869	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.4949999999999974	-122.212999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:31:00	\N	1.04000000000000004	00:55:00	\N	1.42999999999999994	\N	\N	Granite Rock, Redwood Creek	CA
62870	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4932999999999979	-122.042000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:07:00	0	\N	01:12:00	2.60000000000000009	\N	\N	\N	Mowry Slough	CA
62871	Redwood City, Wharf 5, San Francisco Bay, California (sub)	NOS	9414523	37.5067777777777778	-122.211527777777803	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	1.05000000000000004	00:48:00	\N	1.44999999999999996	\N	\N	Redwood City, Wharf 5	CA
62872	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583000000000013	-122.105000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:14:00	\N	0.680000000000000049	00:59:00	\N	1.34000000000000008	\N	\N	Palo Alto Yacht Harbor	CA
62873	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.466700000000003	-122.066999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:49:00	0.100000000000000006	\N	01:05:00	2.79999999999999982	\N	\N	\N	Calaveras Point, west of	CA
62874	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.4350000000000023	-122.007000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:13:00	\N	1.12999999999999989	01:14:00	\N	1.65999999999999992	\N	\N	Upper Guadalupe Slough	CA
62875	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4232999999999976	-121.974999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:21:00	\N	0.959999999999999964	01:03:00	\N	1.66999999999999993	\N	\N	Gold Street Bridge, Alviso Slough	CA
62876	Coyote Creek, Tributary no.1, San Francisco Bay, California	NOS	9414561	37.4466999999999999	-121.962999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:45:00	-0.299999999999999989	\N	01:21:00	2.60000000000000009	\N	\N	\N	Coyote Creek, Tributary no.1	CA
62877	Coyote Creek, Alviso Slough, San Francisco Bay, California (sub)	NOS	9414575	37.4650000000000034	-122.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:49:00	\N	1.09000000000000008	00:59:00	\N	1.6100000000000001	\N	\N	Coyote Creek, Alviso Slough	CA
62878	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5516999999999967	-122.162000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:37:00	0.100000000000000006	\N	01:02:00	2.20000000000000018	\N	\N	\N	South Bay Wreck	CA
62879	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5632999999999981	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:21:00	\N	0.450000000000000011	00:52:00	\N	1.16999999999999993	\N	\N	Coyote Hills Slough entrance	CA
62880	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.5949999999999989	-122.144999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:25:00	\N	0.270000000000000018	00:57:00	\N	1.05000000000000004	\N	\N	Alameda Creek	CA
62881	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6082999999999998	-122.182000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:19:00	0	\N	00:48:00	1.80000000000000004	\N	\N	\N	San Mateo Bridge (east end)	CA
62882	San Leandro Marina, San Francisco Bay, California (sub)	NOS	9414688	37.6950000000000003	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:23:00	\N	1.01000000000000001	00:54:00	\N	1.28000000000000003	\N	\N	San Leandro Marina	CA
62883	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7316999999999965	-122.207999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:45:00	\N	0.959999999999999964	00:40:00	\N	1.14999999999999991	\N	\N	Oakland Airport	CA
62884	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483000000000004	-122.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:52:00	\N	0.979999999999999982	00:42:00	\N	1.15999999999999992	\N	\N	San Leandro Channel, San Leandro Bay	CA
62885	Alameda, San Francisco Bay, California (sub)	NOS	9414750	37.7717000000000027	-122.299999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:39:00	\N	0.989999999999999991	00:29:00	\N	1.1100000000000001	\N	\N	Alameda	CA
62886	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.7950000000000017	-122.283000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:42:00	0	\N	00:33:00	0.400000000000000022	\N	\N	\N	Oakland Harbor, Grove Street	CA
62887	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.7950000000000017	-122.329999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:48:00	0	\N	00:33:00	0.200000000000000011	\N	\N	\N	Oakland Pier	CA
62888	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933000000000021	-122.314999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	\N	1	00:24:00	\N	1.1100000000000001	\N	\N	Alameda Naval Air Station	CA
62889	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.8049999999999997	-122.337999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:31:00	\N	0.959999999999999964	00:21:00	\N	1.07000000000000006	\N	\N	Oakland Middle Harbor	CA
62890	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.8100000000000023	-122.326999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:36:00	0	\N	00:28:00	0.299999999999999989	\N	\N	\N	Oakland, Matson Wharf	CA
62891	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.8100000000000023	-122.359999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	\N	0.989999999999999991	00:25:00	\N	1.06000000000000005	\N	\N	Yerba Buena Island	CA
62892	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.8200000000000003	-121.447000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	06:20:00	\N	0.680000000000000049	06:14:00	\N	0.760000000000000009	\N	\N	Grant Line Canal (drawbridge)	CA
62893	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267000000000024	-122.417000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
62894	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8466999999999985	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:14:00	\N	1	00:10:00	\N	0.969999999999999973	\N	\N	Sausalito	CA
62895	Nurse Slough, Bradmoor Island, Suisun Bay, California (sub)	NOS	9414811	38.1833000000000027	-121.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:06:00	\N	0.989999999999999991	00:59:00	\N	1.07000000000000006	\N	\N	Bradmoor Island, Nurse Slough	CA
62896	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.8599999999999994	-122.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:21:00	0	\N	00:13:00	-0.200000000000000011	\N	\N	\N	Angel Island (west side)	CA
62897	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633000000000024	-122.420000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:20:00	\N	1.04000000000000004	00:16:00	\N	1.02000000000000002	\N	\N	Angel Island, East Garrison	CA
62898	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865000000000002	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:21:00	\N	1	00:10:00	\N	0.979999999999999982	\N	\N	Sausalito, Corps of Engineers Dock	CA
62899	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917000000000002	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:54:00	\N	0.619999999999999996	04:50:00	\N	0.67000000000000004	\N	\N	Borden Highway Bridge, Middle River	CA
62900	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8832999999999984	-121.576999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:35:00	\N	0.609999999999999987	04:40:00	\N	0.640000000000000013	\N	\N	Borden Highway Bridge, Old River	CA
62901	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917000000000002	-122.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:32:00	\N	0.959999999999999964	00:28:00	\N	0.979999999999999982	\N	\N	Point Chauncey	CA
62902	Point Isabel, San Francisco Bay, California	NOS	9414843	37.898299999999999	-122.319999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:33:00	0	\N	00:23:00	0.100000000000000006	\N	\N	\N	Point Isabel	CA
62903	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.9099999999999966	-122.358000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:30:00	\N	0.979999999999999982	00:16:00	\N	1.04000000000000004	\N	\N	Richmond Inner Harbor	CA
62904	Chevron Oil Company Pier, Richmond, San Francisco Bay, California (sub)	NOS	9414863	37.9230000000000018	-122.409583333333302	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:38:00	\N	0.979999999999999982	00:24:00	\N	1.04000000000000004	\N	\N	Chevron Oil Company Pier, Richmond	CA
62905	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.9350000000000023	-121.435000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:39:00	\N	0.680000000000000049	04:18:00	\N	0.800000000000000044	\N	\N	Holt, Whiskey Slough	CA
62906	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9382999999999981	-121.560000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:33:00	\N	0.680000000000000049	04:32:00	\N	0.760000000000000009	\N	\N	Orwood, Old River	CA
62907	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.9450000000000003	-122.474999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:50:00	\N	0.930000000000000049	00:42:00	\N	0.989999999999999991	\N	\N	Point San Quentin	CA
62908	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.9433000000000007	-122.513000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:51:00	\N	0.949999999999999956	00:36:00	\N	0.989999999999999991	\N	\N	Corte Madera Creek	CA
62909	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583000000000013	-122.424999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:52:00	\N	0.959999999999999964	00:50:00	\N	1.03000000000000003	\N	\N	Point Orient	CA
62910	Stockton, San Joaquin River, California	NOS	9414883	37.9583000000000013	-121.290000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:33:00	\N	0.660000000000000031	04:06:00	\N	0.810000000000000053	\N	\N	Stockton	CA
62911	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183000000000007	-122.528000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:10:00	0	\N	-00:17:00	0.299999999999999989	\N	\N	\N	Point Bonita, Bonita Cove	CA
62912	Bolinas, Bolinas Lagoon, California (sub)	NOS	9414958	37.9077796936035156	-122.678611755371094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:38:00	\N	0.609999999999999987	-00:10:00	\N	0.699999999999999956	\N	\N	Bolinas Lagoon	CA
62913	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9932999999999979	-122.447000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:07:00	\N	0.92000000000000004	01:02:00	\N	1.01000000000000001	\N	\N	Point San Pedro	CA
62914	Blackslough Landing, San Joaquin River, California (sub)	NOS	9415021	37.9946944444444412	-121.419044444444395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:15:00	\N	0.619999999999999996	04:00:00	\N	0.75	\N	\N	Blackslough Landing	CA
62915	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.0150000000000006	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:25:00	\N	0.890000000000000013	01:18:00	\N	1.02000000000000002	\N	\N	Gallinas, Gallinas Creek	CA
62916	Davis Slough, San Joaquin River, California	NOS	9415053	38.0116999999999976	-121.638000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:46:00	\N	0.719999999999999973	02:33:00	\N	0.680000000000000049	\N	\N	Dutch Slough	CA
62917	Antioch, San Joaquin River, California (sub)	NOS	9415064	38.0200000000000031	-121.814999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:26:00	\N	0.780000000000000027	01:12:00	\N	0.770000000000000018	\N	\N	Antioch	CA
62918	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.023299999999999	-122.292000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:39:00	\N	0.849999999999999978	01:15:00	\N	1.05000000000000004	\N	\N	Hercules, Refugio Landing	CA
62919	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.033299999999997	-121.582999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:34:00	\N	0.680000000000000049	03:29:00	\N	0.729999999999999982	\N	\N	Irish Landing, Sand Mound Slough	CA
62920	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367000000000033	-121.879999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:05:00	\N	0.839999999999999969	00:59:00	\N	0.82999999999999996	\N	\N	Pittsburg, New York Slough	CA
62921	Wards Island, Little Connection Slough, San Joaquin River, California (sub)	NOS	9415105	38.0500252777777774	-121.496855555555598	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:51:00	\N	0.609999999999999987	03:45:00	\N	0.680000000000000049	\N	\N	Wards Island, Little Connection Slough	CA
62922	Benicia, California	NOS	9415111	38.0433000000000021	-122.129999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	-00:33:00	\N	1.17999999999999994	-00:24:00	\N	1.09000000000000008	\N	\N	Benicia	CA
62923	Mallard Island Ferry Wharf, Suisun Bay, California (sub)	NOS	9415112	38.0433000000000021	-121.918000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:57:00	\N	0.810000000000000053	00:54:00	\N	0.82999999999999996	\N	\N	Mallard Island Ferry Wharf	CA
62924	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.0450000000000017	-121.420000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:12:00	\N	0.660000000000000031	04:12:00	\N	0.790000000000000036	\N	\N	Bishop Cut, Disappointment Slough	CA
62925	Selby, California	NOS	9415142	38.0583000000000027	-122.242999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:04:00	0	\N	01:29:00	0.599999999999999978	\N	\N	\N	Selby	CA
62926	Crockett, Carquinez Strait, California (sub)	NOS	9415143	38.0583000000000027	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	-01:05:00	\N	1.31000000000000005	-00:58:00	\N	1.21999999999999997	\N	\N	Crockett	CA
62927	False River, San Joaquin River, California	NOS	9415145	38.0549999999999997	-121.656999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:45:00	\N	0.640000000000000013	02:45:00	\N	0.660000000000000031	\N	\N	False River	CA
62928	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617000000000019	-121.555000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:29:00	\N	0.689999999999999947	03:25:00	\N	0.729999999999999982	\N	\N	Prisoners Point	CA
62929	Vallejo, Mare Island Strait, California	NOS	9415165	38.111699999999999	-122.272999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:12:00	\N	0.839999999999999969	01:47:00	\N	1.02000000000000002	\N	\N	Vallejo, Mare Island Strait	CA
62930	Collinsville, Sacramento River, California	NOS	9415176	38.0733000000000033	-121.847999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:20:00	\N	0.800000000000000044	01:11:00	\N	0.800000000000000044	\N	\N	Collinsville	CA
62931	Threemile Slough entrance, San Joaquin River, California (sub)	NOS	9415193	38.0867000000000004	-121.685000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:52:00	\N	0.680000000000000049	02:27:00	\N	0.709999999999999964	\N	\N	Threemile Slough entrance	CA
62932	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767000000000024	-121.885000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:27:00	\N	0.819999999999999951	01:16:00	\N	0.839999999999999969	\N	\N	Montezuma Slough	CA
62933	Mare Island Naval Shipyard, Carquinez Strait, California (sub)	NOS	9415218	38.0700000000000003	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:58:00	\N	0.839999999999999969	01:32:00	\N	1.01000000000000001	\N	\N	Mare Island	CA
62934	Point Buckler, Suisun Bay, California	NOS	9415227	38.1000000000000014	-122.033000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:22:00	\N	1.08000000000000007	00:13:00	\N	1.12000000000000011	\N	\N	Point Buckler	CA
62935	Inverness, Tomales Bay, California	NOS	9415228	38.1133000000000024	-122.867999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:08:00	\N	0.910000000000000031	00:29:00	\N	0.939999999999999947	\N	\N	Inverness, Tomales Bay	CA
62936	Threemile Slough, Sacramento River, California	NOS	9415236	38.1066999999999965	-121.700000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:58:00	\N	0.780000000000000027	01:49:00	\N	0.819999999999999951	\N	\N	Threemile Slough	CA
62937	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.1153055555555582	-122.505666666666698	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:08:00	\N	0.859999999999999987	01:23:00	\N	1.06000000000000005	\N	\N	Petaluma River entrance	CA
62938	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.1099999999999994	-121.498000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:11:00	\N	0.589999999999999969	03:53:00	\N	0.699999999999999956	\N	\N	Terminous, South Fork	CA
62961	Clarksburg, Sacramento River, California	NOS	9415846	38.4166999999999987	-121.522999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	05:02:00	\N	0.409999999999999976	03:58:00	\N	0.599999999999999978	\N	\N	Clarksburg	CA
62939	Suisun Slough entrance, Suisun Bay, California (sub)	NOS	9415265	38.128300000000003	-122.072999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:26:00	\N	0.930000000000000049	00:13:00	\N	0.969999999999999973	\N	\N	Suisun Slough entrance	CA
62940	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1266999999999996	-122.099999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:41:00	\N	0.959999999999999964	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
62941	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	03:41:00	\N	0.589999999999999969	03:29:00	\N	0.67000000000000004	\N	\N	Georgiana Slough entrance	CA
62942	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1366999999999976	-121.906999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:11:00	\N	0.930000000000000049	00:57:00	\N	1.01000000000000001	\N	\N	Meins Landing, Montezuma Slough	CA
62943	Rio Vista, Sacramento River, California (sub)	NOS	9415316	38.1450000000000031	-121.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:02:00	\N	0.780000000000000027	01:51:00	\N	0.880000000000000004	\N	\N	Rio Vista	CA
62944	Reynolds, Tomales Bay, California	NOS	9415320	38.1467000000000027	-122.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:59:00	\N	0.82999999999999996	00:26:00	\N	0.890000000000000013	\N	\N	Reynolds, Tomales Bay	CA
62945	Marshall, Tomales Bay, California	NOS	9415339	38.1617000000000033	-122.893000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:16:00	-0.100000000000000006	\N	00:38:00	-0.599999999999999978	\N	\N	\N	Marshall, Tomales Bay	CA
62946	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617000000000033	-122.549999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:36:00	\N	0.790000000000000036	01:47:00	\N	1.07000000000000006	\N	\N	Hog Island, San Antonio Creek	CA
62947	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.1799999999999997	-122.045000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:41:00	\N	1	00:21:00	\N	1.07000000000000006	\N	\N	Joice Island, Suisun Slough	CA
62948	Blakes Landing, Tomales Bay, California	NOS	9415396	38.1899999999999977	-122.917000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:15:00	\N	0.790000000000000036	00:32:00	\N	0.859999999999999987	\N	\N	Blakes Landing, Tomales Bay	CA
62949	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867000000000019	-121.980000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	00:46:00	\N	0.949999999999999956	00:37:00	\N	1.01000000000000001	\N	\N	Montezuma Slough Bridge	CA
62950	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833000000000027	-121.655000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	02:48:00	\N	0.650000000000000022	02:24:00	\N	0.800000000000000044	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
62951	Edgerley Island, Napa River, California	NOS	9415415	38.1916999999999973	-122.311999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:29:00	\N	0.760000000000000009	02:02:00	\N	1.06000000000000005	\N	\N	Edgerley Island, Napa River	CA
62952	Brazos Drawbridge, Napa River, California	NOS	9415446	38.2100000000000009	-122.307000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:29:00	\N	0.859999999999999987	02:02:00	\N	1.1399999999999999	\N	\N	Brazos Drawbridge, Napa River	CA
62953	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.2100000000000009	-122.427000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	03:11:00	-0.299999999999999989	\N	02:12:00	0.100000000000000006	\N	\N	\N	Wingo, Sonoma Creek	CA
62954	Tomales Bay entrance, California	NOS	9415469	38.2282999999999973	-122.977000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	00:20:00	\N	0.910000000000000031	-00:12:00	\N	0.869999999999999996	\N	\N	Tomales Bay entrance	CA
62955	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.226700000000001	-121.489999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	04:56:00	\N	0.680000000000000049	04:22:00	\N	0.729999999999999982	\N	\N	New Hope Bridge	CA
62956	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.236699999999999	-122.030000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	01:01:00	\N	1	00:36:00	\N	1.1100000000000001	\N	\N	Suisun City, Suisun Slough	CA
62957	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2766999999999982	-121.495000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	05:36:00	\N	0.390000000000000013	05:00:00	\N	0.489999999999999991	\N	\N	Snodgrass Slough	CA
62958	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2282999999999973	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:59:00	\N	0.819999999999999951	02:11:00	\N	1.14999999999999991	\N	\N	Upper drawbridge, Petaluma River	CA
62959	Napa, Napa River, California	NOS	9415623	38.2982999999999976	-122.280000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:37:00	\N	0.900000000000000022	02:05:00	\N	1.21999999999999997	\N	\N	Napa, Napa River	CA
62960	Bodega Harbor entrance, California	NOS	9415625	38.3083000000000027	-123.055000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:16:00	0.100000000000000006	\N	-00:38:00	-0.200000000000000011	\N	\N	\N	Bodega Harbor entrance	CA
62963	Sacramento, Sacramento River, California	NOS	9416174	38.5799999999999983	-121.507000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60872	06:32:00	\N	0.409999999999999976	05:07:00	\N	0.599999999999999978	\N	\N	Sacramento	CA
62964	Westport, California	NOS	9417624	39.6332999999999984	-123.783000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:00:00	\N	0.949999999999999956	00:14:00	\N	0.979999999999999982	\N	\N	Westport	CA
62965	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867000000000019	-124.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:15:00	\N	0.979999999999999982	00:06:00	\N	1.01000000000000001	\N	\N	Hookton Slough	CA
62966	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567000000000021	-124.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	01:32:00	\N	0.309999999999999998	00:19:00	\N	0.709999999999999964	\N	\N	Elk River Railroad Bridge	CA
62967	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783000000000015	-124.197000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:16:00	\N	1	00:17:00	\N	1.01000000000000001	\N	\N	Bucksport	CA
62968	Eureka, Humboldt Bay, California	NOS	9418801	40.8066999999999993	-124.167000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:13:00	\N	1.03000000000000003	00:26:00	\N	1.06000000000000005	\N	\N	Eureka	CA
62969	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8066999999999993	-124.141999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:19:00	\N	1.02000000000000002	00:33:00	\N	1.08000000000000007	\N	\N	Eureka Slough Bridge	CA
62970	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.8500000000000014	-124.117000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:54:00	0.100000000000000006	\N	00:48:00	0.100000000000000006	\N	\N	\N	Arcata Wharf	CA
62971	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865000000000002	-124.147999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60888	00:35:00	\N	1.07000000000000006	00:43:00	\N	1.12000000000000011	\N	\N	Mad River Slough, Arcata Bay	CA
62972	Trinidad Harbor, California	NOS	9419059	41.0566999999999993	-124.147000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	-00:03:00	\N	0.979999999999999982	-00:02:00	\N	0.969999999999999973	\N	\N	Trinidad Harbor	CA
62973	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433000000000021	-124.284999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
62974	Bandon, Coquille River, Oregon	NOS	9432373	43.1199999999999974	-124.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:02:00	\N	0.939999999999999947	-00:05:00	\N	0.92000000000000004	\N	\N	Bandon, Coquille River	OR
62975	Coos Bay, Oregon	NOS	9432845	43.3800000000000026	-124.215000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:28:00	\N	0.880000000000000004	01:26:00	\N	0.959999999999999964	\N	\N	Coos Bay	OR
62976	Empire, Coos Bay, Oregon	NOS	9432864	43.3917000000000002	-124.280000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:50:00	\N	0.880000000000000004	00:37:00	\N	0.859999999999999987	\N	\N	Empire	OR
62977	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3766999999999996	-124.296999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:08:00	\N	1.01000000000000001	00:07:00	\N	1.01000000000000001	\N	\N	Sitka Dock, Coos Bay	OR
62978	Florence, Siuslaw River, Oregon	NOS	9434032	43.966700000000003	-124.102999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:58:00	\N	0.800000000000000044	00:44:00	\N	0.859999999999999987	\N	\N	Florence	OR
62979	Siuslaw River entrance, Oregon	NOS	9434132	44.0167000000000002	-124.129999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	00:03:00	\N	0.959999999999999964	-00:06:00	\N	0.959999999999999964	\N	\N	Suislaw River Entrance	OR
62980	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4132999999999996	-123.989999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:51:00	\N	0.530000000000000027	00:44:00	\N	0.82999999999999996	\N	\N	Drift Creek, Alsea River	OR
62981	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167000000000016	-123.936999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:17:00	\N	1.02000000000000002	01:02:00	\N	1.31000000000000005	\N	\N	TOLEDO	OR
62982	South Beach, Yaquina Bay and River, Oregon (sub)	NOS	9435380	44.625	-124.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:34:00	\N	1.10000000000000009	00:41:00	\N	1.22999999999999998	\N	\N	Southbeach	OR
62983	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6266999999999996	-124.055000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:35:00	\N	1.1100000000000001	00:39:00	\N	1.21999999999999997	\N	\N	YAQUINA USCG STA, NEWPORT	OR
62984	Depoe Bay, Oregon (sub)	NOS	9435827	44.8100000000000023	-124.058000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:27:00	\N	1.10000000000000009	00:27:00	\N	1.20999999999999996	\N	\N	Depoe Bay	OR
62985	Kernville, Siletz River, Oregon	NOS	9436031	44.8967000000000027	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:53:00	\N	0.67000000000000004	01:24:00	\N	0.859999999999999987	\N	\N	Kernville, Siletz River	OR
62986	Taft, Siletz Bay, Oregon	NOS	9436101	44.9266999999999967	-124.013000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:13:00	\N	0.75	00:48:00	\N	0.939999999999999947	\N	\N	Taft, Siletz Bay	OR
62987	Netarts, Netarts Bay, Oregon	NOS	9437262	45.4299999999999997	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:38:00	\N	0.849999999999999978	01:17:00	\N	0.979999999999999982	\N	\N	Netarts, Netarts Bay	OR
62988	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.4600000000000009	-123.844999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	03:15:00	\N	0.57999999999999996	01:52:00	\N	0.939999999999999947	\N	\N	Tillamook, Hoquarten Slough	OR
62989	Garibaldi, Tillamook Bay, Oregon (sub)	NOS	9437540	45.5545299999999997	-123.918944444391457	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:11:00	\N	1.06000000000000005	01:19:00	\N	1.18999999999999995	\N	\N	Garibaldi	OR
62990	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683000000000007	-123.942999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:56:00	\N	0.92000000000000004	00:42:00	\N	1.08000000000000007	\N	\N	Barview	OR
62991	Brighton, Nehalem River, Oregon	NOS	9437815	45.6700000000000017	-123.924999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:54:00	\N	1	00:51:00	\N	1.12999999999999989	\N	\N	Brighton	OR
62992	Nehalem, Nehalem River, Oregon	NOS	9437908	45.7100000000000009	-123.890000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:56:00	\N	0.75	01:17:00	\N	1.03000000000000003	\N	\N	Nehalem	OR
62993	Astoria (Port Docks), Oregon	NOS	9439023	46.1867000000000019	-123.859999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
62994	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717000000000013	-123.841999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:14:00	0.100000000000000006	\N	-00:13:00	0.100000000000000006	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
62995	Settlers Point, Oregon	NOS	9439054	46.1749999999999972	-123.677999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:53:00	-0.100000000000000006	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
62996	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867000000000019	-123.587999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:58:00	\N	0.859999999999999987	00:29:00	\N	0.969999999999999973	\N	\N	Knappa, Knappa Slough	OR
62997	Hungry Harbor, Washington	NOS	9440563	46.2582999999999984	-123.847999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:09:00	0.100000000000000006	\N	00:04:00	-0.200000000000000011	\N	\N	\N	Hungry Harbor, Wash.	WA
62998	Fort Canby, Jetty 'A', Washington	NOS	9440572	46.2683000000000035	-124.037000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-01:05:00	\N	1.21999999999999997	-00:41:00	\N	0.969999999999999973	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
62999	Chinook, Baker Bay, Washington	NOS	9440573	46.2717000000000027	-123.947999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:52:00	\N	1.12000000000000011	-00:30:00	\N	0.949999999999999956	\N	\N	Chinook, Baker Bay, Wash.	WA
63000	Columbia River entrance (N. Jetty), Washington	NOS	9440574	46.273299999999999	-124.072000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-01:00:00	0.100000000000000006	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
63001	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033000000000001	-124.040000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:01:00	-0.100000000000000006	\N	-00:13:00	-0.800000000000000044	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
63002	Naselle River, 4 miles above swing bridge, Willapa Bay, Washington	NOS	9440662	46.388300000000001	-123.840000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:02:00	\N	0.930000000000000049	01:02:00	\N	1.21999999999999997	\N	\N	Naselle River, 4 miles above swing bridge	WA
63003	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.4299999999999997	-123.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:37:00	\N	1.08000000000000007	00:42:00	\N	1.21999999999999997	\N	\N	Naselle River, swing bridge	WA
63004	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4682999999999993	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:41:00	\N	1.04000000000000004	00:43:00	\N	1.14999999999999991	\N	\N	Paradise Point, Long Island	WA
63005	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5016999999999996	-124.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:28:00	\N	1.01000000000000001	00:29:00	\N	1.12999999999999989	\N	\N	Nahcotta	WA
63006	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867000000000004	-123.909999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:31:00	\N	0.959999999999999964	00:25:00	\N	1.04000000000000004	\N	\N	Palix River, south fork	WA
63007	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233000000000004	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:22:00	\N	1.03000000000000003	00:09:00	\N	1.04000000000000004	\N	\N	Bay Center, Palix River	WA
63008	South Bend, Willapa River, Willapa Bay, Washington (sub)	NOS	9440875	46.6632999999999996	-123.798000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:15:00	\N	1.05000000000000004	00:14:00	\N	1.1100000000000001	\N	\N	South Bend, Willapa River	WA
63009	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833000000000027	-123.754999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:17:00	\N	1.04000000000000004	00:27:00	\N	1.12999999999999989	\N	\N	Raymond, Willapa River	WA
63010	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.861699999999999	-124.060000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:26:00	\N	1.12999999999999989	-00:01:00	\N	1.10000000000000009	\N	\N	Bay City, South Bay	WA
63011	Markham, Grays Harbor, Washington	NOS	9441098	46.9067000000000007	-123.998000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:15:00	\N	1.02000000000000002	00:05:00	\N	1.06000000000000005	\N	\N	Markham	WA
63012	Westport, Point Chehalis, Grays Harbor, Washington (sub)	NOS	9441102	46.9043100000000024	-124.105083333121399	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:29:00	\N	1.01000000000000001	-00:11:00	\N	1.03000000000000003	\N	\N	Westport, Point Chehalis	WA
63013	Point Brown, Grays Harbor, Washington	NOS	9441156	46.9500000000000028	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:24:00	\N	1.04000000000000004	-00:09:00	\N	1.06000000000000005	\N	\N	Point Brown	WA
63014	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.966700000000003	-123.778000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:15:00	\N	1.12000000000000011	00:26:00	\N	1.22999999999999998	\N	\N	Cosmopolis, Chehalis River	WA
63015	Point Grenville, Washington	NOS	9441627	47.3033000000000001	-124.269999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:44:00	\N	0.900000000000000022	-00:37:00	\N	0.92000000000000004	\N	\N	Point Grenville	WA
63016	James Island, Washington	NOS	9442388	47.9067000000000007	-124.647000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:32:00	\N	0.959999999999999964	-00:39:00	\N	0.92000000000000004	\N	\N	James Island	WA
63017	La Push, Quillayute River, Washington (sub)	NOS	9442396	47.9133333333333269	-124.636944444444396	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:34:00	\N	0.939999999999999947	-00:39:00	\N	0.910000000000000031	\N	\N	La Push, Quillayute River	WA
63018	Makah Bay, Washington	NOS	9442861	48.2967000000000013	-124.671999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:28:00	\N	1.10000000000000009	-00:25:00	\N	0.989999999999999991	\N	\N	Makah Bay	WA
63019	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.3917007446289062	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60937	-00:10:00	\N	1	-00:08:00	\N	1.01000000000000001	\N	\N	Tatoosh Island, Cape Flattery	WA
63020	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.1749992370605469	-123.949996948242188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60937	00:59:00	\N	1.19999999999999996	00:47:00	\N	0.890000000000000013	\N	\N	Twin Rivers	WA
63021	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617000000000033	-123.724999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-02:02:00	\N	0.800000000000000044	-02:41:00	\N	0.800000000000000044	\N	\N	Crescent Bay	WA
63022	Port Angeles, Strait Of Juan De Fuca, Washington (sub)	NOS	9444090	48.1247222222222319	-123.441138888888901	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-01:14:00	\N	0.770000000000000018	-01:45:00	\N	0.82999999999999996	\N	\N	Port Angeles	WA
63023	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.1400000000000006	-123.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-01:13:00	\N	0.900000000000000022	-01:37:00	\N	0.810000000000000053	\N	\N	Ediz Hook, Port Angeles	WA
63024	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1666999999999987	-123.117000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:38:00	\N	0.900000000000000022	-00:54:00	\N	0.900000000000000022	\N	\N	Dungeness	WA
63025	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0816999999999979	-123.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:07:00	\N	0.939999999999999947	-00:39:00	\N	0.939999999999999947	\N	\N	Sequim Bay entrance	WA
63026	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583000000000027	-122.917000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:17:00	\N	0.939999999999999947	-00:47:00	\N	0.939999999999999947	\N	\N	Gardiner, Discovery Bay	WA
63027	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583000000000027	-122.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:52:00	\N	0.989999999999999991	00:15:00	\N	0.949999999999999956	\N	\N	Mystery Bay, Marrowstone Island	WA
63028	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.091700000000003	-122.689999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:05:00	-0.100000000000000006	\N	00:02:00	0.400000000000000022	\N	\N	\N	Marrowstone Point	WA
63029	Foulweather Bluff, Washington (sub)	NOS	9445016	47.9266999999999967	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:07:00	\N	0.979999999999999982	-00:11:00	\N	0.890000000000000013	\N	\N	Foulweather Bluff	WA
63030	Port Ludlow, Washington	NOS	9445017	47.9249999999999972	-122.680000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:14:00	\N	0.949999999999999956	-00:14:00	\N	0.869999999999999996	\N	\N	Port Ludlow	WA
63031	Port Gamble, Washington	NOS	9445059	47.8582999999999998	-122.579999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	0.949999999999999956	-00:09:00	\N	0.900000000000000022	\N	\N	Port Gamble	WA
63032	Lofall, Washington	NOS	9445088	47.8149999999999977	-122.656999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:06:00	\N	1.01000000000000001	-00:08:00	\N	0.939999999999999947	\N	\N	Lofall	WA
63033	Bangor Wharf, Washington (sub)	NOS	9445133	47.7483000000000004	-122.727000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:01:00	\N	1.03000000000000003	-00:06:00	\N	0.969999999999999973	\N	\N	Bangor Wharf	WA
63034	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7616999999999976	-122.849999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:02:00	\N	1.06000000000000005	-00:05:00	\N	1.01000000000000001	\N	\N	Whitney Point, Dabob Bay	WA
63035	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117000000000004	-122.822000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	1.02000000000000002	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
63036	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.7999999999999972	-122.858000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:02:00	\N	1.04000000000000004	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
63037	Pleasant Harbor, Washington	NOS	9445293	47.6649999999999991	-122.912000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1.02000000000000002	-00:14:00	\N	1.01000000000000001	\N	\N	Pleasant Harbor	WA
63038	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417000000000002	-122.828000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:01:00	\N	1.06000000000000005	-00:04:00	\N	1.01000000000000001	\N	\N	Seabeck, Seabeck Bay	WA
63039	Triton Head, Washington	NOS	9445326	47.6032999999999973	-122.981999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:06:00	\N	1.02000000000000002	-00:06:00	\N	1	\N	\N	Triton Head	WA
63040	Ayock Point, Washington	NOS	9445388	47.5082999999999984	-123.052000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.07000000000000006	-00:03:00	\N	0.989999999999999991	\N	\N	Ayock Point	WA
63041	Lynch Cove Dock, Washington	NOS	9445441	47.4183000000000021	-122.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:06:00	\N	1.08000000000000007	00:00:00	\N	1.07000000000000006	\N	\N	Lynch Cove Dock	WA
63042	Hansville, Puget Sound, Washington	NOS	9445526	47.9183000000000021	-122.545000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:08:00	\N	0.979999999999999982	-00:07:00	\N	0.92000000000000004	\N	\N	Hansville	WA
63043	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967000000000013	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:05:00	\N	1	-00:05:00	\N	0.969999999999999973	\N	\N	Kingston, Appletree Cove	WA
63044	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.746699999999997	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.979999999999999982	-00:03:00	\N	0.949999999999999956	\N	\N	Port Jefferson	WA
63045	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.7250000000000014	-122.638000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:12:00	\N	1.01000000000000001	00:05:00	\N	1.03000000000000003	\N	\N	Poulsbo, Liberty Bay	WA
63046	Port Madison, Puget Sound, Washington	NOS	9445753	47.7049999999999983	-122.525000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:03:00	\N	0.989999999999999991	00:09:00	\N	1	\N	\N	Port Madison	WA
63047	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6516999999999982	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:09:00	\N	1.03000000000000003	00:07:00	\N	1.04000000000000004	\N	\N	Brownsville, Port Orchard	WA
63048	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.6199999999999974	-122.515000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.02000000000000002	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
63049	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.6099999999999994	-122.659999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:53:00	\N	0.949999999999999956	00:28:00	\N	1.06000000000000005	\N	\N	Tracyton, Dyes Inlet	WA
63050	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5966999999999985	-122.510000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	0.989999999999999991	00:04:00	\N	1.01000000000000001	\N	\N	Port Blakely	WA
63051	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733000000000033	-122.543000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	1	00:03:00	\N	1.01000000000000001	\N	\N	Clam Bay, Rich Passage	WA
63052	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.523299999999999	-122.516999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	0.989999999999999991	-00:06:00	\N	1.02000000000000002	\N	\N	Harper, Yukon Harbor	WA
63053	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5116999999999976	-122.462999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:02:00	\N	1.01000000000000001	00:02:00	\N	1.02000000000000002	\N	\N	Point Vashon, Vashon Island	WA
63054	Des Moines, East Passage, Puget Sound, Washington	NOS	9446248	47.3999999999999986	-122.328000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:08:00	\N	1.01000000000000001	00:05:00	\N	1.03000000000000003	\N	\N	Des Moines, East Passage	WA
63055	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.3950000000000031	-122.462999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:03:00	\N	1.02000000000000002	00:01:00	\N	1.06000000000000005	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
63056	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3832999999999984	-122.822999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:59:00	\N	1.07000000000000006	00:48:00	\N	1.26000000000000001	\N	\N	Allyn, Case Inlet	WA
63057	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.341700000000003	-122.775000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.06000000000000005	00:51:00	\N	1.26000000000000001	\N	\N	Vaughn, Case Inlet	WA
63058	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.3400000000000034	-122.587999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:22:00	\N	0.989999999999999991	00:18:00	\N	1.05000000000000004	\N	\N	Gig Harbor	WA
63059	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333000000000013	-122.507000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:05:00	\N	1.01000000000000001	00:04:00	\N	1.05000000000000004	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
63060	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3016999999999967	-122.682000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:46:00	\N	1.05000000000000004	00:38:00	\N	1.19999999999999996	\N	\N	Horsehead Bay, Carr Inlet	WA
63061	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington (sub)	NOS	9446484	47.2666699999999977	-122.413333333333327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:04:00	\N	1	00:04:00	\N	1.04000000000000004	\N	\N	Tacoma, Commencement Bay, Sitcum Waterway	WA
63062	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717000000000027	-122.552000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:23:00	\N	1.02000000000000002	00:28:00	\N	1.1100000000000001	\N	\N	Tacoma Narrows Bridge	WA
63063	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817000000000007	-122.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:55:00	\N	1.07000000000000006	00:44:00	\N	1.26000000000000001	\N	\N	Walkers Landing, Pickering Passage	WA
63064	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.2800000000000011	-122.652000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:40:00	\N	1.04000000000000004	00:31:00	\N	1.17999999999999994	\N	\N	Arletta, Hale Passage	WA
63065	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.2749999999999986	-122.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:45:00	\N	1.04000000000000004	00:37:00	\N	1.18999999999999995	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
63066	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.246699999999997	-122.861999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:52:00	\N	1.06000000000000005	00:40:00	\N	1.23999999999999999	\N	\N	McMicken Island, Case Inlet	WA
63067	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.2150000000000034	-123.082999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	02:05:00	\N	0.92000000000000004	01:26:00	\N	1.26000000000000001	\N	\N	Shelton, Oakland Bay	WA
63068	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.2100000000000009	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:47:00	\N	1.02000000000000002	00:38:00	\N	1.19999999999999996	\N	\N	Longbranch, Filucy Bay	WA
63069	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1966999999999999	-122.938000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	01:05:00	\N	1.06000000000000005	00:49:00	\N	1.28000000000000003	\N	\N	Arcadia, Totten Inlet	WA
63070	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1666999999999987	-122.763000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:50:00	\N	1.10000000000000009	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
63071	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1732999999999976	-122.602999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:45:00	\N	1.05000000000000004	00:37:00	\N	1.19999999999999996	\N	\N	Steilacoom, Cormorant Passage	WA
63072	Barron Point, Little Snookum Inlet Entrance, Puget Sound, Washington	NOS	9446742	47.1567000000000007	-123.007999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:59:00	\N	1.06000000000000005	00:50:00	\N	1.29000000000000004	\N	\N	Barron Point, Little Snookum Inlet Entrance	WA
63073	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.1550000000000011	-122.837999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:58:00	\N	1.06000000000000005	00:47:00	\N	1.23999999999999999	\N	\N	Henderson Inlet	WA
63074	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417000000000002	-122.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.09000000000000008	00:44:00	\N	1.28000000000000003	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
63075	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1182999999999979	-122.665000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:49:00	\N	1.04000000000000004	00:41:00	\N	1.19999999999999996	\N	\N	Dupont Wharf, Nisqually Reach	WA
63076	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.0600000000000023	-122.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:57:00	\N	1.08000000000000007	00:45:00	\N	1.29000000000000004	\N	\N	Olympia, Budd Inlet	WA
63077	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.5349999999999966	-122.322000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:11:00	\N	0.949999999999999956	00:10:00	\N	0.969999999999999973	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
63078	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.5850000000000009	-122.361999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
63079	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6882999999999981	-122.403000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	0.989999999999999991	00:00:00	\N	0.979999999999999982	\N	\N	Meadow Point, Shilshole Bay	WA
63080	Edmonds, Puget Sound, Washington	NOS	9447427	47.8132999999999981	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.989999999999999991	00:00:00	\N	0.959999999999999964	\N	\N	Edmonds	WA
63081	Glendale, Whidbey Island, Washington	NOS	9447814	47.9399999999999977	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:03:00	\N	0.989999999999999991	00:01:00	\N	0.969999999999999973	\N	\N	Glendale, Whidbey Island	WA
63082	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.033299999999997	-122.606999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:45:00	\N	1.08000000000000007	00:10:00	\N	1.09000000000000008	\N	\N	Bush Point, Whidbey Island	WA
63083	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0266999999999982	-122.534999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.989999999999999991	00:01:00	\N	1.01000000000000001	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
63084	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.0349999999999966	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:01:00	\N	1	00:03:00	\N	0.989999999999999991	\N	\N	Sandy Point, Whidbey Island	WA
63085	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.158299999999997	-122.668000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:20:00	-0.100000000000000006	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
63086	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233000000000018	-122.689999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:09:00	\N	0.989999999999999991	00:15:00	\N	1.01000000000000001	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
63087	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2316999999999965	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:15:00	\N	0.92000000000000004	-00:11:00	\N	0.92000000000000004	\N	\N	Point Partridge, Whidbey Island	WA
63088	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.283299999999997	-122.727999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:16:00	\N	0.949999999999999956	-00:27:00	\N	0.869999999999999996	\N	\N	Sunset Beach, Whidbey Island	WA
63089	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867000000000033	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:04:00	\N	0.989999999999999991	00:04:00	\N	1.03000000000000003	\N	\N	Crescent Harbor, N. Whidbey Island	WA
63090	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3166999999999973	-122.837000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:25:00	\N	0.82999999999999996	-00:13:00	\N	0.82999999999999996	\N	\N	Smith Island	WA
63091	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967000000000027	-122.587000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:26:00	\N	0.949999999999999956	00:12:00	\N	0.92000000000000004	\N	\N	Ala Spit, Whidbey Island	WA
63092	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4016999999999982	-122.623000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:26:00	\N	0.949999999999999956	00:15:00	\N	0.890000000000000013	\N	\N	Cornet Bay, Deception Pass	WA
63093	Kayak Point, Washington	NOS	9448094	48.1366999999999976	-122.367000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	-00:02:00	\N	0.989999999999999991	00:00:00	\N	0.989999999999999991	\N	\N	Kayak Point	WA
63094	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917000000000002	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:39:00	\N	0.949999999999999956	00:21:00	\N	0.900000000000000022	\N	\N	La Conner, Swinomish Channel	WA
63095	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4132999999999996	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:38:00	-0.200000000000000011	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
63096	Burrows Bay (Allan Island), Washington	NOS	9448683	48.4600000000000009	-122.694999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:03:00	\N	0.880000000000000004	00:09:00	\N	0.949999999999999956	\N	\N	Burrows Bay (Allan Island)	WA
63097	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067000000000021	-122.677000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:29:00	\N	1.02000000000000002	00:18:00	\N	0.930000000000000049	\N	\N	Ship Harbor, Fidalgo Island	WA
63098	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183000000000035	-122.620000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:33:00	\N	1	00:22:00	\N	0.959999999999999964	\N	\N	Anacortes, Guemes Channel	WA
63099	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.5649999999999977	-122.721999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:52:00	\N	0.949999999999999956	00:34:00	\N	0.949999999999999956	\N	\N	Strawberry Bay, Cypress Island	WA
63100	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867000000000004	-122.748000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:41:00	\N	0.949999999999999956	00:31:00	\N	0.939999999999999947	\N	\N	Tide Point, Cypress Island	WA
63101	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.7299999999999969	-122.670000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:10:00	\N	0.969999999999999973	00:41:00	\N	1.04000000000000004	\N	\N	Gooseberry Point	WA
63102	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.7449999999999974	-122.495000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:11:00	\N	0.939999999999999947	00:43:00	\N	0.989999999999999991	\N	\N	Bellingham	WA
63103	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.7899999999999991	-122.707999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:24:00	\N	1.03000000000000003	00:52:00	\N	1.05000000000000004	\N	\N	Sandy Point, Lummi Bay	WA
63104	Drayton Harbor, Blaine, Strait of Georgia, Washington (sub)	NOS	9449679	48.9917000000000016	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:27:00	\N	1.06000000000000005	00:54:00	\N	1.1100000000000001	\N	\N	Blaine, Semiahmoo Bay	WA
63105	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867000000000033	-122.969999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:30:00	0	\N	01:03:00	0.200000000000000011	\N	\N	\N	Patos Island Wharf	WA
63106	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567000000000021	-122.897000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:34:00	0	\N	01:01:00	0.100000000000000006	\N	\N	\N	Echo Bay, Sucia Islands	WA
63107	Orcas, Orcas Island, Washington	NOS	9449798	48.6000000000000014	-122.950000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:56:00	\N	0.900000000000000022	00:33:00	\N	0.900000000000000022	\N	\N	Orcas, Orcas Island	WA
63108	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.6099999999999994	-123.155000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:47:00	\N	0.989999999999999991	00:33:00	\N	0.900000000000000022	\N	\N	Roche Harbor, San Juan Island	WA
63109	Friday Harbor, San Juan Island, San Juan Channel, Washington (sub)	NOS	9449880	48.5453055555555579	-123.012888888888895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:51:00	\N	0.92000000000000004	00:33:00	\N	0.910000000000000031	\N	\N	Friday Harbor, San Juan Island	WA
63110	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.5850000000000009	-122.927999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:56:00	\N	0.989999999999999991	00:31:00	\N	0.900000000000000022	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
63111	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.4249999999999972	-122.852999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	-00:08:00	\N	0.880000000000000004	-00:18:00	\N	0.880000000000000004	\N	\N	Aleck Bay, Lopez Island	WA
63112	Minnie Bay, Alaska	NOS	9450041	54.726700000000001	-132.301999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:00:00	0.100000000000000006	\N	-00:05:00	2.70000000000000018	\N	\N	\N	Minnie Bay	AK
63113	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483000000000004	-132.85499999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
63114	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.8200000000000003	-130.699999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:09:00	\N	0.890000000000000013	00:01:00	\N	0.949999999999999956	\N	\N	Nakat Harbor, Alaska	AK
63115	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.8500000000000014	-132.830000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
63116	Hunter Bay, Alaska	NOS	9450139	54.871699999999997	-132.322000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:03:00	0.100000000000000006	\N	-00:02:00	2.70000000000000018	\N	\N	\N	Hunter Bay	AK
63117	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8766999999999996	-131.300000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.959999999999999964	-00:04:00	\N	0.939999999999999947	\N	\N	Kelp Island Passage, Duke Island	AK
63118	Elbow Bay, Alaska	NOS	9450158	54.8999999999999986	-132.652999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:04:00	0.100000000000000006	\N	-00:04:00	2.60000000000000009	\N	\N	\N	Elbow Bay	AK
63119	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.9200000000000017	-131.254999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:15:00	\N	0.959999999999999964	00:03:00	\N	0.959999999999999964	\N	\N	Morse Cove, Duke Island	AK
63120	Kassa Inlet entrance, Alaska	NOS	9450176	54.9266999999999967	-132.521999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.100000000000000006	\N	-00:03:00	2.60000000000000009	\N	\N	\N	Kassa Inlet entrance	AK
63121	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.9799999999999969	-132.007000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:04:00	\N	0.959999999999999964	00:03:00	\N	0.930000000000000049	\N	\N	Ingraham Bay, Prince of Wales Island	AK
63122	Mabel Island, Alaska	NOS	9450226	55	-132.592000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	0.100000000000000006	\N	-00:10:00	2.79999999999999982	\N	\N	\N	Mabel Island	AK
63123	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0266999999999982	-132.013000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.890000000000000013	-00:02:00	\N	0.939999999999999947	\N	\N	Menefee Anch., Prince of Wales Island	AK
63124	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0416999999999987	-130.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:06:00	\N	0.959999999999999964	00:00:00	\N	0.969999999999999973	\N	\N	Kah Shakes Cove	AK
63125	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467000000000013	-132.576999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0.100000000000000006	\N	-00:13:00	2.79999999999999982	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
63126	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0666999999999973	-132.120000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:09:00	\N	0.959999999999999964	00:03:00	\N	0.939999999999999947	\N	\N	Niblack Anchorage, Moira Sound	AK
63127	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0666999999999973	-133.199999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:05:00	0	\N	00:01:00	0.299999999999999989	\N	\N	\N	Sakie Bay	AK
63128	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0666999999999973	-131.542000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:08:00	\N	0.890000000000000013	-00:09:00	\N	0.979999999999999982	\N	\N	Tamgas Harbor, Annette Island	AK
63129	Keete Inlet, Alaska	NOS	9450281	55.0799999999999983	-132.490000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	0.100000000000000006	\N	-00:11:00	2.89999999999999991	\N	\N	\N	Keete Inlet	AK
63130	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0816999999999979	-132.632000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.100000000000000006	\N	-00:05:00	2.79999999999999982	\N	\N	\N	Mud Bay	AK
63131	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833000000000013	-133.016999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	0	\N	-00:02:00	2.79999999999999982	\N	\N	\N	View Cove	AK
63132	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167000000000016	-130.798000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.979999999999999982	00:00:00	\N	0.979999999999999982	\N	\N	Boca de Quadra	AK
63133	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1266999999999996	-133.167000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:04:00	-0.100000000000000006	\N	-00:04:00	-0.200000000000000011	\N	\N	\N	Sea Otter Harbor	AK
63134	Metlakatla, Port Chester, Alaska (sub)	NOS	9450314	55.128300000000003	-131.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:07:00	\N	0.959999999999999964	-00:10:00	\N	0.949999999999999956	\N	\N	Metlakatla, Port Chester	AK
63135	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1666999999999987	-131.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:01:00	\N	0.959999999999999964	-00:01:00	\N	0.949999999999999956	\N	\N	Nehenta Bay, Gravina Island	AK
63136	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1666999999999987	-132.870000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	0.100000000000000006	\N	-00:02:00	2.89999999999999991	\N	\N	\N	South Pass, Sukkwan Strait	AK
63137	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1816999999999993	-132.794999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0.100000000000000006	\N	-00:08:00	2.89999999999999991	\N	\N	\N	Saltery Point	AK
63138	North Pass, West End, Tlevak Strait, Alaska	NOS	9450366	55.2049999999999983	-132.939999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	0.100000000000000006	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
63139	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.2100000000000009	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	0.100000000000000006	\N	-00:10:00	2.79999999999999982	\N	\N	\N	Copper Harbor	AK
63140	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2132999999999967	-132.094999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.959999999999999964	00:05:00	\N	0.979999999999999982	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
63141	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2282999999999973	-131.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.959999999999999964	-00:05:00	\N	0.979999999999999982	\N	\N	Alva Bay, Revillagigedo Island	AK
63142	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2332999999999998	-133.043000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0.100000000000000006	\N	-00:05:00	2.89999999999999991	\N	\N	\N	Natalia Point	AK
63143	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2516999999999996	-132.300000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:08:00	\N	0.959999999999999964	-00:05:00	\N	0.979999999999999982	\N	\N	Divide Head, Cholmondeley Sound	AK
63144	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.2633018493652344	-133.115005493164062	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	\N	1	00:07:00	\N	1.19999999999999996	\N	\N	Block Island, Tlevak Narrows	AK
63145	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.2749999999999986	-132.967000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:07:00	0.100000000000000006	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
63146	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.2849999999999966	-132.622000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:08:00	0.100000000000000006	\N	-00:02:00	2.89999999999999991	\N	\N	\N	Sulzer	AK
63147	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3832999999999984	-131.235000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.979999999999999982	-00:05:00	\N	0.979999999999999982	\N	\N	Mop Point, Thorne Arm	AK
63148	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.398299999999999	-131.727000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:03:00	\N	0.959999999999999964	-00:05:00	\N	1.02000000000000002	\N	\N	Ward Cove	AK
63149	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4016999999999982	-132.328000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	1.01000000000000001	00:04:00	\N	1.01000000000000001	\N	\N	Saltery Cove, Skowl Arm	AK
63150	Vallenar Point, Alaska	NOS	9450511	55.4266999999999967	-131.847000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:06:00	\N	0.959999999999999964	-00:01:00	\N	0.989999999999999991	\N	\N	Vallenar Point	AK
63151	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617000000000004	-131.504999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:07:00	\N	0.959999999999999964	-00:03:00	\N	0.989999999999999991	\N	\N	Coon Island, George Inlet	AK
63152	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.4799999999999969	-132.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	1.01000000000000001	00:06:00	\N	1.03000000000000003	\N	\N	Hollis Anchorage	AK
63153	Craig, Klawock Inlet, Bucareli Bay, Alaska (sub)	NOS	9450551	55.4883000000000024	-133.141999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	\N	0.939999999999999947	-00:08:00	\N	1.02000000000000002	\N	\N	Craig, Klawock Inlet	AK
63154	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.533299999999997	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	\N	0.930000000000000049	-00:12:00	\N	1.04000000000000004	\N	\N	Steamboat Bay, Noyes Island	AK
63155	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.5349999999999966	-132.396999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	1.01000000000000001	00:05:00	\N	1.02000000000000002	\N	\N	Kasaan	AK
63156	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5416999999999987	-133.314999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	-0.100000000000000006	\N	-00:15:00	0.100000000000000006	\N	\N	\N	Cruz Pass, San Fernando Island	AK
63157	Loring, Naha Bay, Alaska	NOS	9450624	55.601700000000001	-131.632000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:06:00	\N	0.959999999999999964	-00:02:00	\N	1.02000000000000002	\N	\N	Loring, Naha Bay	AK
63158	Lindeman Cove, Kasaan Bay, Alaska (sub)	NOS	9450625	55.601700000000001	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	1.01000000000000001	00:06:00	\N	1.02000000000000002	\N	\N	Lindeman Cove	AK
63159	Rudyerd Bay, Alaska	NOS	9450651	55.6417000000000002	-130.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.959999999999999964	00:01:00	\N	1.02000000000000002	\N	\N	Rudyerd Bay	AK
63160	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833000000000027	-133.586999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	-0.100000000000000006	\N	-00:18:00	0.400000000000000022	\N	\N	\N	Anguilla Island	AK
63161	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska (sub)	NOS	9450711	55.7216666666666569	-133.349999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	\N	0.939999999999999947	-00:14:00	\N	1.05000000000000004	\N	\N	Nossuk Bay, Tonowek Bay	AK
63162	Davis River entrance, Alaska	NOS	9450729	55.759999999999998	-130.176999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:00:00	\N	0.959999999999999964	-00:02:00	\N	1.08000000000000007	\N	\N	Davis River entrance, Alaska	AK
63163	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117000000000019	-133.60499999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:14:00	0	\N	-00:20:00	0.900000000000000022	\N	\N	\N	Port Alice, Heceta Island	AK
63164	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.8800000000000026	-132.594999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:00:00	\N	0.989999999999999991	00:09:00	\N	1.03000000000000003	\N	\N	Ratz Harbor, Prince of Wales Island	AK
63165	Tuxekan, 0.5 mile south of, Davidson Inlet, Alaska	NOS	9450817	55.8832999999999984	-133.242999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:07:00	-0.100000000000000006	\N	-00:17:00	0.900000000000000022	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
63166	Coronation Island, Alaska	NOS	9450829	55.9033000000000015	-134.117999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:17:00	0	\N	-00:16:00	0.800000000000000044	\N	\N	\N	Coronation Island	AK
63167	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9132999999999996	-131.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.959999999999999964	00:00:00	\N	1.02000000000000002	\N	\N	Yes Cannery, Yes Bay	AK
63168	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367000000000019	-133.324999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:10:00	-0.100000000000000006	\N	-00:11:00	0.900000000000000022	\N	\N	\N	El Capitan Island	AK
63169	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.9500000000000028	-133.662000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:08:00	0	\N	-00:20:00	0.900000000000000022	\N	\N	\N	Edna Bay	AK
63170	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.9549999999999983	-133.810000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:22:00	-0.100000000000000006	\N	-00:22:00	1.39999999999999991	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
63171	Fitzgibbon Cove, Alaska	NOS	9450879	55.9832999999999998	-131.175000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	-00:01:00	\N	0.959999999999999964	-00:05:00	\N	1.02000000000000002	\N	\N	Fitzgibbon Cove	AK
63172	Lake Bay, Alaska	NOS	9450904	56.023299999999999	-132.919999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.890000000000000013	00:10:00	\N	1.03000000000000003	\N	\N	Lake Bay	AK
63173	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467000000000013	-132.861999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	1.01000000000000001	00:10:00	\N	1.05000000000000004	\N	\N	Beck Island, Clarence Strait	AK
63174	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369000000000028	-134.115000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	\N	0.949999999999999956	-00:09:00	\N	1.09000000000000008	\N	\N	Affleck Canal entrance, Kuiu Island	AK
63175	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733000000000033	-133.312999999999988	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:02:00	-0.100000000000000006	\N	-00:05:00	0.900000000000000022	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
63176	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583000000000027	-132.967999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.979999999999999982	00:12:00	\N	1.04000000000000004	\N	\N	Thorne Island, Whale Passage	AK
63177	Point St. Albans, Alaska	NOS	9450943	56.0816999999999979	-133.969999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	0	\N	-00:17:00	1.39999999999999991	\N	\N	\N	Point St. Albans	AK
63178	Thoms Point, Zimovia Strait, Alaska (sub)	NOS	9450970	56.1182999999999979	-132.078000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.989999999999999991	00:07:00	\N	1.06000000000000005	\N	\N	Thoms Point, Zimovia Strait	AK
63179	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1266999999999996	-132.89500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:24:00	\N	0.930000000000000049	00:13:00	\N	1.03000000000000003	\N	\N	Blashke Island	AK
63180	Shakan Bay Entrance, Alaska	NOS	9450982	56.1400000000000006	-133.610000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:13:00	1.80000000000000004	\N	\N	\N	Shakan Bay Entrance	AK
63181	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.148299999999999	-133.460000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:10:00	\N	0.949999999999999956	-00:07:00	\N	1.15999999999999992	\N	\N	Shakan Strait, Kosciusko Island	AK
63182	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.1499999999999986	-134.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:01:00	0	\N	00:01:00	1.30000000000000004	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
63183	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1666999999999987	-134.245000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:13:00	0	\N	-00:15:00	1.10000000000000009	\N	\N	\N	Table Bay, Kuiu Island	AK
63184	Point Harrington, Clarence Strait, Alaska (sub)	NOS	9451005	56.1783000000000001	-132.697000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.969999999999999973	00:09:00	\N	1.04000000000000004	\N	\N	Point Harrington	AK
63185	Bradfield Canal, Alaska (sub)	NOS	9451012	56.1833000000000027	-131.572000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	0.989999999999999991	00:11:00	\N	1.08000000000000007	\N	\N	Bradfield Canal, Ernest Sound	AK
63186	Village Rock, Zimovia Strait, Alaska (sub)	NOS	9451037	56.2199999999999989	-132.296999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.969999999999999973	00:09:00	\N	1.05000000000000004	\N	\N	Village Rock, Zimovia Strait	AK
63187	Port Alexander, Baranof Island, Alaska (sub)	NOS	9451054	56.246699999999997	-134.646999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:10:00	\N	1.01000000000000001	00:07:00	\N	1.1399999999999999	\N	\N	Port Alexander, Baranof Island	AK
63188	Bushy Island, Snow Passage, Alaska (sub)	NOS	9451074	56.2766999999999982	-132.985000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.930000000000000049	00:03:00	\N	0.949999999999999956	\N	\N	Bushy Island, Snow Passage	AK
63189	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2882999999999996	-133.961999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	-0.100000000000000006	\N	-00:14:00	1.89999999999999991	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
63190	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.3049999999999997	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:13:00	0.100000000000000006	\N	00:04:00	1.19999999999999996	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
63191	Port Protection, Prince of Wales Island., Alaska	NOS	9451095	56.3083000000000027	-133.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:11:00	0	\N	-00:13:00	2.39999999999999991	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
63192	Reef Point, Stikine Strait, Alaska (sub)	NOS	9451124	56.3532999999999973	-132.552999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:02:00	\N	0.959999999999999964	00:09:00	\N	1.04000000000000004	\N	\N	Reef Point, Stikine Strait	AK
63193	Reid Bay, Alaska	NOS	9451148	56.388300000000001	-133.88300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
63194	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917000000000002	-134.659999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:13:00	0.100000000000000006	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
63195	Madan Bay, Clarence Strait, Alaska (sub)	NOS	9451152	56.3922000000000025	-132.169000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:04:00	\N	0.979999999999999982	00:12:00	\N	1.05000000000000004	\N	\N	Madan Bay	AK
63196	Sumner Island, Alaska	NOS	9451163	56.4099999999999966	-133.793000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:19:00	2.60000000000000009	\N	\N	\N	Sumner Island	AK
63197	Wrangell, Wrangell Island, Alaska (sub)	NOS	9451204	56.4699999999999989	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:01:00	\N	0.959999999999999964	00:10:00	\N	1.04000000000000004	\N	\N	Wrangell, Wrangell Island	AK
63198	Greys Island, Alaska	NOS	9451238	56.5217000000000027	-132.542000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:05:00	\N	0.939999999999999947	00:11:00	\N	1.01000000000000001	\N	\N	Greys Island	AK
63199	Monte Carlo Island, Keku Strait, Alaska (sub)	NOS	9451247	56.5349999999999966	-133.766999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:03:00	\N	0.890000000000000013	00:03:00	\N	0.800000000000000044	\N	\N	Monte Carlo Island	AK
63200	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska (sub)	NOS	9451263	56.5583000000000027	-132.962999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:08:00	\N	0.979999999999999982	00:15:00	\N	0.979999999999999982	\N	\N	Point Lockwood, Woewodski Island	AK
63201	Beecher Pass, Wrangell Narrows, Alaska (sub)	NOS	9451287	56.5949999999999989	-132.986999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:14:00	\N	0.979999999999999982	00:22:00	\N	1	\N	\N	Beecher Pass	AK
63202	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615000000000002	-132.574999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	0	\N	-00:18:00	-0.200000000000000011	\N	\N	\N	Dry Strait	AK
63203	Anchor Point, Wrangell Narrows, Alaska (sub)	NOS	9451317	56.638300000000001	-132.926999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:40:00	\N	0.989999999999999991	00:31:00	\N	1.04000000000000004	\N	\N	Anchor Point	AK
63204	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6632999999999996	-132.61699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	\N	0.989999999999999991	-00:05:00	\N	0.979999999999999982	\N	\N	Cosmos Point	AK
63205	Papke's Landing, Wrangell Narrows, Alaska (sub)	NOS	9451346	56.6766999999999967	-132.932999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:50:00	\N	1.01000000000000001	00:33:00	\N	1	\N	\N	Papke's Landing	AK
63206	The Summit, Keku Strait, Alaska (sub)	NOS	9451349	56.6824222222222218	-133.736908333333304	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:23:00	\N	0.989999999999999991	00:19:00	\N	0.979999999999999982	\N	\N	The Summit	AK
63207	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7216999999999985	-135.074999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:02:00	\N	0.949999999999999956	-00:02:00	\N	0.969999999999999973	\N	\N	Dorothy Cove, Necker Bay	AK
63208	Turn Point, Alaska (sub)	NOS	9451434	56.7999999999999972	-132.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:38:00	\N	0.959999999999999964	00:25:00	\N	1.04000000000000004	\N	\N	Turn Point	AK
63209	Entrance Island, Keku Strait, Alaska (sub)	NOS	9451438	56.8117000000000019	-133.787000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:20:00	\N	0.979999999999999982	00:18:00	\N	0.939999999999999947	\N	\N	Entrance Island	AK
63210	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.8149999999999977	-132.956999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60982	00:37:00	\N	0.969999999999999973	00:28:00	\N	1.04000000000000004	\N	\N	Petersburg	AK
63211	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8566999999999965	-135.52000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:16:00	0	\N	-00:15:00	-0.100000000000000006	\N	\N	\N	Symonds Bay, Biorka Island	AK
63212	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.996699999999997	-132.784999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:07:00	-0.100000000000000006	\N	00:07:00	-0.800000000000000044	\N	\N	\N	Thomas Bay	AK
63213	Baranof, Warm Spring Bay, Alaska (sub)	NOS	9451625	57.0883333333333312	-134.824999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	-0.100000000000000006	\N	-00:07:00	-2.79999999999999982	\N	\N	\N	Baranof, Warm Spring Bay	AK
63214	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133000000000024	-134.379999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:07:00	\N	0.910000000000000031	-00:08:00	\N	0.839999999999999969	\N	\N	Herring Bay	AK
63215	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1882999999999981	-134.287000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.92000000000000004	-00:06:00	\N	0.869999999999999996	\N	\N	Eliza Harbor, Admiralty Island	AK
63216	Kasnyku Bay, Alaska	NOS	9451717	57.216700000000003	-134.867999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	-0.100000000000000006	\N	-00:10:00	-2.39999999999999991	\N	\N	\N	Kasnyku Bay	AK
63217	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2182999999999993	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:03:00	-0.100000000000000006	\N	-00:01:00	-1.19999999999999996	\N	\N	\N	Cleveland Passage, Whitney Island	AK
63218	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2282999999999973	-135.537000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
63219	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3066999999999993	-134.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	\N	0.939999999999999947	-00:08:00	\N	0.900000000000000022	\N	\N	Cannery Cove, Pybus Bay	AK
63220	The Brothers, Stephens Passage, Alaska (sub)	NOS	9451785	57.2950000000000017	-133.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.979999999999999982	-00:07:00	\N	0.910000000000000031	\N	\N	The Brothers	AK
63221	Scraggy Point, Alaska	NOS	9451802	57.3367000000000004	-135.723000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:00:00	0.100000000000000006	\N	-00:09:00	-0.100000000000000006	\N	\N	\N	Scraggy Point	AK
63222	Scraggy Island, Alaska (sub)	NOS	9451805	57.3400000000000034	-135.706999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:01:00	\N	1.03000000000000003	00:00:00	\N	1	\N	\N	Scraggy Island	AK
63223	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.371699999999997	-135.617999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:12:00	0.100000000000000006	\N	00:03:00	0.200000000000000011	\N	\N	\N	Haley Anchorage, Fish Bay	AK
63224	Hobart Bay, Alaska	NOS	9451851	57.4067000000000007	-133.419999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:03:00	-0.100000000000000006	\N	-00:06:00	-1.10000000000000009	\N	\N	\N	Hobart Bay	AK
63225	Sergius Narrows, Alaska (sub)	NOS	9451853	57.4099999999999966	-135.62700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:24:00	\N	1.05000000000000004	00:19:00	\N	1.33000000000000007	\N	\N	Serguis Narrows	AK
63226	Klokachef Island, Alaska	NOS	9451858	57.4166999999999987	-135.889999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:06:00	0.100000000000000006	\N	-00:10:00	-0.100000000000000006	\N	\N	\N	Klokachef Island	AK
63227	Bear Bay, Alaska	NOS	9451859	57.4183000000000021	-135.582999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:29:00	0.200000000000000011	\N	00:18:00	3.70000000000000018	\N	\N	\N	Bear Bay	AK
63228	Killisnoo, Alaska	NOS	9451895	57.4699999999999989	-134.564999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	0	\N	-00:06:00	-2.10000000000000009	\N	\N	\N	Killisnoo	AK
63229	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4832999999999998	-133.960000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.959999999999999964	-00:01:00	\N	0.92000000000000004	\N	\N	Gambier Bay (cannery wharf)	AK
63230	Good Island, Gambier Bay, Alaska	NOS	9451909	57.486699999999999	-133.897999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	0.959999999999999964	-00:05:00	\N	0.930000000000000049	\N	\N	Good Island, Gambier Bay	AK
63231	Provorotni Island, Alaska (sub)	NOS	9451936	57.5150000000000006	-135.555000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	-0.100000000000000006	\N	-00:09:00	-1.30000000000000004	\N	\N	\N	Povorotni Island, Pogibshi Point	AK
63232	Windham Bay, Alaska	NOS	9451962	57.5433000000000021	-133.49799999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	-0.100000000000000006	\N	00:00:00	-1.10000000000000009	\N	\N	\N	Windham Bay	AK
63233	Nismeni Cove, Alaska	NOS	9451979	57.5617000000000019	-135.412000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	-0.100000000000000006	\N	-00:15:00	-1.30000000000000004	\N	\N	\N	Nismeni Cove	AK
63234	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217000000000027	-133.055000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	\N	0.989999999999999991	00:01:00	\N	0.979999999999999982	\N	\N	Upper Endicott Arm, North Shore	AK
63235	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.878300000000003	-133.189999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	\N	1.01000000000000001	00:02:00	\N	0.969999999999999973	\N	\N	Sawyer Island, Tracy Arm	AK
63236	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7182999999999993	-133.578000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:06:00	-0.100000000000000006	\N	00:03:00	-0.800000000000000044	\N	\N	\N	Holkham Bay, Wood Spit	AK
63237	Holkham Bay, Tracy Arm Entrance, Alaska	NOS	9452067	57.759999999999998	-133.603000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	\N	0.959999999999999964	00:01:00	\N	0.959999999999999964	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
63238	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0966999999999985	-133.74199999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	\N	0.969999999999999973	-00:03:00	\N	0.979999999999999982	\N	\N	Port Snettisham, Crib Point	AK
63239	Taku Harbor, Alaska	NOS	9452123	58.0683000000000007	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	\N	1	-00:03:00	\N	0.969999999999999973	\N	\N	Taku Harbor	AK
63240	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.3999999999999986	-134.014999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:13:00	0	\N	00:14:00	0.400000000000000022	\N	\N	\N	Taku Point, Taku Inlet	AK
63241	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783000000000001	-134.038000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	0.100000000000000006	\N	00:06:00	-0.699999999999999956	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
63242	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233000000000018	-134.060000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:04:00	-0.100000000000000006	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Greely Point, Taku Inlet	AK
63243	Young Bay, Alaska	NOS	9452249	58.1833000000000027	-134.586999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
63244	Auke Bay, Alaska	NOS	9452263	58.3817000000000021	-134.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:03:00	0	\N	-00:06:00	-0.400000000000000022	\N	\N	\N	Auke Bay	AK
63245	Hawk Inlet Entrance, Alaska (sub)	NOS	9452294	58.0850000000000009	-134.776999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.979999999999999982	-00:04:00	\N	0.939999999999999947	\N	\N	Hawk Inlet Entrance	AK
63246	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3216999999999999	-134.877999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	0.989999999999999991	-00:04:00	\N	0.959999999999999964	\N	\N	Barlow Cove, Mansfield Peninsula	AK
63247	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.2550000000000026	-134.89500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:01:00	0	\N	00:00:00	-1.10000000000000009	\N	\N	\N	Funter, Funter Bay	AK
63248	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983000000000004	-134.965000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:01:00	\N	1	-00:03:00	\N	0.979999999999999982	\N	\N	Lincoln Island	AK
63249	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7516999999999996	-135.027999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	\N	1.02000000000000002	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
63250	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.2150000000000034	-135.12700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:11:00	\N	1.08000000000000007	00:14:00	\N	1.40999999999999992	\N	\N	Swanson Harbor	AK
63251	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.7800000000000011	-135.211999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	-0.100000000000000006	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
63252	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7132999999999967	-135.231999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
63253	Skagway, Taiya Inlet, Lynn Canal, Alaska (sub)	NOS	9452400	59.4500000000000028	-135.326999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	1.01000000000000001	-00:03:00	\N	1.03000000000000003	\N	\N	Skagway, Taiya Inlet	AK
63254	Chilkat Inlet, Lynn Canal, Alaska (sub)	NOS	9452421	59.1700000000000017	-135.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:01:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Chilkat Inlet	AK
63255	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3016999999999967	-135.427999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:02:00	\N	1.01000000000000001	-00:04:00	\N	1.03000000000000003	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
63256	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.2299999999999969	-135.432999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
63257	Excursion Inlet Entrance, Icy Strait, Alaska	NOS	9452437	58.4166999999999987	-135.447000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:16:00	\N	1.05000000000000004	00:15:00	\N	1.37999999999999989	\N	\N	Excursion Inlet Entrance	AK
63258	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.496699999999997	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:24:00	\N	1.07000000000000006	00:26:00	\N	1.3600000000000001	\N	\N	Excursion Inlet, North End	AK
63259	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867000000000033	-135.802999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:35:00	\N	1.1100000000000001	00:29:00	\N	1.31000000000000005	\N	\N	Point Adolphus	AK
63260	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.4566999999999979	-135.88300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:22:00	\N	1.1100000000000001	00:19:00	\N	1.3600000000000001	\N	\N	Bartlett Cove	AK
63261	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117000000000004	-136.034999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:06:00	\N	0.959999999999999964	00:06:00	\N	1.19999999999999996	\N	\N	Mud Bay, Goose Island	AK
63262	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133000000000024	-136.086999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:13:00	\N	1.03000000000000003	00:08:00	\N	0.979999999999999982	\N	\N	Elbow Passage, Klag Bay	AK
63263	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867000000000019	-136.106999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:06:00	\N	1.03000000000000003	00:05:00	\N	0.92000000000000004	\N	\N	Kimshan Cove, Ogden Passage	AK
63264	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9132999999999996	-136.108000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:49:00	\N	1.18999999999999995	00:39:00	\N	1.55000000000000004	\N	\N	Muir Inlet	AK
63265	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6082999999999998	-136.11699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:50:00	\N	1.15999999999999992	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
63266	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.263300000000001	-136.324999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:03:00	\N	1.01000000000000001	00:12:00	\N	1.05000000000000004	\N	\N	Inian Cove, North Inian Pass	AK
63267	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9466999999999999	-136.332999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:50:00	\N	1.19999999999999996	00:39:00	\N	1.57000000000000006	\N	\N	Wachusett Inlet, Glacier Bay	AK
63268	Miner Island, Lisianski Strait and Inlet, Alaska	NOS	9452633	58.009999999999998	-136.342000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:06:00	\N	0.959999999999999964	-00:08:00	\N	0.939999999999999947	\N	\N	Miner Island	AK
63269	Elfin Cove, Port Althorp, Cross Sound, Alaska (sub)	NOS	9452634	58.1947199999999967	-136.346944444444432	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:05:00	\N	1.01000000000000001	00:04:00	\N	1.10000000000000009	\N	\N	Elfin Cove, Port Althorp	AK
63270	Canoe Cove, North Pass, Lisianski Strait and Inlet, Alaska	NOS	9452649	57.8466999999999985	-136.421999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:01:00	\N	0.890000000000000013	00:02:00	\N	0.910000000000000031	\N	\N	Canoe Cove, North Pass	AK
63271	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283000000000001	-136.52000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:01:00	\N	1.03000000000000003	-00:04:00	\N	0.900000000000000022	\N	\N	Takanis Bay	AK
63272	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183000000000035	-136.527999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:02:00	\N	0.959999999999999964	00:00:00	\N	0.880000000000000004	\N	\N	Surge Bay	AK
63273	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.888300000000001	-136.573000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:51:00	\N	1.19999999999999996	00:45:00	\N	1.54000000000000004	\N	\N	Composite Island	AK
63274	Graves Harbor, Alaska	NOS	9452704	58.2766999999999982	-136.677999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:07:00	\N	1.03000000000000003	00:04:00	\N	0.910000000000000031	\N	\N	Graves Harbor	AK
63275	Dixon Harbor, Alaska	NOS	9452747	58.3832999999999984	-136.86699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:07:00	\N	0.959999999999999964	00:07:00	\N	0.890000000000000013	\N	\N	Dixon Harbor	AK
63276	Lituya Bay, 2 miles inside entrance, Alaska	NOS	9452928	58.6167000000000016	-137.650000000000006	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	00:36:00	\N	0.890000000000000013	00:06:00	\N	0.869999999999999996	\N	\N	Lituya Bay, 2 miles inside entrance	AK
63277	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.611699999999999	-139.580000000000013	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:00:00	\N	0.92000000000000004	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
63278	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033000000000015	-139.62700000000001	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	0.930000000000000049	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
63279	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5816999999999979	-139.701999999999998	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
63280	Yakutat, Yakutat Bay, Alaska (sub)	NOS	9453220	59.5484999999999971	-139.733399999999989	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:16:00	\N	0.949999999999999956	00:17:00	\N	1.01000000000000001	\N	\N	Yakutat, Yakutat Bay	AK
63281	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.0782999999999987	-141.275000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:17:00	\N	0.969999999999999973	00:20:00	\N	0.959999999999999964	\N	\N	Tyndall Glacier, Icy Bay	AK
63282	Riou Bay, Alaska	NOS	9453456	59.884999999999998	-141.456999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:03:00	\N	1.01000000000000001	00:02:00	\N	0.979999999999999982	\N	\N	Icy Bay	AK
63283	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.4650000000000034	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:16:00	-0.100000000000000006	\N	-00:11:00	-1.10000000000000009	\N	\N	\N	Shag Rock	AK
63284	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.7100000000000009	-146.085000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	-0.100000000000000006	\N	-00:16:00	-0.699999999999999956	\N	\N	\N	Comfort Cove, Port Gravina	AK
63285	Middleton Island (north end), Alaska	NOS	9454224	59.4617000000000004	-146.310000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:14:00	-0.100000000000000006	\N	-00:21:00	-2.20000000000000018	\N	\N	\N	Middleton Island (north end)	AK
63286	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8532999999999973	-146.534999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:08:00	-0.100000000000000006	\N	-00:12:00	-0.699999999999999956	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
63287	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.0399999999999991	-146.615000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:02:00	\N	0.989999999999999991	-00:01:00	\N	0.989999999999999991	\N	\N	Jack Bay	AK
63288	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4816999999999965	-146.610000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:02:00	-0.100000000000000006	\N	-00:07:00	-0.800000000000000044	\N	\N	\N	Johnstone Point	AK
63289	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.2383000000000024	-146.647999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.979999999999999982	-00:10:00	\N	0.880000000000000004	\N	\N	Cape Hinchinbrook	AK
63290	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.9466999999999999	-146.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:03:00	\N	0.989999999999999991	00:00:00	\N	0.989999999999999991	\N	\N	Rocky Point	AK
63291	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.898299999999999	-146.782000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61035	-00:02:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	Busby Island	AK
63292	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.8800000000000026	-147.223000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	0	\N	-00:10:00	-0.599999999999999978	\N	\N	\N	Jackson Cove, Glacier Island	AK
63293	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2417999999999978	-147.248999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	\N	0.969999999999999973	-00:02:00	\N	0.939999999999999947	\N	\N	Port Chalmers	AK
63294	Perch Point, Montague Island, Alaska (sub)	NOS	9454561	60.1266999999999996	-147.39500000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.939999999999999947	-00:08:00	\N	0.92000000000000004	\N	\N	Perch Point	AK
63295	Wooded Islands, Montague Island, Alaska (sub)	NOS	9454562	59.875	-147.402999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.949999999999999956	-00:02:00	\N	0.800000000000000044	\N	\N	Wooded Islands	AK
63296	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833000000000027	-147.388000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:08:00	-0.100000000000000006	\N	-00:18:00	-0.699999999999999956	\N	\N	\N	Naked Island, McPherson Passage	AK
63297	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.2700000000000031	-147.437999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	-0.200000000000000011	\N	-00:21:00	-0.800000000000000044	\N	\N	\N	Gibbon Anchorage, Green Island	AK
63298	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067000000000007	-147.449999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:05:00	-0.100000000000000006	\N	-00:12:00	-2.29999999999999982	\N	\N	\N	Patton Bay	AK
63299	Montague Island, Alaska (sub)	NOS	9454616	60.0249999999999986	-147.592000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.959999999999999964	-00:02:00	\N	0.910000000000000031	\N	\N	5 miles NE of Point Brazil, Montague Island	AK
63300	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617000000000004	-147.671999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	\N	1.04000000000000004	00:00:00	\N	0.959999999999999964	\N	\N	Louis Bay	AK
63301	Snug Harbor, Knight Island, Alaska (sub)	NOS	9454662	60.25	-147.717000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.969999999999999973	-00:03:00	\N	0.910000000000000031	\N	\N	Snug Harbor, Knight Island	AK
63302	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533000000000015	-147.766999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	\N	1	-00:03:00	\N	0.92000000000000004	\N	\N	Point Helen	AK
63303	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3432999999999993	-147.768000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	\N	0.949999999999999956	00:00:00	\N	0.92000000000000004	\N	\N	Port Audrey	AK
63304	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.8900000000000006	-147.794999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:04:00	\N	0.959999999999999964	00:10:00	\N	0.890000000000000013	\N	\N	Macleod Harbor	AK
63305	Herring Point, Knight Island, Prince William Sound, Alaska (sub)	NOS	9454691	60.4750000000000014	-147.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	1.01000000000000001	-00:04:00	\N	0.949999999999999956	\N	\N	Herring Point	AK
63306	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533000000000001	-147.907000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
63307	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483000000000033	-147.978000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:04:00	0	\N	00:01:00	-0.400000000000000022	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
63308	Guguak, Alaska (sub)	NOS	9454751	60.1000000000000014	-148.038000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	\N	0.949999999999999956	-00:07:00	\N	0.910000000000000031	\N	\N	Guguak	AK
63309	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.1966999999999999	-148.042000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.979999999999999982	-00:06:00	\N	0.930000000000000049	\N	\N	Bainbridge Point, Bainbridge Island	AK
63310	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617000000000004	-148.044999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	1.03000000000000003	-00:11:00	\N	0.92000000000000004	\N	\N	Eshamy Lagoon	AK
63311	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0516999999999967	-148.064999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:03:00	0	\N	-00:03:00	-1.19999999999999996	\N	\N	\N	Sawmill Bay, Evans Island	AK
63312	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.283299999999997	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	1	-00:03:00	\N	0.939999999999999947	\N	\N	Chenega Island, southwest end	AK
63407	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.7800000000000011	-176.806999999999988	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:21:00	\N	0.969999999999999973	-00:07:00	\N	0.969999999999999973	\N	\N	Unalga Bight	AK
63313	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.3299999999999983	-148.143000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:06:00	0	\N	-00:01:00	-0.900000000000000022	\N	\N	\N	Chenega Island, Dangerous Passage	AK
63314	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233000000000004	-148.164999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:06:00	0	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Applegate Island	AK
63315	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417000000000016	-148.171999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	0	\N	-00:15:00	-0.400000000000000022	\N	\N	\N	Culross Bay, Wells Passage	AK
63316	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767000000000024	-148.194999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:03:00	-0.100000000000000006	\N	-00:12:00	-1.89999999999999991	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
63317	Point Elrington, Elrington Island, Prince William Sound, Alaska (sub)	NOS	9454814	59.9382999999999981	-148.227000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:02:00	\N	0.939999999999999947	-00:13:00	\N	0.839999999999999969	\N	\N	Point Elrington, Elrington Island	AK
63318	Long Bay Entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6916999999999973	-148.263000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:09:00	-0.100000000000000006	\N	00:03:00	-0.900000000000000022	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
63319	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5416999999999987	-148.460000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:09:00	0	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
63320	Whittier, Prince William Sound, Alaska (sub)	NOS	9454949	60.7783000000000015	-148.664999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	0	\N	-00:05:00	-0.299999999999999989	\N	\N	\N	Whittier, Passage Canal	AK
63321	Day Harbor, Alaska	NOS	9455036	60.009999999999998	-149.062000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:00:00	\N	1.01000000000000001	-00:02:00	\N	0.989999999999999991	\N	\N	Day Harbor	AK
63322	Seward, Resurrection Bay, Alaska (sub)	NOS	9455090	60.1199999999999974	-149.426666699999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:13:00	\N	0.910000000000000031	-00:06:00	\N	0.82999999999999996	\N	\N	Seward, Resurrection Bay	AK
63323	Agnes Cove, Aialik Peninsula, Alaska (sub)	NOS	9455120	59.773299999999999	-149.587999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.910000000000000031	-00:06:00	\N	0.839999999999999969	\N	\N	Agnes Cove, Aialik Peninsula	AK
63324	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8016999999999967	-149.615000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:01:00	\N	0.969999999999999973	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
63325	Aialik Bay, north end, Alaska (sub)	NOS	9455145	59.9532999999999987	-149.715000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.890000000000000013	-00:06:00	\N	0.82999999999999996	\N	\N	Aialik Bay, North end	AK
63326	Aialik Sill, Aialik Bay, Alaska (sub)	NOS	9455146	59.884999999999998	-149.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.900000000000000022	-00:05:00	\N	0.82999999999999996	\N	\N	Aialik Sill, Aialik Bay	AK
63327	Camp Cove, Harris Peninsula, Alaska (sub)	NOS	9455151	59.6933000000000007	-149.74799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:00:00	\N	0.900000000000000022	-00:06:00	\N	0.839999999999999969	\N	\N	Camp Cove, Aialik Bay	AK
63328	Crater Bay, Harris Bay, Alaska (sub)	NOS	9455159	59.7132999999999967	-149.787000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	\N	0.869999999999999996	-00:03:00	\N	0.839999999999999969	\N	\N	Crater Bay, Harris Bay	AK
63329	Upper Northwestern Fiord, Harris Bay, Alaska (sub)	NOS	9455204	59.7899999999999991	-150.032000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:11:00	\N	0.900000000000000022	00:01:00	\N	0.849999999999999978	\N	\N	Upper Northwestern Fiord, Harris Bay	AK
63330	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617000000000033	-150.108000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	-00:05:00	\N	0.939999999999999947	-00:10:00	\N	1.03000000000000003	\N	\N	Two Arm Bay, Harris Bay	AK
63331	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883000000000024	-150.312000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:01:00	\N	1.01000000000000001	00:00:00	\N	1.04000000000000004	\N	\N	Chance Cove (Lagoon)	AK
63332	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5266999999999982	-150.627999999999986	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:14:00	\N	1.01000000000000001	00:12:00	\N	1.08000000000000007	\N	\N	Beauty Bay, Nuka Bay	AK
63333	Nuka Passage, Alaska	NOS	9455308	59.408299999999997	-150.667000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:12:00	\N	1.01000000000000001	00:11:00	\N	1.09000000000000008	\N	\N	Nuka Passage	AK
63334	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2616999999999976	-150.981999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:18:00	\N	1.01000000000000001	00:23:00	\N	1.14999999999999991	\N	\N	Takoma Cove, Port Dick	AK
63335	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.2550000000000026	-151.419999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61048	00:21:00	\N	1.01000000000000001	00:26:00	\N	1.22999999999999998	\N	\N	Picnic Harbor, Rocky Bay	AK
63336	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2132999999999967	-151.728000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:34:00	\N	0.92000000000000004	-00:28:00	\N	0.780000000000000027	\N	\N	Port Chatham	AK
63337	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.3500000000000014	-151.826666666666711	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
63338	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9466999999999999	-152.268000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:04:00	\N	0.760000000000000009	-00:08:00	\N	0.760000000000000009	\N	\N	Ushagat Island, Barren Islands	AK
63339	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4316999999999993	-151.356999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	0	\N	-00:01:00	0.200000000000000011	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
63340	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.490000000000002	-151.365000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:04:00	-0.100000000000000006	\N	-00:04:00	0.100000000000000006	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
63341	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5966999999999985	-151.219999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	0	\N	-00:03:00	0.699999999999999956	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
63342	Homer, Kachemak Bay, Cook Inlet, Alaska	NOS	9455557	59.6032999999999973	-151.419999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:03:00	\N	0.969999999999999973	00:05:00	\N	1.01000000000000001	\N	\N	Homer, Kachemak Bay	AK
63343	Bear Cove, Kachemak Bay, Cook Inlet, Alaska (sub)	NOS	9455595	59.7250000000000014	-151.022999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.400000000000000022	\N	\N	\N	Bear Cove, Kachemak Bay	AK
63344	Anchor Point, Cook Inlet, Alaska (sub)	NOS	9455606	59.7719722222222316	-151.867027777777793	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:21:00	0	\N	00:29:00	0.400000000000000022	\N	\N	\N	Anchor Point	AK
63345	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.5549999999999997	-152.13300000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:04:00	\N	1.17999999999999994	01:39:00	\N	1.01000000000000001	\N	\N	Drift River Terminal	AK
63346	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.5450000000000017	-151.217999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:55:00	-0.100000000000000006	\N	01:54:00	1.89999999999999991	\N	\N	\N	Kenai City Pier	AK
63347	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.1074722222222206	-152.581666666666706	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	01:15:00	0	\N	01:04:00	-2.29999999999999982	\N	\N	\N	Snug Harbor, Cook Inlet	AK
63348	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533000000000015	-152.634999999999991	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:53:00	0.200000000000000011	\N	00:39:00	-1.30000000000000004	\N	\N	\N	Tuxedni Channel	AK
63349	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.6400000000000006	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	01:16:00	\N	0.82999999999999996	01:15:00	\N	0.770000000000000018	\N	\N	Oil Bay, Kamishak Bay	AK
63350	Nukshak Island, Shelikof Strait, Alaska (sub)	NOS	9456717	58.3917000000000002	-153.957999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:07:00	\N	0.949999999999999956	-00:01:00	\N	0.760000000000000009	\N	\N	Nukshak Island, Shelikof Strait	AK
63351	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783000000000001	-154.086999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:22:00	-0.200000000000000011	\N	00:10:00	-2.79999999999999982	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
63352	Kukak, Kukak Bay, Alaska	NOS	9456835	58.341700000000003	-154.11699999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:05:00	\N	0.739999999999999991	-00:08:00	\N	0.739999999999999991	\N	\N	Kukak, Kukak Bay	AK
63353	Aguchik Island, Kukak Bay, Alaska (sub)	NOS	9456901	58.2899999999999991	-154.27000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:06:00	\N	0.939999999999999947	-00:04:00	\N	0.75	\N	\N	Aguchik Island, Kukak Bay	AK
63354	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0632999999999981	-154.477000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:03:00	\N	1	-00:09:00	\N	0.729999999999999982	\N	\N	Takli Island, Shelikof Strait	AK
63355	Tonki Bay, Alaska	NOS	9457152	58.3166999999999973	-152.067000000000007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:21:00	0.200000000000000011	\N	00:12:00	2.29999999999999982	\N	\N	\N	Tonki Bay	AK
63356	Seal Bay, Alaska	NOS	9457201	58.371699999999997	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:36:00	0.299999999999999989	\N	00:29:00	2.39999999999999991	\N	\N	\N	Seal Bay	AK
63357	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183000000000035	-152.414999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	0.299999999999999989	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
63358	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.783299999999997	-152.427999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
63359	Spruce Island (north side), Alaska	NOS	9457262	57.9382999999999981	-152.417000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:08:00	0.100000000000000006	\N	00:02:00	0.400000000000000022	\N	\N	\N	Spruce Island (north side)	AK
63360	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3566999999999965	-152.448000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:39:00	0.299999999999999989	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
63361	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.7449999999999974	-152.483000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:02:00	0	\N	-00:05:00	-0.100000000000000006	\N	\N	\N	Kodiak, St. Paul Harbor	AK
63362	Ouzinkie, Spruce Island, Alaska (sub)	NOS	9457287	57.9217000000000013	-152.49799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:04:00	0	\N	-00:05:00	0.200000000000000011	\N	\N	\N	Ouzinkie, Spruce Island	AK
63363	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867000000000004	-152.513000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:07:00	\N	0.729999999999999982	00:06:00	\N	0.729999999999999982	\N	\N	Carry Inlet	AK
63364	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4532999999999987	-152.594999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:02:00	-0.200000000000000011	\N	-00:14:00	-4.40000000000000036	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
63365	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.5549999999999997	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:15:00	\N	0.770000000000000018	00:10:00	\N	0.770000000000000018	\N	\N	Big Bay	AK
63366	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4816999999999965	-152.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:20:00	-0.100000000000000006	\N	-00:29:00	-0.299999999999999989	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
63367	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9782999999999973	-152.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	0.200000000000000011	\N	00:22:00	1.19999999999999996	\N	\N	\N	Fox Bay, Whale Island	AK
63368	Kizhuyak Bay, Alaska	NOS	9457401	57.8200000000000003	-152.900000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:11:00	0	\N	00:06:00	0.800000000000000044	\N	\N	\N	Kizhuyak Bay	AK
63369	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1632999999999996	-153.151999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:06:00	0.100000000000000006	\N	-00:18:00	-0.299999999999999989	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
63370	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.1099999999999994	-153.155000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:05:00	-0.100000000000000006	\N	-00:25:00	-4.09999999999999964	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
63371	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5482999999999976	-153.735000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:00:00	\N	0.770000000000000018	-00:09:00	\N	0.770000000000000018	\N	\N	Zachar Bay	AK
63372	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.4600000000000009	-153.817000000000007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:10:00	-0.100000000000000006	\N	-00:37:00	-4.09999999999999964	\N	\N	\N	Mining Camp	AK
63373	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0016999999999996	-154.147999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61086	00:10:00	\N	1.01000000000000001	00:11:00	\N	0.989999999999999991	\N	\N	Moser Bay (Trap Point)	AK
63374	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617000000000033	-154.228000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61086	03:54:00	\N	0.0599999999999999978	03:46:00	\N	0.100000000000000006	\N	\N	Olga Bay (A. P. A. Cannery)	AK
63375	Alitak, Lazy Bay, Alaska (sub)	NOS	9457804	56.8973999999999975	-154.24799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:19:00	\N	1.41999999999999993	00:02:00	\N	1.37999999999999989	\N	\N	Alitak, Lazy Bay	AK
63376	Puale Bay, Alaska (sub)	NOS	9458209	57.7066999999999979	-155.393000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:03:00	\N	0.67000000000000004	-00:22:00	\N	0.67000000000000004	\N	\N	Puale Bay	AK
63377	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.5200000000000031	-156.051999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:51:00	0.299999999999999989	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
63378	Chowiet Island, Semidi Island, Alaska (sub)	NOS	9458519	56.0516999999999967	-156.698000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:25:00	\N	1.29000000000000004	00:15:00	\N	1.04000000000000004	\N	\N	Chowiet Island, Semidi Island	AK
63379	Unavikshak Island, Alaska	NOS	9458762	56.4917000000000016	-157.740000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	\N	1.23999999999999999	00:31:00	\N	1.05000000000000004	\N	\N	Unavikshak Island	AK
63380	Nakchamik Island, Alaska	NOS	9458779	56.351700000000001	-157.812000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:41:00	\N	1.33000000000000007	00:29:00	\N	1.04000000000000004	\N	\N	Nakchamik Island	AK
63381	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133000000000024	-157.983000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:46:00	\N	1.35000000000000009	00:31:00	\N	1.10000000000000009	\N	\N	Kujulik Bay (North Shore)	AK
63382	Chankliut Island, Alaska	NOS	9458849	56.1467000000000027	-158.106999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:43:00	\N	1.27000000000000002	00:32:00	\N	0.979999999999999982	\N	\N	Chankliut Island	AK
63383	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967000000000013	-158.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:44:00	\N	1.28000000000000003	00:34:00	\N	1.04000000000000004	\N	\N	Chignik, Anchorage Bay	AK
63384	Hump Island, Kuiukta Bay, Alaska (sub)	NOS	9458964	56.1133000000000024	-158.598000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:42:00	\N	1.22999999999999998	00:35:00	\N	0.910000000000000031	\N	\N	Hump Island, Kuiukta Bay	AK
63385	Mitrofania Island, Alaska (sub)	NOS	9459016	55.8900000000000006	-158.819999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:39:00	\N	1.22999999999999998	00:32:00	\N	0.880000000000000004	\N	\N	Mitrofania Island	AK
63386	Chiachi Island (east side), Alaska	NOS	9459085	55.8432999999999993	-159.10499999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	\N	1.28000000000000003	00:22:00	\N	0.890000000000000013	\N	\N	Chiachi Island (east side)	AK
63387	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.7899999999999991	-159.349999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:35:00	\N	1.28000000000000003	00:19:00	\N	0.890000000000000013	\N	\N	Kupreanof Harbor, Paul Island	AK
63388	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.783299999999997	-159.879999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:33:00	\N	1.18999999999999995	00:17:00	\N	0.859999999999999987	\N	\N	Dent Point, Stepovak Bay	AK
63389	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.1550000000000011	-159.995000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:03:00	\N	0.979999999999999982	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
63390	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.361699999999999	-160.360000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	0.979999999999999982	00:08:00	\N	1.03000000000000003	\N	\N	Pirate Cove, Popof Island	AK
63391	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.5900000000000034	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	1.05000000000000004	-00:02:00	\N	1.06000000000000005	\N	\N	Albatross Anchorage, Balboa Bay	AK
63392	Beaver Bay, Alaska	NOS	9459522	55.4733000000000018	-160.840000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:02:00	\N	1.05000000000000004	00:03:00	\N	1.01000000000000001	\N	\N	Beaver Bay	AK
63393	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365000000000002	-161.324999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:05:00	\N	1.05000000000000004	00:00:00	\N	0.979999999999999982	\N	\N	Seal Cape, Coal Bay	AK
63394	Ukolnoi Island, Alaska	NOS	9459696	55.2582999999999984	-161.537000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:00:00	\N	0.979999999999999982	00:07:00	\N	0.969999999999999973	\N	\N	Ukolnoi Island	AK
63395	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1182999999999979	-162.377999999999986	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:17:00	\N	0.979999999999999982	00:12:00	\N	0.979999999999999982	\N	\N	Lenard Harbor, Cold Bay	AK
63396	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933000000000035	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:08:00	\N	1.05000000000000004	-00:05:00	\N	0.82999999999999996	\N	\N	Peterson Bay	AK
63397	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4816999999999965	-162.812000000000012	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:03:00	\N	1.05000000000000004	00:14:00	\N	0.890000000000000013	\N	\N	Sanak Harbor	AK
63398	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6032999999999973	-178.61699999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:43:00	\N	0.949999999999999956	00:01:00	\N	0.949999999999999956	\N	\N	Ogliuga Island (east coast)	AK
63399	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717000000000013	-178.044999999999987	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:39:00	\N	1.1399999999999999	-00:56:00	\N	1.1399999999999999	\N	\N	Lash Bay	AK
63400	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7182999999999993	-177.997000000000014	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:32:00	\N	1.08000000000000007	-00:06:00	\N	1.08000000000000007	\N	\N	Tanaga Bay	AK
63401	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783000000000015	-177.800000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:12:00	\N	0.839999999999999969	-00:40:00	\N	0.839999999999999969	\N	\N	Hot Springs Bay	AK
63402	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.6649999999999991	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:54:00	\N	1.1100000000000001	-01:44:00	\N	1.1100000000000001	\N	\N	Cape Chunu	AK
63403	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7182999999999993	-177.199999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:44:00	\N	1.05000000000000004	-01:39:00	\N	1.05000000000000004	\N	\N	Kanaga Bay	AK
63404	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.7100000000000009	-177.14500000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-01:34:00	\N	0.92000000000000004	-01:22:00	\N	0.92000000000000004	\N	\N	Cape Chlanak	AK
63405	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.8699999999999974	-177.068000000000012	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:16:00	\N	0.859999999999999987	00:01:00	\N	0.859999999999999987	\N	\N	Shoal Point	AK
63406	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417000000000002	-176.824999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:04:00	\N	0.949999999999999956	-01:20:00	\N	0.949999999999999956	\N	\N	Bay of Waterfalls	AK
63408	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7132999999999967	-176.530000000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:09:00	\N	0.969999999999999973	-01:38:00	\N	0.969999999999999973	\N	\N	Boot Bay	AK
63409	Adak Bight, Adak Island, Alaska	NOS	9461406	51.7700000000000031	-176.435000000000002	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
63410	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.8250000000000028	-176.401999999999987	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:07:00	\N	0.969999999999999973	-00:04:00	\N	0.969999999999999973	\N	\N	Laska Cove, Kagalaska Island	AK
63411	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733000000000018	-176.085000000000008	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:20:00	\N	0.969999999999999973	-00:05:00	\N	0.969999999999999973	\N	\N	Sand Bay, Great Sitkin Island	AK
63412	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0382999999999996	-175.97999999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:05:00	\N	0.890000000000000013	00:01:00	\N	0.890000000000000013	\N	\N	Bugle Point, Great Sitkin Island	AK
63413	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.9600000000000009	-175.587999999999994	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:13:00	\N	0.890000000000000013	-00:04:00	\N	0.890000000000000013	\N	\N	Fenimore Pass	AK
63414	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067000000000021	-175.319999999999993	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:10:00	\N	1.23999999999999999	-01:07:00	\N	1.23999999999999999	\N	\N	Atka Pass, east end	AK
63415	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367000000000033	-175.115000000000009	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:04:00	\N	0.949999999999999956	00:11:00	\N	0.949999999999999956	\N	\N	Bechevin Bay	AK
63416	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733000000000033	-174.568000000000012	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:24:00	\N	1.23999999999999999	-02:43:00	\N	1.23999999999999999	\N	\N	Explorer Bay	AK
63417	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0266999999999982	-174.47999999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:25:00	\N	1.23999999999999999	-01:26:00	\N	1.23999999999999999	\N	\N	Sagchudak Island	AK
63418	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.226700000000001	-174.292000000000002	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:21:00	\N	0.869999999999999996	00:19:00	\N	0.869999999999999996	\N	\N	Martin Harbor, Korovin Bay	AK
63419	Cape Utalug (4 miles west of), Atka Island, Alaska	NOS	9461704	52.1182999999999979	-174.206999999999994	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-02:32:00	\N	1.18999999999999995	-01:38:00	\N	1.18999999999999995	\N	\N	Cape Utalug (4 miles west of)	AK
63420	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917000000000002	-172.405000000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	00:07:00	\N	0.869999999999999996	-01:00:00	\N	0.869999999999999996	\N	\N	Finch Cove, Seguam Island	AK
63421	North side, Yunaska Island, Alaska	NOS	9462144	52.6816999999999993	-170.706999999999994	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:29:00	\N	1.18999999999999995	-01:05:00	\N	1.02000000000000002	\N	\N	North side	AK
63422	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533000000000015	-170.562999999999988	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:35:00	\N	0.849999999999999978	-01:36:00	\N	0.880000000000000004	\N	\N	East Cove	AK
63423	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.861699999999999	-169.861999999999995	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:58:00	\N	1.27000000000000002	-00:21:00	\N	1.08000000000000007	\N	\N	Applegate Cove, Chuginadak Island	AK
63424	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117000000000033	-169.164999999999992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:56:00	\N	1.10000000000000009	-00:33:00	\N	1.02000000000000002	\N	\N	Adugak Island	AK
63425	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.841700000000003	-169.043000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:16:00	\N	1.02000000000000002	-03:03:00	\N	1.19999999999999996	\N	\N	Cape Sagak	AK
63426	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167000000000002	-168.835000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:43:00	\N	1.10000000000000009	-00:07:00	\N	0.989999999999999991	\N	\N	Okee Bay	AK
63427	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583000000000013	-168.719999999999999	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:22:00	\N	1.10000000000000009	-02:56:00	\N	1.35000000000000009	\N	\N	Driftwood Bay	AK
63428	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.0450000000000017	-168.442000000000007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:42:00	\N	1.27000000000000002	-03:04:00	\N	1.37000000000000011	\N	\N	Kigul Island	AK
63429	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967000000000013	-168.352000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:30:00	\N	0.930000000000000049	-00:06:00	\N	0.959999999999999964	\N	\N	Inanudak Bay	AK
63430	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.9299999999999997	-168.032999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:55:00	\N	1.10000000000000009	-00:30:00	\N	1.08000000000000007	\N	\N	Bogoslof Island	AK
63431	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967000000000027	-167.842999999999989	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:40:00	\N	0.930000000000000049	-00:27:00	\N	0.880000000000000004	\N	\N	Otter Point	AK
63432	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.3950000000000031	-167.532999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:29:00	\N	1.10000000000000009	-00:10:00	\N	1.02000000000000002	\N	\N	Chernofski Harbor	AK
63433	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.6099999999999994	-167.044999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:19:00	\N	1.10000000000000009	-00:07:00	\N	1.05000000000000004	\N	\N	Skan Bay	AK
63434	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617000000000004	-167.02000000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:35:00	\N	1.27000000000000002	-03:10:00	\N	1.45999999999999996	\N	\N	Kuliliak Bay	AK
63435	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.4750000000000014	-166.87299999999999	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:48:00	\N	1.27000000000000002	-03:16:00	\N	1.48999999999999999	\N	\N	Raven Bay	AK
63436	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783000000000001	-166.831999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:28:00	\N	1.10000000000000009	-00:01:00	\N	1.08000000000000007	\N	\N	Anderson Bay	AK
63437	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.5150000000000006	-166.789999999999992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:45:00	\N	1.18999999999999995	-03:30:00	\N	1.55000000000000004	\N	\N	Usof Bay	AK
63438	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7132999999999967	-166.572000000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:14:00	\N	1.10000000000000009	-02:59:00	\N	1.39999999999999991	\N	\N	Kisselen Bay, Beaver Inlet	AK
63439	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917000000000002	-166.537000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
63440	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.736699999999999	-166.294999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:59:00	\N	1.02000000000000002	-03:32:00	\N	1.37000000000000011	\N	\N	Udagak Strait	AK
63441	English Bay, Unalaska Island, Alaska	NOS	9462641	53.9249999999999972	-166.257000000000005	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:01:00	\N	0.760000000000000009	00:16:00	\N	0.790000000000000036	\N	\N	English Bay	AK
63442	Biorka Village, Biverly Inlet, Alaska (sub)	NOS	9462645	53.8289166666666716	-166.216250000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:25:00	\N	1.35000000000000009	-03:13:00	\N	1.35000000000000009	\N	\N	Udamat Bay, Sedanka Island	AK
63443	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.128300000000003	-165.807999999999993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:07:00	\N	1.10000000000000009	-00:17:00	\N	1.08000000000000007	\N	\N	Akutan Harbor, Akutan Island	AK
63444	Trident Bay, Akun Island, Aleutian Islands, Alaska (sub)	NOS	9462721	54.1400000000000006	-165.526999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-04:11:00	\N	0.760000000000000009	-03:59:00	\N	0.989999999999999991	\N	\N	Trident Bay, Akun Island	AK
63445	Cape Sarichef, Unimak Island, Alaska (sub)	NOS	9462787	54.6000000000000014	-164.927999999999997	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:56:00	\N	1.27000000000000002	-00:24:00	\N	1.37000000000000011	\N	\N	Cape Sarichef	AK
63446	Scotch Cap, Unimak Island, Alaska (sub)	NOS	9462808	54.3936388888888871	-164.745722222222213	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:49:00	\N	1.27000000000000002	-02:27:00	\N	1.39999999999999991	\N	\N	Scotch Cap	AK
63447	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283000000000001	-164.467000000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:19:00	\N	1.3600000000000001	00:26:00	\N	1.72999999999999998	\N	\N	Cape Mordvinof	AK
63448	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.009999999999998	-163.507000000000005	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:18:00	\N	1.3600000000000001	00:04:00	\N	1.22999999999999998	\N	\N	St. Catherine Cove	AK
63449	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.7100000000000009	-163.266999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:15:00	\N	1.05000000000000004	00:15:00	\N	0.869999999999999996	\N	\N	Dora Harbor	AK
63450	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4132999999999996	-163.115000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	01:48:00	\N	1.78000000000000003	01:47:00	\N	2.12999999999999989	\N	\N	Amak Island	AK
63451	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.2700000000000031	-162.900000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	04:05:00	\N	0.849999999999999978	03:03:00	\N	1.22999999999999998	\N	\N	Grant Point, Izembek Lagoon	AK
63452	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.466666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	00:08:00	\N	0.900000000000000022	00:09:00	\N	0.979999999999999982	\N	\N	Settlement Point, Pavlof Bay	AK
63453	Port Heiden, Bristol Bay, Alaska	NOS	9464096	56.9333000000000027	-158.728000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	02:05:00	\N	1.17999999999999994	01:43:00	\N	1.14999999999999991	\N	\N	Port Heiden	AK
63454	Village Cove, St. Paul Island, Bering Sea, Alaska (sub)	NOS	9464212	57.1253055555555633	-170.285166666666697	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:27:00	\N	1.06000000000000005	00:26:00	\N	0.930000000000000049	\N	\N	Village Cove, St. Paul Island	AK
63455	Egegik, Egegik River, Alaska	NOS	9464874	58.216700000000003	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	05:36:00	\N	0.359999999999999987	03:42:00	\N	1.19999999999999996	\N	\N	Egegik	AK
63456	Egegik River entrance, Alaska	NOS	9464881	58.2383000000000024	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	03:47:00	\N	1.1399999999999999	03:16:00	\N	1.68999999999999995	\N	\N	Egegik River Ent, Bristol Bay	AK
63457	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4532999999999987	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	04:10:00	\N	1.1399999999999999	03:56:00	\N	1.84000000000000008	\N	\N	Middle Bluff, Kvichak Bay	AK
63458	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.6717000000000013	-156.657000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	09:46:00	\N	0.0899999999999999967	05:43:00	\N	0.239999999999999991	\N	\N	King Salmon Airport	AK
63459	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.7066999999999979	-156.757000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	08:35:00	\N	0.140000000000000013	04:58:00	\N	0.689999999999999947	\N	\N	Omakstalia Point	AK
63460	Black Rock, Walrus Islands, Nushagak Bay, Alaska (sub)	NOS	9465182	58.7083000000000013	-160.187999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	04:53:00	\N	0.819999999999999951	04:53:00	\N	0.800000000000000044	\N	\N	Black Rock, Walrus Islands	AK
63461	Naknek River entrance, Alaska	NOS	9465183	58.7216999999999985	-157.056999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	05:26:00	\N	1	04:27:00	\N	2.14999999999999991	\N	\N	Naknek River Entrance, Kvichak B	AK
63462	Kvichak, Kvichak River, Alaska	NOS	9465342	58.9699999999999989	-156.947000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	07:49:00	\N	0.409999999999999976	05:21:00	\N	1.54000000000000004	\N	\N	Kvichak	AK
63463	Goodnews Bay entrance, Alaska	NOS	9465368	59.0450000000000017	-161.807999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61137	00:11:00	\N	0.949999999999999956	00:04:00	\N	1.01000000000000001	\N	\N	Goodnews Bay entrance	AK
63464	Snag Point, Dillingham, Alaska (sub)	NOS	9465374	59.0399999999999991	-158.447000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	00:54:00	\N	0.969999999999999973	00:28:00	\N	1.03000000000000003	\N	\N	Snag Point	AK
63465	Platinum, Alaska (sub)	NOS	9465396	59.0467000000000013	-161.818000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	05:41:00	\N	0.25	06:17:00	\N	0.380000000000000004	\N	\N	Platinum	AK
63466	Levelock, Kvichak River, Alaska	NOS	9465419	59.1133000000000024	-156.831999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61123	09:34:00	\N	0.23000000000000001	06:13:00	\N	0.900000000000000022	\N	\N	Levelock	AK
63467	Apokak Creek entrance, Alaska	NOS	9466079	60.1366999999999976	-162.157999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61137	04:30:00	\N	0.790000000000000036	03:18:00	\N	1.46999999999999997	\N	\N	Apokak Creek entrance	AK
63468	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.3582999999999998	-172.715000000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	00:50:00	\N	0.569999999999999951	00:22:00	\N	0.569999999999999951	\N	\N	St. Matthew Island	AK
63469	Bethel, Kuskokwim River, Alaska (sub)	NOS	9466477	60.7999999999999972	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61133	03:47:00	\N	0.160000000000000003	01:48:00	\N	0.149999999999999994	\N	\N	Bethel	AK
63470	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.2800000000000011	-162.602000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-01:13:00	\N	1.08000000000000007	-01:13:00	\N	1.08000000000000007	\N	\N	Pikmiktalik River entrance	AK
63471	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.466700000000003	-170.016999999999996	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	-03:08:00	\N	0.67000000000000004	-03:00:00	\N	1.12999999999999989	\N	\N	Fossil River entrance	AK
63472	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.4750000000000014	-162.026999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
63473	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.6199999999999974	-171.38300000000001	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	-03:31:00	\N	0.67000000000000004	-03:27:00	\N	0.82999999999999996	\N	\N	Niyrakpak Lagoon entrance	AK
63474	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.628300000000003	-162.516999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-00:28:00	\N	0.719999999999999973	-00:28:00	\N	0.719999999999999973	\N	\N	North Bay, Stuart Island	AK
63475	Point Spencer, Port Clarence, Norton Sound, Alaska (sub)	NOS	9469237	65.256699999999995	-166.847000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	05:26:00	\N	0.349999999999999978	05:15:00	\N	0.810000000000000053	\N	\N	Point Spencer, Port Clarence	AK
63476	Teller, Port Clarence, Alaska (sub)	NOS	9469239	65.2667000000000002	-166.353000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	04:13:00	\N	0.869999999999999996	04:01:00	\N	0.800000000000000044	\N	\N	Teller, Port Clarance	AK
63477	Lost River, Seward Peninsula, Alaska (sub)	NOS	9469338	65.3900000000000006	-167.14500000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	05:30:00	\N	0.28999999999999998	06:43:00	\N	0.709999999999999964	\N	\N	Lost River, Seward Peninsula	AK
63478	Tin City, Bering Sea, Alaska (sub)	NOS	9469439	65.5583333333333371	-167.974999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61156	06:14:00	\N	0.320000000000000007	07:30:00	\N	0.609999999999999987	\N	\N	Tin City	AK
63479	Point Barrow, Alaska	NOS	9495048	71.3599999999999994	-156.353000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:26:00	\N	0.0400000000000000008	-00:37:00	\N	0.0400000000000000008	\N	\N	Point Barrow	AK
63480	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3266999999999989	-64.8516999999999939	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61186	00:44:00	\N	1.28000000000000003	-00:46:00	\N	1.28000000000000003	\N	\N	Redhook Bay, St. Thomas Island	VI
63481	Mayagez, Puerto Rico (sub)	NOS	9759394	18.2188888888888911	-67.1624999999999943	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:11:00	\N	0.760000000000000009	-00:09:00	\N	0.930000000000000049	\N	\N	Mayaguez	PR
63482	Troy, Hudson River, New York	NOS	TEC1603	42.7166666666666686	-73.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60323	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
63483	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6000000000000014	-74.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60333	00:37:00	\N	1.05000000000000004	00:23:00	\N	1.07000000000000006	\N	\N	Chelsea	NJ
63484	Oregon Inlet, North Carolina	NOS	TEC2771	35.7666666666670068	-75.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60451	-00:27:00	\N	0.709999999999999964	-00:03:00	\N	1.97999999999999998	\N	\N	Oregon Inlet	NC
63485	Cape Hatteras, North Carolina	NOS	TEC2789	35.2333333333329932	-75.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:01:00	\N	1.08000000000000007	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
63486	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2000000000000028	-75.7333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:13:00	\N	0.82999999999999996	00:08:00	\N	0.660000000000000031	\N	\N	Hatteras Inlet	NC
63487	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.066666666667011	-76.0166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:11:00	\N	0.82999999999999996	00:09:00	\N	0.630000000000000004	\N	\N	Ocracoke Inlet	NC
63488	Shell Point, Harkers Island, North Carolina	NOS	TEC2801	34.683333333332989	-76.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	02:34:00	\N	0.82999999999999996	01:52:00	\N	0.540000000000000036	\N	\N	Shell Point, Harkers Island	NC
63489	N.C. State Fisheries, North Carolina	NOS	TEC2831	34.7166666666670096	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	01:32:00	\N	0.82999999999999996	01:05:00	\N	0.660000000000000031	\N	\N	N.C. State Fisheries	NC
63490	Bogue Inlet, North Carolina	NOS	TEC2837	34.6499999999999986	-77.0999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:15:00	\N	0.82999999999999996	00:13:00	\N	0.729999999999999982	\N	\N	Bogue Inlet	NC
63491	Cape Fear, North Carolina	NOS	TEC2847	33.8500000000000014	-77.9666666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60454	00:07:00	\N	1.33000000000000007	00:04:00	\N	1.46999999999999997	\N	\N	Cape Fear	NC
63492	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.3500000000000014	-77.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	02:54:00	\N	0.419999999999999984	02:44:00	\N	0.419999999999999984	\N	\N	Castle Hayne, Northeast River	NC
63493	Bannermans Branch, Northeast River, Cape Fear River, North Carolina	NOS	TEC2865	34.5833333333329946	-77.7666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60463	06:08:00	\N	0.309999999999999998	05:58:00	\N	0.320000000000000007	\N	\N	Bannermans Branch, Northeast River	NC
63494	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.9166666666670054	-78.2333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60470	00:15:00	\N	1	00:04:00	\N	0.839999999999999969	\N	\N	Lockwoods Folly Inlet	NC
63495	Winyah Bay Entrance (South Jetty), South Carolina	NOS	TEC2929	33.183333333332989	-79.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:24:00	\N	0.890000000000000013	-00:21:00	\N	0.869999999999999996	\N	\N	Winyah Bay Entrance (South Jetty)	SC
63496	Frazier Point, South Carolina	NOS	TEC2937	33.316666666667011	-79.2833333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	02:07:00	\N	0.680000000000000049	01:26:00	\N	0.660000000000000031	\N	\N	Frazier Point	SC
63497	North Santee River Inlet, South Carolina	NOS	TEC2991	33.1333333333329918	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:04:00	\N	0.839999999999999969	-00:09:00	\N	0.849999999999999978	\N	\N	North Santee River Inlet	SC
63498	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.1499999999999986	-79.3333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	01:31:00	\N	0.790000000000000036	00:27:00	\N	0.780000000000000027	\N	\N	Brown Island, South Santee River	SC
63499	Cape Romain, 46 miles east of, South Carolina	NOS	TEC3011	33.1000000000000014	-78.4333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-01:13:00	\N	0.790000000000000036	-01:05:00	\N	0.780000000000000027	\N	\N	Cape Romain, 46 miles east of	SC
63500	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.933333333332989	-79.5833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:15:00	\N	0.949999999999999956	-00:14:00	\N	0.949999999999999956	\N	\N	Jack Creek entrance	SC
63501	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.7666666666670068	-79.8333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:12:00	\N	1	-00:08:00	\N	0.989999999999999991	\N	\N	Sullivans Island (outer coast)	SC
63502	Shipyard Creek, 0.8 mile above entrance., South Carolina	NOS	TEC3061	32.8333333333329946	-79.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	00:20:00	\N	1	00:34:00	\N	1.01000000000000001	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
63503	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.6499999999999986	-79.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60489	-00:14:00	\N	1	-00:08:00	\N	0.979999999999999982	\N	\N	Folly Island (outer coast)	SC
63504	Euhaw Creek, 2.5 mi. above entrance, Broad River, South Carolina	NOS	TEC3327	32.4350000000000023	-80.8516666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:09:00	\N	0.910000000000000031	01:33:00	\N	1.1399999999999999	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
63505	Tybee Creek entrance, Georgia	NOS	TEC3399	31.9833333333329932	-80.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:05:00	\N	1	-00:09:00	\N	0.989999999999999991	\N	\N	Tybee Creek entrance	GA
63506	Beach Hammock, Georgia	NOS	TEC3401	31.9499999999999993	-80.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
63507	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.9333333333329925	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:03:00	\N	1.03000000000000003	00:08:00	\N	1.03000000000000003	\N	\N	Romerly Marsh Creek	GA
63508	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:06:00	\N	1.1399999999999999	00:14:00	\N	1.12999999999999989	\N	\N	Savannah Sheraton Resort Hotel	GA
63509	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.0333333333329904	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:12:00	\N	1.1399999999999999	00:32:00	\N	1.14999999999999991	\N	\N	Thunderbolt	GA
63510	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.066666666667011	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:44:00	\N	1.09000000000000008	00:40:00	\N	1.10000000000000009	\N	\N	North entrance	GA
63511	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.9833333333329932	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:28:00	\N	1.12999999999999989	00:50:00	\N	1.12999999999999989	\N	\N	Isle of Hope, Skidaway River	GA
63512	Egg Islands, Georgia	NOS	TEC3413	31.8333333333329911	-81.0833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:10:00	\N	1.04000000000000004	00:04:00	\N	1.04000000000000004	\N	\N	Egg Islands	GA
63513	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.9333333333329925	-81.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09000000000000008	01:05:00	\N	1.09000000000000008	\N	\N	Coffee Bluff, Forest River	GA
63514	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.8833333333329918	-81.2166666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
63515	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.9833333333329932	-81.2833333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	04:25:00	\N	0.140000000000000013	03:19:00	\N	0.149999999999999994	\N	\N	Highway bridge, Ogeechee River	GA
63516	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.8166666666670075	-81.1666666666670125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	0.949999999999999956	00:46:00	\N	1.09000000000000008	\N	\N	Florida Passage, Bear River	GA
63517	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.8166666666670075	-81.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:43:00	\N	1.05000000000000004	00:55:00	\N	1.05000000000000004	\N	\N	Cane Patch Creek entrance	GA
63518	North Newport River, Georgia	NOS	TEC3445	31.6666666666670089	-81.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:36:00	\N	1.09000000000000008	00:56:00	\N	1.10000000000000009	\N	\N	North Newport River	GA
63519	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.6666666666670089	-81.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:54:00	\N	1.04000000000000004	01:01:00	\N	1.08000000000000007	\N	\N	South Newport Cut, N. Newport River	GA
63520	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.5833333333329911	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	01:04:00	\N	1.09000000000000008	00:48:00	\N	1.10000000000000009	\N	\N	Dallas Bluff, Julienton River	GA
63521	Blackbeard Island, Georgia	NOS	TEC3463	31.5333333333329904	-81.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
63522	Wolf Island, south end, Georgia	NOS	TEC3491	31.3333333333329911	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:45:00	\N	1.09000000000000008	00:25:00	\N	0.969999999999999973	\N	\N	Wolf Island, south end	GA
63523	Hampton River entrance, Georgia	NOS	TEC3495	31.2166666666670096	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:04:00	\N	0.949999999999999956	00:16:00	\N	0.959999999999999964	\N	\N	Hampton River entrance	GA
63524	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3000000000000007	-81.3333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:13:00	\N	1.05000000000000004	01:03:00	\N	1.05000000000000004	\N	\N	Jones Creek entrance, Hampton River	GA
63525	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1000000000000014	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	-00:02:00	\N	0.949999999999999956	-00:01:00	\N	0.949999999999999956	\N	\N	St. Simons Sound Bar	GA
63526	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.1833333333329925	-81.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:42:00	\N	1.09000000000000008	01:03:00	\N	1.10000000000000009	\N	\N	Allied Chemical Corp. docks	GA
63527	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.1499999999999986	-81.5666666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60496	00:49:00	\N	1.09000000000000008	01:07:00	\N	1.10000000000000009	\N	\N	Highway bridge, South Brunswick River	GA
63528	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.1666666666670089	-81.6166666666670011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	01:31:00	\N	1.22999999999999998	01:09:00	\N	1.22999999999999998	\N	\N	Below Spring Bluff	GA
63529	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.9499999999999993	-81.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60519	05:05:00	\N	0.530000000000000027	03:55:00	\N	0.530000000000000027	\N	\N	Burnt Fort	GA
63530	Cape Canaveral, Florida	NOS	TEC3693	28.4333333333329925	-80.5666666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	-00:44:00	\N	1.41999999999999993	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
63531	Jupiter Inlet, U.S. Highway 1 Bridge, Florida	NOS	TEC3783	26.9483333333329931	-80.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:05:00	\N	1.1399999999999999	00:28:00	\N	0.859999999999999987	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
63532	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.9499999999999993	-80.1016666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:58:00	\N	1.1399999999999999	00:59:00	\N	0.800000000000000044	\N	\N	Tequesta	FL
63533	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.9516666666670091	-80.1016666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60580	01:42:00	\N	0.92000000000000004	00:51:00	\N	0.780000000000000027	\N	\N	Tequesta, North Fork entrance	FL
63534	Cape Sable, East Cape, Florida	NOS	TEC4165	25.1166666666670082	-81.0833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:50:00	\N	0.979999999999999982	01:33:00	\N	1.30000000000000004	\N	\N	Cape Sable, East Cape	FL
63535	Whitewater Bay, Florida	NOS	TEC4169	25.3166666666670075	-81.0333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	04:38:00	\N	0.330000000000000016	03:53:00	\N	0.260000000000000009	\N	\N	Whitewater Bay	FL
63536	Indian Key, Florida	NOS	TEC4183	25.8000000000000007	-81.4666666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:19:00	\N	0.979999999999999982	00:55:00	\N	1.47999999999999998	\N	\N	Indian Key	FL
63537	Round Key, Florida	NOS	TEC4185	25.8333333333329911	-81.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60603	01:12:00	\N	0.979999999999999982	00:54:00	\N	1.47999999999999998	\N	\N	Round Key	FL
63538	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.4499999999999993	-82.0166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:12:00	\N	1.20999999999999996	-01:50:00	\N	1.20999999999999996	\N	\N	Point Ybel, San Carlos Bay entrance	FL
63539	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.6833333333329925	-82.7333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60624	-01:30:00	\N	0.869999999999999996	-01:34:00	\N	0.869999999999999996	\N	\N	Pass-a-Grille Beach	FL
63540	Suwannee River entrance, Florida	NOS	TEC4299	29.2833333333329904	-83.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:18:00	\N	0.949999999999999956	00:06:00	\N	0.880000000000000004	\N	\N	Suwannee River entrance	FL
63541	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.3666666666670011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60645	00:24:00	\N	0.949999999999999956	00:12:00	\N	0.880000000000000004	\N	\N	Pepperfish Keys	FL
63542	Fishermans Rest, Florida	NOS	TEC4305	29.7333333333329932	-83.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	-00:02:00	\N	0.859999999999999987	-00:14:00	\N	0.930000000000000049	\N	\N	Fishermans Rest	FL
63543	Rock Islands, Florida	NOS	TEC4309	29.9666666666670096	-83.8333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60648	00:04:00	\N	0.910000000000000031	-00:03:00	\N	0.930000000000000049	\N	\N	Rock Islands	FL
63544	Lower Anchorage, Apalachicola Bay, Florida	NOS	TEC4343	29.6000000000000014	-85.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60659	-00:35:00	\N	1	-00:17:00	\N	0.930000000000000049	\N	\N	Lower Anchorage	FL
63545	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.6166666666670082	-87.0333333333329904	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60682	01:47:00	\N	1.19999999999999996	01:40:00	\N	1.19999999999999996	\N	\N	Milton, Blackwater River	FL
63546	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.9333333333329961	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	05:58:00	\N	1.04000000000000004	05:53:00	\N	1.04000000000000004	\N	\N	Paris Road Bridge (ICWW)	LA
63547	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.2666666666670068	-89.9666666666670096	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60744	00:46:00	\N	0.939999999999999947	01:32:00	\N	0.939999999999999947	\N	\N	Bayou Rigaud, Grand Isle	LA
63548	Mermentau River entrance, Louisiana	NOS	TEC4495	29.75	-93.0999999999999943	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-00:59:00	\N	1.79000000000000004	-01:54:00	\N	1.79000000000000004	\N	\N	Mermentau River entrance	LA
63549	Galveston Bay entrance, south jetty, Texas	NOS	TEC4507	29.3333333333329911	-94.7000000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	-01:05:00	\N	1.42999999999999994	-00:39:00	\N	1.42999999999999994	\N	\N	Galveston Bay entrance, south jetty	TX
63550	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.3833333333329918	-94.8833333333329989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
63551	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.5166666666670068	-94.4833333333329932	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60789	04:18:00	\N	0.859999999999999987	03:16:00	\N	0.859999999999999987	\N	\N	Gilchrist, East Bay	TX
63552	Guanica, Puerto Rico	NOS	TEC4731	17.9666666666670096	-66.9166666666670125	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	00:18:00	\N	1	-01:22:00	\N	1	\N	\N	Guanica	PR
63553	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.9666666666670096	-66.6166666666670011	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	-00:13:00	\N	1.1399999999999999	-00:39:00	\N	1.1399999999999999	\N	\N	Playa de Ponce	PR
63554	Playa Cortada, Puerto Rico	NOS	TEC4735	17.9833333333329932	-66.4500000000000028	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	-00:37:00	\N	1.1399999999999999	00:16:00	\N	1.1399999999999999	\N	\N	Playa Cortada	PR
63555	Arroyo, Puerto Rico	NOS	TEC4737	17.9666666666670096	-66.0666666666670039	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	00:13:00	\N	1.1399999999999999	00:52:00	\N	1.1399999999999999	\N	\N	Arroyo	PR
63556	Puerto Maunabo, Puerto Rico	NOS	TEC4739	18	-65.8833333333329989	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	01:13:00	\N	1	-00:56:00	\N	1	\N	\N	Puerto Maunabo	PR
63557	Culebrita, Isla, Puerto Rico	NOS	TEC4741	18.3166666666670075	-65.2333333333329932	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	02:40:00	\N	1.57000000000000006	-02:34:00	\N	1.57000000000000006	\N	\N	Culebrita, Isla	PR
63558	Puerto Ferro, Isla de Vieques, Puerto Rico	NOS	TEC4743	18.1000000000000014	-65.4333333333329961	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61201	03:01:00	\N	1.1399999999999999	-02:26:00	\N	1.1399999999999999	\N	\N	Puerto Ferro, Isla de Vieques	PR
63559	Punta Mulas, Isla de Vieques, Puerto Rico	NOS	TEC4745	18.1499999999999986	-65.4333333333329961	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:17:00	\N	0.719999999999999973	-00:14:00	\N	0.719999999999999973	\N	\N	Punta Mulas, Isla de Vieques	PR
63560	Roosevelt Roads, Puerto Rico	NOS	TEC4747	18.2333333333329932	-65.6166666666670011	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	00:20:00	\N	0.630000000000000004	00:02:00	\N	0.630000000000000004	\N	\N	Roosevelt Roads	PR
63561	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3000000000000007	-65.2833333333329904	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:15:00	\N	0.630000000000000004	-00:34:00	\N	0.630000000000000004	\N	\N	Ensenada Honda, Culebra Island	PR
63562	Playa de Fajardo, Puerto Rico	NOS	TEC4751	18.3333333333329911	-65.6333333333329989	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61196	-00:13:00	\N	0.989999999999999991	-00:10:00	\N	0.989999999999999991	\N	\N	Playa de Fajardo	PR
63563	Magens Bay, St. Thomas, Virgin Islands	NOS	TEC4759	18.3666666666670082	-64.9166666666670125	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61186	-00:17:00	\N	1.59000000000000008	-00:06:00	\N	1.59000000000000008	\N	\N	Magens Bay, St. Thomas Island	VI
63564	Pagan Island, Marianas	NOS	TPT2621	18.1332999999999984	145.766660000000002	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	00:01:00	\N	0.939999999999999947	00:05:00	\N	0.939999999999999947	\N	\N	Pagan Island	MP
63565	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.1999999999999993	145.716666666670079	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	00:07:00	\N	0.800000000000000044	00:02:00	\N	0.800000000000000044	\N	\N	Saipan Harbor, Saipan Island	MP
63566	Tinian Island, Marianas	NOS	TPT2625	14.9666666666670078	145.616666666670085	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:23:00	\N	0.330000000000000016	-00:02:00	\N	0.739999999999999991	\N	\N	Tinian Island	MP
63567	Rota Island, Marianas	NOS	TPT2627	14.1333000000000002	145.133299999999991	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:06:00	\N	0.939999999999999947	-00:03:00	\N	0.939999999999999947	\N	\N	Rota Island	MP
63568	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.449999999999989	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60147	-00:13:00	\N	1.33000000000000007	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
63569	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.63333333333330444	149.416666666670068	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:43:00	\N	0.739999999999999991	-00:53:00	\N	0.739999999999999991	\N	\N	Pulap Atoll	FM
63570	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.58333333333329662	149.650000000000006	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:21:00	\N	0.689999999999999947	-01:23:00	\N	0.689999999999999947	\N	\N	Namonuito Atoll	FM
63571	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.44999999999999929	151.783333333329921	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:20:00	\N	0.800000000000000044	-00:08:00	\N	0.800000000000000044	\N	\N	Nomwin Atoll, Hall Islands	FM
63572	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.59999999999999964	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:00:00	\N	0.849999999999999978	-00:28:00	\N	0.849999999999999978	\N	\N	Murilo Atoll, Hall Islands	FM
63573	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45000000000000018	151.849999999999994	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:11:00	\N	0.849999999999999978	00:10:00	\N	0.849999999999999978	\N	\N	Moen Island, Truk Islands	FM
63574	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.36666666666670444	151.883333333329915	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:30:00	\N	1.07000000000000006	00:02:00	\N	1.07000000000000006	\N	\N	Dublon Island, Truk Islands	FM
63575	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.90000000000000036	152.733333333329909	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:25:00	\N	0.800000000000000044	-00:03:00	\N	0.800000000000000044	\N	\N	Losap Atoll	FM
63576	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.90000000000000036	153.133333333329915	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:27:00	\N	0.800000000000000044	-00:01:00	\N	0.800000000000000044	\N	\N	Namoluk Atoll	FM
63577	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.33333333333330373	153.733333333329909	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60152	00:25:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Satawan Anchorage, Nomoi Islands	FM
63578	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.5999999999999996	165.550000000000011	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
63579	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.333333333329932	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:16:00	\N	0.849999999999999978	-00:15:00	\N	0.849999999999999978	\N	\N	Eniirikku Island, Bikini Atoll	MH
63580	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.1500000000000004	166.900000000000006	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:07:00	\N	0.959999999999999964	-00:07:00	\N	0.959999999999999964	\N	\N	Rongelap Island, Rongelap Atoll	MH
63581	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.3833333333330078	167.516666666670091	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:15:00	0	\N	-00:14:00	0.100000000000000006	\N	\N	\N	Rongerik Atoll	MH
63582	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.03333333333329591	165.599999999999994	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
63583	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.40000000000000036	167.483333333329909	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
63584	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.28333333333330391	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	00:07:00	0.299999999999999989	\N	00:08:00	0.400000000000000022	\N	\N	\N	Ailinglapalap Atoll	MH
63585	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.91666666666669627	169.650000000000006	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:08:00	-0.100000000000000006	\N	-00:12:00	-0.100000000000000006	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
63586	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.59999999999999964	168.683333333329927	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0.100000000000000006	\N	-00:10:00	0.100000000000000006	\N	\N	\N	Ebon (Boston) Atoll	MH
63587	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.5666666666670075	168.949999999999989	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
63588	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.133333333329915	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
63589	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.2166666666670078	169.983333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
63590	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.81666666666670373	169.316666666670073	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:01:00	0	\N	00:00:00	0.100000000000000006	\N	\N	\N	Likiep Atoll	MH
63591	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.46666666666670409	170.233333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:11:00	-0.200000000000000011	\N	-00:11:00	-0.200000000000000011	\N	\N	\N	Wotje Atoll	MH
63592	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.19999999999999929	169.916666666670068	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
63593	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.71666666666670409	171.233333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.100000000000000006	\N	\N	\N	Maloelap Atoll	MH
63594	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.11666666666670444	171.366666666670085	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:06:00	0.100000000000000006	\N	-00:05:00	0.299999999999999989	\N	\N	\N	Majuro Atoll	MH
63595	Arno Atoll, Marshall Islands	NOS	TPT2723	7.13333333333330444	171.699999999999989	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.599999999999999978	\N	\N	\N	Arno Atoll	MH
63596	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.23333333333329609	171.800000000000011	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60151	00:04:00	0	\N	00:04:00	0.699999999999999956	\N	\N	\N	Port Rhin, Mili Atoll	MH
63597	Howland Island	NOS	TPT2737	0.800000000000000044	-176.633333333329915	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	03:46:00	0.400000000000000022	\N	03:48:00	4.20000000000000018	\N	\N	\N	Howland Island	\N
63598	Palmyra Island	NOS	TPT2739	5.88333333333330444	-162.083333333329932	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	01:13:00	-0.200000000000000011	\N	01:19:00	0.599999999999999978	\N	\N	\N	Palmyra Island	\N
63599	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.849999999999994	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	-00:04:00	\N	1	-00:22:00	\N	1.12999999999999989	\N	\N	Waikane, Kaneohe Bay	HI
63600	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.6499999999999986	-157.933333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60140	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
63601	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.7833333333329904	-156.466666666670079	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:19:00	\N	0.540000000000000036	01:52:00	\N	0.939999999999999947	\N	\N	Kihei, Maalaea Bay	HI
63602	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.8833333333329918	-156.683333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60142	01:01:00	\N	0.810000000000000053	01:18:00	\N	0.890000000000000013	\N	\N	Lahaina	HI
63603	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.5166666666670068	-156.683333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60137	00:03:00	0	\N	-00:15:00	0.200000000000000011	\N	\N	\N	Smuggler Cove	HI
63604	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.2166666666666703	-169.533333333333303	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60150	-00:24:00	\N	1	-00:25:00	\N	1.42999999999999994	\N	\N	Tau Island, Manua Islands	AS
63605	Point Loma, California	NOS	TWC0405	32.6666666666670054	-117.233333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:02:00	\N	0.92000000000000004	-00:09:00	\N	0.92000000000000004	\N	\N	Point Loma	CA
63606	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.7666666666670068	-117.233333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	00:04:00	\N	0.949999999999999956	00:05:00	\N	0.949999999999999956	\N	\N	Quivira Basin, Mission Bay	CA
63607	San Clemente, California	NOS	TWC0419	33.4166666666670054	-117.616666666669957	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60824	-00:11:00	\N	0.92000000000000004	-00:15:00	\N	0.92000000000000004	\N	\N	San Clemente	CA
63608	Los Patos (highway bridge), California	NOS	TWC0427	33.7166666666670096	-118.049999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	01:12:00	\N	0.599999999999999978	01:00:00	\N	0.82999999999999996	\N	\N	Los Patos (highway bridge)	CA
63609	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.266666666669948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:02:00	0	\N	00:04:00	-0.100000000000000006	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
63610	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1000000000000014	-119.099999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:11:00	\N	0.959999999999999964	00:03:00	\N	0.959999999999999964	\N	\N	Mugu Lagoon (ocean pier)	CA
63611	Santa Barbara Island, California	NOS	TWC0463	33.4833333333329932	-119.033333333330049	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60828	00:04:00	\N	0.92000000000000004	-00:02:00	\N	0.92000000000000004	\N	\N	Santa Barbara Island	CA
63612	Point Arguello, California	NOS	TWC0473	34.5833333333329946	-120.650000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60835	-00:08:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Point Arguello	CA
63613	San Francisco Bar, California	NOS	TWC0509	37.7666666666670068	-122.633333333330043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	-00:31:00	0	\N	-00:35:00	-0.200000000000000011	\N	\N	\N	San Francisco Bar	CA
63614	Roberts Landing, 1.3 miles west of, San Francisco Bay, California	NOS	TWC0547	37.6666666666670054	-122.200000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:28:00	0.100000000000000006	\N	00:52:00	1.39999999999999991	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
63615	Redwood Creek entrance (inside), San Francisco Bay, California	NOS	TWC0573	37.5166666666670068	-122.200000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	01:38:00	0.100000000000000006	\N	01:06:00	2.10000000000000009	\N	\N	\N	Redwood Creek entrance (inside)	CA
63616	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2000000000000028	-122.566666666669946	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60843	02:50:00	\N	0.810000000000000053	01:59:00	\N	1.1100000000000001	\N	\N	Lakeville, Petaluma River	CA
63617	Point Arena, California	NOS	TWC0771	38.9500000000000028	-123.733333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:01:00	\N	0.949999999999999956	00:03:00	\N	0.979999999999999982	\N	\N	Point Arena	CA
63618	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.2999999999999972	-123.799999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60883	00:01:00	\N	0.949999999999999956	00:07:00	\N	0.979999999999999982	\N	\N	Mendocino, Mendocino Bay	CA
63619	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.433333333332989	-124.416666666669954	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	00:16:00	\N	0.92000000000000004	00:09:00	\N	0.949999999999999956	\N	\N	Wedderburn, Rogue River	OR
63620	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.7333333333329932	-124.116666666669957	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60896	01:09:00	\N	0.800000000000000044	00:56:00	\N	0.880000000000000004	\N	\N	Gardiner	OR
63621	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.1666666666670054	-123.966666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:12:00	\N	0.92000000000000004	00:55:00	\N	1.10000000000000009	\N	\N	Nestucca Bay entrance	OR
63622	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.5499999999999972	-123.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	01:26:00	\N	0.92000000000000004	01:15:00	\N	1.06000000000000005	\N	\N	Miami Cove	OR
63623	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.5166666666670068	-123.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60891	02:00:00	\N	0.82999999999999996	01:33:00	\N	1.02000000000000002	\N	\N	Bay City	OR
63624	Point Adams, Oregon	NOS	TWC0881	46.2000000000000028	-123.950000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:38:00	0.100000000000000006	\N	-00:25:00	-0.200000000000000011	\N	\N	\N	Point Adams, Oreg.	OR
63625	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.1666666666670054	-123.916666666669954	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	-00:19:00	0.100000000000000006	\N	-00:13:00	-0.100000000000000006	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
63626	Harrington Point, Washington	NOS	TWC0895	46.2666666666670068	-123.650000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60913	00:52:00	-0.200000000000000011	\N	00:21:00	-0.800000000000000044	\N	\N	\N	Harrington Point, Wash.	WA
63627	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.3699999999999974	-124.004999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:14:00	\N	1.05000000000000004	00:45:00	\N	1.05000000000000004	\N	\N	Tarlatt Slough	WA
63628	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.6883333333329915	-123.816666666669946	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	00:11:00	\N	1.02000000000000002	00:18:00	\N	1.07000000000000006	\N	\N	Mailboat Slough, Willapa River	WA
63629	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.9683333333329927	-123.599999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	01:45:00	\N	0.939999999999999947	01:34:00	\N	0.939999999999999947	\N	\N	Montesano, Chehalis River	WA
63630	Destruction Island, Washington	NOS	TWC0965	47.6666666666670054	-124.483333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60931	-00:43:00	\N	1.02000000000000002	-00:37:00	\N	0.979999999999999982	\N	\N	Destruction Island	WA
63631	Burns Point, Totten Inlet, Puget Sound, Washington	NOS	TWC1113	47.1216666666670108	-123.056666666669955	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	01:07:00	\N	1.06000000000000005	00:54:00	\N	1.33000000000000007	\N	\N	Burns Point, Totten Inlet	WA
63632	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.0816666666670045	-123.004999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:56:00	\N	1.10000000000000009	00:39:00	\N	1.31000000000000005	\N	\N	Rocky Point, Eld Inlet	WA
63633	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.0450000000000017	-122.211666666669956	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	00:29:00	\N	0.890000000000000013	00:09:00	\N	0.949999999999999956	\N	\N	Marysville, Quilceda Creek	WA
63634	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.2166666666666686	-122.366666666666703	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60951	02:14:00	\N	0.28999999999999998	00:23:00	\N	0.619999999999999996	\N	\N	Stanwood, Stillaguamish River	WA
63635	Peavine Pass, Washington	NOS	TWC1165	48.6000000000000014	-122.799999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:18:00	\N	0.92000000000000004	00:34:00	\N	0.979999999999999982	\N	\N	Peavine Pass	WA
63636	Chuckanut Bay, Bellingham Bay, Washington	NOS	TWC1169	48.6666666666670054	-122.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:53:00	-0.100000000000000006	\N	00:33:00	0	\N	\N	\N	Chuckanut Bay	WA
63637	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.716666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	00:51:00	0	\N	00:56:00	0.100000000000000006	\N	\N	\N	Point Migley	WA
63638	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.8333333333329946	-122.716666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	60941	01:20:00	0	\N	00:49:00	0.5	\N	\N	\N	Ferndale	WA
63639	Tah Bay, Alaska	NOS	TWC1487	54.8333333333329946	-132.333333333329932	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:03:00	0.100000000000000006	\N	-00:04:00	2.60000000000000009	\N	\N	\N	Tah Bay	AK
63640	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.0166666666670068	-132.783333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:05:00	0	\N	-00:13:00	2.79999999999999982	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
63641	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.9166666666670054	-133.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:12:00	0	\N	-00:16:00	1.10000000000000009	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
63642	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.466666666670079	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:15:00	-0.100000000000000006	\N	-00:19:00	0.800000000000000044	\N	\N	\N	Marble Island	AK
63643	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.066666666667011	-134.116666666670085	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	-00:07:00	-0.100000000000000006	\N	-00:11:00	0.599999999999999978	\N	\N	\N	Port McArthur, Kuiu Island	AK
63644	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.6666666666670054	-132.633333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:09:00	-0.200000000000000011	\N	\N	\N	Ideal Cove, Mitkof Island	AK
63645	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.8833333333329918	-132.800000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:10:00	-0.100000000000000006	\N	-00:14:00	-0.299999999999999989	\N	\N	\N	Brown Cove	AK
63646	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.316666666670073	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:15:00	0	\N	-00:19:00	-0.699999999999999956	\N	\N	\N	Portage Bay, Kupreanof Island	AK
63647	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.1666666666670054	-134.283333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:19:00	-0.100000000000000006	\N	-00:19:00	-1.89999999999999991	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
63648	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.2999999999999972	-133.466666666670079	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:17:00	-0.100000000000000006	\N	-00:21:00	-0.800000000000000044	\N	\N	\N	Port Houghton, Robert Islands	AK
63649	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.8666666666670082	-134.266666666670091	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:18:00	0	\N	00:14:00	-0.200000000000000011	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
63650	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.9666666666670096	-133.883333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:06:00	-0.100000000000000006	\N	-00:12:00	-0.400000000000000022	\N	\N	\N	Port Snettisham, Point Styleman	AK
63651	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.316666666667011	-134.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:05:00	-0.100000000000000006	\N	-00:01:00	-0.299999999999999989	\N	\N	\N	Fritz Cove, Douglas Island	AK
63652	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.4166666666670054	-134.133333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61015	00:11:00	0.100000000000000006	\N	00:04:00	1.80000000000000004	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
63653	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.2333333333329932	-134.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:15:00	0.299999999999999989	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
63654	Point Thatcher, Alaska	NOS	TWC1735	57.4166666666670054	-134.849999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:11:00	0.200000000000000011	\N	-00:15:00	-1.89999999999999991	\N	\N	\N	Point Thatcher	AK
63655	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.4833333333329932	-134.550000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:15:00	0.299999999999999989	\N	00:11:00	-2.79999999999999982	\N	\N	\N	Favorite Bay	AK
63656	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.5333333333329904	-134.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	01:31:00	\N	0.619999999999999996	01:22:00	\N	0.67000000000000004	\N	\N	Mitchell Bay	AK
63657	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.8500000000000014	-135.016666666670091	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	00:00:00	0.299999999999999989	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
63658	Point Elizabeth, Alaska	NOS	TWC1783	57.5166666666670068	-135.283333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-1.60000000000000009	\N	\N	\N	Point Elizabeth	AK
63659	Lindenburg Head, Alaska	NOS	TWC1785	57.4500000000000028	-135.033333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-1.80000000000000004	\N	\N	\N	Lindenburg Head	AK
63660	Fairway Island, Alaska	NOS	TWC1787	57.4500000000000028	-134.883333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61023	-00:05:00	0	\N	-00:15:00	-2.10000000000000009	\N	\N	\N	Fairway Island	AK
63661	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.5499999999999972	-135.933333333329927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61031	-00:07:00	\N	1.10000000000000009	-00:05:00	\N	0.959999999999999964	\N	\N	Falcon Arm, Slocum Arm	AK
63662	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.0499999999999972	-144.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61033	00:08:00	\N	1.01000000000000001	00:05:00	\N	0.989999999999999991	\N	\N	Wingham Island, Controller Bay	AK
63663	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.3833333333329918	-145.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:38:00	0	\N	00:06:00	-2.39999999999999991	\N	\N	\N	Pete Dahl Slough	AK
63664	Eyak River entrance, Alaska	NOS	TWC1869	60.4666666666670096	-145.666666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:58:00	-0.100000000000000006	\N	00:14:00	-1.60000000000000009	\N	\N	\N	Eyak River entrance	AK
63665	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.4666666666670096	-145.966666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:31:00	0	\N	00:01:00	-0.100000000000000006	\N	\N	\N	Gravel Point	AK
63666	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.5833333333329946	-145.716666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	0	\N	00:01:00	-0.200000000000000011	\N	\N	\N	Orca	AK
63667	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.566666666667011	-145.966666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
63668	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.3333333333329946	-146.550000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	00:01:00	-0.200000000000000011	\N	-00:09:00	-1.30000000000000004	\N	\N	\N	Port Etches	AK
63669	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.9500000000000028	-147.683333333329927	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:05:00	-0.100000000000000006	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
63670	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.5333333333329904	-147.316666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:04:00	-0.100000000000000006	\N	-00:05:00	-0.800000000000000044	\N	\N	\N	Smith Island	AK
63671	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.7333333333329932	-146.650000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61034	-00:06:00	0	\N	-00:07:00	-0.599999999999999978	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
63672	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.0166666666670068	-151.716666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:54:00	0.200000000000000011	\N	00:41:00	1.19999999999999996	\N	\N	\N	Cape Ninilchik	AK
63673	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.5499999999999972	-151.283333333329921	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:18:00	0.5	\N	01:52:00	2.70000000000000018	\N	\N	\N	Kenai River entrance	AK
63674	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.7166666666670096	-151.416666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
63675	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.6166666666670082	-153.583333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:16:00	\N	0.819999999999999951	00:12:00	\N	0.800000000000000044	\N	\N	Iliamna Bay	AK
63676	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.2333333333329932	-151.866666666670085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:07:00	0	\N	00:18:00	0.900000000000000022	\N	\N	\N	Marmot Island, Marmot Strait	AK
63677	Izhut Bay, Alaska	NOS	TWC2023	58.2166666666670096	-152.316666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:21:00	0	\N	00:12:00	0.100000000000000006	\N	\N	\N	Izhut Bay	AK
63678	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.1333333333329918	-152.566666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:06:00	0.200000000000000011	\N	00:04:00	0.599999999999999978	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
63679	Kizhuyak Point, Alaska	NOS	TWC2031	57.8999999999999986	-152.650000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:09:00	0.100000000000000006	\N	00:05:00	0.599999999999999978	\N	\N	\N	Kizhuyak Point	AK
63680	Three Saints Bay, Alaska	NOS	TWC2047	57.1166666666670082	-153.516666666670091	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:13:00	0.100000000000000006	\N	-00:22:00	-0.200000000000000011	\N	\N	\N	Three Saints Bay	AK
63681	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.133333333329915	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:07:00	0.200000000000000011	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
63682	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.7833333333329904	-153.550000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:02:00	\N	0.800000000000000044	-00:15:00	\N	0.800000000000000044	\N	\N	Village Islands	AK
63683	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.7333333333329932	-153.333333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	\N	0.770000000000000018	-00:12:00	\N	0.770000000000000018	\N	\N	Northeast Arm	AK
63684	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.7999999999999972	-153.300000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:02:00	\N	0.810000000000000053	-00:07:00	\N	0.810000000000000053	\N	\N	Uganik Passage	AK
63685	Viekoda Bay, Alaska	NOS	TWC2073	57.8999999999999986	-153.166666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:03:00	\N	0.800000000000000044	-00:11:00	\N	0.800000000000000044	\N	\N	Viekoda Bay	AK
63686	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.0499999999999972	-153.233333333329909	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	-00:01:00	\N	0.800000000000000044	00:00:00	\N	0.800000000000000044	\N	\N	Onion Bay	AK
63687	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.9500000000000028	-153.033333333329921	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:13:00	\N	0.770000000000000018	00:02:00	\N	0.770000000000000018	\N	\N	Dry Spruce Island	AK
63688	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.183333333332989	-152.949999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:00:00	\N	0.810000000000000053	-00:14:00	\N	0.810000000000000053	\N	\N	Malina Bay, Shelikof Strait	AK
63689	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.983333333329909	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61055	00:01:00	\N	0.709999999999999964	-00:14:00	\N	0.709999999999999964	\N	\N	Katmai Bay, Shelikof Strait	AK
63690	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.433333333332989	-156.300000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:32:00	0.200000000000000011	\N	00:21:00	3.20000000000000018	\N	\N	\N	Lees Cabins, Wide Bay	AK
63691	Three Star Point, Alaska	NOS	TWC2105	55.8999999999999986	-159.166666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:37:00	\N	1.28000000000000003	00:28:00	\N	0.900000000000000022	\N	\N	Three Star Point	AK
63692	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.6333333333329918	-159.616666666670085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	00:33:00	\N	1.18999999999999995	00:18:00	\N	0.859999999999999987	\N	\N	Fox Bay, Kupreanof Peninsula	AK
63693	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.1333333333329918	-159.849999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61096	-00:01:00	\N	0.900000000000000022	00:01:00	\N	0.969999999999999973	\N	\N	Mist Harbor, Nagai Island	AK
63694	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.9833333333329932	-166.166666666670068	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:05:00	\N	0.930000000000000049	-00:18:00	\N	0.849999999999999978	\N	\N	Malga Bay, Unalga Island	AK
63695	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.4666666666670096	-167.083333333329932	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-00:24:00	\N	1.18999999999999995	-00:08:00	\N	1.08000000000000007	\N	\N	Kashega Bay	AK
63696	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.4833333333329932	-166.933333333329927	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-03:16:00	\N	1.02000000000000002	-02:56:00	\N	1.45999999999999996	\N	\N	Eagle Bay	AK
63697	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.7166666666670096	-170.150000000000006	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-01:51:00	\N	0.930000000000000049	-01:40:00	\N	1.1399999999999999	\N	\N	Herbert Island, west side	AK
63698	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.5166666666670068	-171.233333333329909	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	-02:03:00	\N	1.10000000000000009	-01:32:00	\N	0.939999999999999947	\N	\N	Amukta Island, north side	AK
63699	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.800000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
63700	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.4166666666670054	179.283333333329921	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:06:00	\N	0.760000000000000009	00:19:00	\N	0.760000000000000009	\N	\N	Constantine Harbor, Amchitka Island	AK
63701	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.933333333332989	177.449999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:19:00	\N	0.859999999999999987	00:02:00	\N	0.859999999999999987	\N	\N	Gertrude Cove, Kiska Island	AK
63702	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.9833333333329932	177.550000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61102	-00:13:00	\N	0.969999999999999973	00:24:00	\N	0.969999999999999973	\N	\N	Kiska Harbor, Kiska Island	AK
63703	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.7166666666666686	174.066666666666691	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	-00:03:00	\N	1.03000000000000003	00:00:00	\N	1.03000000000000003	\N	\N	Alcan Harbor, Shemya Island	AK
63704	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.3666666666666671	173.616666666666703	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	-00:13:00	\N	1.03000000000000003	-00:14:00	\N	1.03000000000000003	\N	\N	Otkriti Bay, Agattu Island	AK
63705	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.9166666666666572	173.216666666666697	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:16:00	\N	1.09000000000000008	00:13:00	\N	1.09000000000000008	\N	\N	Chichagof Harbor	AK
63706	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.9166666666666572	173.166666666666714	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:18:00	\N	1.12000000000000011	-00:04:00	\N	1.12000000000000011	\N	\N	Holtz Bay	AK
63707	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.9666666666666686	172.900000000000006	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:11:00	\N	1.12000000000000011	-00:13:00	\N	1.12000000000000011	\N	\N	Steller Cove	AK
63708	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.9166666666666572	172.616666666666703	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61101	00:03:00	\N	1.12000000000000011	-00:17:00	\N	1.12000000000000011	\N	\N	Etienne Bay	AK
63709	Zapadni Bay, St. George Island, Bering Sea, Alaska	NOS	TWC2375	56.566666666667011	-169.683333333329927	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61105	01:18:00	\N	0.890000000000000013	01:15:00	\N	0.890000000000000013	\N	\N	Zapadni Bay, St. George Island	AK
63710	Apoon Mouth, Yukon River, Norton Sound, Alaska	NOS	TWC2405	63.0499999999999972	-163.383333333329915	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61154	-01:30:00	\N	1.03000000000000003	-01:30:00	\N	1.03000000000000003	\N	\N	Apoon Mouth, Yukon River	AK
63711	Flaxman Island, Alaska	NOS	TWC2423	70.1833333333329961	-145.833333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	61073	-00:28:00	\N	0.0899999999999999967	-00:57:00	\N	0.0800000000000000017	\N	\N	Flaxman Island	AK
63712	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.2266699999999986	-69.9833299999999952	:America/New_York	USA	knots	225	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:14:00	\N	0.900000000000000022	01:03:00	\N	0.900000000000000022	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
63713	Miacomet Pond, 3.0 miles SSE of, Massachusetts Current	NOS	ACT1596_1	41.1899999999999977	-70.0966700000000031	:America/New_York	USA	knots	280	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:16:00	\N	0.800000000000000044	02:03:00	\N	0.599999999999999978	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
63714	Tuckernuck Island, 4.2 miles SSW of, Massachusetts Current	NOS	ACT1601_1	41.2261700000000033	-70.2816700000000054	:America/New_York	USA	knots	280	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:56:00	\N	0.599999999999999978	03:13:00	\N	0.299999999999999989	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
63715	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.5649999999999977	-69.9233300000000071	:America/New_York	USA	knots	212	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:38:00	\N	1.10000000000000009	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
63716	Monomoy Pt., channel 0.2 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.5499999999999972	-70.0216700000000003	:America/New_York	USA	knots	346	170	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:23:00	\N	1.19999999999999996	00:39:00	\N	0.800000000000000044	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
63717	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.6566699999999983	-69.9749999999999943	:America/New_York	USA	knots	144	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:28:00	\N	0.599999999999999978	01:29:00	\N	0.299999999999999989	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
63718	Dennis Port, 2.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.6166699999999992	-70.1149999999999949	:America/New_York	USA	knots	269	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:04:00	\N	0.200000000000000011	00:52:00	\N	0.200000000000000011	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
63719	Monomoy Point, 6 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.558329999999998	-70.1500000000000057	:America/New_York	USA	knots	275	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:22:00	\N	0.299999999999999989	01:52:00	\N	0.200000000000000011	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
63720	Handkerchief Lighted Whistle Buoy 'H', Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.4883299999999977	-70.066670000000002	:America/New_York	USA	knots	251	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:59:00	\N	0.800000000000000044	01:10:00	\N	0.599999999999999978	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
63721	Halfmoon Shoal, 1.9 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.4841699999999989	-70.1924999999999955	:America/New_York	USA	knots	265	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:44:00	\N	0.299999999999999989	01:49:00	\N	0.400000000000000022	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
63722	Halfmoon Shoal, 3.5 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.4683300000000017	-70.1533299999999969	:America/New_York	USA	knots	295	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:11:00	\N	0.599999999999999978	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
63723	Great Point, 0.5 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.3933299999999988	-70.0616700000000066	:America/New_York	USA	knots	195	29	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:33:00	\N	0.699999999999999956	01:37:00	\N	0.599999999999999978	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
63724	Great Point, 3 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.3900000000000006	-70.1133300000000048	:America/New_York	USA	knots	248	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:08:00	\N	0.5	01:23:00	\N	0.400000000000000022	01:15:00	00:51:00	Great Point, 3 miles west of	MA
63725	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.4050000000000011	-70.1733300000000071	:America/New_York	USA	knots	287	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
63726	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.3066699999999969	-70.0999999999999943	:America/New_York	USA	knots	350	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:58:00	\N	0.900000000000000022	01:55:00	\N	0.599999999999999978	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
63727	Eel Pt., Nantucket I. 2.5 miles NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.3216699999999975	-70.1700000000000017	:America/New_York	USA	knots	284	94	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:15:00	\N	0.200000000000000011	01:12:00	\N	0.299999999999999989	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
63728	Muskeget I., channel 1 mile northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.3500000000000014	-70.2849999999999966	:America/New_York	USA	knots	295	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:56:00	\N	0.900000000000000022	00:45:00	\N	0.599999999999999978	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
63729	Muskeget Rock, 1.3 miles southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.3200000000000003	-70.393330000000006	:America/New_York	USA	knots	192	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:18:00	\N	0.599999999999999978	00:23:00	\N	0.599999999999999978	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
63730	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.3483299999999971	-70.4200000000000017	:America/New_York	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	1.89999999999999991	00:38:00	\N	1.89999999999999991	01:40:00	01:29:00	Muskeget Channel	MA
63731	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.4083299999999994	-70.3333300000000037	:America/New_York	USA	knots	260	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:13:00	\N	0.599999999999999978	01:12:00	\N	0.699999999999999956	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
63732	Cape Poge Lt., 1.7 miles SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.3999999999999986	-70.4266700000000014	:America/New_York	USA	knots	215	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:48:00	\N	0.699999999999999956	-00:07:00	\N	0.800000000000000044	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
63733	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.4483299999999986	-70.2916699999999963	:America/New_York	USA	knots	272	91	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:59:00	\N	0.5	01:48:00	\N	0.599999999999999978	01:48:00	01:55:00	Cross Rip Channel	MA
63734	Cape Poge Lt., 3.2 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.4583299999999966	-70.4000000000000057	:America/New_York	USA	knots	300	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:37:00	\N	0.699999999999999956	02:03:00	\N	0.800000000000000044	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
63735	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.5499999999999972	-70.2849999999999966	:America/New_York	USA	knots	276	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
63736	Point Gammon, 1.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.5883299999999991	-70.2566699999999997	:America/New_York	USA	knots	260	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	0.599999999999999978	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
63737	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.6316699999999997	-70.2733300000000014	:America/New_York	USA	knots	184	4	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:22:00	\N	0.800000000000000044	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
63738	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.6099999999999994	-70.4300000000000068	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:35:00	\N	0.400000000000000022	02:33:00	\N	0.299999999999999989	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
63739	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.5333299999999994	-70.4283300000000025	:America/New_York	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:45:00	\N	0.800000000000000044	01:32:00	\N	0.800000000000000044	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
63740	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.4716700000000031	-70.4833299999999952	:America/New_York	USA	knots	268	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:44:00	\N	0.699999999999999956	02:34:00	\N	0.699999999999999956	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
63741	Cape Poge Light, 1.4 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.4241699999999966	-70.4833299999999952	:America/New_York	USA	knots	250	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:39:00	\N	0.100000000000000006	01:54:00	\N	0.200000000000000011	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
63742	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.4650000000000034	-70.5366700000000009	:America/New_York	USA	knots	329	131	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:04:00	\N	1.10000000000000009	00:55:00	\N	0.699999999999999956	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
63743	East Chop, 1 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.4849999999999994	-70.558329999999998	:America/New_York	USA	knots	297	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.30000000000000004	01:52:00	\N	1.10000000000000009	02:40:00	02:17:00	East Chop, 1 mile north of	MA
63744	West Chop, 0.8 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.4933300000000003	-70.5949999999999989	:America/New_York	USA	knots	282	96	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:35:00	\N	1.80000000000000004	01:58:00	\N	1.60000000000000009	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
63745	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.5050000000000026	-70.5366700000000009	:America/New_York	USA	knots	276	106	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:52:00	\N	1.30000000000000004	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
63746	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.5300000000000011	:America/New_York	USA	knots	203	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:01:00	\N	0.800000000000000044	02:14:00	\N	0.800000000000000044	03:21:00	03:40:00	Waquoit Bay entrance	MA
63747	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.5266700000000029	-70.5766699999999929	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.39999999999999991	02:03:00	\N	1.19999999999999996	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
63748	Nobska Point, 1.8 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.5183299999999988	-70.6183300000000003	:America/New_York	USA	knots	240	63	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:49:00	\N	1	01:45:00	\N	1.19999999999999996	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
63749	West Chop, 0.2 mile west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.4833300000000023	-70.6099999999999994	:America/New_York	USA	knots	241	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	0.800000000000000044	01:34:00	\N	1.30000000000000004	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
63750	Nobska Point, 1 mile southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.5016699999999972	-70.643330000000006	:America/New_York	USA	knots	259	71	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:19:00	\N	1.39999999999999991	02:15:00	\N	1.30000000000000004	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
63751	Norton Point, 0.5 mile north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.4683300000000017	-70.6650000000000063	:America/New_York	USA	knots	240	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:12:00	\N	1.39999999999999991	01:44:00	\N	1.69999999999999996	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
63752	Tarpaulin Cove, 1.5 miles east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.4716700000000031	-70.7249999999999943	:America/New_York	USA	knots	232	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:33:00	\N	1.39999999999999991	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
63753	Robinsons Hole, 1.2 miles southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.4350000000000023	-70.7800000000000011	:America/New_York	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:02:00	\N	1.19999999999999996	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
63754	Gay Head, 3 miles northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.384999999999998	-70.7833300000000065	:America/New_York	USA	knots	238	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	0.800000000000000044	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
63755	Gay Head, 3 miles north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.4016700000000029	-70.8533299999999997	:America/New_York	USA	knots	255	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:17:00	\N	0.699999999999999956	01:24:00	\N	0.599999999999999978	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
63756	Gay Head, 1.5 miles northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.3633299999999977	-70.8633300000000048	:America/New_York	USA	knots	249	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	1.19999999999999996	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
63757	Black Point, SW of, Sakonnet River (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.5066699999999997	-71.2199999999999989	:America/New_York	USA	knots	194	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:26:00	\N	0.200000000000000011	-01:55:00	\N	0.200000000000000011	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
63758	Almy Point Bridge, south of, Sakonnet River (Depth 15ft), Rhode Island Current	NOS	ACT2076_1	41.6216700000000017	-71.2199999999999989	:America/New_York	USA	knots	180	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-03:13:00	\N	0.800000000000000044	-02:10:00	\N	0.200000000000000011	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
63759	Brenton Point, 1.4 n.mi. southwest of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.4316699999999969	-71.3766700000000043	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.400000000000000022	-00:38:00	\N	0.200000000000000011	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
63760	Castle Hill, west of, East Passage (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.4566700000000026	-71.3783300000000054	:America/New_York	USA	knots	237	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:29:00	\N	0.699999999999999956	-00:42:00	\N	0.400000000000000022	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
63761	Bull Point, east of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.4799999999999969	-71.3499999999999943	:America/New_York	USA	knots	206	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:33:00	\N	0.800000000000000044	-00:47:00	\N	0.599999999999999978	-01:10:00	-01:10:00	Bull Point, east of	RI
63762	Rose Island, northeast of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.5033299999999983	-71.3316700000000026	:America/New_York	USA	knots	124	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:08:00	\N	0.5	-00:07:00	\N	0.400000000000000022	-01:57:00	-01:17:00	Rose Island, northeast of	RI
63763	Rose Island, northwest of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.5066699999999997	-71.3516699999999986	:America/New_York	USA	knots	190	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:39:00	\N	0.5	-00:26:00	\N	0.400000000000000022	-01:38:00	-01:38:00	Rose Island, northwest of	RI
63764	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.4966700000000017	-71.3499999999999943	:America/New_York	USA	knots	172	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:28:00	\N	0.599999999999999978	-00:34:00	\N	0.400000000000000022	-00:42:00	-01:20:00	Rose Island, west of	RI
63765	Gould Island, southeast of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.5249999999999986	-71.336669999999998	:America/New_York	USA	knots	217	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.400000000000000022	-01:28:00	\N	0.299999999999999989	-01:40:00	-01:14:00	Gould Island, southeast of	RI
63766	Gould Island, west of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.5316699999999983	-71.3583299999999952	:America/New_York	USA	knots	193	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:07:00	\N	0.400000000000000022	-00:32:00	\N	0.299999999999999989	-00:16:00	-01:13:00	Gould Island, west of	RI
63767	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.5750000000000028	-71.296670000000006	:America/New_York	USA	knots	236	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:37:00	\N	0.400000000000000022	-01:13:00	\N	0.400000000000000022	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
63768	Conanicut Point, ENE of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.5750000000000028	-71.3416699999999935	:America/New_York	USA	knots	183	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.200000000000000011	-00:24:00	\N	0.200000000000000011	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
63769	Dyer Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.586669999999998	-71.308329999999998	:America/New_York	USA	knots	216	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:34:00	\N	0.599999999999999978	-00:46:00	\N	0.400000000000000022	-01:04:00	-00:53:00	Dyer Island, west of	RI
63770	Mount Hope Bridge (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.6400000000000006	-71.2583300000000008	:America/New_York	USA	knots	230	47	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:58:00	\N	0.800000000000000044	-01:34:00	\N	0.599999999999999978	-01:22:00	-01:08:00	Mount Hope Bridge	RI
63771	Hog Island, northwest of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.6466700000000003	-71.2950000000000017	:America/New_York	USA	knots	199	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.200000000000000011	-00:04:00	\N	0.200000000000000011	-02:16:00	-00:30:00	Hog Island, northwest of	RI
63772	Common Fence Point, west of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.6499999999999986	-71.2450000000000045	:America/New_York	USA	knots	224	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:37:00	\N	0.400000000000000022	00:08:00	\N	0.200000000000000011	-01:13:00	-01:00:00	Common Fence Point, west of	RI
63773	Mount Hope Point, northeast of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.6799999999999997	-71.211669999999998	:America/New_York	USA	knots	217	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:57:00	\N	0.200000000000000011	-00:20:00	\N	0.200000000000000011	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
63774	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.7283299999999997	-71.288330000000002	:America/New_York	USA	knots	171	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
63775	Beavertail Point, 0.8 mile northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.4583299999999966	-71.4116700000000009	:America/New_York	USA	knots	188	3	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:19:00	\N	0.599999999999999978	-00:54:00	\N	0.299999999999999989	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
63776	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.4966700000000017	-71.4033299999999969	:America/New_York	USA	knots	233	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:47:00	\N	0.599999999999999978	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
63777	Dutch Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.5050000000000026	-71.4099999999999966	:America/New_York	USA	knots	206	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.699999999999999956	-01:49:00	\N	0.699999999999999956	-01:33:00	-01:21:00	Dutch Island, west of	RI
63778	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.6583299999999994	-71.3533299999999997	:America/New_York	USA	knots	157	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:37:00	\N	0.5	-02:29:00	\N	0.400000000000000022	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
63779	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.663330000000002	-71.3733299999999957	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.5	-01:21:00	\N	0.299999999999999989	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
63780	Nayatt Point, WNW of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.7283299999999997	-71.3599999999999994	:America/New_York	USA	knots	128	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:11:00	\N	0.100000000000000006	00:47:00	\N	0.100000000000000006	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
63781	Cryders Point, 0.4 mile NNW of, East River, New York Current	NOS	ACT3341_1	40.8003300000000024	-73.7986700000000013	:America/New_York	USA	knots^2	285	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.200000000000000011	-00:43:00	\N	0.400000000000000022	-00:29:00	-00:30:00	Cryders Point, 0.4 mile NNW of	NY
63782	Bronx-Whitestone Bridge, East of (Depth 14ft), East River, New York Current	NOS	ACT3346_1	40.8016700000000014	-73.8266699999999929	:America/New_York	USA	knots^2	247	76	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:27:00	\N	0.200000000000000011	-00:46:00	\N	0.5	-00:34:00	-00:10:00	Bronx-Whitestone Bridge, East of	NY
63783	College Point Reef, 0.25 n.mi. NW of (Depth 15ft), East River, New York Current	NOS	ACT3356_1	40.8010000000000019	-73.8546699999999987	:America/New_York	USA	knots^2	261	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.299999999999999989	-00:47:00	\N	0.400000000000000022	-00:27:00	-00:32:00	College Point Reef, 0.25 n.mi. NW of	NY
63784	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.7833299999999994	-73.8833300000000008	:America/New_York	USA	knots^2	261	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.299999999999999989	-00:04:00	\N	0.299999999999999989	00:04:00	00:04:00	Rikers I. chan., off La Guardia Field	NY
63785	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.7999999999999972	-73.8833300000000008	:America/New_York	USA	knots^2	280	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:05:00	\N	0.299999999999999989	-00:10:00	\N	0.5	00:01:00	00:01:00	Hunts Point, southwest of	NY
63786	South Brother Island, NW of (Depth 15ft), East River, New York Current	NOS	ACT3381_1	40.7966699999999989	-73.9016699999999958	:America/New_York	USA	knots^2	252	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:12:00	\N	0.299999999999999989	00:04:00	\N	0.400000000000000022	-00:17:00	-00:06:00	South Brother Island, NW of	NY
63787	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.7866700000000009	-73.9166699999999963	:America/New_York	USA	knots^2	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.5	00:02:00	\N	1	00:04:00	-00:01:00	Off Winthrop Ave., Astoria	NY
63788	Mill Rock, northeast of, East River, New York Current	NOS	ACT3391_1	40.7816699999999983	-73.9366700000000066	:America/New_York	USA	knots^2	288	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:32:00	\N	0.100000000000000006	00:05:00	\N	0.699999999999999956	-00:23:00	-00:29:00	Mill Rock, northeast of	NY
63789	Mill Rock, west of, East River, New York Current	NOS	ACT3396_1	40.7800000000000011	-73.941670000000002	:America/New_York	USA	knots^2	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:17:00	\N	0.200000000000000011	00:08:00	\N	0.400000000000000022	-00:26:00	-00:02:00	Mill Rock, west of	NY
63790	Roosevelt Island, west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.7666699999999977	-73.9500000000000028	:America/New_York	USA	knots^2	215	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	1	-00:04:00	\N	1.10000000000000009	-00:02:00	-00:08:00	west of, off 75th Street	NY
63791	Roosevelt Island, east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.7666699999999977	-73.9500000000000028	:America/New_York	USA	knots^2	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.699999999999999956	-00:04:00	\N	1	-00:08:00	-00:08:00	east of, off 36th Avenue	NY
63792	Roosevelt Island, west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.7623299999999986	-73.9539999999999935	:America/New_York	USA	knots^2	230	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:11:00	\N	0.900000000000000022	-00:08:00	\N	1.10000000000000009	00:13:00	00:06:00	west of, off 67th Street	NY
63793	Roosevelt Island, west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.7596699999999998	-73.9544999999999959	:America/New_York	USA	knots^2	223	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.599999999999999978	-00:08:00	\N	0.800000000000000044	-00:10:00	00:00:00	west of, off 63rd Street	NY
63794	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.7581699999999998	-73.9513299999999987	:America/New_York	USA	knots^2	200	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.599999999999999978	-00:06:00	\N	0.800000000000000044	00:00:00	00:02:00	east of	NY
63795	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.7396699999999967	-73.9694999999999965	:America/New_York	USA	knots^2	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:36:00	\N	0.5	-00:11:00	\N	0.400000000000000022	00:09:00	-00:02:00	Manhattan, off 31st Street	NY
63796	Pier 67, off 19th Street, East River, New York Current	NOS	ACT3441_1	40.7333300000000023	-73.9666699999999935	:America/New_York	USA	knots^2	179	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.400000000000000022	00:08:00	\N	0.5	-00:08:00	-00:08:00	Pier 67, off 19th Street	NY
63797	Williamsburg Bridge, 0.3 mile north of, East River, New York Current	NOS	ACT3446_1	40.7180000000000035	-73.9706699999999984	:America/New_York	USA	knots^2	220	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:10:00	\N	0.599999999999999978	00:12:00	\N	0.800000000000000044	-00:05:00	-00:01:00	Williamsburg Bridge, 0.3 mile north of	NY
63798	Manhattan Bridge, East of (Depth 15ft), East River, New York Current	NOS	ACT3451_1	40.7083299999999966	-73.9899999999999949	:America/New_York	USA	knots^2	259	83	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.5	00:19:00	\N	0.699999999999999956	-00:28:00	-00:13:00	Manhattan Bridge, East of	NY
63799	Brooklyn Bridge, 0.1 mile southwest of, East River, New York Current	NOS	ACT3461_1	40.7033300000000011	-74	:America/New_York	USA	knots^2	222	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:07:00	\N	0.800000000000000044	00:08:00	\N	0.900000000000000022	-00:18:00	-00:04:00	Brooklyn Bridge, 0.1 mile southwest of	NY
63800	East 107th Street (Depth 15ft), Harlem River, New York Current	NOS	ACT3476_1	40.7899999999999991	-73.9350000000000023	:America/New_York	USA	knots^2	30	206	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:39:00	\N	0.200000000000000011	-00:03:00	\N	0.200000000000000011	-00:08:00	-01:09:00	East 107th Street	NY
63801	Willis Ave. Bridge, 0.1 mile NW of, Harlem River, New York Current	NOS	ACT3481_1	40.8049999999999997	-73.9300000000000068	:America/New_York	USA	knots^2	330	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:13:00	\N	0.299999999999999989	00:00:00	\N	0.400000000000000022	-00:30:00	-00:12:00	Willis Ave. Bridge, 0.1 mile NW of	NY
63802	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.8133300000000006	-73.9350000000000023	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:14:00	\N	0.400000000000000022	00:18:00	\N	0.5	-00:20:00	-00:21:00	Madison Ave. Bridge	NY
63803	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.8283300000000011	-73.9350000000000023	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.299999999999999989	00:14:00	\N	0.5	-00:20:00	-00:22:00	Macombs Dam Bridge	NY
63804	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.8416700000000006	-73.9316699999999969	:America/New_York	USA	knots^2	15	189	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.400000000000000022	00:08:00	\N	0.599999999999999978	-00:20:00	-00:23:00	High Bridge	NY
63805	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.8633299999999977	-73.9150000000000063	:America/New_York	USA	knots^2	35	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:02:00	\N	0.400000000000000022	00:05:00	\N	0.599999999999999978	-00:22:00	-00:22:00	West 207th Street Bridge	NY
63806	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.8733300000000028	-73.9116700000000009	:America/New_York	USA	knots^2	299	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:04:00	\N	0.5	00:08:00	\N	0.599999999999999978	-00:23:00	-00:20:00	Broadway Bridge	NY
63807	Henry Hudson Bridge, 0.7 nmi. SE of (Depth 16ft), Harlem River, New York Current	NOS	ACT3511_1	40.8766699999999972	-73.921670000000006	:America/New_York	USA	knots^2	326	137	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:41:00	\N	0.299999999999999989	00:31:00	\N	0.200000000000000011	00:12:00	-00:31:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
63808	Bergen Point Reach (Bayonne Bridge) (Depth 29ft), Kill Van Kull, New York Current	NOS	ACT3951_2	40.6416699999999977	-74.143330000000006	:America/New_York	USA	knots	79	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16145	-00:04:00	\N	0.900000000000000022	00:02:00	\N	0.800000000000000044	-00:15:00	00:14:00	BERGEN POINT REACH (BAYONNE BRIDGE)	NY
63809	Cedar Point, 2.9 n.mi. ENE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.3108300000000028	-76.3133299999999934	:America/New_York	USA	knots	164	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:55:00	\N	0.800000000000000044	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
63810	Cedar Point, 2.9 n.mi. ENE of (Depth 50ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.3108300000000028	-76.3133299999999934	:America/New_York	USA	knots	141	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:15:00	\N	0.299999999999999989	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
63811	Cedar Point, 1.1 miles ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3044999999999973	-76.3516699999999986	:America/New_York	USA	knots	185	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.800000000000000044	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
63812	Cove Point, 1.1 n.mi. east of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.3813299999999984	-76.3603300000000047	:America/New_York	USA	knots	165	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:14:00	\N	0.900000000000000022	-02:42:00	\N	0.900000000000000022	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
63813	Cove Point, 1.1 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.3813299999999984	-76.3603300000000047	:America/New_York	USA	knots	165	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:26:00	\N	0.699999999999999956	-03:19:00	\N	0.800000000000000044	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
63814	Cove Point, 2.7 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	169	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.900000000000000022	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
63815	Cove Point, 2.7 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.599999999999999978	-02:39:00	\N	0.900000000000000022	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
63816	Cove Point, 2.7 n.mi. east of (Depth 98ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	165	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:36:00	\N	0.5	-04:02:00	\N	0.699999999999999956	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
63817	Cove Point, 3.9 n.mi. east of (Depth 11ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.3753299999999982	-76.2986700000000013	:America/New_York	USA	knots	171	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:44:00	\N	0.599999999999999978	-03:36:00	\N	0.400000000000000022	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
63818	Cove Point, 4.9 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	159	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.699999999999999956	-02:29:00	\N	0.699999999999999956	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
63819	Cove Point, 4.9 n.mi. NNE of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	149	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.400000000000000022	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
63820	Cove Point, 4.9 n.mi. NNE of (Depth 67ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	135	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:58:00	\N	0.400000000000000022	-03:38:00	\N	0.599999999999999978	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
63821	Kenwood Beach, 1.5 miles northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.5183299999999988	-76.481669999999994	:America/New_York	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:37:00	\N	0.400000000000000022	-02:41:00	\N	0.200000000000000011	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
63822	James Island, 3.4 miles west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.5249999999999986	-76.4200000000000017	:America/New_York	USA	knots	175	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:02:00	\N	0.400000000000000022	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
63823	James Island, 2.5 miles WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.5333299999999994	-76.393330000000006	:America/New_York	USA	knots	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:36:00	\N	0.599999999999999978	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
63824	Plum Point, 1.4 miles ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6124999999999972	-76.4775000000000063	:America/New_York	USA	knots	155	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.699999999999999956	-01:37:00	\N	0.200000000000000011	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
63825	Sharp Island Lt., 2.3 n.mi. SE of (Depth 20ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.6071700000000035	-76.347999999999999	:America/New_York	USA	knots	203	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:54:00	\N	0.699999999999999956	-03:34:00	\N	0.800000000000000044	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
63826	Sharp Island Lt., 2.1 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.6433299999999988	-76.420330000000007	:America/New_York	USA	knots	183	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:33:00	\N	0.5	-01:36:00	\N	0.400000000000000022	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
63827	Sharp Island Lt., 3.4 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.6438300000000012	-76.4479999999999933	:America/New_York	USA	knots	186	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:43:00	\N	0.5	-01:41:00	\N	0.400000000000000022	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
63828	Sharp Island Lt., 3.4 n.mi. west of (Depth 35ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.6438300000000012	-76.4479999999999933	:America/New_York	USA	knots	183	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:24:00	\N	0.400000000000000022	-02:23:00	\N	0.400000000000000022	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
63829	Plum Point, 2.1 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.6450000000000031	-76.4871700000000061	:America/New_York	USA	knots	174	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:01:00	\N	0.5	-01:51:00	\N	0.400000000000000022	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
63830	Poplar Island, 2.2 n.mi. WSW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.7561699999999973	-76.4295000000000044	:America/New_York	USA	knots	185	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:49:00	\N	0.800000000000000044	-01:26:00	\N	0.599999999999999978	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
63831	Poplar Island, 3.0 n.mi. WSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.7496700000000018	-76.4454999999999956	:America/New_York	USA	knots	189	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:08:00	\N	0.5	-01:22:00	\N	0.599999999999999978	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
63832	Poplar Island, 3.0 n.mi. WSW of (Depth 48ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.7496700000000018	-76.4454999999999956	:America/New_York	USA	knots	172	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:13:00	\N	0.400000000000000022	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
63833	Holland Point, 2.0 n.mi east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.7516699999999972	-76.4988299999999981	:America/New_York	USA	knots	180	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:39:00	\N	0.400000000000000022	-01:24:00	\N	0.200000000000000011	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
63834	Kent Point, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.7916700000000034	-76.433329999999998	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:05:00	\N	0.599999999999999978	-01:04:00	\N	0.599999999999999978	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
63835	Kent Point, 1.3 miles south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.816670000000002	-76.3641700000000014	:America/New_York	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:47:00	\N	0.5	-03:38:00	\N	0.599999999999999978	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
63836	Horseshoe Point, 1.7 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.8383299999999991	-76.453329999999994	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:10:00	\N	0.599999999999999978	-00:39:00	\N	0.599999999999999978	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
63837	Bloody Point Bar Light, 0.6 mi. NW of (Depth 19ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.839500000000001	-76.4028299999999945	:America/New_York	USA	knots	190	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.599999999999999978	-00:23:00	\N	0.900000000000000022	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
63838	Thomas Pt. Shoal Lt., 1.8 mi. SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.461669999999998	:America/New_York	USA	knots	190	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.400000000000000022	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
63839	Thomas Pt. Shoal Lt., 2.0 n.mi. east of (Depth 22ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.8958299999999966	-76.3868300000000033	:America/New_York	USA	knots	186	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:20:00	\N	0.599999999999999978	-00:14:00	\N	0.599999999999999978	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
63840	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.8909999999999982	-76.4270000000000067	:America/New_York	USA	knots	191	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:41:00	\N	1.30000000000000004	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
63841	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 33ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.8909999999999982	-76.4270000000000067	:America/New_York	USA	knots	196	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:20:00	\N	0.699999999999999956	-01:18:00	\N	0.699999999999999956	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
63842	Tolly Point, 1.6 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9344999999999999	-76.4170000000000016	:America/New_York	USA	knots	190	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:24:00	\N	0.900000000000000022	-00:19:00	\N	0.599999999999999978	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
63843	Chesapeake Bay Bridge, main channel, Chesapeake Bay, Maryland Current	NOS	ACT4981_1	38.9916699999999992	-76.3850000000000051	:America/New_York	USA	knots	230	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:13:00	\N	1.10000000000000009	00:08:00	\N	0.900000000000000022	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
63844	Sandy Point, 2.3 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.0026700000000019	-76.3488300000000066	:America/New_York	USA	knots	199	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:29:00	\N	0.900000000000000022	00:15:00	\N	1.10000000000000009	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
63845	Sandy Point, 2.3 n.mi. east of (Depth 41ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.0026700000000019	-76.3488300000000066	:America/New_York	USA	knots	210	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:39:00	\N	0.599999999999999978	-01:14:00	\N	0.800000000000000044	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
63846	Sandy Point, 0.8 n.mi. ESE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.0039999999999978	-76.3799999999999955	:America/New_York	USA	knots	199	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	1.5	00:24:00	\N	1.19999999999999996	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
63847	Sandy Point, 0.8 n.mi. ESE of (Depth 43ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.0039999999999978	-76.3799999999999955	:America/New_York	USA	knots	197	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
63848	Craighill Channel entrance, Buoy '2C' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.0403299999999973	-76.377830000000003	:America/New_York	USA	knots	182	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:09:00	\N	0.900000000000000022	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
63849	Craighill Channel entrance, Buoy '2C' (Depth 38ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.0403299999999973	-76.377830000000003	:America/New_York	USA	knots	147	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:18:00	\N	0.599999999999999978	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
63850	Love Point, 2.5 miles north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.0796700000000001	-76.3121699999999947	:America/New_York	USA	knots	240	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:07:00	\N	0.5	00:19:00	\N	0.800000000000000044	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
63851	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.0813300000000012	-76.3944999999999936	:America/New_York	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:34:00	\N	0.900000000000000022	00:40:00	\N	0.800000000000000044	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
63852	Craighill Channel, Belvidere Shoal (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.0946700000000007	-76.3930000000000007	:America/New_York	USA	knots	186	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:19:00	\N	0.599999999999999978	00:46:00	\N	0.699999999999999956	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
63853	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.1283299999999983	-76.3878299999999939	:America/New_York	USA	knots	170	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:23:00	\N	0.599999999999999978	00:27:00	\N	0.599999999999999978	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
63854	Swan Point, 2.7 n.mi. SW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.107999999999997	-76.3053299999999979	:America/New_York	USA	knots	170	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.5	00:42:00	\N	0.599999999999999978	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
63855	Swan Point, 2.7 n.mi. SW of (Depth 27ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.107999999999997	-76.3053299999999979	:America/New_York	USA	knots	142	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.400000000000000022	00:30:00	\N	0.599999999999999978	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
63856	Swan Point, 1.6 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625000000000014	-76.3046700000000016	:America/New_York	USA	knots	215	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:57:00	\N	0.900000000000000022	00:44:00	\N	0.800000000000000044	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
63857	Brewerton Channel Eastern Ext., Buoy '7' (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.1629999999999967	-76.3896699999999953	:America/New_York	USA	knots	175	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.400000000000000022	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
63858	Tolchester Channel, SW of Bouy '58B' (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1824999999999974	-76.281170000000003	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:54:00	\N	1.10000000000000009	00:20:00	\N	1.10000000000000009	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
63859	Tolchester Channel, SW of Bouy '58B' (Depth 25ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1824999999999974	-76.281170000000003	:America/New_York	USA	knots	217	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:48:00	\N	0.699999999999999956	00:02:00	\N	0.900000000000000022	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
63860	Tolchester Channel, Buoy '22' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.1911699999999996	-76.265829999999994	:America/New_York	USA	knots	231	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:23:00	\N	0.800000000000000044	01:10:00	\N	0.900000000000000022	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
63861	Tolchester Channel, south of Buoy '38B' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.1928300000000007	-76.2878299999999996	:America/New_York	USA	knots	208	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:50:00	\N	0.800000000000000044	01:08:00	\N	0.699999999999999956	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
63862	North Point, 2.5 miles northeast of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.214500000000001	-76.3953300000000013	:America/New_York	USA	knots	225	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:06:00	\N	0.5	01:00:00	\N	0.400000000000000022	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
63863	Tolchester Beach, 0.33 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.217170000000003	-76.2483299999999957	:America/New_York	USA	knots	201	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:24:00	\N	1.10000000000000009	01:20:00	\N	1.19999999999999996	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
63864	Pooles Island, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.2266699999999986	-76.3313299999999941	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:12:00	\N	0.800000000000000044	00:48:00	\N	0.599999999999999978	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
63865	Pooles Island 2.0 n.mi. SSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.2463300000000004	-76.296670000000006	:America/New_York	USA	knots	238	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:29:00	\N	0.699999999999999956	00:58:00	\N	0.699999999999999956	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
63866	Pooles Island, 0.8 mile south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.2616700000000023	-76.2733300000000014	:America/New_York	USA	knots	255	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:20:00	\N	1.19999999999999996	01:24:00	\N	0.900000000000000022	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
63867	Miller Island, 1.5 miles ENE of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.2749999999999986	-76.3316700000000026	:America/New_York	USA	knots	185	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.299999999999999989	00:15:00	\N	0.599999999999999978	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
63868	Pooles Island, 1.6 n.mi. east of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745000000000033	-76.2261699999999962	:America/New_York	USA	knots	208	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:03:00	\N	1.10000000000000009	01:34:00	\N	1.10000000000000009	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
63869	Robins Point, 0.7 mile ESE of (Depth 5ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.2958300000000023	-76.268330000000006	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:13:00	\N	1	-00:14:00	\N	1.39999999999999991	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
63870	Worton Point, 1.5 n.mi. WSW of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.3116699999999994	-76.2171699999999959	:America/New_York	USA	knots	211	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:36:00	\N	1.10000000000000009	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
63871	Worton Point, 1.1 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.3316700000000026	-76.2000000000000028	:America/New_York	USA	knots	245	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1.5	01:43:00	\N	1.39999999999999991	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
63872	Howell Point, 0.8 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3704999999999998	-76.1299999999999955	:America/New_York	USA	knots	235	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:33:00	\N	1.30000000000000004	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
63873	Howell Point, 0.4 mile NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.3766699999999972	-76.1149999999999949	:America/New_York	USA	knots	245	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:18:00	\N	1.10000000000000009	01:24:00	\N	1.10000000000000009	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
63874	Grove Point, 0.7 n.mi.NW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.396329999999999	-76.0503300000000024	:America/New_York	USA	knots	211	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:03:00	\N	1	02:01:00	\N	0.599999999999999978	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
63875	Turkey Point, 1.2 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.4433300000000031	-76.0338299999999947	:America/New_York	USA	knots	193	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:00:00	\N	0.800000000000000044	01:30:00	\N	0.599999999999999978	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
63876	Spesutie Island, channel north of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4804999999999993	-76.0816700000000026	:America/New_York	USA	knots	100	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:40:00	\N	0.599999999999999978	01:20:00	\N	0.800000000000000044	01:42:00	01:49:00	Spesutie Island, channel north of	MD
63877	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.4883299999999977	-75.9975000000000023	:America/New_York	USA	knots	196	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:49:00	\N	0.699999999999999956	01:28:00	\N	0.599999999999999978	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
63878	Red Point, 0.2 mile W of, Northeast River (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.5291700000000006	-75.9846699999999942	:America/New_York	USA	knots	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:47:00	\N	0.599999999999999978	01:28:00	\N	0.900000000000000022	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
63879	Swan Point, Potomac River, Virginia Current	NOS	ACT5846_1	38.2733300000000014	-76.9449999999999932	:America/New_York	USA	knots	140	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:09:00	\N	1	-02:04:00	\N	0.400000000000000022	-01:54:00	-02:32:00	Swan Point	VA
63880	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.3683300000000003	-76.9899999999999949	:America/New_York	USA	knots	175	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:24:00	\N	1.80000000000000004	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
63881	Potomac River Bridge, 0.4 mile south of, Potomac River, Maryland Current	NOS	ACT5866_1	38.3563299999999998	-76.9866700000000037	:America/New_York	USA	knots	165	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:17:00	\N	1.80000000000000004	-01:28:00	\N	1.10000000000000009	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
63882	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.3466700000000031	-77.1966699999999975	:America/New_York	USA	knots	80	270	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:19:00	\N	1.80000000000000004	-01:14:00	\N	1.39999999999999991	-01:04:00	-01:42:00	Maryland Point	MD
63883	Quantico, Potomac River, Virginia Current	NOS	ACT5881_1	38.5216700000000003	-77.2766699999999958	:America/New_York	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:09:00	\N	1.10000000000000009	-01:04:00	\N	0.900000000000000022	-00:54:00	-01:32:00	Quantico	VA
63884	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.5283299999999969	-77.288330000000002	:America/New_York	USA	knots	115	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:34:00	\N	0.599999999999999978	-01:29:00	\N	0.599999999999999978	-01:19:00	-01:57:00	Quantico Creek entrance	VA
63885	Freestone Point, 2.3 miles east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.5963300000000018	-77.1979999999999933	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:06:00	\N	0.900000000000000022	-00:01:00	\N	0.900000000000000022	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
63886	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.6450000000000031	-77.1274999999999977	:America/New_York	USA	knots	149	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:15:00	\N	1.39999999999999991	-00:05:00	\N	1.39999999999999991	00:12:00	-00:24:00	Hallowing Point	MD
63887	Jones Point, Alexandria, Potomac River, Virginia Current	NOS	ACT5901_1	38.7936699999999988	-77.0371700000000033	:America/New_York	USA	knots	171	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:07:00	\N	1.10000000000000009	00:01:00	\N	1.19999999999999996	00:36:00	00:09:00	Jones Point, Alexandria	VA
63888	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.8513299999999973	-77.0220000000000056	:America/New_York	USA	knots	176	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.400000000000000022	00:31:00	\N	0.800000000000000044	00:20:00	00:04:00	Hains Point	DC
63889	Hog Point, 0.6 n.mi. north of (Depth 13ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.3179999999999978	-76.4011699999999934	:America/New_York	USA	knots	70	258	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:00:00	\N	0.599999999999999978	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
63890	Hog Point, 0.6 n.mi. north of (Depth 41ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.3179999999999978	-76.4011699999999934	:America/New_York	USA	knots	61	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:38:00	\N	0.299999999999999989	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
63891	Drum Point, 0.3 mile SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155000000000001	-76.419169999999994	:America/New_York	USA	knots	65	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
63892	Sandy Point, 0.5 mile south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.308329999999998	-76.4549999999999983	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:55:00	\N	0.599999999999999978	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
63893	Point Patience, 0.1 mile southwest of (Depth 15ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.3283300000000011	-76.4866700000000037	:America/New_York	USA	knots	145	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:01:00	\N	1	-06:12:00	\N	0.599999999999999978	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
63894	Broomes Island, 0.4 mile south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.3950000000000031	-76.5541699999999992	:America/New_York	USA	knots	110	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:02:00	\N	0.599999999999999978	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
63895	Sheridan Point, 0.1 mile southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.4661699999999982	-76.6479999999999961	:America/New_York	USA	knots	135	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:16:00	\N	0.800000000000000044	-04:54:00	\N	0.800000000000000044	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
63896	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.5116700000000023	-76.6721699999999942	:America/New_York	USA	knots	190	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:35:00	\N	0.599999999999999978	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
63897	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.7466700000000017	-76.6850000000000023	:America/New_York	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:29:00	\N	1.10000000000000009	-03:24:00	\N	1.39999999999999991	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
63898	Ragged Point, 1.5 miles east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.5300000000000011	-76.2441699999999969	:America/New_York	USA	knots	235	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:57:00	\N	0.200000000000000011	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
63899	Cook Point, 1.4 n.mi. NNW of (Depth 15ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.6471700000000027	-76.3066699999999969	:America/New_York	USA	knots	241	49	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:24:00	\N	0.699999999999999956	-04:06:00	\N	0.800000000000000044	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
63900	Cook Point, 1.4 n.mi. NNW of (Depth 45ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.6471700000000027	-76.3066699999999969	:America/New_York	USA	knots	232	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:12:00	\N	0.599999999999999978	-04:05:00	\N	0.599999999999999978	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
63901	Holland Point, 2.0 n.mi. SSW of (Depth 14ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.6738300000000024	-76.2574999999999932	:America/New_York	USA	knots	262	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:00:00	\N	0.200000000000000011	-04:21:00	\N	0.299999999999999989	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
63902	Chlora Point, 0.5 n.mi. SSW of (Depth 17ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.6283299999999983	-76.1516699999999958	:America/New_York	USA	knots	332	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:58:00	\N	0.5	-03:32:00	\N	0.599999999999999978	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
63903	Chlora Point, 0.5 n.mi. SSW of (Depth 24ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.6283299999999983	-76.1516699999999958	:America/New_York	USA	knots	323	143	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.400000000000000022	-03:33:00	\N	0.400000000000000022	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
63904	Martin Point, 0.6 n.mi. west of (Depth 18ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.6271699999999996	-76.1358299999999986	:America/New_York	USA	knots	341	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:34:00	\N	0.200000000000000011	-03:42:00	\N	0.299999999999999989	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
63905	Howell Point, 0.5 n.mi. south of (Depth 7ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.6038300000000021	-76.1145000000000067	:America/New_York	USA	knots	274	122	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.5	-04:04:00	\N	0.400000000000000022	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
63906	Cambridge hwy. bridge, W. of Swing Span (Depth 18ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.5796700000000001	-76.0611700000000042	:America/New_York	USA	knots	316	132	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:13:00	\N	0.299999999999999989	-03:05:00	\N	0.599999999999999978	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
63907	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.6096700000000013	-75.982830000000007	:America/New_York	USA	knots	205	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.800000000000000044	-02:32:00	\N	0.599999999999999978	-02:13:00	-02:44:00	Off Jamaica Point	MD
63908	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.6753300000000024	-75.9663299999999992	:America/New_York	USA	knots	100	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
63909	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.7566699999999997	-75.9986700000000042	:America/New_York	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:47:00	\N	1	-01:50:00	\N	1.10000000000000009	-01:19:00	-01:25:00	Dover Bridge	MD
63910	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.7291700000000034	-76.3050000000000068	:America/New_York	USA	knots	175	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
63911	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.7483300000000028	-76.3533299999999997	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:20:00	\N	0.800000000000000044	-02:20:00	\N	1.19999999999999996	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
63912	Kent Point, 1.4 n.mi. east of (Depth 15ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.8388300000000015	-76.3375000000000057	:America/New_York	USA	knots	233	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:12:00	\N	0.400000000000000022	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
63913	Long Point, 1 mile southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.8433300000000017	-76.3266699999999929	:America/New_York	USA	knots	235	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:40:00	\N	0.5	-03:40:00	\N	0.599999999999999978	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
63914	Wye River, west of Bruffs Island (Depth 9ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.8546699999999987	-76.1979999999999933	:America/New_York	USA	knots	190	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:00:00	\N	0.900000000000000022	-03:18:00	\N	0.800000000000000044	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
63915	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055000000000021	-76.2091700000000003	:America/New_York	USA	knots	25	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.599999999999999978	-03:52:00	\N	0.599999999999999978	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
63916	Greenbury Point, 1.8 miles east of (Depth 8ft), Maryland Current	NOS	ACT6106_1	38.9733299999999971	-76.4166699999999963	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:47:00	\N	0.800000000000000044	-01:05:00	\N	0.800000000000000044	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
63917	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.0578300000000027	-76.4371699999999947	:America/New_York	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.400000000000000022	-02:00:00	\N	0.800000000000000044	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
63918	Love Point, 1.6 n.mi. east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6126_1	39.0341700000000031	-76.2678300000000036	:America/New_York	USA	knots	341	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:15:00	\N	0.400000000000000022	-01:15:00	\N	0.599999999999999978	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
63919	Kent Island Narrows (highway bridge) (Depth 4ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705000000000013	-76.247169999999997	:America/New_York	USA	knots	190	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:56:00	\N	1.10000000000000009	-02:25:00	\N	1.19999999999999996	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
63920	Hail Point, 0.7 n.mi.east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105000000000004	-76.1825000000000045	:America/New_York	USA	knots	168	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:37:00	\N	0.599999999999999978	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
63921	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.1063299999999998	-76.1205000000000069	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.900000000000000022	-00:33:00	\N	0.599999999999999978	-00:31:00	-00:32:00	Deep Point	MD
63922	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.2071699999999979	-76.0611700000000042	:America/New_York	USA	knots	220	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:17:00	\N	0.599999999999999978	00:05:00	\N	0.800000000000000044	-00:21:00	-00:02:00	Chestertown	MD
63923	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.4383299999999934	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:10:00	\N	0.5	-00:10:00	\N	0.699999999999999956	00:00:00	00:00:00	Lynch Point, Back River	MD
63924	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.3116699999999994	-76.308329999999998	:America/New_York	USA	knots	205	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	0.400000000000000022	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
63925	Bush River, 0.4 mi. SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.3566700000000012	-76.2566699999999997	:America/New_York	USA	knots	165	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:20:00	\N	0.599999999999999978	-00:24:00	\N	0.800000000000000044	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
63926	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.3783299999999983	-76.0433299999999974	:America/New_York	USA	knots	288	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:44:00	\N	0.400000000000000022	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
63927	Ordinary Point, 0.4 mile west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.3741699999999994	-75.9874999999999972	:America/New_York	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:58:00	\N	0.5	00:37:00	\N	0.599999999999999978	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
63928	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.3611700000000013	-75.886170000000007	:America/New_York	USA	knots	200	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:25:00	\N	0.5	00:25:00	\N	0.400000000000000022	01:00:00	00:56:00	Georgetown	MD
63929	Arnold Point, 0.4 mile west of, Elk River, Maryland Current	NOS	ACT6216_1	39.4638300000000015	-75.9741700000000009	:America/New_York	USA	knots	215	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
63930	Old Town Point Wharf, northwest of (Depth 17ft), Elk River, Maryland Current	NOS	ACT6221_1	39.5038300000000007	-75.9186700000000059	:America/New_York	USA	knots	242	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.60000000000000009	01:53:00	\N	1.30000000000000004	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
63931	Old Town Point Wharf, northwest of (Depth 29ft), Elk River, Maryland Current	NOS	ACT6221_2	39.5038300000000007	-75.9186700000000059	:America/New_York	USA	knots	237	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.39999999999999991	02:04:00	\N	1.19999999999999996	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
63932	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.5533300000000025	-75.8599999999999994	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:05:00	\N	0.900000000000000022	02:05:00	\N	0.599999999999999978	02:05:00	02:05:00	Hendersons Point	MD
63933	Bodie Island-Pea Island, between (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_1	35.7766700000000029	-75.5349999999999966	:America/New_York	USA	knots	28	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:52:00	\N	0.599999999999999978	02:20:00	\N	1.19999999999999996	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
63934	Bodie Island-Pea Island, between (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_2	35.7766700000000029	-75.5349999999999966	:America/New_York	USA	knots	36	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.599999999999999978	02:36:00	\N	1.19999999999999996	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
63935	Coast Guard Tower, southwest of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_1	35.7616700000000023	-75.5316700000000054	:America/New_York	USA	knots	28	205	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:18:00	\N	0.800000000000000044	02:30:00	\N	0.800000000000000044	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
63936	Coast Guard Tower, southwest of (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_2	35.7616700000000023	-75.5316700000000054	:America/New_York	USA	knots	33	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.699999999999999956	02:33:00	\N	0.800000000000000044	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
63937	Herbert C. Bonner Bridge, WSW of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6281_1	35.7700000000000031	-75.546670000000006	:America/New_York	USA	knots	87	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:46:00	\N	0.900000000000000022	02:55:00	\N	0.599999999999999978	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
63938	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2000000000000028	-75.75	:America/New_York	USA	knots	148	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:38:00	\N	1	02:42:00	\N	1.19999999999999996	02:42:00	02:18:00	Hatteras Inlet	NC
63939	Channel entrance, Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.065330000000003	-76.0188299999999941	:America/New_York	USA	knots	145	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:40:00	\N	1.19999999999999996	02:24:00	\N	1	02:48:00	01:43:00	channel entrance	NC
63940	Teaches Hole Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.0791699999999977	-76.0046700000000044	:America/New_York	USA	knots	195	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:47:00	\N	0.800000000000000044	02:27:00	\N	0.599999999999999978	02:49:00	01:42:00	Teaches Hole Channel	NC
63941	Blair Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.0813300000000012	-76.0338299999999947	:America/New_York	USA	knots	140	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:03:00	\N	0.900000000000000022	02:33:00	\N	0.599999999999999978	02:52:00	01:48:00	Blair Channel	NC
63942	Wallace Channel (Depth 9ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.0796700000000001	-76.0520000000000067	:America/New_York	USA	knots	140	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:13:00	\N	0.900000000000000022	02:57:00	\N	0.900000000000000022	02:51:00	02:03:00	Wallace Channel	NC
63943	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.066670000000002	-76.0999999999999943	:America/New_York	USA	knots	95	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:56:00	\N	0.200000000000000011	03:18:00	\N	0.100000000000000006	02:33:00	01:35:00	Sheep Island Slue	NC
63944	Shackleford Banks, 0.8 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.6663300000000021	-76.6555000000000035	:America/New_York	USA	knots	145	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.699999999999999956	01:16:00	\N	0.800000000000000044	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
63945	Approach, Beaufort Inlet, North Carolina Current	NOS	ACT6331_1	34.6716699999999989	-76.6700000000000017	:America/New_York	USA	knots	161	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:57:00	\N	0.699999999999999956	01:19:00	\N	0.200000000000000011	02:03:00	00:37:00	Approach	NC
63946	Fort Macon, 0.6 mile SE of, Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.6858300000000028	-76.6683299999999974	:America/New_York	USA	knots	154	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:38:00	\N	0.900000000000000022	01:47:00	\N	0.699999999999999956	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
63947	Fort Macon, 0.2 mile NE of (Depth 10ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.6996699999999976	-76.6753300000000024	:America/New_York	USA	knots	151	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:21:00	\N	0.900000000000000022	01:20:00	\N	1.10000000000000009	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
63948	Fort Macon, 0.2 mile NE of (Depth 20ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.6996699999999976	-76.6753300000000024	:America/New_York	USA	knots	153	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	0.900000000000000022	01:18:00	\N	1.10000000000000009	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
63949	Tombstone Point, 0.1 mile E of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.7038300000000035	-76.6861700000000042	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:27:00	\N	0.800000000000000044	01:25:00	\N	0.900000000000000022	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
63950	Turning Basin (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713000000000001	-76.6941699999999997	:America/New_York	USA	knots	144	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.800000000000000044	01:11:00	00:50:00	Turning Basin	NC
63951	Turning Basin (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713000000000001	-76.6941699999999997	:America/New_York	USA	knots	138	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.699999999999999956	01:09:00	00:59:00	Turning Basin	NC
63952	Sugarloaf Island, 0.2 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7124999999999986	-76.7138300000000015	:America/New_York	USA	knots	94	266	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:14:00	\N	0.800000000000000044	01:39:00	\N	0.699999999999999956	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
63953	Morehead City, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.7166700000000006	-76.732830000000007	:America/New_York	USA	knots	110	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	0.699999999999999956	01:47:00	\N	0.800000000000000044	02:12:00	01:29:00	Morehead City, S of	NC
63954	Morehead City, RR. bridge, N of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.7228300000000019	-76.6938300000000055	:America/New_York	USA	knots	185	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.5	01:01:00	\N	0.599999999999999978	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
63955	Newport Marshes, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.7313299999999998	-76.683329999999998	:America/New_York	USA	knots	215	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.599999999999999978	01:02:00	\N	0.800000000000000044	00:57:00	00:18:00	Newport Marshes, SE of	NC
63956	Newport Marshes, SE of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.7313299999999998	-76.683329999999998	:America/New_York	USA	knots	226	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.599999999999999978	01:15:00	\N	0.800000000000000044	00:53:00	00:21:00	Newport Marshes, SE of	NC
63957	Newport Marshes, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.7378300000000024	-76.680499999999995	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.5	00:11:00	\N	0.599999999999999978	00:07:00	-00:37:00	Newport Marshes, E of	NC
63958	Radio Island, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.711669999999998	-76.6796700000000016	:America/New_York	USA	knots	202	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.599999999999999978	00:55:00	\N	0.699999999999999956	00:55:00	00:20:00	Radio Island, E of	NC
63959	Bird Shoal, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7004999999999981	-76.6538299999999992	:America/New_York	USA	knots	304	126	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.400000000000000022	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
63960	Shackleford Point, NE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.6921699999999973	-76.6521699999999981	:America/New_York	USA	knots	305	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.599999999999999978	01:28:00	\N	0.800000000000000044	01:32:00	01:10:00	Shackleford Point, NE of	NC
63961	Carrot Island (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.7021700000000024	-76.6175000000000068	:America/New_York	USA	knots	262	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:49:00	\N	0.699999999999999956	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
63962	Middle Marshes, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.6783300000000025	-76.613829999999993	:America/New_York	USA	knots	275	123	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	0.5	01:04:00	\N	0.800000000000000044	00:59:00	01:03:00	Middle Marshes, S of	NC
63963	Winyah Bay entrance, Winyah Bay, South Carolina Current	NOS	ACT6531_1	33.2071699999999979	-79.1844999999999999	:America/New_York	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:20:00	\N	1	01:35:00	\N	1.10000000000000009	01:47:00	01:05:00	Winyah Bay entrance	SC
63964	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.2441699999999969	-79.205830000000006	:America/New_York	USA	knots	130	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	1.10000000000000009	01:57:00	\N	1.19999999999999996	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
63965	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.2950000000000017	-79.272829999999999	:America/New_York	USA	knots	115	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:59:00	\N	0.5	01:52:00	\N	1.10000000000000009	01:52:00	02:20:00	Frazier Point, south of	SC
63966	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.309669999999997	-79.2866700000000009	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:41:00	\N	1	02:19:00	\N	0.900000000000000022	02:23:00	02:01:00	Frazier Point, west of	SC
63967	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.339500000000001	-79.281329999999997	:America/New_York	USA	knots	215	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.900000000000000022	02:46:00	\N	1.19999999999999996	02:39:00	02:14:00	Rabbit Island, northwest of	SC
63968	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.3513299999999973	-79.2803300000000064	:America/New_York	USA	knots	135	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.699999999999999956	01:20:00	\N	0.599999999999999978	01:33:00	01:39:00	Sampit River entrance	SC
63969	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.3591699999999989	-79.2874999999999943	:America/New_York	USA	knots	80	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.599999999999999978	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
63970	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3704999999999998	-79.2638299999999987	:America/New_York	USA	knots	210	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:43:00	\N	0.5	03:13:00	\N	0.400000000000000022	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
63971	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.3686700000000016	-79.2519999999999953	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:31:00	\N	0.599999999999999978	03:04:00	\N	0.400000000000000022	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
63972	Butler Island, 0.3 mile south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.4166700000000034	-79.2120000000000033	:America/New_York	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:55:00	\N	0.5	03:34:00	\N	0.400000000000000022	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
63973	North Santee River entrance (Depth 6ft), South Carolina Current	NOS	ACT6581_1	33.1358299999999986	-79.2408300000000025	:America/New_York	USA	knots	165	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:01:00	\N	0.900000000000000022	00:33:00	\N	0.900000000000000022	01:00:00	00:03:00	North Santee River entrance	SC
63974	South Santee River entrance (Depth 5ft), South Carolina Current	NOS	ACT6586_1	33.1199999999999974	-79.2750000000000057	:America/New_York	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.800000000000000044	00:38:00	\N	0.900000000000000022	00:20:00	00:27:00	South Santee River entrance	SC
63975	Fort Sumter Range, Buoy '2', Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.6829999999999998	-79.7259999999999991	:America/New_York	USA	knots	104	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.200000000000000011	-00:51:00	\N	0.200000000000000011	-01:05:00	-01:11:00	Fort Sumter Range, Buoy '2'	SC
63976	Fort Sumter Range, Buoy '4', Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.6976700000000022	-79.755669999999995	:America/New_York	USA	knots	117	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.200000000000000011	-00:59:00	\N	0.299999999999999989	-00:49:00	-01:10:00	Fort Sumter Range, Buoy '4'	SC
63977	Fort Sumter Range, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.7150000000000034	-79.7923300000000069	:America/New_York	USA	knots	128	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	-00:16:00	\N	0.400000000000000022	-00:15:00	00:17:00	Fort Sumter Range, Buoy '8'	SC
63978	Fort Sumter Range, Buoy '14', Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.7243300000000019	-79.8100000000000023	:America/New_York	USA	knots	116	287	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.800000000000000044	-00:04:00	\N	0.599999999999999978	-00:10:00	00:16:00	Fort Sumter Range, Buoy '14'	SC
63979	North Jetty, 0.8 mile southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175000000000011	-79.7999999999999972	:America/New_York	USA	knots	110	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:16:00	\N	0.599999999999999978	-00:48:00	\N	0.200000000000000011	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
63980	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.7333300000000023	-79.8333300000000037	:America/New_York	USA	knots	121	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.900000000000000022	00:04:00	\N	1.10000000000000009	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
63981	Fort Sumter Range, Buoy '20', Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.7404999999999973	-79.8444999999999965	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:51:00	\N	0.900000000000000022	-00:15:00	\N	0.900000000000000022	-00:33:00	-00:33:00	Fort Sumter Range, Buoy '20'	SC
63982	South Jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.7311699999999988	-79.8503299999999996	:America/New_York	USA	knots	204	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.39999999999999991	00:31:00	\N	0.699999999999999956	00:38:00	00:06:00	South Jetty, break in	SC
63983	Ft. Sumter, 0.6 n.mi. NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.7611699999999999	-79.8671700000000016	:America/New_York	USA	knots	138	322	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:24:00	\N	0.900000000000000022	-00:03:00	\N	0.900000000000000022	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
63984	South Chan., 0.8 mi. ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.7586700000000022	-79.8846699999999998	:America/New_York	USA	knots	115	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	1.30000000000000004	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
63985	South Chan., 0.4 mi. NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.7580000000000027	-79.906329999999997	:America/New_York	USA	knots	104	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1	00:58:00	\N	0.400000000000000022	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
63986	Sullivans I., 0.7 mi. NE of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6671_1	32.7620000000000005	-79.8675000000000068	:America/New_York	USA	knots	132	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.800000000000000044	00:37:00	\N	0.800000000000000044	00:17:00	00:01:00	Sullivans I., 0.7 mi. NE of Ft. Sumter	SC
63987	Castle Pinckney, 0.4 mile south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767000000000003	-79.9116700000000009	:America/New_York	USA	knots	98	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:58:00	\N	0.900000000000000022	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
63988	South Channel, Buoy '32', Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.7621699999999976	-79.9110000000000014	:America/New_York	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy '32'	SC
63989	Castle Pinckney, 0.6 mile southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.7663300000000035	-79.9194999999999993	:America/New_York	USA	knots	156	318	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.699999999999999956	01:20:00	\N	0.400000000000000022	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
63990	Shutes Folly Island, 0.4 mile west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.7763300000000015	-79.9208299999999952	:America/New_York	USA	knots	164	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:08:00	\N	1.10000000000000009	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
63991	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.7794999999999987	-79.9224999999999994	:America/New_York	USA	knots	190	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:23:00	\N	0.699999999999999956	01:03:00	\N	0.599999999999999978	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
63992	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7824999999999989	-79.9200000000000017	:America/New_York	USA	knots	153	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.900000000000000022	00:37:00	\N	0.599999999999999978	00:46:00	00:37:00	Customhouse Reach	SC
63993	Town Creek Lower Reach, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7924999999999969	-79.9244999999999948	:America/New_York	USA	knots	172	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	1.10000000000000009	00:24:00	\N	0.599999999999999978	00:34:00	00:02:00	Town Creek Lower Reach	SC
63994	Town Creek, 0.2 mile above bridge, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.8053299999999979	-79.9316699999999969	:America/New_York	USA	knots	166	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	1.30000000000000004	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
63995	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.7663300000000035	-79.8733299999999957	:America/New_York	USA	knots	143	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:48:00	\N	0.400000000000000022	00:27:00	\N	0.400000000000000022	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
63996	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7674999999999983	-79.8719999999999999	:America/New_York	USA	knots	151	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	01:14:00	\N	0.699999999999999956	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
63997	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.781170000000003	-79.8763299999999958	:America/New_York	USA	knots	125	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.400000000000000022	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
63998	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.7696699999999979	-79.9011699999999934	:America/New_York	USA	knots	104	301	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:59:00	\N	0.599999999999999978	-00:03:00	\N	0.699999999999999956	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
63999	Folly Reach, Buoy '5', Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.7763300000000015	-79.899169999999998	:America/New_York	USA	knots	110	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	0.800000000000000044	00:35:00	\N	0.699999999999999956	00:02:00	00:18:00	Folly Reach, Buoy '5'	SC
64000	Shutes Reach, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.7821700000000007	-79.9108300000000042	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.800000000000000044	00:22:00	\N	0.699999999999999956	00:18:00	00:15:00	Shutes Reach, Buoy '8'	SC
64001	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.7861699999999985	-79.9150000000000063	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	1	00:23:00	\N	0.800000000000000044	00:36:00	-00:12:00	Horse Reach	SC
64002	Hog Island Reach, Buoy '12', Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.7944999999999993	-79.9150000000000063	:America/New_York	USA	knots	193	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.699999999999999956	00:28:00	\N	0.699999999999999956	00:13:00	00:14:00	Hog Island Reach, Buoy '12'	SC
64003	Drum Island, 0.4 mile SSE of, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7944999999999993	-79.9208299999999952	:America/New_York	USA	knots	155	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.900000000000000022	00:53:00	\N	0.800000000000000044	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
64004	Drum Island, east of (bridge), Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8044999999999973	-79.9153299999999973	:America/New_York	USA	knots	183	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:06:00	\N	1	00:42:00	\N	0.699999999999999956	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
64005	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.8118300000000005	-79.9120000000000061	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	0.699999999999999956	00:44:00	\N	0.699999999999999956	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
64006	Drum Island Reach, off Drum I., Buoy '45', Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.8161699999999996	-79.9228300000000047	:America/New_York	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:00:00	\N	0.5	01:00:00	\N	0.400000000000000022	00:26:00	01:06:00	Drum Island Reach, off Drum I., Buoy '45'	SC
64007	Drum Island, 0.2 mile above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.8196700000000021	-79.9291699999999992	:America/New_York	USA	knots	152	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	1.19999999999999996	01:09:00	\N	0.599999999999999978	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
64008	Daniel Island Reach, Buoy '48', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.8271700000000024	-79.9288300000000049	:America/New_York	USA	knots	182	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:55:00	\N	0.699999999999999956	01:29:00	\N	0.699999999999999956	01:01:00	00:53:00	Daniel Island Reach, Buoy '48'	SC
64009	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.8299999999999983	-79.9350000000000023	:America/New_York	USA	knots	197	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.800000000000000044	01:06:00	\N	0.299999999999999989	00:41:00	-00:29:00	Shipyard Creek entrance	SC
64010	Daniel Island Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.8328300000000013	-79.9300000000000068	:America/New_York	USA	knots	190	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	1.19999999999999996	01:49:00	\N	0.800000000000000044	01:29:00	00:42:00	Daniel Island Reach	SC
64011	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.8483299999999971	-79.9291699999999992	:America/New_York	USA	knots	153	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	1.10000000000000009	01:29:00	\N	0.699999999999999956	00:55:00	00:55:00	Daniel Island Bend	SC
64012	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.863669999999999	-79.9588300000000061	:America/New_York	USA	knots	142	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.900000000000000022	02:28:00	\N	0.599999999999999978	01:26:00	01:04:00	North Charleston	SC
64013	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.8886699999999976	-79.9653299999999945	:America/New_York	USA	knots	180	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:27:00	\N	0.900000000000000022	02:06:00	\N	0.699999999999999956	01:31:00	01:08:00	Filbin Creek Reach	SC
64014	Filbin Creek Reach, 0.2 mile east of, Cooper River, South Carolina Current	NOS	ACT6816_1	32.8879999999999981	-79.9604999999999961	:America/New_York	USA	knots	197	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:29:00	\N	0.699999999999999956	01:47:00	\N	0.400000000000000022	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
64015	Filbin Creek Reach, Buoy '58', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.896329999999999	-79.9611699999999956	:America/New_York	USA	knots	214	31	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:09:00	\N	0.699999999999999956	02:04:00	\N	0.599999999999999978	01:18:00	01:24:00	Filbin Creek Reach, Buoy '58'	SC
64016	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.906329999999997	-79.9528300000000058	:America/New_York	USA	knots	242	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:07:00	\N	0.599999999999999978	02:34:00	\N	0.599999999999999978	01:35:00	01:05:00	Ordnance Reach	SC
64017	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.9088300000000018	-79.9363299999999981	:America/New_York	USA	knots	270	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.699999999999999956	02:41:00	\N	0.400000000000000022	02:06:00	00:57:00	Yellow House Creek	SC
64018	Yellow House Landing, 1 mile NW of, Cooper River, South Carolina Current	NOS	ACT6836_1	32.9196700000000035	-79.930499999999995	:America/New_York	USA	knots	170	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:06:00	\N	0.900000000000000022	02:43:00	\N	0.400000000000000022	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
64019	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.9258308410644531	-79.932830810546875	:America/New_York	USA	knots	157	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
64020	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.9316699999999969	-79.9383299999999934	:America/New_York	USA	knots	201	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.699999999999999956	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
64021	Snow Point, 0.5 mile north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.9300000000000068	:America/New_York	USA	knots	210	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.699999999999999956	02:36:00	\N	0.599999999999999978	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
64022	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.9683300000000017	-79.933329999999998	:America/New_York	USA	knots	67	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:34:00	\N	0.599999999999999978	00:45:00	\N	0.599999999999999978	00:46:00	00:48:00	Back River entrance	SC
64023	Amoco Pier, off, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.9591700000000003	-79.9180000000000064	:America/New_York	USA	knots	191	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.5	02:49:00	\N	0.400000000000000022	02:09:00	02:10:00	Amoco Pier, off	SC
64024	Moreland, 0.5 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005000000000024	-79.9046699999999959	:America/New_York	USA	knots	216	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:19:00	\N	1	02:58:00	\N	1.10000000000000009	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
64025	Hagan Island, 1 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.0333299999999994	-79.913330000000002	:America/New_York	USA	knots	134	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.699999999999999956	03:52:00	\N	0.800000000000000044	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
64026	The Tee, 0.4 mile southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.0633300000000006	-79.9296700000000016	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:20:00	\N	0.900000000000000022	04:20:00	\N	0.599999999999999978	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
64027	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.0658299999999983	-79.9230000000000018	:America/New_York	USA	knots	161	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.5	03:09:00	\N	0.599999999999999978	03:00:00	02:36:00	The Tee	SC
64028	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.093829999999997	-79.9424999999999955	:America/New_York	USA	knots	141	309	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:34:00	\N	0.900000000000000022	04:27:00	\N	0.400000000000000022	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
64029	East Branch, 0.2 mile above entrance, Cooper River, South Carolina Current	NOS	ACT6891_1	33.0683300000000031	-79.9200000000000017	:America/New_York	USA	knots	262	84	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:06:00	\N	0.900000000000000022	03:07:00	\N	1.10000000000000009	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
64030	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.0716699999999975	-79.8833300000000008	:America/New_York	USA	knots	197	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:36:00	\N	0.400000000000000022	03:10:00	\N	0.400000000000000022	03:27:00	02:44:00	Bonneau Ferry, east of	SC
64031	Remley Point, 0.2 mile northwest of, Wando River, South Carolina Current	NOS	ACT6901_1	32.8161699999999996	-79.9094999999999942	:America/New_York	USA	knots	191	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:04:00	\N	0.900000000000000022	00:36:00	\N	0.800000000000000044	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
64032	Wando River Upper Reach, Turning Basin, Wando River, South Carolina Current	NOS	ACT6906_1	32.8333299999999966	-79.8966700000000003	:America/New_York	USA	knots	192	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.599999999999999978	-00:12:00	\N	0.599999999999999978	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
64033	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.859499999999997	-79.8961699999999979	:America/New_York	USA	knots	216	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.900000000000000022	00:35:00	\N	0.800000000000000044	00:25:00	00:18:00	Rathall Creek entrance	SC
64034	Horlbeck Creek, 0.2 mile above entrance, Wando River, South Carolina Current	NOS	ACT6916_1	32.884999999999998	-79.8449999999999989	:America/New_York	USA	knots	218	26	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	00:29:00	\N	0.599999999999999978	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
64035	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.8783299999999983	-79.875	:America/New_York	USA	knots	171	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:39:00	\N	0.599999999999999978	00:42:00	\N	0.400000000000000022	-00:02:00	-00:12:00	Nowell Creek entrance	SC
64036	Buoy '19', off Nowell Creek, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.8719999999999999	-79.8654999999999973	:America/New_York	USA	knots	261	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Buoy '19', off Nowell Creek	SC
64037	Horlbeck Creek, 2.5 miles north of, Wando River, South Carolina Current	NOS	ACT6931_1	32.9183299999999974	-79.8383299999999991	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:28:00	\N	0.699999999999999956	00:41:00	\N	0.5	00:30:00	00:26:00	Horlbeck Creek, 2.5 miles north of	SC
64038	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.7671700000000001	-79.9338300000000004	:America/New_York	USA	knots	114	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.900000000000000022	00:09:00	\N	0.699999999999999956	00:16:00	-00:24:00	Battery, southwest of	SC
64039	Wappoo Creek, off of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.7730000000000032	-79.9500000000000028	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:41:00	\N	0.599999999999999978	-00:05:00	\N	0.699999999999999956	00:07:00	-00:06:00	Wappoo Creek, off of	SC
64040	Highway Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.7819999999999965	-79.9599999999999937	:America/New_York	USA	knots	138	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.599999999999999978	00:30:00	\N	0.699999999999999956	-00:09:00	-00:03:00	Highway Bridge	SC
64041	S.C.L. RR. bridge, 0.1 mile below, Ashley River, South Carolina Current	NOS	ACT6951_1	32.795499999999997	-79.9733300000000042	:America/New_York	USA	knots	150	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:28:00	\N	0.599999999999999978	00:44:00	\N	0.599999999999999978	-00:06:00	-00:12:00	S.C.L. RR. bridge, 0.1 mile below	SC
64042	S.C.L. RR. bridge, 1.5 miles above, Ashley River, South Carolina Current	NOS	ACT6956_1	32.8200000000000003	-79.9650000000000034	:America/New_York	USA	knots	178	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.800000000000000044	00:19:00	\N	0.699999999999999956	00:22:00	00:17:00	S.C.L. RR. bridge, 1.5 miles above	SC
64043	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.8371700000000004	-79.9819999999999993	:America/New_York	USA	knots	114	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:05:00	\N	0.5	-00:04:00	\N	0.599999999999999978	00:06:00	00:05:00	State Hwy. 7 bridge	SC
64044	West Marsh Island, 0.1 mile east of, Ashley River, South Carolina Current	NOS	ACT6966_1	32.8283300000000011	-80.0083300000000008	:America/New_York	USA	knots	86	250	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:25:00	\N	0.5	00:30:00	\N	0.400000000000000022	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
64045	Bees Ferry Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.8466700000000031	-80.0499999999999972	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.19999999999999996	00:44:00	\N	1.10000000000000009	01:13:00	00:37:00	Bees Ferry Bridge	SC
64046	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.6266699999999972	-79.9933300000000003	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:45:00	\N	1.39999999999999991	00:44:00	\N	1.10000000000000009	-00:14:00	-00:09:00	Stono Inlet	SC
64047	Snake Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.6400000000000006	-80.019999999999996	:America/New_York	USA	knots	179	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.5	-00:42:00	\N	0.699999999999999956	-00:44:00	-00:30:00	Snake Island	SC
64048	Johns Island Airport, south of (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.683329999999998	-80.0033300000000054	:America/New_York	USA	knots	192	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.800000000000000044	-00:46:00	\N	0.900000000000000022	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
64049	Johns Island Bridge (Depth 14ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.7533299999999983	-80.0100000000000051	:America/New_York	USA	knots	182	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
64050	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.7666699999999977	-80	:America/New_York	USA	knots	80	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	1	-01:00:00	\N	0.900000000000000022	00:10:00	-00:46:00	Elliott Cut, west end	SC
64051	Johns Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.7866700000000009	-80.106669999999994	:America/New_York	USA	knots	68	249	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:32:00	\N	0.400000000000000022	01:48:00	\N	0.400000000000000022	-00:24:00	00:29:00	Johns Island	SC
64052	Pleasant Point (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.1333300000000008	:America/New_York	USA	knots	196	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:37:00	\N	0.400000000000000022	00:34:00	\N	0.299999999999999989	02:04:00	03:54:00	Pleasant Point	SC
64053	Deveaux Banks, off North Edisto River entrance (Depth 12ft), South Carolina Current	NOS	ACT7021_1	32.5450000000000017	-80.1566700000000054	:America/New_York	USA	knots	126	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:26:00	\N	1	-00:01:00	\N	0.800000000000000044	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
64054	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.5616699999999994	-80.1866700000000066	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1.89999999999999991	01:10:00	\N	1.69999999999999996	00:56:00	01:11:00	North Edisto River entrance	SC
64055	Wadmalaw Island, Wadmalaw River entrance (Depth 12ft), South Carolina Current	NOS	ACT7031_1	32.6649999999999991	-80.2349999999999994	:America/New_York	USA	knots	165	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.400000000000000022	00:11:00	\N	0.699999999999999956	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
64056	Goshen Point, SE of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7036_1	32.7100000000000009	-80.171670000000006	:America/New_York	USA	knots	249	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.400000000000000022	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
64057	Goshen Point, south of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7041_1	32.7133299999999991	-80.1866700000000066	:America/New_York	USA	knots	235	48	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:53:00	\N	0.5	02:03:00	\N	0.400000000000000022	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
64058	White Point, south of, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.2816700000000054	:America/New_York	USA	knots	44	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.400000000000000022	00:02:00	\N	0.400000000000000022	00:31:00	00:29:00	White Point, south of, Dawho River	SC
64059	Whooping Island, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7051_1	32.6366700000000023	-80.3400000000000034	:America/New_York	USA	knots	70	246	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.299999999999999989	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
64060	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.4883299999999977	-80.3483300000000042	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	1.10000000000000009	-00:14:00	\N	1.10000000000000009	00:19:00	-00:09:00	South Edisto River entrance	SC
64061	Pine Island, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7061_1	32.5066699999999997	-80.3616700000000037	:America/New_York	USA	knots	163	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	0.5	-00:09:00	\N	0.699999999999999956	00:00:00	00:12:00	Pine Island, South Edisto River	SC
64062	Fenwick Island Cut, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7066_1	32.5349999999999966	-80.413330000000002	:America/New_York	USA	knots	23	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:26:00	\N	0.400000000000000022	-00:55:00	\N	0.400000000000000022	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
64063	Sampson Island, S end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7071_1	32.5633300000000006	-80.3916700000000048	:America/New_York	USA	knots	244	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.800000000000000044	00:34:00	\N	0.800000000000000044	00:59:00	00:59:00	Sampson Island, S end, South Edisto River	SC
64064	Sampson Island, NE end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7076_1	32.6166699999999992	-80.3866699999999952	:America/New_York	USA	knots	156	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.800000000000000044	01:15:00	\N	0.800000000000000044	01:35:00	01:02:00	Sampson Island, NE end, South Edisto River	SC
64065	Jehossee Island, S tip, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7081_1	32.6033299999999997	-80.4200000000000017	:America/New_York	USA	knots	69	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:05:00	\N	0.699999999999999956	00:48:00	\N	0.699999999999999956	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
64066	Smuggedy Swamp, South Edisto River (Depth 6ft), South Carolina Current	NOS	ACT7086_1	32.6599999999999966	-80.4116700000000009	:America/New_York	USA	knots	166	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.699999999999999956	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
64067	Hutchinson Island, Ashepoo River (Depth 10ft), South Carolina Current	NOS	ACT7091_1	32.5316699999999983	-80.4350000000000023	:America/New_York	USA	knots	68	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:56:00	\N	0.699999999999999956	01:14:00	\N	0.599999999999999978	01:21:00	00:54:00	Hutchinson Island, Ashepoo River	SC
64068	Ashepoo Coosaw Cutoff (Depth 6ft), South Carolina Current	NOS	ACT7096_1	32.5249999999999986	-80.453329999999994	:America/New_York	USA	knots	265	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.599999999999999978	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff	SC
64069	Pelican Bank, St. Helena Sound (Depth 15ft), South Carolina Current	NOS	ACT7101_1	32.4549999999999983	-80.4283300000000025	:America/New_York	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:35:00	\N	0.800000000000000044	-00:33:00	\N	0.900000000000000022	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
64070	Ashepoo River, off Jefford Creek entrance, South Carolina Current	NOS	ACT7106_1	32.5066699999999997	-80.4099999999999966	:America/New_York	USA	knots	197	16	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	0.800000000000000044	00:46:00	\N	0.900000000000000022	01:04:00	01:00:00	Ashepoo River, off Jefford Creek entrance	SC
64071	Egg Bank, St. Helena Sound (Depth 10ft), South Carolina Current	NOS	ACT7111_1	32.4350000000000023	-80.4433300000000031	:America/New_York	USA	knots	128	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.800000000000000044	-01:24:00	\N	0.800000000000000044	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
64072	Morgan Island, NE of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7116_1	32.4883299999999977	-80.4733300000000042	:America/New_York	USA	knots	125	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:19:00	\N	1	00:27:00	\N	0.800000000000000044	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
64073	Ashe Island Cut, SW of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7121_1	32.509999999999998	-80.5049999999999955	:America/New_York	USA	knots	134	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.599999999999999978	-00:09:00	\N	0.599999999999999978	00:32:00	00:43:00	Ashe Island Cut, SW of, Coosaw River	SC
64074	Ashe Island Cut, St. Helena Sound (Depth 6ft), South Carolina Current	NOS	ACT7126_1	32.5200000000000031	-80.4883300000000048	:America/New_York	USA	knots	34	232	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:13:00	\N	0.400000000000000022	01:41:00	\N	0.5	00:31:00	01:01:00	Ashe Island Cut, St. Helena Sound	SC
64075	Combahee River (Depth 8ft), South Carolina Current	NOS	ACT7131_1	32.5266700000000029	-80.5366700000000009	:America/New_York	USA	knots	147	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.800000000000000044	00:59:00	\N	0.599999999999999978	00:55:00	01:04:00	Combahee River	SC
64076	Combahee River (Depth 15ft), South Carolina Current	NOS	ACT7136_1	32.5499999999999972	-80.5633299999999934	:America/New_York	USA	knots	73	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:03:00	\N	1	01:35:00	\N	0.800000000000000044	01:36:00	01:33:00	Combahee River	SC
64077	Parrot Creek, Coosaw Island (Depth 15ft), South Carolina Current	NOS	ACT7141_1	32.4733299999999971	-80.5450000000000017	:America/New_York	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:54:00	\N	0.599999999999999978	-00:48:00	\N	0.699999999999999956	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
64078	Morgan Island, North end, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7146_1	32.5033299999999983	-80.5366700000000009	:America/New_York	USA	knots	85	271	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:30:00	\N	0.900000000000000022	00:41:00	\N	0.800000000000000044	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
64079	Williman Creek (Depth 10ft), South Carolina Current	NOS	ACT7151_1	32.5616699999999994	-80.5916699999999935	:America/New_York	USA	knots	160	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:04:00	\N	0.800000000000000044	01:27:00	\N	0.599999999999999978	00:40:00	01:02:00	Williman Creek	SC
64080	Coosaw Island, South of, Morgan River (Depth 10ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.5833300000000037	:America/New_York	USA	knots	58	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.699999999999999956	00:55:00	\N	0.699999999999999956	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
64081	Sams Point, Northwest of, Coosaw River (Depth 10ft), South Carolina Current	NOS	ACT7161_1	32.4933300000000003	-80.5933299999999946	:America/New_York	USA	knots	117	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.599999999999999978	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northwest of, Coosaw River	SC
64082	Whale Branch River (Depth 10ft), South Carolina Current	NOS	ACT7166_1	32.5266700000000029	-80.691670000000002	:America/New_York	USA	knots	111	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.699999999999999956	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
64083	Fripps Inlet, Fripps Island (Depth 15ft), South Carolina Current	NOS	ACT7171_1	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	knots	104	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.599999999999999978	01:12:00	\N	0.699999999999999956	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
64084	Southeast Channel entrance, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.1333300000000008	-80.5833300000000037	:America/New_York	USA	knots	150	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.800000000000000044	-00:38:00	\N	0.800000000000000044	-00:30:00	-00:09:00	Southeast Channel entrance	SC
64085	Port Royal Plantation Tower, east of (Depth 15ft), South Carolina Current	NOS	ACT7186_1	32.2233299999999971	-80.6566700000000054	:America/New_York	USA	knots	147	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	1	-00:16:00	\N	0.900000000000000022	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
64086	Bay Point Island, S of, Broad River entrance (Depth 15ft), South Carolina Current	NOS	ACT7191_1	32.2333300000000023	-80.6299999999999955	:America/New_York	USA	knots	128	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.900000000000000022	-01:09:00	\N	0.699999999999999956	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
64087	Broad River Entrance, Point Royal Sound (Depth 15ft), South Carolina Current	NOS	ACT7196_1	32.2316700000000012	-80.6400000000000006	:America/New_York	USA	knots	138	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.900000000000000022	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
64088	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.6666699999999963	:America/New_York	USA	knots	146	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.900000000000000022	00:49:00	\N	1.10000000000000009	00:16:00	00:32:00	Hilton Head	SC
64089	Beaufort River Entrance (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.288330000000002	-80.6516699999999958	:America/New_York	USA	knots	195	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.699999999999999956	01:11:00	\N	0.699999999999999956	00:19:00	00:20:00	Beaufort River Entrance	SC
64090	Parris Island, Beaufort River (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7211_1	32.32667	-80.6566700000000054	:America/New_York	USA	knots	175	356	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:00:00	\N	0.800000000000000044	01:12:00	\N	0.699999999999999956	00:29:00	00:11:00	Parris Island, Beaufort River	SC
64091	Chowan Creek (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.3699999999999974	-80.6383299999999963	:America/New_York	USA	knots	246	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.599999999999999978	01:53:00	\N	0.599999999999999978	00:24:00	00:23:00	Chowan Creek	SC
64092	Parris Island, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7221_1	32.3599999999999994	-80.6749999999999972	:America/New_York	USA	knots	149	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	0.699999999999999956	01:19:00	\N	0.699999999999999956	00:56:00	00:51:00	Parris Island, Beaufort River	SC
64093	Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.4033299999999969	-80.671670000000006	:America/New_York	USA	knots	200	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Beaufort River	SC
64094	Beaufort, Beaufort River (Depth 12ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.4299999999999997	-80.6766700000000014	:America/New_York	USA	knots	257	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.599999999999999978	01:18:00	\N	0.699999999999999956	00:55:00	01:08:00	Beaufort, Beaufort River	SC
64095	Beaufort Airport, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.4500000000000028	-80.663330000000002	:America/New_York	USA	knots	152	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
64096	Brickyard Creek (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.4733299999999971	-80.691670000000002	:America/New_York	USA	knots	171	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:58:00	\N	0.400000000000000022	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
64097	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.2633300000000034	-80.7416699999999992	:America/New_York	USA	knots	35	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-02:14:00	\N	0.599999999999999978	-01:20:00	\N	0.400000000000000022	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
64098	Daws Island, SE of, Broad River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.3016700000000014	-80.7249999999999943	:America/New_York	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.800000000000000044	00:05:00	\N	0.800000000000000044	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
64099	Parris Island Lookout Tower, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7256_1	32.3116699999999994	-80.7066700000000026	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.699999999999999956	-00:07:00	\N	0.699999999999999956	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
64100	Daws Island, south of, Chechessee River (Depth 15ft), South Carolina Current	NOS	ACT7261_1	32.2866700000000009	-80.7433300000000003	:America/New_York	USA	knots	142	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.699999999999999956	-00:22:00	\N	0.599999999999999978	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
64101	Lemon Island South, Chechessee River (Depth 10ft), South Carolina Current	NOS	ACT7266_1	32.3500000000000014	-80.8066699999999969	:America/New_York	USA	knots	175	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.699999999999999956	01:19:00	\N	0.599999999999999978	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
64102	Broad River Bridge, S of, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7271_1	32.3816699999999997	-80.7766699999999958	:America/New_York	USA	knots	156	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	0.800000000000000044	-00:15:00	\N	0.599999999999999978	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
64103	Byrd Creek Entrance, SE of, Broad River (Depth 12ft), South Carolina Current	NOS	ACT7276_1	32.4566700000000026	-80.8183300000000031	:America/New_York	USA	knots	174	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.5	00:51:00	\N	0.599999999999999978	01:27:00	01:32:00	Byrd Creek Entrance, SE of, Broad River	SC
64104	Little Barnwell I., E of, Whale Branch River (Depth 6ft), South Carolina Current	NOS	ACT7281_1	32.5016699999999972	-80.7866700000000009	:America/New_York	USA	knots	175	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.400000000000000022	03:03:00	\N	0.599999999999999978	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
64105	Braddock Point, SW of, Calibogue Sound (Depth 10ft), South Carolina Current	NOS	ACT7286_1	32.1049999999999969	-80.836669999999998	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:04:00	\N	1	00:16:00	\N	0.800000000000000044	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
64106	Haig Point Light, NW of, Cooper River (Depth 10ft), South Carolina Current	NOS	ACT7291_1	32.1483300000000014	-80.8416699999999935	:America/New_York	USA	knots	94	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.699999999999999956	-00:05:00	\N	0.400000000000000022	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
64107	Ramshorn Creek Light, E of, Cooper River (Depth 6ft), South Carolina Current	NOS	ACT7296_1	32.1300000000000026	-80.8816699999999997	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:17:00	\N	0.699999999999999956	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
64108	Spanish Wells, Calibogue Sound (Depth 30ft), Calibogue Sound, South Carolina Current	NOS	ACT7301_1	32.1866699999999994	-80.7849999999999966	:America/New_York	USA	knots	204	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.699999999999999956	00:51:00	\N	0.699999999999999956	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
64109	Skull Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.2233299999999971	-80.7849999999999966	:America/New_York	USA	knots	231	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:55:00	\N	0.400000000000000022	02:57:00	\N	0.400000000000000022	00:38:00	01:23:00	Skull Creek, south entrance	SC
64110	MacKay Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.2199999999999989	-80.7900000000000063	:America/New_York	USA	knots	212	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:26:00	\N	0.599999999999999978	00:03:00	\N	0.299999999999999989	00:06:00	00:12:00	MacKay Creek, south entrance	SC
64111	Bloody Pt., 0.5 mile north of, New River, South Carolina Current	NOS	ACT7316_1	32.0883299999999991	-80.8799999999999955	:America/New_York	USA	knots	147	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:13:00	\N	0.599999999999999978	00:00:00	\N	0.599999999999999978	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
64112	Bloody Pt., 0.5 mile west of, New River, South Carolina Current	NOS	ACT7321_1	32.0816700000000026	-80.8833300000000008	:America/New_York	USA	knots	92	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.900000000000000022	-00:21:00	\N	0.900000000000000022	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
64113	Wright R., 0.2 mile above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.0850000000000009	-80.921670000000006	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.800000000000000044	-00:16:00	\N	0.599999999999999978	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
64114	Walls Cut, Turtle Island (Depth 6ft), South Carolina Current	NOS	ACT7336_1	32.0816700000000026	-80.9166699999999963	:America/New_York	USA	knots	100	294	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
64115	Daufuskie Landing Light, south of (Depth 10ft), South Carolina Current	NOS	ACT7341_1	32.1016699999999986	-80.8983300000000014	:America/New_York	USA	knots	226	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:45:00	\N	0.800000000000000044	01:04:00	\N	0.699999999999999956	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
64116	Fort Pulaski, Savannah River, Georgia Current	NOS	ACT7356_1	32.0366700000000009	-80.9016699999999958	:America/New_York	USA	knots	98	283	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:09:00	\N	1.5	00:51:00	\N	0.900000000000000022	00:42:00	00:15:00	Fort Pulaski	GA
64117	Fort Pulaski, 1.8 miles above, Savannah River, Georgia Current	NOS	ACT7361_1	32.0450000000000017	-80.9316699999999969	:America/New_York	USA	knots	140	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:12:00	\N	1.39999999999999991	00:18:00	\N	1.10000000000000009	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
64118	Fort Pulaski, 4.8 miles above, Savannah River, Georgia Current	NOS	ACT7366_1	32.0750000000000028	-80.9766699999999986	:America/New_York	USA	knots	116	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:16:00	\N	1.5	00:31:00	\N	1.10000000000000009	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
64119	McQueen Island Cut (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.0649999999999977	-80.9866700000000037	:America/New_York	USA	knots	69	251	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.599999999999999978	-02:45:00	\N	0.299999999999999989	-02:39:00	-01:04:00	McQueen Island Cut	GA
64120	Elba Island Cut, NE of, Savannah River (Depth 10ft), South Carolina Current	NOS	ACT7376_1	32.0733299999999986	-80.9650000000000034	:America/New_York	USA	knots	104	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:14:00	\N	1.30000000000000004	00:15:00	\N	0.699999999999999956	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
64121	Elba Island, NE of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7381_1	32.0900000000000034	-80.9933300000000003	:America/New_York	USA	knots	149	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	1.19999999999999996	00:40:00	\N	0.599999999999999978	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
64122	Elba Island, west of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7386_1	32.0949999999999989	-81.019999999999996	:America/New_York	USA	knots	40	219	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.800000000000000044	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	GA
64123	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.0850000000000009	-81.0499999999999972	:America/New_York	USA	knots	94	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.699999999999999956	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
64124	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.0883299999999991	-81.0166700000000048	:America/New_York	USA	knots	122	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:35:00	\N	0.699999999999999956	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
64125	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.0016700000000043	:America/New_York	USA	knots	206	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:25:00	\N	0.800000000000000044	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
64126	Savannah, southeast of highway bridge (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.086669999999998	-81.0966700000000031	:America/New_York	USA	knots	146	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:05:00	\N	1.30000000000000004	00:41:00	\N	0.599999999999999978	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
64127	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.0833299999999966	-81.0833300000000037	:America/New_York	USA	knots	106	279	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:18:00	\N	1.10000000000000009	00:45:00	\N	0.800000000000000044	01:12:00	00:01:00	Savannah	GA
64128	Kings Island Channel, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7416_1	32.1266699999999972	-81.1366699999999952	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	1	00:45:00	\N	0.800000000000000044	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
64129	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.1033299999999997	-81.1183300000000003	:America/New_York	USA	knots	150	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:59:00	\N	1.69999999999999996	00:45:00	\N	1.19999999999999996	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
64130	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.1233300000000028	-81.1350000000000051	:America/New_York	USA	knots	160	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:48:00	\N	1	00:54:00	\N	0.699999999999999956	01:21:00	00:33:00	King Island, west of	GA
64149	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.9533300000000011	-81.0649999999999977	:America/New_York	USA	knots	42	218	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
64131	Port Wentworth, 0.2 mile above, Savannah River, Georgia Current	NOS	ACT7431_1	32.1466700000000003	-81.1400000000000006	:America/New_York	USA	knots	210	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:19:00	\N	0.699999999999999956	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
64132	Wassaw Island, N of E end, Wassaw Sound (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.9149999999999991	-80.9383299999999934	:America/New_York	USA	knots	108	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	1	-00:50:00	\N	0.699999999999999956	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
64133	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.9416699999999985	-80.9316699999999969	:America/New_York	USA	knots	156	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1.10000000000000009	-01:00:00	\N	0.900000000000000022	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
64134	Wilmington Island, SSE of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.9666700000000006	-80.9300000000000068	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:00:00	\N	0.699999999999999956	00:38:00	\N	0.400000000000000022	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
64135	Lazaretto Creek Entrance, N of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.9283300000000025	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:04:00	\N	0.699999999999999956	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
64136	Bull River, 2 miles below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.0183299999999988	-80.9399999999999977	:America/New_York	USA	knots	151	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:57:00	\N	0.800000000000000044	-00:18:00	\N	0.599999999999999978	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
64137	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.9166699999999999	-80.9466699999999975	:America/New_York	USA	knots	105	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.900000000000000022	-01:11:00	\N	0.699999999999999956	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
64138	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.9383300000000006	-80.9766699999999986	:America/New_York	USA	knots	138	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.800000000000000044	-00:36:00	\N	0.599999999999999978	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
64139	Joe's Cut, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.9433299999999996	-80.9849999999999994	:America/New_York	USA	knots	123	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1	-00:48:00	\N	0.599999999999999978	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
64140	Wilmington R., 0.5 mi. S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.0050000000000026	-81.0033300000000054	:America/New_York	USA	knots	154	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.699999999999999956	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
64141	Thunderbolt, SE of, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.0233300000000014	-81.0450000000000017	:America/New_York	USA	knots	121	298	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:25:00	\N	0.5	-01:04:00	\N	0.400000000000000022	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
64142	Oatland Island, north tip (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.0733299999999986	-81.0100000000000051	:America/New_York	USA	knots	138	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:32:00	\N	0.5	-02:14:00	\N	0.299999999999999989	-03:20:00	-00:43:00	Oatland Island, north tip	GA
64143	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.0083300000000008	-81.0166700000000048	:America/New_York	USA	knots	16	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.699999999999999956	-00:02:00	\N	0.599999999999999978	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
64144	Skidaway Island, N End, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.009999999999998	-81.0083300000000008	:America/New_York	USA	knots	119	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.900000000000000022	00:16:00	\N	0.599999999999999978	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
64145	Dutch Island, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.9916699999999992	-81.019999999999996	:America/New_York	USA	knots	61	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:02:00	\N	0.599999999999999978	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
64146	Isle of Hope City, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.9766699999999986	-81.046670000000006	:America/New_York	USA	knots	72	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:40:00	\N	0.299999999999999989	-00:30:00	\N	0.200000000000000011	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
64147	Isle of Hope City, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.9800000000000004	-81.0550000000000068	:America/New_York	USA	knots	28	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.299999999999999989	00:00:00	\N	0.400000000000000022	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
64148	Burntpot Island, west of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.9683300000000017	-81.0533300000000025	:America/New_York	USA	knots	18	194	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
64150	Long Island, NNE of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.956669999999999	-81.0600000000000023	:America/New_York	USA	knots	47	226	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:17:00	\N	0.400000000000000022	-01:09:00	\N	0.400000000000000022	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
64151	Long Island, south of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.9433299999999996	-81.0733299999999986	:America/New_York	USA	knots	258	75	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-08:05:00	\N	0.299999999999999989	-04:43:00	\N	0.200000000000000011	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
64152	Pigeon Island, SSE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.9366699999999994	-81.0766699999999929	:America/New_York	USA	knots	150	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:16:00	\N	0.5	-02:43:00	\N	0.200000000000000011	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
64153	Burnside Island, SE of, Burnside River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.9216699999999989	-81.0799999999999983	:America/New_York	USA	knots	295	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.599999999999999978	00:53:00	\N	0.400000000000000022	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
64154	Little Don Island, east of, Vernon River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.870000000000001	-81.0733299999999986	:America/New_York	USA	knots	153	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.699999999999999956	-01:16:00	\N	0.699999999999999956	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
64155	Little Ogeechee River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.8883299999999998	-81.0983300000000042	:America/New_York	USA	knots	71	259	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:06:00	\N	1	-00:59:00	\N	0.699999999999999956	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
64156	Little Ogeechee River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.8883299999999998	-81.0983300000000042	:America/New_York	USA	knots	73	244	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	0.900000000000000022	-00:50:00	\N	0.599999999999999978	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
64157	Montgomery, Vernon River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.9349999999999987	-81.1283300000000054	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:30:00	\N	0.599999999999999978	00:00:00	\N	0.299999999999999989	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
64158	Odingsell River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.8683300000000003	-81	:America/New_York	USA	knots	212	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:14:00	\N	0.900000000000000022	00:44:00	\N	0.699999999999999956	-00:54:00	-00:48:00	Odingsell River Entrance	GA
64159	Odingsell River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.8683300000000003	-81	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:12:00	\N	0.800000000000000044	00:42:00	\N	0.599999999999999978	-01:19:00	-00:42:00	Odingsell River Entrance	GA
64160	Wassaw Island, SSW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.8566700000000012	-81.0083300000000008	:America/New_York	USA	knots	123	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	1.10000000000000009	-01:04:00	\N	0.800000000000000044	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
64161	Wassaw Island, SSW of (Depth 20ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.8566700000000012	-81.0083300000000008	:America/New_York	USA	knots	132	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	0.900000000000000022	-00:58:00	\N	0.699999999999999956	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
64162	Bradley Point, NNE of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.831669999999999	-81.038330000000002	:America/New_York	USA	knots	125	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.800000000000000044	-00:58:00	\N	0.599999999999999978	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
64163	Raccoon Key (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.8616700000000002	-81.0550000000000068	:America/New_York	USA	knots	117	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:35:00	\N	0.900000000000000022	-01:23:00	\N	0.800000000000000044	-00:45:00	-00:36:00	Raccoon Key	GA
64164	Little Wassaw Island, SW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.870000000000001	-81.0499999999999972	:America/New_York	USA	knots	116	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.699999999999999956	-00:17:00	\N	0.900000000000000022	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
64165	Vernon R., 1.2 miles S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.8983300000000014	-81.0983300000000042	:America/New_York	USA	knots	166	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	0.800000000000000044	00:02:00	\N	0.599999999999999978	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
64166	Little Ogeechee River Entrance, north of (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.8966700000000003	-81.0949999999999989	:America/New_York	USA	knots	156	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:03:00	\N	0.800000000000000044	00:29:00	\N	0.599999999999999978	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
64167	Raccoon Key & Egg Island Shoal, between (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.8428299999999993	-81.0674999999999955	:America/New_York	USA	knots	129	254	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	1	00:17:00	\N	0.800000000000000044	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
64168	Florida Passage, N of, Ogeechee River (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.8566700000000012	-81.143330000000006	:America/New_York	USA	knots	127	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:05:00	\N	1	00:01:00	\N	0.699999999999999956	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
64169	Florida Passage (south) (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.8296700000000001	-81.1578300000000041	:America/New_York	USA	knots	18	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.699999999999999956	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
64170	610 Statute Mile Mark (Depth 6ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105000000000011	-81.1766700000000014	:America/New_York	USA	knots	175	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	0.699999999999999956	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
64171	North of Big Tom Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7621_1	31.7833299999999994	-81.1603300000000019	:America/New_York	USA	knots	179	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.699999999999999956	-00:13:00	\N	0.599999999999999978	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
64172	South of Kilkenny Creek Entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.7583300000000008	-81.1733300000000071	:America/New_York	USA	knots	190	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	1	01:25:00	\N	0.599999999999999978	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
64173	Northwest of Newell Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7631_1	31.7488300000000017	-81.1654999999999944	:America/New_York	USA	knots	149	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.900000000000000022	00:12:00	\N	0.599999999999999978	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
64174	Medway River at Marsh Island (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.7433300000000003	-81.2199999999999989	:America/New_York	USA	knots	117	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:56:00	\N	0.800000000000000044	-00:18:00	\N	0.299999999999999989	00:20:00	-00:15:00	Medway River at Marsh Island	GA
64175	St. Catherines Sound Entrance (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7641_1	31.7149999999999999	-81.140500000000003	:America/New_York	USA	knots	126	291	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.800000000000000044	-00:31:00	\N	0.900000000000000022	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
64176	Medway River, northwest of Cedar Point (Depth 10ft), Georgia Current	NOS	ACT7646_1	31.714500000000001	-81.1908300000000054	:America/New_York	USA	knots	146	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.800000000000000044	-00:43:00	\N	0.699999999999999956	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
64177	N. Newport River, NE of Vandyke Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7651_1	31.6911699999999996	-81.1869999999999976	:America/New_York	USA	knots	45	233	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.800000000000000044	00:12:00	\N	0.699999999999999956	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
64178	N. Newport River, above Walburg Creek (Depth 6ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.6738299999999988	-81.1953299999999984	:America/New_York	USA	knots	11	195	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:40:00	\N	0.800000000000000044	00:30:00	\N	0.599999999999999978	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
64179	N. Newport River, NW of Johnson Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7661_1	31.6630000000000003	-81.2104999999999961	:America/New_York	USA	knots	138	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	0.900000000000000022	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
64180	N. Newport River, ESE of S. Newport Cut (Depth 6ft), Georgia Current	NOS	ACT7666_1	31.6653300000000009	-81.2644999999999982	:America/New_York	USA	knots	147	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:15:00	\N	0.699999999999999956	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
64181	S. Newport River, below S. Newport Cut (Depth 10ft), Georgia Current	NOS	ACT7671_1	31.6503300000000003	-81.3020000000000067	:America/New_York	USA	knots	134	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
64182	S. Newport River, above Swain River Ent (Depth 10ft), Georgia Current	NOS	ACT7676_1	31.6245000000000012	-81.2166699999999935	:America/New_York	USA	knots	156	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.599999999999999978	-01:13:00	\N	0.599999999999999978	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
64183	Entrance (Depth 19ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.5399999999999991	-81.1800000000000068	:America/New_York	USA	knots	118	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.10000000000000009	00:28:00	\N	0.900000000000000022	-00:30:00	-00:06:00	Entrance	GA
64184	Entrance (Depth 29ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.5399999999999991	-81.1800000000000068	:America/New_York	USA	knots	116	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:02:00	\N	0.900000000000000022	-00:36:00	\N	0.699999999999999956	-00:48:00	-00:17:00	Entrance	GA
64185	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.6266700000000007	-81.1883299999999934	:America/New_York	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:59:00	\N	0.400000000000000022	-01:08:00	\N	0.400000000000000022	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
64186	Cedar Hammock, south of (Depth 12ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.5450000000000017	-81.2466699999999946	:America/New_York	USA	knots	96	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.599999999999999978	-01:00:00	\N	0.699999999999999956	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
64187	Sapelo River Entrance (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.5350000000000001	-81.2716700000000003	:America/New_York	USA	knots	58	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.599999999999999978	-01:05:00	\N	0.599999999999999978	-00:23:00	-00:13:00	Sapelo River Entrance	GA
64188	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.3333300000000037	:America/New_York	USA	knots	104	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.599999999999999978	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
64189	Front River (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.5133299999999998	-81.2983300000000071	:America/New_York	USA	knots	56	227	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.5	01:16:00	\N	0.400000000000000022	-00:33:00	-00:25:00	Front River	GA
64190	New Teakettle Cr., 0.8 mi. N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.4966700000000017	-81.2900000000000063	:America/New_York	USA	knots	53	236	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.5	-00:29:00	\N	0.400000000000000022	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
64191	Crescent River (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.4866700000000002	-81.3066699999999969	:America/New_York	USA	knots	133	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.5	01:07:00	\N	0.200000000000000011	-01:27:00	-00:34:00	Crescent River	GA
64192	Old Teakettle Creek (north) (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.4783299999999997	-81.328329999999994	:America/New_York	USA	knots	256	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:37:00	\N	0.599999999999999978	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
64193	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.3449999999999989	-81.2349999999999994	:America/New_York	USA	knots	114	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.699999999999999956	-00:29:00	\N	0.699999999999999956	-00:29:00	-00:09:00	Bar	GA
64194	Entrance (Depth 14ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.3416700000000006	-81.2633299999999963	:America/New_York	USA	knots	106	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.900000000000000022	-00:10:00	\N	0.800000000000000044	-00:32:00	-00:24:00	Entrance	GA
64195	Entrance (Depth 22ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.3416700000000006	-81.2633299999999963	:America/New_York	USA	knots	99	276	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.800000000000000044	-00:05:00	\N	0.800000000000000044	-00:56:00	-00:20:00	Entrance	GA
64196	Old Teakettle Creek Entrance, south of (Depth 15ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.4200000000000017	-81.3149999999999977	:America/New_York	USA	knots	159	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
64197	Old Teakettle Creek (south) (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.4366699999999994	-81.308329999999998	:America/New_York	USA	knots	207	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.400000000000000022	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
64198	Folly River and Cardigan River, between (Depth 10ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.4416699999999985	-81.336669999999998	:America/New_York	USA	knots	150	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.299999999999999989	-00:56:00	\N	0.299999999999999989	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
64199	South River (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.3666699999999992	-81.3116700000000066	:America/New_York	USA	knots	95	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.699999999999999956	-00:25:00	\N	0.599999999999999978	-00:22:00	-00:32:00	South River	GA
64200	South River (Depth 21ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.3666699999999992	-81.3116700000000066	:America/New_York	USA	knots	95	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.400000000000000022	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
64201	North River at Darien River (Depth 9ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.3833300000000008	-81.3349999999999937	:America/New_York	USA	knots	29	247	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.200000000000000011	-00:33:00	\N	0.200000000000000011	-00:10:00	00:08:00	North River at Darien River	GA
64202	Doboy Island (North River) (Depth 12ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.4033300000000004	-81.328329999999994	:America/New_York	USA	knots	37	224	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:13:00	\N	0.5	-00:06:00	\N	0.599999999999999978	-00:14:00	00:47:00	Doboy Island (North River)	GA
64203	Doboy Island (North River) (Depth 20ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.4033300000000004	-81.328329999999994	:America/New_York	USA	knots	43	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.299999999999999989	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
64204	Buzzard Roost Creek (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.4149999999999991	-81.375	:America/New_York	USA	knots	2	177	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:28:00	\N	0.200000000000000011	00:12:00	\N	0.299999999999999989	00:22:00	00:56:00	Buzzard Roost Creek	GA
64205	Little Egg Island, northwest of (Depth 12ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.3183299999999996	-81.3050000000000068	:America/New_York	USA	knots	110	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.599999999999999978	-00:53:00	\N	0.599999999999999978	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
64206	Little Mud River Range (Depth 9ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.3183300000000031	:America/New_York	USA	knots	116	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:06:00	\N	0.5	-01:05:00	\N	0.299999999999999989	-00:38:00	-00:23:00	Little Mud River Range	GA
64207	Little St. Simon Island (north) (Depth 11ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.3116699999999994	-81.3533299999999997	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:29:00	\N	0.800000000000000044	00:06:00	\N	0.599999999999999978	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
64208	Onemile Cut, 1 mile southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.3133300000000006	-81.3516699999999986	:America/New_York	USA	knots	92	272	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:32:00	\N	0.900000000000000022	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
64209	Broughton Island (south) (Depth 9ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.3099999999999987	-81.413330000000002	:America/New_York	USA	knots	30	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.400000000000000022	00:12:00	\N	0.400000000000000022	-02:06:00	-00:01:00	Broughton Island (south)	GA
64210	Bar Channel (Depth 12ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.1050000000000004	-81.3383299999999991	:America/New_York	USA	knots	119	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.800000000000000044	-00:44:00	\N	0.400000000000000022	-00:13:00	00:09:00	Bar Channel	GA
64211	Entrance, north of channel (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335000000000015	-81.4039999999999964	:America/New_York	USA	knots	107	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:11:00	\N	0.599999999999999978	00:18:00	\N	0.900000000000000022	-00:32:00	00:07:00	Entrance, north of channel	GA
64212	Entrance, south of channel (Depth 11ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.1266700000000007	-81.4033299999999969	:America/New_York	USA	knots	80	262	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.10000000000000009	-00:32:00	\N	0.800000000000000044	-00:27:00	-00:21:00	Entrance, south of channel	GA
64213	Entrance, south of channel (Depth 29ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.1266700000000007	-81.4033299999999969	:America/New_York	USA	knots	92	257	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.800000000000000044	-00:03:00	\N	0.599999999999999978	-00:18:00	00:06:00	Entrance, south of channel	GA
64214	Back River entrance (Depth 10ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.1483300000000014	-81.441670000000002	:America/New_York	USA	knots	111	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
64215	Back River entrance (Depth 18ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.1483300000000014	-81.441670000000002	:America/New_York	USA	knots	109	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:15:00	\N	0.400000000000000022	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
64216	Mackay R., 0.5 mi. N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.2250000000000014	-81.433329999999998	:America/New_York	USA	knots	166	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:24:00	\N	0.699999999999999956	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
64217	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.1116700000000002	-81.4733300000000042	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	1	-00:03:00	\N	0.699999999999999956	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
64218	Brunswick River Bridge, southeast of (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.1149999999999984	-81.4766699999999986	:America/New_York	USA	knots	132	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:09:00	\N	0.699999999999999956	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
64219	Brunswick River Bridge, southeast of (Depth 21ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.1149999999999984	-81.4766699999999986	:America/New_York	USA	knots	129	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.699999999999999956	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
64220	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.1383299999999998	-81.4966699999999946	:America/New_York	USA	knots	166	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:08:00	\N	0.599999999999999978	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
64221	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.1766700000000014	-81.5250000000000057	:America/New_York	USA	knots	165	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:33:00	\N	0.800000000000000044	00:18:00	\N	0.699999999999999956	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
64222	Turtle River, off Andrews Island (Depth 20ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.1433299999999988	-81.5266699999999958	:America/New_York	USA	knots	153	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:23:00	\N	0.699999999999999956	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
64223	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.9866700000000002	-81.4050000000000011	:America/New_York	USA	knots	103	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	1.10000000000000009	00:13:00	\N	1.10000000000000009	-00:18:00	00:02:00	Entrance	GA
64224	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.0350000000000001	-81.433329999999998	:America/New_York	USA	knots	232	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:20:00	\N	0.699999999999999956	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
64225	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.9583300000000001	-81.4316699999999969	:America/New_York	USA	knots	18	191	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:18:00	\N	0.699999999999999956	00:32:00	\N	0.699999999999999956	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
64226	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.8816699999999997	-81.5133299999999963	:America/New_York	USA	knots	355	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:45:00	\N	0.599999999999999978	01:29:00	\N	0.699999999999999956	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
64227	Mayport (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-00:04:00	\N	1.60000000000000009	01:02:00	\N	1.10000000000000009	00:06:00	00:15:00	Mayport	FL
64228	Mayport (Depth 17ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:05:00	\N	1.30000000000000004	00:38:00	\N	1.10000000000000009	-00:03:00	00:12:00	Mayport	FL
64229	Mayport (Depth 27ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:14:00	\N	0.900000000000000022	00:26:00	\N	0.900000000000000022	-00:27:00	00:15:00	Mayport	FL
64230	Mile Point, southeast of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7976_1	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:44:00	\N	1.60000000000000009	00:38:00	\N	1.5	00:06:00	00:48:00	Mile Point, southeast of	FL
64231	Mile Point, southeast of (Depth 18ft), St. Johns River, Florida Current	NOS	ACT7976_2	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:56:00	\N	1.19999999999999996	00:38:00	\N	1.19999999999999996	-00:12:00	00:54:00	Mile Point, southeast of	FL
64232	Mile Point, southeast of (Depth 29ft), St. Johns River, Florida Current	NOS	ACT7976_3	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:38:00	\N	0.900000000000000022	00:38:00	\N	1.10000000000000009	-00:42:00	01:00:00	Mile Point, southeast of	FL
64233	Pablo Creek bascule bridge (Depth 3ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.3233299999999986	-81.4383299999999934	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:59:00	\N	2.5	-00:18:00	\N	1.69999999999999996	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
64234	Sisters Creek entrance (bridge) (Depth 4ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.3900000000000006	-81.461669999999998	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.800000000000000044	-03:14:00	\N	0.800000000000000044	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
64235	Sisters Creek entrance (bridge) (Depth 10ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.3900000000000006	-81.461669999999998	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.599999999999999978	-03:04:00	\N	0.599999999999999978	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
64236	Drummond Point, channel south of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	60	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:00:00	\N	0.800000000000000044	02:32:00	\N	0.699999999999999956	01:51:00	02:44:00	Drummond Point, channel south of	FL
64237	Drummond Point, channel south of (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	61	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:01:00	\N	0.699999999999999956	02:35:00	\N	0.699999999999999956	01:34:00	02:51:00	Drummond Point, channel south of	FL
64238	Drummond Point, channel south of (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	57	243	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	02:51:00	\N	0.5	02:20:00	\N	0.599999999999999978	01:21:00	02:46:00	Drummond Point, channel south of	FL
64239	Terminal Channel (north end) (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.599999999999999978	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
64240	Terminal Channel (north end) (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	183	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:33:00	\N	0.5	03:06:00	\N	0.599999999999999978	02:16:00	03:20:00	Terminal Channel (north end)	FL
64428	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.9528299999999987	-132.090000000000003	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.699999999999999956	00:01:00	-00:17:00	Eaton Point	AK
64241	Terminal Channel (north end) (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.299999999999999989	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
64242	Commodore Point, terminal channel (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	72	197	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
64243	Commodore Point, terminal channel (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	51	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:25:00	\N	0.400000000000000022	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
64244	Commodore Point, terminal channel (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	35	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:08:00	\N	0.400000000000000022	02:30:00	\N	0.599999999999999978	01:43:00	03:38:00	Commodore Point, terminal channel	FL
64245	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.321670000000001	-81.6533299999999969	:America/New_York	USA	knots	118	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.900000000000000022	03:10:00	\N	0.900000000000000022	02:59:00	02:54:00	Jacksonville, off Washington St	FL
64246	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.3083300000000015	-81.6749999999999972	:America/New_York	USA	knots	15	200	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:59:00	\N	0.5	03:22:00	\N	0.599999999999999978	02:59:00	04:04:00	Winter Point	FL
64247	Mandarin Point (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.400000000000000022	03:39:00	\N	0.299999999999999989	03:07:00	03:24:00	Mandarin Point	FL
64248	Mandarin Point (Depth 15ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.299999999999999989	03:33:00	\N	0.299999999999999989	03:13:00	03:24:00	Mandarin Point	FL
64249	Mandarin Point (Depth 24ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:32:00	\N	0.299999999999999989	03:33:00	\N	0.299999999999999989	02:48:00	03:24:00	Mandarin Point	FL
64250	Red Bay Point, draw bridge (Depth 4ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:02:00	\N	0.299999999999999989	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
64251	Red Bay Point, draw bridge (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.299999999999999989	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
64252	Red Bay Point, draw bridge (Depth 14ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.200000000000000011	03:57:00	\N	0.400000000000000022	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
64253	Point Ybel, 0.4 mile northwest of, Florida Current	NOS	ACT8306_1	26.456669999999999	-82.0186700000000002	:America/New_York	USA	knots	80	255	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:35:00	\N	0.699999999999999956	-00:52:00	\N	0.800000000000000044	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
64254	Captiva Pass, Florida Current	NOS	ACT8311_1	26.6093299999999999	-82.2223299999999995	:America/New_York	USA	knots	251	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:23:00	\N	0.900000000000000022	-01:29:00	\N	1.39999999999999991	-00:53:00	-01:14:00	Captiva Pass	FL
64255	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.7143300000000004	-82.2566699999999997	:America/New_York	USA	knots	251	57	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:05:00	\N	1.30000000000000004	-00:37:00	\N	1.69999999999999996	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
64256	Cape Haze, 2.3 mi. S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745000000000001	-82.1516699999999958	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	01:18:00	\N	0.400000000000000022	00:41:00	\N	0.400000000000000022	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
64257	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.8123299999999993	-82.2810000000000059	:America/New_York	USA	knots	236	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:41:00	\N	0.800000000000000044	-01:13:00	\N	0.800000000000000044	-01:15:00	-00:35:00	Gasparilla Pass	FL
64258	Venice Inlet, Florida Current	NOS	ACT8351_1	27.1133300000000013	-82.4666699999999935	:America/New_York	USA	knots	262	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:59:00	\N	0.699999999999999956	-02:08:00	\N	0.800000000000000044	-02:05:00	-01:57:00	Venice Inlet	FL
64259	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.1233299999999993	-82.4699999999999989	:America/New_York	USA	knots	180	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:10:00	\N	0.5	-01:20:00	\N	0.699999999999999956	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
64260	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.1799999999999997	-82.4950000000000045	:America/New_York	USA	knots	357	167	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.5	-00:56:00	\N	1.10000000000000009	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
64261	Midnight Pass entrance, Florida Current	NOS	ACT8366_1	27.206669999999999	-82.5100000000000051	:America/New_York	USA	knots	242	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:13:00	\N	1.10000000000000009	-01:59:00	\N	1.39999999999999991	-01:43:00	-01:49:00	Midnight Pass entrance	FL
64262	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3000000000000007	-82.5633299999999934	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-02:03:00	\N	0.800000000000000044	-01:49:00	\N	1.19999999999999996	-01:54:00	-01:34:00	Big Sarasota Pass	FL
64263	Sarasota Bay, south end, bridge, Sarasota Bay, Florida Current	NOS	ACT8376_1	27.3016700000000014	-82.546670000000006	:America/New_York	USA	knots	13	196	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:32:00	\N	0.200000000000000011	-01:39:00	\N	0.200000000000000011	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
64264	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.331669999999999	-82.5816700000000026	:America/New_York	USA	knots	231	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:25:00	\N	0.800000000000000044	-02:48:00	\N	1.19999999999999996	-02:06:00	-01:18:00	New Pass	FL
64265	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.3283300000000011	-82.5566699999999969	:America/New_York	USA	knots	159	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:19:00	\N	0.200000000000000011	-01:57:00	\N	0.299999999999999989	-01:38:00	-01:25:00	Golden Gate Point, off	FL
64266	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.4416699999999985	-82.6899999999999977	:America/New_York	USA	knots	267	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:56:00	\N	1.19999999999999996	-02:42:00	\N	1.39999999999999991	-02:32:00	-01:51:00	Longboat Pass	FL
64267	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.4699999999999989	-82.6933300000000031	:America/New_York	USA	knots	162	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:11:00	\N	0.100000000000000006	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
64268	Egmont Channel, marker '10' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005000000000003	-82.8676700000000039	:America/New_York	USA	knots	259	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:31:00	\N	0.200000000000000011	-03:17:00	\N	0.200000000000000011	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
64269	Egmont Channel (3 mi. W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.6083299999999987	-82.8183300000000031	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:29:00	\N	0.5	-00:28:00	\N	0.400000000000000022	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
64270	Southwest Channel (S of Egmont Key) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.5616699999999994	-82.7673300000000012	:America/New_York	USA	knots	269	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:30:00	\N	0.900000000000000022	-00:53:00	\N	0.599999999999999978	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
64271	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045000000000016	-82.7238300000000066	:America/New_York	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:08:00	\N	0.800000000000000044	-00:01:00	\N	0.800000000000000044	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
64272	Passage Key Inlet (off Bean Pt.) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.5393299999999996	-82.7476699999999994	:America/New_York	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:08:00	\N	0.699999999999999956	-01:50:00	\N	0.599999999999999978	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
64273	Rattlesnake Key, 3.1 miles west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.553329999999999	-82.6883299999999934	:America/New_York	USA	knots	250	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:04:00	\N	0.400000000000000022	-00:05:00	\N	0.299999999999999989	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
64274	Rattlesnake Key, 1.1 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.5708300000000008	-82.6438299999999941	:America/New_York	USA	knots	210	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:09:00	\N	0.100000000000000006	-00:34:00	\N	0.200000000000000011	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
64275	Mullet Key Channel, marker '24' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.6083299999999987	-82.6940000000000026	:America/New_York	USA	knots	255	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.699999999999999956	-00:07:00	\N	0.699999999999999956	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
64276	Bunces Pass (West of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.6469999999999985	-82.7395000000000067	:America/New_York	USA	knots	315	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:02:00	\N	0.699999999999999956	-00:46:00	\N	0.800000000000000044	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
64277	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.692499999999999	-82.7171699999999959	:America/New_York	USA	knots	280	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:00:00	\N	0.599999999999999978	-00:29:00	\N	0.299999999999999989	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
64278	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.7083300000000001	-82.7246700000000033	:America/New_York	USA	knots	150	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
64279	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.6388299999999987	-82.6255000000000024	:America/New_York	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:46:00	\N	0.699999999999999956	00:07:00	\N	0.800000000000000044	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
64280	Joe Island, 1.8 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125000000000007	-82.625	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:02:00	\N	0.699999999999999956	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
64281	Harbor Key, 1.3 miles west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.6111700000000013	-82.5944999999999965	:America/New_York	USA	knots	160	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:38:00	\N	0.299999999999999989	-00:56:00	\N	0.200000000000000011	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
64282	2.6 miles south of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8486_1	27.660499999999999	-82.6416700000000048	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:34:00	\N	0.699999999999999956	-00:23:00	\N	0.599999999999999978	-00:46:00	-00:16:00	2.6 miles south of	FL
64283	0.5 mile southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8491_1	27.6969999999999992	-82.6324999999999932	:America/New_York	USA	knots	220	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:57:00	\N	0.200000000000000011	-01:19:00	\N	0.200000000000000011	-01:28:00	-01:53:00	0.5 mile southeast of	FL
64284	1.9 miles SE of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8496_1	27.6846700000000006	-82.6096699999999942	:America/New_York	USA	knots	180	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:20:00	\N	0.599999999999999978	-00:32:00	\N	0.5	00:29:00	-00:06:00	1.9 miles SE of	FL
64285	3 miles southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8501_1	27.6729999999999983	-82.5930000000000035	:America/New_York	USA	knots	200	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:47:00	\N	0.599999999999999978	00:23:00	\N	0.599999999999999978	00:29:00	00:20:00	3 miles southeast of	FL
64286	Port Manatee Channel entrance (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8506_1	27.661999999999999	-82.5991700000000009	:America/New_York	USA	knots	216	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.599999999999999978	00:08:00	\N	0.599999999999999978	-00:01:00	00:24:00	Port Manatee Channel entrance	FL
64287	Port Manatee Channel, marker '4' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535000000000011	-82.5898300000000063	:America/New_York	USA	knots	242	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.299999999999999989	-00:11:00	\N	0.200000000000000011	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
64288	Piney Point, 0.6 mile NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.6536700000000017	-82.5621699999999947	:America/New_York	USA	knots	215	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.400000000000000022	-00:29:00	\N	0.299999999999999989	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
64289	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.6849999999999987	-82.7349999999999994	:America/New_York	USA	knots	186	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:17:00	\N	1	-00:43:00	\N	0.900000000000000022	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
64290	Bridge, 0.8 mi. south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.6933299999999996	-82.6800000000000068	:America/New_York	USA	knots	255	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:50:00	\N	1	-01:22:00	\N	0.900000000000000022	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
64291	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.7566699999999997	-82.7616699999999952	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:12:00	\N	0.299999999999999989	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
64292	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.8766708374023438	-82.8499984741210938	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:54:00	\N	0.100000000000000006	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
64293	Clearwater Pass, 0.2 mi. NE of Sand Key, Florida Current	NOS	ACT8656_1	27.956669999999999	-82.8233299999999986	:America/New_York	USA	knots	348	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:50:00	\N	0.800000000000000044	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
64294	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.0466699999999989	-84.1800000000000068	:America/New_York	USA	knots	170	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:08:00	\N	0.400000000000000022	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
64295	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.1116700000000002	-84.203329999999994	:America/New_York	USA	knots	187	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:26:00	\N	0.299999999999999989	-00:14:00	\N	0.299999999999999989	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
64296	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.1550000000000011	-84.2016699999999929	:America/New_York	USA	knots	247	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.299999999999999989	01:10:00	\N	0.200000000000000011	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
64297	Bolivar Roads (Depth 8ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.3433300000000017	-94.781329999999997	:America/Chicago	USA	knots	125	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:01:00	\N	1.10000000000000009	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
64298	Bolivar Roads (Depth 31ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.3433300000000017	-94.781329999999997	:America/Chicago	USA	knots	115	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:08:00	\N	0.599999999999999978	-00:11:00	\N	0.800000000000000044	-00:32:00	00:17:00	Bolivar Roads	TX
64299	Houston Channel, W of Port Bolivar (Depth 3ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	135	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	1	-00:18:00	\N	1.10000000000000009	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
64300	Houston Channel, W of Port Bolivar (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:55:00	\N	0.900000000000000022	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
64301	Houston Channel, W of Port Bolivar (Depth 26ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	0.800000000000000044	-00:14:00	\N	0.900000000000000022	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
64302	Houston Ship Channel (Red Fish Bar) (Depth 7ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	154	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
64303	Houston Ship Channel (Red Fish Bar) (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	148	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:10:00	\N	0.699999999999999956	01:28:00	\N	0.699999999999999956	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
64304	Houston Ship Channel (Red Fish Bar) (Depth 24ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	144	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
64305	Morgans Point (Depth 6ft), Galveston Bay, Texas Current	NOS	ACT8886_1	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	163	336	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:16:00	\N	0.5	01:43:00	\N	0.299999999999999989	02:15:00	-01:05:00	Morgans Point	TX
64306	Morgans Point (Depth 15ft), Galveston Bay, Texas Current	NOS	ACT8886_2	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	159	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:11:00	\N	0.400000000000000022	01:23:00	\N	0.299999999999999989	01:44:00	-00:50:00	Morgans Point	TX
64307	Morgans Point (Depth 25ft), Galveston Bay, Texas Current	NOS	ACT8886_3	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:20:00	\N	0.299999999999999989	00:58:00	\N	0.200000000000000011	00:47:00	-01:02:00	Morgans Point	TX
64308	Aransas Pass (Depth 15ft), Texas Current	NOS	ACT8896_1	27.833829999999999	-97.044169999999994	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	1.5	00:00:00	\N	1.10000000000000009	00:00:00	00:00:00	Aransas Pass	TX
64309	Aransas Pass (Depth 50ft), Texas Current	NOS	ACT8896_3	27.833829999999999	-97.044169999999994	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	0.800000000000000044	00:00:00	\N	0.900000000000000022	00:00:00	00:00:00	Aransas Pass	TX
64310	Port Ingleside (Depth 5ft), Texas Current	NOS	ACT8901_1	27.8150000000000013	-97.230000000000004	:America/Chicago	USA	knots	102	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	01:09:00	\N	0.5	01:48:00	\N	0.699999999999999956	00:24:00	02:11:00	Port Ingleside	TX
64311	Punta Ostiones, 1.5 miles west of, Puerto Rico Current	NOS	ACT8921_1	18.0866700000000016	-67.2266699999999986	:America/Puerto_Rico	USA	knots	1	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-00:35:00	\N	1.30000000000000004	-00:52:00	\N	1.69999999999999996	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
64312	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645000000000017	-65.5699999999999932	:America/Puerto_Rico	USA	knots	355	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:05:00	\N	0.900000000000000022	-01:16:00	\N	0.699999999999999956	-00:44:00	-01:28:00	Vieques Sound	PR
64313	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.3166699999999985	-65.5833300000000037	:America/Puerto_Rico	USA	knots	330	186	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:08:00	\N	1	-01:28:00	\N	0.699999999999999956	-00:52:00	-01:33:00	Largo Shoals, west of	PR
64314	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.3333300000000001	-65.6166699999999992	:America/Puerto_Rico	USA	knots	339	162	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:45:00	\N	1.60000000000000009	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
64315	Point Loma Light, 0.8 nmi. east of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0026_1	32.6658299999999997	-117.226169999999996	:America/Los_Angeles	USA	knots	174	328	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:45:00	\N	0.400000000000000022	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
64316	Point Loma Light, 0.8 nmi. east of (Depth 33ft), San Diego Bay, California Current	NOS	PCT0026_2	32.6658299999999997	-117.226169999999996	:America/Los_Angeles	USA	knots	166	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:23:00	\N	0.200000000000000011	-00:46:00	\N	0.400000000000000022	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
64317	Ballast Point, south of (Depth 5ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6844999999999999	-117.232169999999996	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-02:03:00	\N	0.200000000000000011	-01:02:00	\N	0.400000000000000022	-01:04:00	-01:01:00	Ballast Point, south of	CA
64318	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.683329999999998	-117.233329999999995	:America/Los_Angeles	USA	knots	133	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:02:00	\N	0.900000000000000022	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
64319	Ballast Point, 0.55 nmi. north of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0046_1	32.6958300000000008	-117.232500000000002	:America/Los_Angeles	USA	knots	193	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:24:00	\N	0.400000000000000022	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
64320	Ballast Point, 0.55 nmi. north of (Depth 34ft), San Diego Bay, California Current	NOS	PCT0046_2	32.6958300000000008	-117.232500000000002	:America/Los_Angeles	USA	knots	147	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.200000000000000011	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
64321	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7000000000000028	-117.233329999999995	:America/Los_Angeles	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:20:00	\N	0.800000000000000044	00:15:00	\N	0.800000000000000044	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
64322	North Island (Depth 14ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713000000000001	-117.212829999999997	:America/Los_Angeles	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.400000000000000022	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
64323	North Island (Depth 34ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713000000000001	-117.212829999999997	:America/Los_Angeles	USA	knots	241	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:33:00	\N	0.200000000000000011	-01:05:00	\N	0.299999999999999989	-00:43:00	-00:44:00	North Island	CA
64324	Harbor Island (east end), SSW of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0061_1	32.7191699999999983	-117.191670000000002	:America/Los_Angeles	USA	knots	293	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:23:00	\N	0.299999999999999989	00:09:00	\N	0.299999999999999989	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
64325	San Diego, 0.5 mile west of, San Diego Bay, California Current	NOS	PCT0066_1	32.7166700000000006	-117.183329999999998	:America/Los_Angeles	USA	knots	304	121	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:12:00	\N	0.5	-00:08:00	\N	0.599999999999999978	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
64326	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0081_1	32.7083299999999966	-117.177499999999995	:America/Los_Angeles	USA	knots	304	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:41:00	\N	0.299999999999999989	00:20:00	\N	0.299999999999999989	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
64327	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 37ft), San Diego Bay, California Current	NOS	PCT0081_2	32.7083299999999966	-117.177499999999995	:America/Los_Angeles	USA	knots	301	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.200000000000000011	00:21:00	\N	0.299999999999999989	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
64328	Coronado, off northeast end (Depth 14ft), San Diego Bay, California Current	NOS	PCT0091_1	32.6980000000000004	-117.163830000000004	:America/Los_Angeles	USA	knots	317	128	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:09:00	\N	0.5	-00:58:00	\N	0.699999999999999956	-00:24:00	-00:51:00	Coronado, off northeast end	CA
64329	Coronado, off northeast end (Depth 38ft), San Diego Bay, California Current	NOS	PCT0091_2	32.6980000000000004	-117.163830000000004	:America/Los_Angeles	USA	knots	319	130	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:03:00	\N	0.400000000000000022	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
64330	28th St. Pier (San Diego), 0.92 nmi. SW (Depth 7ft), San Diego Bay, California Current	NOS	PCT0096_1	32.674669999999999	-117.149500000000003	:America/Los_Angeles	USA	knots	351	182	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:05:00	\N	0.100000000000000006	-01:17:00	\N	0.200000000000000011	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
64331	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 14ft), San Diego Bay, California Current	NOS	PCT0101_1	32.6828300000000027	-117.142830000000004	:America/Los_Angeles	USA	knots	317	133	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:13:00	\N	0.200000000000000011	00:15:00	\N	0.299999999999999989	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
64332	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 28ft), San Diego Bay, California Current	NOS	PCT0101_2	32.6828300000000027	-117.142830000000004	:America/Los_Angeles	USA	knots	328	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:35:00	\N	0.200000000000000011	00:24:00	\N	0.200000000000000011	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
64333	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.6499999999999986	-117.116669999999999	:America/Los_Angeles	USA	knots	2	166	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:50:00	\N	0.400000000000000022	00:00:00	\N	0.400000000000000022	00:23:00	-00:02:00	National City	CA
64334	National City, WSW of Pier 12 (Depth 32ft), San Diego Bay, California Current	NOS	PCT0111_1	32.6621700000000033	-117.125500000000002	:America/Los_Angeles	USA	knots	351	178	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.200000000000000011	00:34:00	\N	0.200000000000000011	00:22:00	00:34:00	National City, WSW of Pier 12	CA
64335	Sweetwater Channel, southwest of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0116_1	32.6450000000000031	-117.122829999999993	:America/Los_Angeles	USA	knots	348	203	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:46:00	\N	0.200000000000000011	-00:33:00	\N	0.100000000000000006	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
64336	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.1216700000000017	-124.419669999999996	:America/Los_Angeles	USA	knots	290	91	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:17:00	\N	0.599999999999999978	-01:25:00	\N	0.400000000000000022	-01:00:00	-01:27:00	Coquille River entrance	OR
64337	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.3549999999999969	-124.341170000000005	:America/Los_Angeles	USA	knots	280	100	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.10000000000000009	-00:42:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Coos Bay entrance	OR
64338	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.6783300000000025	-124.193330000000003	:America/Los_Angeles	USA	knots	190	10	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.5	-00:32:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Umpqua River entrance	OR
64339	Heceta Head, Oregon Current	NOS	PCT1071_1	44.1333300000000008	-124.133330000000001	:America/Los_Angeles	USA	knots	185	5	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.699999999999999956	-00:12:00	\N	0.400000000000000022	00:06:00	-00:12:00	Heceta Head	OR
64340	Yaquina Bay entrance, Yaquina Bay, Oregon Current	NOS	PCT1076_1	44.6166699999999992	-124.066670000000002	:America/Los_Angeles	USA	knots	235	50	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:55:00	\N	1.10000000000000009	-01:04:00	\N	0.800000000000000044	-01:20:00	-01:17:00	Yaquina Bay entrance	OR
64341	Highway Bridge, Yaquina Bay, Oregon Current	NOS	PCT1081_1	44.6233300000000028	-124.057000000000002	:America/Los_Angeles	USA	knots	222	44	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:53:00	\N	1	-00:50:00	\N	0.599999999999999978	-01:31:00	-01:40:00	Highway Bridge	OR
64342	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.6019999999999968	-124.011330000000001	:America/Los_Angeles	USA	knots	2	184	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:33:00	\N	0.5	-00:50:00	\N	0.299999999999999989	-01:09:00	-01:33:00	Yaquina, Yaquina River	OR
64343	Yaquina River, 1 mile below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.6004999999999967	-123.941670000000002	:America/Los_Angeles	USA	knots	132	332	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:02:00	\N	0.699999999999999956	-00:13:00	\N	0.400000000000000022	-00:27:00	-00:46:00	Yaquina River, 1 mile below Toledo	OR
64344	Tillamook Bay entrance, Tillamook Bay, Oregon Current	NOS	PCT1096_1	45.5621700000000018	-123.938329999999993	:America/Los_Angeles	USA	knots	305	141	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	1.30000000000000004	-00:47:00	\N	0.900000000000000022	-00:20:00	-01:05:00	Tillamook Bay entrance	OR
64345	Sand Island Tower, 1nm SE of (midchannel) (Depth 15ft), Washington Current	NOS	PCT1106_1	46.252830000000003	-123.990830000000003	:America/Los_Angeles	USA	knots	275	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:07:00	\N	1.60000000000000009	01:03:00	\N	1.60000000000000009	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	WA
64346	Sand Island Tower, 0.9nm SE of (north channel) (Depth 15ft), Washington Current	NOS	PCT1111_1	46.2578299999999984	-123.994500000000002	:America/Los_Angeles	USA	knots	262	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:44:00	\N	0.699999999999999956	00:33:00	\N	1.10000000000000009	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	WA
64347	Baker Bay entrance, E of Sand Island Tower (Depth 23ft), Washington Current	NOS	PCT1116_1	46.2620000000000005	-123.998000000000005	:America/Los_Angeles	USA	knots	202	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:14:00	\N	0.299999999999999989	00:08:00	\N	0.599999999999999978	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	WA
64348	Clatsop Spit, NNE of (Depth 15ft), Washington Current	NOS	PCT1121_1	46.2461699999999993	-123.994169999999997	:America/Los_Angeles	USA	knots	289	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:20:00	\N	1.10000000000000009	00:56:00	\N	1.39999999999999991	00:45:00	00:56:00	Clatsop Spit, NNE of	WA
64349	Sand Island, SSE of (Depth 12ft), Washington Current	NOS	PCT1126_1	46.2554999999999978	-123.968000000000004	:America/Los_Angeles	USA	knots	265	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:32:00	\N	0.400000000000000022	-00:25:00	\N	0.299999999999999989	00:18:00	-00:16:00	Sand Island, SSE of	WA
64350	Youngs Bay Bridge (Depth 9ft), Oregon Current	NOS	PCT1146_1	46.1778300000000002	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:28:00	\N	0.299999999999999989	-00:14:00	\N	0.400000000000000022	00:10:00	00:50:00	Youngs Bay Bridge	OR
64351	Hammond, northeast of ship channel (Depth 15ft), Oregon Current	NOS	PCT1151_1	46.2111700000000027	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:01:00	\N	0.599999999999999978	00:24:00	\N	0.400000000000000022	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
64352	McGowan, SSW of (Depth 14ft), Washington Current	NOS	PCT1156_1	46.2394999999999996	-123.915329999999997	:America/Los_Angeles	USA	knots	282	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:23:00	\N	1.60000000000000009	01:14:00	\N	0.900000000000000022	01:28:00	00:21:00	McGowan, SSW of	WA
64353	Point Ellice, east of (Depth 17ft), Washington Current	NOS	PCT1161_1	46.2416699999999992	-123.848330000000004	:America/Los_Angeles	USA	knots	254	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:11:00	\N	0.900000000000000022	00:25:00	\N	0.800000000000000044	00:55:00	00:51:00	Point Ellice, east of	WA
64354	Point Adams, NNE OF (Depth 14ft), Oregon Current	NOS	PCT1166_1	46.2278299999999973	-123.967500000000001	:America/Los_Angeles	USA	knots	297	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:11:00	\N	0.900000000000000022	00:13:00	\N	0.800000000000000044	01:16:00	00:26:00	Point Adams, NNE OF	OR
64355	Chinook Point, WSW of (Depth 14ft), Washington Current	NOS	PCT1171_1	46.2421700000000016	-123.964169999999996	:America/Los_Angeles	USA	knots	287	117	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	0.900000000000000022	00:25:00	\N	1.19999999999999996	00:29:00	00:45:00	Chinook Point, WSW of	WA
64356	Tongue Point, northwest of (Depth 15ft), Oregon Current	NOS	PCT1176_1	46.2191699999999983	-123.766670000000005	:America/Los_Angeles	USA	knots	249	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:46:00	\N	0.900000000000000022	01:09:00	\N	0.400000000000000022	02:31:00	00:24:00	Tongue Point, northwest of	OR
64357	Woody Island Channel (Depth 15ft), Washington Current	NOS	PCT1186_1	46.2394999999999996	-123.673330000000007	:America/Los_Angeles	USA	knots	298	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:15:00	\N	0.299999999999999989	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
64358	Woody Island Channel (off Seal Island) (Depth 12ft), Oregon Current	NOS	PCT1191_1	46.2175000000000011	-123.629170000000002	:America/Los_Angeles	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:53:00	\N	0.400000000000000022	01:53:00	\N	0.299999999999999989	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
64359	Quinn Island, Prairie Channel (Depth 8ft), Washington Current	NOS	PCT1201_1	46.237169999999999	-123.503330000000005	:America/Los_Angeles	USA	knots	281	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:53:00	\N	0.5	01:52:00	\N	0.299999999999999989	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
64360	Clifton Channel (Depth 10ft), Washington Current	NOS	PCT1206_1	46.2178299999999993	-123.465329999999994	:America/Los_Angeles	USA	knots	301	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:17:00	\N	0.400000000000000022	02:27:00	\N	0.299999999999999989	03:41:00	01:21:00	Clifton Channel	WA
64361	Hunting Island, south of (Depth 20ft), Washington Current	NOS	PCT1216_1	46.2071699999999979	-123.404169999999993	:America/Los_Angeles	USA	knots	295	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	03:20:00	\N	0.400000000000000022	02:56:00	\N	0.200000000000000011	04:20:00	01:38:00	Hunting Island, south of	WA
64362	Cathlamet Channel, SE of Nassa Point (Depth 19ft), Washington Current	NOS	PCT1231_1	46.156170000000003	-123.314999999999998	:America/Los_Angeles	USA	knots	278	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:38:00	\N	0.599999999999999978	03:23:00	\N	0.100000000000000006	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
64363	Walker Island, south of (Depth 12ft), Washington Current	NOS	PCT1251_1	46.1411700000000025	-123.045829999999995	:America/Los_Angeles	USA	knots	330	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:09:00	\N	0.400000000000000022	04:15:00	\N	0.200000000000000011	05:46:00	02:41:00	Walker Island, south of	WA
64364	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.664670000000001	-123.801329999999993	:America/Los_Angeles	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:06:00	\N	0.5	00:20:00	\N	0.599999999999999978	00:19:00	00:24:00	South Bend, Willapa River	WA
64365	Entrance, 0.2 mile south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.9263300000000001	-124.161330000000007	:America/Los_Angeles	USA	knots	243	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:47:00	\N	0.599999999999999978	00:16:00	\N	1.30000000000000004	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
64366	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.9083299999999994	-124.155500000000004	:America/Los_Angeles	USA	knots	268	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	1.10000000000000009	-00:11:00	\N	0.900000000000000022	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
64367	Entrance, 0.6 mile WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.914670000000001	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:00:00	\N	0.699999999999999956	00:00:00	\N	1.19999999999999996	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
64368	Entrance, 1.1 miles NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.9166700000000034	-124.133330000000001	:America/Los_Angeles	USA	knots	233	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:23:00	\N	0.900000000000000022	-00:06:00	\N	0.900000000000000022	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
64369	Channel, 1.5 miles north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.933329999999998	-124.099999999999994	:America/Los_Angeles	USA	knots	226	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:25:00	\N	0.599999999999999978	-00:04:00	\N	0.699999999999999956	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
64370	Channel, 2.1 miles NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.933329999999998	-124.083330000000004	:America/Los_Angeles	USA	knots	249	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:02:00	\N	0.5	00:00:00	\N	0.599999999999999978	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
64371	Westport, channel 0.4 mile NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.9141699999999986	-124.108329999999995	:America/Los_Angeles	USA	knots	310	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:36:00	\N	0.699999999999999956	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
64372	Port Townsend Canal, Admiralty Inlet, Washington Current	NOS	PCT1561_1	48.0333299999999994	-122.733329999999995	:America/Los_Angeles	USA	knots^2	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	-00:31:00	\N	0.400000000000000022	-00:40:00	\N	0.5	00:06:00	-00:46:00	Port Townsend Canal	WA
64373	Skagit Bay, 1 mi. S of Goat Island, Washington Current	NOS	PCT1941_1	48.3444999999999965	-122.543670000000006	:America/Los_Angeles	USA	knots^2	312	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	-00:53:00	\N	0.200000000000000011	-01:26:00	\N	0.299999999999999989	-01:07:00	-00:53:00	Skagit Bay, 1 mi. S of Goat Island	WA
64374	Yokeko Point, Deception Pass, Rosario Strait, Washington Current	NOS	PCT1951_1	48.4128299999999996	-122.613669999999999	:America/Los_Angeles	USA	knots^2	222	64	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	00:17:00	\N	0.400000000000000022	-00:24:00	\N	0.400000000000000022	00:04:00	-00:25:00	Yokeko Point, Deception Pass	WA
64375	Cape Muzon, 4 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6000000000000014	-132.683330000000012	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.19999999999999996	-00:47:00	\N	0.800000000000000044	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
64376	Point Marsh, 5 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.6333300000000008	-132.300000000000011	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.10000000000000009	-00:47:00	\N	0.699999999999999956	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
64377	West Devil Rock, 2 miles north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7000000000000028	-131.599999999999994	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.19999999999999996	-00:42:00	\N	0.800000000000000044	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
64378	Barren Island Light, 2 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7000000000000028	-131.349999999999994	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.10000000000000009	-00:37:00	\N	0.699999999999999956	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
64379	East Devil Rock, 1 mile north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7000000000000028	-131.083329999999989	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.10000000000000009	00:23:00	\N	0.699999999999999956	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
64380	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7000000000000028	-130.833329999999989	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.39999999999999991	00:18:00	\N	0.599999999999999978	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
64381	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.7823300000000017	-130.737169999999992	:America/Juneau	USA	knots	157	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:31:00	\N	0.599999999999999978	-02:40:00	\N	0.299999999999999989	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
64382	Boston Islands, 1 mile south from, Dixon Entrance, Alaska Current	NOS	PCT2661_1	54.683329999999998	-130.566669999999988	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.10000000000000009	-00:37:00	\N	0.699999999999999956	-00:29:00	-00:47:00	Boston Islands, 1 mile south from	AK
64383	Portland Inlet, 2 miles S. of Wales Pt, Dixon Entrance, Alaska Current	NOS	PCT2666_1	54.6666700000000034	-130.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.19999999999999996	00:28:00	\N	0.800000000000000044	00:36:00	00:18:00	Portland Inlet, 2 miles S. of Wales Pt	AK
64384	Haystack Island, Tongass Passage, Pearse Canal, Alaska Current	NOS	PCT2671_1	54.7166700000000006	-130.616669999999999	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.19999999999999996	00:23:00	\N	0.800000000000000044	00:31:00	00:13:00	Haystack Island, Tongass Passage	AK
64385	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.7833299999999994	-130.633330000000001	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.30000000000000004	00:23:00	\N	0.900000000000000022	00:31:00	00:13:00	Point Phipp	AK
64386	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.8346700000000027	-130.485500000000002	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:47:00	\N	1.30000000000000004	00:26:00	\N	0.900000000000000022	00:34:00	00:31:00	Narrows	AK
64387	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.0333299999999994	-130.216669999999993	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Blaine Point	AK
64388	Wales Point, 2 miles south from, Portland Canal, Alaska Current	NOS	PCT2691_1	54.6666700000000034	-130.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.19999999999999996	00:28:00	\N	0.800000000000000044	00:36:00	00:18:00	Wales Point, 2 miles south from	AK
64389	Cliff Point, 1 mile east from, Portland Canal, Alaska Current	NOS	PCT2696_1	54.7999999999999972	-130.316669999999988	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.10000000000000009	00:28:00	\N	0.699999999999999956	00:36:00	00:18:00	Cliff Point, 1 mile east from	AK
64390	Flat Point , 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2701_1	54.9166700000000034	-130.166670000000011	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	1	00:33:00	\N	0.599999999999999978	00:41:00	00:23:00	Flat Point , 1 mile east of	AK
64391	Tree Point, 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2706_1	55.0333299999999994	-130.166670000000011	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.900000000000000022	00:33:00	\N	0.599999999999999978	00:41:00	00:23:00	Tree Point, 1 mile east of	AK
64392	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.1499999999999986	-130.150000000000006	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.699999999999999956	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
64393	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.566670000000002	-130.116669999999999	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:59:00	\N	0.5	00:38:00	\N	0.299999999999999989	00:46:00	00:28:00	White Point	AK
64394	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.2833299999999994	-129.983329999999995	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.599999999999999978	-00:22:00	\N	0.400000000000000022	-00:14:00	-00:32:00	Camp Point	AK
64395	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.7166700000000006	-130.150000000000006	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.400000000000000022	-00:17:00	\N	0.299999999999999989	-00:09:00	-00:27:00	Miners Point	AK
64396	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.8833300000000008	-130.033330000000007	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.200000000000000011	-00:17:00	\N	0.200000000000000011	-00:09:00	-00:27:00	Lion Point	AK
64397	Race Point, 0.7 mile ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.2858299999999971	-131.545999999999992	:America/Juneau	USA	knots	300	145	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.200000000000000011	00:22:00	\N	0.200000000000000011	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
64398	Saxman Spire, 0.2 mile south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155000000000001	-131.602669999999989	:America/Juneau	USA	knots	110	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:12:00	\N	0.299999999999999989	-02:00:00	\N	0.200000000000000011	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
64399	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.3361700000000027	-131.644170000000003	:America/Juneau	USA	knots	120	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:41:00	\N	0.100000000000000006	00:08:00	\N	0.299999999999999989	-00:50:00	00:04:00	Ketchikan	AK
64400	Hotspur Island, 0.5 mile southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.9666700000000006	-131.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:56:00	\N	0.400000000000000022	-01:29:00	\N	0.299999999999999989	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
64401	Point Davidson, 1 mile south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.9833300000000023	-131.599999999999994	:America/Juneau	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.599999999999999978	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
64402	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.533330000000007	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.80000000000000004	-00:37:00	\N	1.30000000000000004	-00:29:00	-00:47:00	Harris Island	AK
64403	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.466669999999993	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.39999999999999991	-00:32:00	\N	0.900000000000000022	-00:24:00	-00:42:00	Ajax Reef	AK
64404	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.383330000000001	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.80000000000000004	-00:27:00	\N	1.30000000000000004	-00:19:00	-00:37:00	Snipe Island	AK
64405	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.0216700000000003	-131.522330000000011	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.19999999999999996	-00:32:00	\N	0.800000000000000044	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
64406	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.0333299999999994	-131.349999999999994	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.60000000000000009	-00:27:00	\N	1.10000000000000009	-00:19:00	-00:37:00	Indian Reef	AK
64407	Customhouse Cove, 1 mile west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1000000000000014	-131.266670000000005	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
64408	Hid Reef, 2.7 miles south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.0333299999999994	-131.666670000000011	:America/Juneau	USA	knots	190	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:12:00	\N	0.200000000000000011	-00:54:00	\N	0.200000000000000011	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
64563	Port Heiden, Alaska Current	NOS	PCT5771_1	56.9833300000000023	-158.883330000000001	:America/Anchorage	USA	knots	233	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:15:00	\N	0.400000000000000022	-01:05:00	\N	0.400000000000000022	-02:23:00	-01:14:00	Port Heiden	AK
64409	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.1166699999999992	-131.699999999999989	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Point McCartey Light	AK
64410	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.133499999999998	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.10000000000000009	-00:32:00	\N	0.699999999999999956	-00:24:00	-00:42:00	Wharburton Island	AK
64411	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.183329999999998	-131.599999999999994	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.900000000000000022	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Driest Point	AK
64412	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.2486699999999971	-131.669330000000002	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	1.10000000000000009	-00:22:00	\N	0.699999999999999956	-00:14:00	-00:32:00	Blank Point	AK
64413	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2000000000000028	-131.116669999999999	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Point Sykes	AK
64414	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.9136700000000033	-131.532000000000011	:America/Juneau	USA	knots	264	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-02:58:00	\N	0.599999999999999978	-03:07:00	\N	0.100000000000000006	-01:41:00	-03:41:00	Behm Narrows	AK
64415	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6000000000000014	-131.833329999999989	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.599999999999999978	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Helm Point	AK
64416	Guard Islands, 2 miles northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.4666700000000006	-131.900000000000006	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
64417	Grass Rock, 1 mile south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.550000000000011	:America/Juneau	USA	knots	235	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:22:00	\N	0.599999999999999978	-00:29:00	\N	0.200000000000000011	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
64418	Moira Rock, 2 miles east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.0833299999999966	-131.933330000000012	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
64419	Skin Island, 3 miles east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.2999999999999972	-131.983329999999995	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
64420	Guard Island Lighthouse, 5.1 miles SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.3999999999999986	-132	:America/Juneau	USA	knots	164	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:20:00	\N	0.299999999999999989	-00:03:00	\N	0.200000000000000011	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
64421	Guard Islands, 2 miles west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.4500000000000028	-131.949999999999989	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
64422	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6000000000000014	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.699999999999999956	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
64423	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.7833299999999994	-132.416670000000011	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.699999999999999956	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
64424	Mabel Island, 3 miles west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.9166700000000034	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	0.699999999999999956	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
64425	Lincoln Rock Light, 1 mile west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.0499999999999972	-132.716669999999993	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
64426	McHenry Ledge, 1 mile north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.7999999999999972	-132.300000000000011	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	1	-00:17:00	\N	0.599999999999999978	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
64427	Vixen Point, 3 miles west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.8500000000000014	-132.183330000000012	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.800000000000000044	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
64429	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.0333299999999994	-132.083329999999989	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.699999999999999956	00:06:00	-00:12:00	Niblack Islands	AK
64430	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.0833299999999966	-132.083329999999989	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Blanche Rock	AK
64431	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.183329999999998	-131.966669999999993	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	1	00:08:00	\N	0.599999999999999978	00:16:00	-00:02:00	Point Warde	AK
64432	Blake Island, Alaska Current	NOS	PCT3071_1	56.222999999999999	-131.908829999999995	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1.19999999999999996	00:13:00	\N	0.800000000000000044	00:21:00	00:03:00	Blake Island	AK
64433	Berg Bay, Alaska Current	NOS	PCT3076_1	56.343670000000003	-132.00766999999999	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.10000000000000009	00:18:00	\N	0.699999999999999956	00:26:00	00:08:00	Berg Bay	AK
64434	The Narrows, Alaska Current	NOS	PCT3081_1	56.3678299999999979	-132.102669999999989	:America/Juneau	USA	knots	45	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.39999999999999991	00:23:00	\N	0.900000000000000022	00:31:00	00:13:00	The Narrows	AK
64435	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.3751699999999971	-132.169669999999996	:America/Juneau	USA	knots	320	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1	00:23:00	\N	0.599999999999999978	00:31:00	00:13:00	Channel Island, north of	AK
64436	Mill Creek, Alaska Current	NOS	PCT3091_1	56.4500000000000028	-132.216669999999993	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	0.900000000000000022	00:23:00	\N	0.599999999999999978	00:31:00	00:13:00	Mill Creek	AK
64437	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.383330000000001	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.699999999999999956	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
64438	Found Island, 1 mile northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.1166699999999992	-132.099999999999994	:America/Juneau	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.800000000000000044	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
64439	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.1499999999999986	-132.150000000000006	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.800000000000000044	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
64440	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.2166700000000006	-132.316669999999988	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
64441	Young Rock, 2 miles south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.3333299999999966	-132.383330000000001	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.800000000000000044	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
64442	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.3833300000000008	-132.400000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.800000000000000044	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
64443	Wrangell Harbor, 1.6 miles west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.4666700000000006	-132.449999999999989	:America/Juneau	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:33:00	\N	0.400000000000000022	03:36:00	\N	0.299999999999999989	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
64444	Cape Muzon, 5 miles east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.6666700000000034	-132.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	0.599999999999999978	-00:47:00	\N	0.400000000000000022	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
64445	Dewey Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.299999999999999989	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
64446	Boat Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.816670000000002	-132.566669999999988	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.299999999999999989	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
64447	Webster Point, 1 mile west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.9666700000000006	-132.633330000000001	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.800000000000000044	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
64448	Mellen Rock, 1 mile east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.0333299999999994	-132.650000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
64449	Shoe Rock, 1 mile north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.9666700000000006	-132.733329999999995	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.800000000000000044	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
64450	Grand Island, 2 miles north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.866669999999999	:America/Juneau	USA	knots	115	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
64451	High Point, 1 mile east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.0166699999999977	-132.933330000000012	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.900000000000000022	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
64452	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.066670000000002	-132.949999999999989	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.800000000000000044	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
64453	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.1333300000000008	-132.966669999999993	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
64454	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.1983299999999986	-132.824000000000012	:America/Juneau	USA	knots	130	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:09:00	\N	0.599999999999999978	-00:45:00	\N	0.400000000000000022	-00:29:00	-00:20:00	Sukkwan Narrows	AK
64455	The Sentinels, 1 mile west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.183329999999998	-133.016670000000005	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.800000000000000044	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
64456	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.2578299999999984	-133.182829999999996	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.699999999999999956	-00:19:00	-00:37:00	Meares Island, south of	AK
64457	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2000000000000028	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.599999999999999978	-00:37:00	\N	0.400000000000000022	-00:29:00	-00:47:00	Millar Rocks	AK
64458	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.183329999999998	-133.283330000000007	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.5	-00:37:00	\N	0.299999999999999989	-00:29:00	-00:47:00	Diver Islands	AK
64459	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.3500000000000014	-133.316669999999988	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.10000000000000009	-00:27:00	\N	0.699999999999999956	-00:19:00	-00:37:00	Cape Flores	AK
64460	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.2999999999999972	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Waterfall Cannery	AK
64461	Cape Bartolome, 2 miles east of, Alaska Current	NOS	PCT3316_1	55.2333300000000023	-133.550000000000011	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.599999999999999978	-00:37:00	\N	0.400000000000000022	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
64462	Point Arboleda, 1 mile west of, Alaska Current	NOS	PCT3326_1	55.316670000000002	-133.483329999999995	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.400000000000000022	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
64463	Cabras Islands, 1 mile west of, Alaska Current	NOS	PCT3331_1	55.3500000000000014	-133.416670000000011	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.599999999999999978	-00:32:00	\N	0.400000000000000022	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
64464	Cape Flores, 1 mile north of, Alaska Current	NOS	PCT3336_1	55.3666699999999992	-133.300000000000011	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
64465	Toti Island, 1.1 miles west of, Alaska Current	NOS	PCT3346_1	55.4166700000000034	-133.150000000000006	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
64466	Coronados Islands, 2 miles west of, Alaska Current	NOS	PCT3351_1	55.433329999999998	-133.166670000000011	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
64467	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.4833300000000023	-133.150000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Craig Cannery	AK
64468	Tuxekan Passage, 0.2 mile S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.8826699999999974	-133.24233000000001	:America/Juneau	USA	knots	137	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-03:05:00	\N	0.200000000000000011	-03:32:00	\N	0.299999999999999989	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
64469	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.914670000000001	-133.312330000000003	:America/Juneau	USA	knots	207	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:03:00	\N	1	-00:19:00	\N	0.699999999999999956	-00:06:00	-00:11:00	Skookumchuck Pass	AK
64470	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.9668300000000016	-133.30483000000001	:America/Juneau	USA	knots	182	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:31:00	\N	0.200000000000000011	00:43:00	\N	0.100000000000000006	00:28:00	-00:13:00	Brockman Island, east of	AK
64471	Tenass Island, 0.3 mile  SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.9866699999999966	-133.30483000000001	:America/Juneau	USA	knots	220	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:05:00	\N	0.299999999999999989	-00:48:00	\N	0.200000000000000011	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
64472	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.1601700000000008	-133.337999999999994	:America/Juneau	USA	knots	248	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	05:37:00	\N	0.100000000000000006	05:37:00	\N	0.200000000000000011	04:57:00	05:54:00	The Narrows, west of	AK
64473	Cora Point, 2 miles east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.9166700000000034	-134.050000000000011	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1	-00:42:00	\N	0.100000000000000006	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
64474	Point St. Albans, 3 miles SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.0333299999999994	-133.949999999999989	:America/Juneau	USA	knots	232	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:28:00	\N	0.400000000000000022	-01:14:00	\N	0.200000000000000011	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
64475	Point St. Albans, 4 miles east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.0833299999999966	-133.849999999999994	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.100000000000000006	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
64476	Ruins Point, 2 miles west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.066670000000002	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:49:00	\N	0.299999999999999989	00:38:00	\N	0.200000000000000011	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
64477	Shakan Light, 2.8 miles WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.1666700000000034	-133.699999999999989	:America/Juneau	USA	knots	182	19	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:36:00	\N	0.299999999999999989	-01:48:00	\N	0.200000000000000011	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
64478	Beauclerc Island Light, 1 mile east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.816669999999988	:America/Juneau	USA	knots	205	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:28:00	\N	0.400000000000000022	-00:41:00	\N	0.100000000000000006	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
64479	Sumner Island, 1.8 miles south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.3666699999999992	-133.816669999999988	:America/Juneau	USA	knots	240	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.299999999999999989	-03:33:00	\N	0.299999999999999989	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
64480	Blaquiere Point, 1 mile SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.5499999999999972	-132.566669999999988	:America/Juneau	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:23:00	\N	0.5	00:23:00	\N	0.299999999999999989	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
64481	Southern entrance to Keku Strait, Keku Strait, Alaska Current	NOS	PCT3701_1	56.566670000000002	-133.716669999999993	:America/Juneau	USA	knots	184	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:32:00	\N	0.599999999999999978	00:13:00	\N	0.299999999999999989	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
64482	Eagle Island, 0.5 mile southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.6073299999999975	-133.682170000000013	:America/Juneau	USA	knots	130	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
64483	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.6361699999999999	-133.68950000000001	:America/Juneau	USA	knots	90	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.800000000000000044	-00:09:00	\N	0.800000000000000044	-00:18:00	-00:41:00	Devils Elbow	AK
64484	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6764999999999972	-133.732499999999987	:America/Juneau	USA	knots	10	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:46:00	\N	1.19999999999999996	01:43:00	\N	0.699999999999999956	01:48:00	02:10:00	Summit Island, west of	AK
64485	High Island, 1.1 miles south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.7023300000000035	-133.733000000000004	:America/Juneau	USA	knots	10	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:30:00	\N	0.5	00:40:00	\N	0.299999999999999989	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
64486	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.733329999999995	:America/Juneau	USA	knots	325	210	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.400000000000000022	00:49:00	\N	0.299999999999999989	00:07:00	00:34:00	High Island, northwest of	AK
64487	Cucumber Reef, 0.2 mile northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.7899999999999991	-133.766999999999996	:America/Juneau	USA	knots	325	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:11:00	\N	0.800000000000000044	00:16:00	\N	0.400000000000000022	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
64488	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.5103300000000033	-132.958329999999989	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.299999999999999989	00:06:00	-00:12:00	Point Alexander	AK
64489	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.5333299999999994	-132.966669999999993	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.299999999999999989	00:06:00	-00:12:00	Point Deception	AK
64490	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.5558300000000003	-132.961829999999992	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.39999999999999991	-00:02:00	\N	0.900000000000000022	00:06:00	-00:12:00	Point Lockwood	AK
64491	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.6009999999999991	-132.975999999999999	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	2.10000000000000009	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
64492	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6394999999999982	-132.931170000000009	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.60000000000000009	-00:02:00	\N	1.10000000000000009	00:06:00	-00:12:00	Anchor Point	AK
64493	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.657829999999997	-132.926999999999992	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.19999999999999996	-00:02:00	\N	0.800000000000000044	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
64494	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7000000000000028	-132.949999999999989	:America/Juneau	USA	knots	5	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.299999999999999989	00:11:00	-00:07:00	Green Point	AK
64495	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.7333300000000023	-132.949999999999989	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1	00:13:00	\N	0.599999999999999978	00:21:00	00:03:00	Mountain Point	AK
64496	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.7783299999999969	-132.979330000000004	:America/Juneau	USA	knots	340	160	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.60000000000000009	00:23:00	\N	1.10000000000000009	00:31:00	00:13:00	Blunt Point	AK
64497	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.8078300000000027	-132.983499999999992	:America/Juneau	USA	knots	40	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.80000000000000004	00:23:00	\N	1.39999999999999991	00:31:00	00:13:00	Turn Point	AK
64498	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.8223300000000009	-132.948329999999999	:America/Juneau	USA	knots	60	240	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.60000000000000009	00:23:00	\N	1.10000000000000009	00:31:00	00:13:00	Prolewy Rocks	AK
64499	Cosmos Point, 0.5 mile east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.6666700000000034	-132.599999999999994	:America/Juneau	USA	knots	305	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:42:00	\N	0.200000000000000011	01:15:00	\N	0.100000000000000006	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
64500	The Brothers, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.2999999999999972	-133.716669999999993	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.299999999999999989	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
64501	Point Gambier, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.433329999999998	-133.766670000000005	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.200000000000000011	00:08:00	\N	0.200000000000000011	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
64502	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.6166699999999992	-133.766670000000005	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.299999999999999989	00:21:00	00:03:00	Point Hugh	AK
64503	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.8333299999999966	-133.833329999999989	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.299999999999999989	00:21:00	00:03:00	Midway Island	AK
64504	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.1499999999999986	-134.133330000000001	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	0.5	00:18:00	\N	0.299999999999999989	00:26:00	00:08:00	Point Arden	AK
64505	0.2 mile off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.3333299999999966	-134.050000000000011	:America/Juneau	USA	knots	200	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:07:00	\N	0.5	00:11:00	\N	0.200000000000000011	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
64562	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.8333299999999966	-160.783330000000007	:America/Anchorage	USA	knots	337	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
64506	0.2 mile off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.3999999999999986	-134.016670000000005	:America/Juneau	USA	knots	203	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:08:00	\N	0.400000000000000022	00:34:00	\N	0.400000000000000022	00:53:00	00:10:00	0.2 mile off Taku Point	AK
64507	Douglas, north of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.2830000000000013	-134.393669999999986	:America/Juneau	USA	knots	144	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:32:00	\N	0.200000000000000011	00:44:00	\N	0.100000000000000006	02:12:00	00:11:00	Douglas, north of	AK
64508	Douglas, north of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.2830000000000013	-134.393669999999986	:America/Juneau	USA	knots	136	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:08:00	\N	0.299999999999999989	00:41:00	\N	0.100000000000000006	01:33:00	00:27:00	Douglas, north of	AK
64509	Juneau Harbor, S of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.291170000000001	-134.407000000000011	:America/Juneau	USA	knots	102	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:05:00	\N	0.299999999999999989	02:03:00	\N	0.100000000000000006	03:19:00	00:34:00	Juneau Harbor, S of	AK
64510	West Juneau, NE of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.2963299999999975	-134.424499999999995	:America/Juneau	USA	knots	137	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:21:00	\N	0.200000000000000011	00:49:00	\N	0.100000000000000006	00:24:00	00:32:00	West Juneau, NE of	AK
64511	Aurora Basin, SW of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.3049999999999997	-134.440830000000005	:America/Juneau	USA	knots	163	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:51:00	\N	0.400000000000000022	00:34:00	\N	0.200000000000000011	01:01:00	00:10:00	Aurora Basin, SW of	AK
64512	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.8833300000000008	-134.599999999999994	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Hazy Islands	AK
64513	Cape Ommaney Light, 5 miles east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.1666700000000034	-134.516670000000005	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
64514	Port Walter Light, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.3833300000000008	-134.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.699999999999999956	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
64515	Point Ellis, 4 miles west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.566670000000002	-134.449999999999989	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.699999999999999956	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
64516	Kingsmill Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.8333299999999966	-134.516670000000005	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.599999999999999978	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
64517	Point Gardner Light, 2 miles west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.0166699999999977	-134.666670000000011	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
64518	Point Caution, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.733329999999995	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
64519	Point Thatcher, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.4166700000000034	-134.733329999999995	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
64520	Danger Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.5166699999999977	-134.699999999999989	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
64521	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.583329999999989	:America/Juneau	USA	knots	285	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:09:00	\N	2.89999999999999991	00:48:00	\N	2.20000000000000018	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
64522	South Passage Point, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.7666699999999977	-134.833329999999989	:America/Juneau	USA	knots	355	175	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
64523	Point Augusta, ESE of (Depth 70ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.0249999999999986	-134.87333000000001	:America/Juneau	USA	knots	164	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.299999999999999989	-00:04:00	\N	0.200000000000000011	-00:02:00	00:01:00	Point Augusta, ESE of	AK
64524	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.8333299999999966	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.200000000000000011	00:20:00	\N	0.100000000000000006	00:47:00	00:15:00	Biorka Channel	AK
64525	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.0499999999999972	-135.333329999999989	:America/Juneau	USA	knots	156	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.200000000000000011	-01:17:00	\N	0.100000000000000006	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
64526	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.1499999999999986	-135.583329999999989	:America/Juneau	USA	knots	64	242	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:30:00	\N	0.5	-00:51:00	\N	0.400000000000000022	-00:43:00	-01:01:00	West Channel (narrows)	AK
64527	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.1666700000000034	-135.550000000000011	:America/Juneau	USA	knots	229	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:23:00	\N	0.699999999999999956	-00:32:00	\N	0.400000000000000022	-00:30:00	-00:48:00	East Channel (narrows)	AK
64528	Allan Pt., 1.5mile W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.433330000000012	:America/Juneau	USA	knots	82	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:40:00	\N	0.800000000000000044	-01:06:00	\N	0.599999999999999978	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
64529	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.2666699999999977	-135.583329999999989	:America/Juneau	USA	knots	323	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:13:00	\N	0.699999999999999956	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
64530	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.2833299999999994	-135.599999999999994	:America/Juneau	USA	knots	330	144	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:34:00	\N	0.699999999999999956	-00:29:00	\N	0.299999999999999989	-00:15:00	-00:11:00	Highwater Island, west of	AK
64531	Sea Rock, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.3500000000000014	-135.883330000000001	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
64532	Kalinin Point, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.3500000000000014	-135.800000000000011	:America/Juneau	USA	knots	260	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
64533	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.3500000000000014	-135.766670000000005	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
64534	Otstoia Island Light, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.5833299999999966	-135.449999999999989	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
64535	Nismeni Point, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.5833299999999966	-135.416670000000011	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
64536	Peschani Point, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.5333299999999994	-135.300000000000011	:America/Juneau	USA	knots	145	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
64537	Point Elizabeth, 1 mile northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.5166699999999977	-135.266670000000005	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
64538	Point Benham, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.4833300000000023	-135.183330000000012	:America/Juneau	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
64539	False Linderberg Head, 1 mile south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.4500000000000028	-135.083329999999989	:America/Juneau	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
64540	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.4500000000000028	-135.033330000000007	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Lindenberg Head	AK
64541	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.4500000000000028	-134.933330000000012	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.599999999999999978	00:03:00	\N	0.400000000000000022	00:11:00	-00:07:00	Eva Islands	AK
64542	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.4500000000000028	-134.883330000000001	:America/Juneau	USA	knots	85	265	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Fairway Island	AK
64543	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.4500000000000028	-134.816669999999988	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
64544	Claybluff Point Light, 3.5 nmi. south of (Depth 75ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.9099999999999966	-141.594999999999999	:America/Anchorage	USA	knots	209	104	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:20:00	\N	0.200000000000000011	-02:09:00	\N	0.200000000000000011	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
64545	Claybluff Point Light, 2.3 nmi. SE of (Depth 206ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.9466699999999975	-141.52000000000001	:America/Anchorage	USA	knots	215	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:14:00	\N	0.100000000000000006	-02:44:00	\N	0.100000000000000006	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
64546	Carson Creek Entrance, 1.4 nmi. ESE of (Depth 15ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.9833300000000023	-141.469999999999999	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:09:00	\N	0.00100000000000000002	-00:36:00	\N	0.200000000000000011	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
64547	Carson Creek Entrance, 3.3 nmi. SE of (Depth 78ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.9699999999999989	-141.413330000000002	:America/Anchorage	USA	knots	232	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:03:00	\N	0.200000000000000011	-01:45:00	\N	0.299999999999999989	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
64548	Carson Creek Entrance, 2.4 nmi. ESE of (Depth 50ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.9866699999999966	-141.436669999999992	:America/Anchorage	USA	knots	244	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:06:00	\N	0.299999999999999989	-01:38:00	\N	0.200000000000000011	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
64549	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.0499999999999972	-144.383330000000001	:America/Anchorage	USA	knots	288	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:06:00	\N	0.599999999999999978	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
64550	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.0833299999999966	-144.300000000000011	:America/Anchorage	USA	knots	255	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
64551	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.3333299999999966	-160.516670000000005	:America/Anchorage	USA	knots	199	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:11:00	\N	0.200000000000000011	-02:05:00	\N	0.100000000000000006	-02:32:00	-01:28:00	Popof Strait	AK
64552	Unga Strait (1.4 miles N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.433329999999998	-160.733329999999995	:America/Anchorage	USA	knots	114	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	05:06:00	\N	0.100000000000000006	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
64553	Amak Island, 5 miles north of, Alaska Current	NOS	PCT5426_1	55.5	-163.166670000000011	:America/Nome	USA	knots^2	139	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	05:09:00	\N	0.200000000000000011	05:31:00	\N	0.200000000000000011	04:52:00	04:50:00	Amak Island, 5 miles north of	AK
64554	Amak Island, 5 miles southeast of, Alaska Current	NOS	PCT5431_1	55.3500000000000014	-163.016670000000005	:America/Nome	USA	knots^2	200	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	04:35:00	\N	0.200000000000000011	04:45:00	\N	0.200000000000000011	04:24:00	04:32:00	Amak Island, 5 miles southeast of	AK
64555	Otter Point, off of, north side, Unimak Island, Alaska Current	NOS	PCT5441_1	55.066670000000002	-163.783330000000007	:America/Nome	USA	knots^2	258	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	03:53:00	\N	0.299999999999999989	03:36:00	\N	0.200000000000000011	03:36:00	03:35:00	Otter Point, off of, north side	AK
64556	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.9833300000000023	-163.433330000000012	:America/Nome	USA	knots^2	139	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	00:02:00	\N	0.5	-00:26:00	\N	0.5	-00:55:00	00:14:00	Bechevin Bay, off Rocky Point	AK
64557	Cape Lieskof, 3 miles west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.199999999999989	:America/Nome	USA	knots	248	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:53:00	\N	0.299999999999999989	-04:39:00	\N	0.299999999999999989	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
64558	Entrance Point, 3 miles west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.650000000000006	:America/Anchorage	USA	knots	2	174	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:34:00	\N	0.800000000000000044	-04:28:00	\N	0.699999999999999956	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
64559	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.9833300000000023	-160.583329999999989	:America/Anchorage	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:27:00	\N	0.599999999999999978	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
64560	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.9166700000000034	-160.599999999999994	:America/Anchorage	USA	knots	335	158	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:26:00	\N	0.800000000000000044	-04:03:00	\N	0.400000000000000022	-04:28:00	-04:59:00	Harbor Point	AK
64561	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.8999999999999986	-160.766670000000005	:America/Anchorage	USA	knots	33	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:21:00	\N	0.599999999999999978	-04:39:00	\N	0.900000000000000022	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
64564	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.7333300000000023	-156.933330000000012	:America/Anchorage	USA	knots	294	111	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	01:15:00	\N	0.900000000000000022	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
64565	Cape Constantine, 4 miles Southeast of, Alaska Current	NOS	PCT5791_1	58.3333299999999966	-158.766670000000005	:America/Anchorage	USA	knots	238	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:52:00	\N	0.699999999999999956	-01:38:00	\N	0.599999999999999978	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
64566	Protection Point, 2.5 miles east of, Alaska Current	NOS	PCT5796_1	58.5	-158.616669999999999	:America/Anchorage	USA	knots	180	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
64567	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.566670000000002	-158.416670000000011	:America/Anchorage	USA	knots	180	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
64568	Etolin Point, 8.5 miles west of, Alaska Current	NOS	PCT5806_1	58.6333300000000008	-158.583329999999989	:America/Anchorage	USA	knots	173	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:05:00	\N	1.19999999999999996	00:13:00	\N	0.900000000000000022	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
64569	Clarks Point, 1 mile west of, Alaska Current	NOS	PCT5811_1	58.8333299999999966	-158.583329999999989	:America/Anchorage	USA	knots	213	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:02:00	\N	1.39999999999999991	00:34:00	\N	1.30000000000000004	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
64570	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.066670000000002	-161.783330000000007	:America/Anchorage	USA	knots	213	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:02:00	\N	0.900000000000000022	-06:05:00	\N	0.900000000000000022	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
64571	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.2833299999999994	-162.366669999999999	:America/Nome	USA	knots	212	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:21:00	\N	0.599999999999999978	-04:29:00	\N	0.599999999999999978	-05:10:00	-03:44:00	Carter Bay, west of	AK
64572	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.7833299999999994	-162.233329999999995	:America/Nome	USA	knots	188	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:45:00	\N	0.800000000000000044	-03:21:00	\N	0.599999999999999978	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
64573	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.1333300000000008	-162.166670000000011	:America/Nome	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:51:00	\N	1.10000000000000009	-03:42:00	\N	1.10000000000000009	-05:04:00	-02:04:00	Apokak Creek entrance	AK
64574	Walrus Island, 0.5 mile west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.183329999999998	-169.949999999999989	:America/Nome	USA	knots	210	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:38:00	\N	0.5	-06:47:00	\N	0.400000000000000022	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
64575	SW Point, St. Paul Island, 1 mile off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.1499999999999986	-170.449999999999989	:America/Nome	USA	knots	170	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-08:10:00	\N	0.299999999999999989	-08:10:00	\N	0.800000000000000044	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
64576	Hooper Bay entrance, Alaska Current	NOS	PCT5866_1	61.5	-166.050000000000011	:America/Nome	USA	knots	223	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	11:03:00	\N	0.800000000000000044	11:16:00	\N	0.699999999999999956	10:08:00	11:14:00	Hooper Bay entrance	AK
64577	St. Mathew I., southwest coast, Alaska Current	NOS	PCT5871_1	60.3500000000000014	-172.716669999999993	:America/Nome	USA	knots	119	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	03:07:00	\N	0.400000000000000022	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
64578	Apavawook Cape, 1 mile south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.1166699999999992	-168.933330000000012	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:23:00	\N	0.400000000000000022	-02:14:00	\N	0.200000000000000011	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
64579	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.3333299999999966	-168.833329999999989	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2018-12-26	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:10:00	\N	0.299999999999999989	00:57:00	\N	0.299999999999999989	-00:41:00	01:16:00	Off Northeast Cape	AK
\.



COPY public.data_sets_old (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
16159	San Diego Bay Entrance, California Current	NOS	PCT0031_1	32.6816669999999974	-117.230000000000004	:America/Los_Angeles	USA	knots	175	355	\N	\N	1      San Diego Bay Entr., California     T.M. 120 W.\n-00090 1 3 1 0 0 0 355 175	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.0899999999999999967	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entr., California     T.M. 120 W.	CA
16144	Baltimore Harbor Approach (off Sandy Point), Maryland Current	NOS	ACT4996_1	39.0129999999999981	-76.3683330000000069	:America/New_York	USA	knots	190	25	\N	\N	1      Baltimore Harbor, Maryland    T.M. 75 W.\n000000 1 3 1 0 0 0 025 190	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor, Maryland    T.M. 75 W.	MD
16161	San Juan Channel (south entrance), Washington Current	NOS	PCT2186_1	48.4613330000000033	-122.950833000000003	:America/Los_Angeles	USA	knots	180	10	\N	\N	1      San Juan Channel, Washington    T.M. 120 W.\n-00050 1 3 1 0 0 0 010 180	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.0500000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, Washington    T.M. 120 W.	WA
16149	Deception Pass (narrows), Washington Current	NOS	PCT1956_1	48.4061670000000035	-122.643000000000001	:America/Los_Angeles	USA	knots^2	270	90	\N	\N	1      Deception Pass, Washington    T.M. 120 W.\n-00650 1 3 1 1 0 0 090 270	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.650000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass, Washington    T.M. 120 W.	WA
16145	Bergen Point Reach (Bayonne Bridge), Kill van Kull, New York Current (16d)	NOS	ACT3951_1	40.6416669999999982	-74.1433329999999984	:America/New_York	USA	knots	76	259	\N	\N	1      Bayonne Bridge, Kill van Kull, New York      T.M. 75 W\n000000 1 3 1 0 0 0 259 076	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge, Kill van Kull, New York      T.M. 75 W	NY
16162	Savannah River Entrance (between jetties), Georgia Current (11d)	NOS	ACT7351_1	32.0356669999999966	-80.8903329999999983	:America/New_York	USA	knots	110	286	\N	\N	1      Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->\n000000 1 3 1 0 0 0 286 110 0 0 0   0   0   0	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance, Georgia    T.M. 75 W.  *** Used 1999 ->	GA
16157	Pollock Rip Channel (Butler Hole), Massachusetts Current	NOS	ACT1616_1	41.5499999999999972	-69.9833330000000018	:America/New_York	USA	knots	225	35	\N	\N	1      Pollock Rip Channel, Massachusetts    T.M. 75 W.\n  0150 1 3 1 0 0 0 035 225	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.149999999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel, Massachusetts    T.M. 75 W.	MA
16151	Hell Gate (off Mill Rock), New York Current	NOS	ACT3401_1	40.7783330000000035	-73.9383330000000001	:America/New_York	USA	knots^2	230	50	\N	\N	1      Hell Gate, New York     T.M. 75 W.\n-00600 1 3 1 1 0 0 050 230	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.599999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate, New York     T.M. 75 W.	NY
16148	Charleston Harbor (off Fort Sumter), South Carolina Current	NOS	ACT6651_1	32.7560000000000002	-79.8703330000000022	:America/New_York	USA	knots	127	313	\N	\N	1      Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **\n  -217 1 3 1 0 0 0 313 127 0                       Used 1997 ->	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.216999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor, South Carolina    T.M. 75 W. ** Used 1997 -> **	SC
16146	Bolivar Roads, Texas Current (14d)	NOS	ACT8856_2	29.3433330000000012	-94.7813330000000036	:America/Chicago	USA	knots	123	296	\N	\N	1      Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->\n-00135 1 3 1 0 0 0 306 116\nHarmonized directions with 2009 predictions	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	-0.135000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads, Texas   T.M. 90 W.           Used 2000 ->	TX
16143	Aransas Pass, Texas Current (35d)	NOS	ACT8896_2	27.8338329999999985	-97.0441670000000016	:America/Chicago	USA	knots	120	300	\N	\N	1      Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **\n+00032 1 3 1 0 0 0 300 120                    major axis only	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-06:00:00	\N	0.0320000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Pass, Texas     T.M. 90 W           ** USED 1995 -> **	TX
16150	Grays Harbor Entrance, Washington Current	NOS	PCT1291_1	46.9224999999999994	-124.132999999999996	:America/Los_Angeles	USA	knots	240	60	\N	\N	1      Grays Harbor Entrance, Washington    T.M. 120 W.\n-00300 1 3 1 0 0 0 060 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance, Washington    T.M. 120 W.	WA
16171	Vieques Passage, Puerto Rico Current	NOS	ACT8926_1	18.1883330000000001	-65.6183330000000069	:America/Puerto_Rico	USA	knots	55	250	\N	\N	1      Vieques Passage, Puerto Rico     T.M. 60 W.\n-00030 1 3 1 0 0 0 250 055	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-04:00:00	\N	-0.0299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage, Puerto Rico     T.M. 60 W.	PR
16163	St. Johns River Entrance (between jetties), Florida Current (16d)	NOS	SJR9801_8	30.4003329999999998	-81.3858330000000052	:America/New_York	USA	knots	82	262	\N	\N	1      St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->\n-00128 1 3 1 0 0 0 262 082	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	-0.128000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Entrance, Fla.  T.M. 75 W.       ** Use 1999->	FL
25446	Wrangell Narrows (off Petersburg), Alaska Current (6d)	NOS	SEA0103_8	56.8162999999999982	-132.963999999999999	:America/Anchorage	USA	knots	62	246	\N	\N	1      Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W\n   290 1 3 1 0 0 0 246 062         Used 2004 ->	NOS data via Mitch Cline and Dean Pentcheff, 2011-02-07	Public domain	2011-04-07	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.28999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg), Alaska  T.M. 135 W	AK
16165	Tampa Bay Entrance (Egmont Channel), Florida Current (15d)	NOS	ACT8411_1	27.6043330000000005	-82.7603330000000028	:America/New_York	USA	knots	297	118	\N	\N	1       Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.\n000037 1 3 1 0 0 0 118 297             major axis only, k'	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-05:00:00	\N	0.0369999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	 Tampa Bay Entrance (Egmont Channel), Florida  T.M. 75 W.	FL
16154	Kvichak Bay (off Naknek River entrance), Alaska Current	NOS	PCT5776_1	58.7000000000000028	-157.25	:America/Anchorage	USA	knots	240	55	\N	\N	1      Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W\n-00300 1 3 1 0 0 0 055 240	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	-0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River Entr.), Alaska        T.M. 135 W	AK
16152	Isanotski Strait (False Pass Cannery), Alaska Current	NOS	PCT5446_1	54.8666669999999996	-163.400000000000006	:America/Anchorage	USA	knots^2	185	0	\N	\N	1      Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W\n000400 1 3 1 1 0 0 000 185	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-09:00:00	\N	0.400000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cannery), Alaska    T.M. 135 W	AK
16158	Rosario Strait, Washington Current	NOS	PCT1996_1	48.4583330000000032	-122.783332999999999	:America/Los_Angeles	USA	knots	175	335	\N	\N	1      Rosario Strait, Washington     T.M. 120 W.\n-00400 1 3 1 0 0 0 335 175	CURCON00.US	Public domain	2008-12-23	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	-08:00:00	\N	-0.400000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait, Washington     T.M. 120 W.	WA
55614	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033000000000015	-159.592000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000515	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
55615	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9543999999999997	-159.356099999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
55616	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.3066944444444495	-157.86699999999999	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
55617	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.3299999999999983	-157.967000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
55618	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683000000000014	-157.939999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000000089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
55619	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.4330555555555584	-157.789999999999992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
55620	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.0850000000000009	-157.032000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
55621	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.8949999999999996	-156.476694444444405	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.11999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
55622	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.829399999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.919999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
55623	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.7302780151367188	-155.055557250976562	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
55624	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7382999999999988	-169.530000000000001	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
55625	Sand Island, Midway Islands	NOS	1619910	28.2117000000000004	-177.360000000000014	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.649999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
55626	Apra Harbor, Guam	NOS	1630000	13.4433888888888902	144.656361111111096	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
55627	Pago Bay, Guam	NOS	1631428	13.4283333000000002	144.796944400000001	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
55628	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2266999999999992	145.736999999999995	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
55629	Pago Pago, American Samoa	NOS	1770000	-14.2766666999999998	-170.689444400000014	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
55630	Kwajalein, Marshall Islands	NOS	1820000	8.73166656494140625	167.736114501953125	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
55631	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667000000000012	151.847000000000008	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000000089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
55632	Wake Island, Pacific Ocean	NOS	1890000	19.2906666666666702	166.6175833333333	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.14000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
55633	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.903305555555562	-66.9849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
55634	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.8699999999999974	-67.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
55635	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9232999999999976	-67.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
55636	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.1284444444444475	-67.1446666666666658	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
55637	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.8233333333333306	-67.1516666666666708	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
55638	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.6570281982421875	-67.2046661376953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
55639	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417000000000002	-67.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
55640	Milbridge, Narraguagus River, Maine	NOS	8412581	44.5399999999999991	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
55641	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.3921944444444421	-68.2042777777777758	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
55642	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.5349999999999966	-68.4217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
55644	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.1923055555555635	-68.6209305555555602	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
55645	Bangor, Penobscot River, Maine	NOS	8414612	44.7849999999999966	-68.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
55646	Fort Point, Penobscot River, Maine	NOS	8414721	44.4716999999999985	-68.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
55647	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567000000000007	-68.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
55648	Rockland, Penobscot River, Maine	NOS	8415490	44.1049999999999969	-69.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.32999999999999918	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
55649	Thomaston, St. George River, Maine	NOS	8415709	44.0716999999999999	-69.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
55650	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333000000000027	-69.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
55651	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
55652	Phipps Point, Back River, Maine	NOS	8417087	43.898299999999999	-69.743300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Phipps Pt.	ME
55653	Gardiner, Kennebec River, Maine	NOS	8417134	44.2332999999999998	-69.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
55655	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.7550000000000026	-69.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
55656	Richmond, Kennebec River, Maine	NOS	8417208	44.0882999999999967	-69.7982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.97000000000000242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
55657	Bath, Kennebec River, Maine	NOS	8417227	43.9249999999999972	-69.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
55658	Portland, Casco Bay, Maine	NOS	8418150	43.6567000000000007	-70.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
55659	Pine Point, Maine	NOS	8418445	43.5450000000000017	-70.3332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.75999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
55660	Camp Ellis, Saco River Entrance, Maine	NOS	8418606	43.4617000000000004	-70.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.82000000000000117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
55661	Biddeford, Saco River, Maine	NOS	8418828	43.4917000000000016	-70.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
55662	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3582999999999998	-70.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.80999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
55663	Wells, Webhannet River, Maine	NOS	8419317	43.3200000000000003	-70.5633055555555586	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
55664	Seavey Island, Portsmouth Harbor, New Hampshire	NOS	8419870	43.0799999999999983	-70.7416999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	NH
55665	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983000000000033	-70.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.90999999999999925	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
55667	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.0713882446289062	-70.7105560302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
55668	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8382999999999967	-70.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
55669	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.8250000000000028	-70.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
55670	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts	NOS	8440452	42.8166999999999973	-70.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
55671	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.8149999999999977	-70.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
55672	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.763300000000001	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
55673	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.710138888888892	-70.7886111111111092	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
55674	Rockport Harbor, Massachusetts	NOS	8441551	42.658299999999997	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70999999999999908	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
55675	Essex, Essex River, Massachusetts	NOS	8441771	42.6317000000000021	-70.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.08000000000000096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
55676	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.523299999999999	-70.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
55677	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583000000000013	-70.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
55678	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.3950000000000031	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.23999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
55679	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3866999999999976	-71.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
55680	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.3539166666666631	-71.0503333333333273	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
55681	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3282999999999987	-70.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.91000000000000103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
55682	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.2800000000000011	-70.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.17000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
55683	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483000000000004	-70.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
55684	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017000000000024	-70.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
55685	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833000000000013	-70.6466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.94999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
55686	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.0495916666666574	-70.1821583333333336	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.03000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
55687	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0382999999999996	-70.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.48999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
55688	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.9600000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
55689	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.7749999999999986	-70.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
55690	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717000000000027	-70.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
55691	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.7700000000000031	-70.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
55692	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7516999999999996	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.22000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
55693	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.7449999999999974	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
55694	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417000000000016	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
55695	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.7349999999999994	-70.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.77000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
55696	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117000000000004	-70.7150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
55697	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.7043055555555569	-71.1641111111111115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
55698	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.6950000000000003	-70.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.90000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
55699	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.6884722222222166	-69.9510833333333295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham, Lydia Cove	MA
55700	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683000000000021	-70.0567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
55701	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6666999999999987	-69.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
55702	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317000000000021	-70.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.91999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
55703	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.6049999999999969	-70.6517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
55704	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5932999999999993	-70.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
55705	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5382999999999996	-70.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
55706	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.5236129760742188	-70.671112060546875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.979999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
56023	Turtle Mound, Florida	NOS	8721223	28.9267000000000003	-80.8250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
55707	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583000000000013	-70.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
55708	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.4500000000000028	-70.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
55709	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.388300000000001	-70.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
55710	Menemsha Harbor, Massachusetts	NOS	8448725	41.3544444444444466	-70.7678333333333285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
55711	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.3262222222222206	-70.5903333333333336	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.43999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
55712	Nantucket, Nantucket Island, Nantucket Island, Massachusetts	NOS	8449130	41.2852783203125	-70.0963897705078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
55713	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.4650000000000034	-71.1932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61000000000000121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
55714	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6366999999999976	-71.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
55715	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.6967010498046875	-71.2932968139648438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
55716	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.5050000000000026	-71.3267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
55717	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.7166666666666686	-71.3433333333333337	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.10000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
55718	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.496699999999997	-71.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
55719	Providence, State Pier no.1, Narragansett Bay, Rhode Island	NOS	8454000	41.806666700000001	-71.4005556000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
55720	Quonset Point, Rhode Island	NOS	8454049	41.5867999999999967	-71.4110000000000014	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
55721	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5716999999999999	-71.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
55722	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.6650009155273438	-71.4449996948242188	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
55723	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633000000000024	-71.4899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
55724	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.7078018188476562	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.19000000000000128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
55725	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817000000000021	-71.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
55726	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3282999999999987	-71.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
55727	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1732999999999976	-71.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
55729	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1632999999999996	-71.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
55730	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.3432998657226562	-71.9749984741210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
55731	New London, Thames River, Connecticut	NOS	8461490	41.3549999999999969	-72.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.53999999999999959	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London, Thames River	CT
55732	Clinton Harbor, Connecticut	NOS	8463701	41.2683000000000035	-72.5317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.46999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
55733	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.283299999999997	-72.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
55734	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.1757500000000007	-73.1840277777777715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.61999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
55735	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567000000000007	-73.2133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.63000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
55736	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1332999999999984	-73.283299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
55737	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.1199989318847656	-73.3683013916015625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
55738	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0966999999999985	-73.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.80999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
55739	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0382999999999996	-73.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
55740	Mianus, Connecticut	NOS	8469057	41.0391940000000019	-73.5920279999999991	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
55741	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0382999999999996	-73.5467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
55743	Lake Montauk, Long Island, New York	NOS	8510448	41.0733000000000033	-71.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
55744	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.048333300000003	-71.9594443999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.23999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
55745	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567000000000021	-72.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42000000000000082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
55747	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717000000000013	-72.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
55748	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.003300000000003	-72.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
55749	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1366999999999976	-72.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
55750	Greenport, Shelter Island Sound, New York	NOS	8511907	41.1009999999999991	-72.3611666666666622	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
55751	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367000000000004	-72.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61000000000000298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
55752	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.8500000000000014	-72.5032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
55753	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.0150000000000006	-72.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
55754	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.9350000000000023	-72.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
55755	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.8185555555555624	-72.586611111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
55756	Northville, Long Island, New York	NOS	8512987	40.9816999999999965	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
55757	Moriches Coast Guard Station, Long Island, New York	NOS	8513388	40.7867000000000033	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.19000000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
55758	Moriches Inlet, Long Island, New York	NOS	8513398	40.7644166666666692	-72.7559722222222263	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
55759	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383000000000024	-72.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.729999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
55760	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.659999999999999698	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
55761	Cedar Beach, Long Island, New York	NOS	8514422	40.9650000000000034	-73.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
55762	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.6492500000000021	-73.1506111111111181	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.699999999999999289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
55763	Fire Island Coast Guard Station, Great South Bay, New York	NOS	8515186	40.6266999999999996	-73.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
55764	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.8999999999999986	-73.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.86999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
55765	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9532999999999987	-73.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
55766	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.9099999999999966	-73.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
55767	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.8733000000000004	-73.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRINGS HARBOR	NY
55768	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233000000000004	-73.5016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.75999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
55769	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033000000000015	-73.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
55770	Point Lookout, Long Island, New York	NOS	8516402	40.5938888888888911	-73.5839722222222292	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
55771	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6332999999999984	-73.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.41999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
55772	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.8346111111111085	-73.6524166666666673	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
55773	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633000000000024	-73.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
55774	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.6300000000000026	-73.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56000000000000227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
55775	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.5963333333333267	-73.6550833333333372	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.44000000000000128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
55776	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8316999999999979	-73.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
55777	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.5949999999999989	-73.743300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
55778	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.634999999999998	-73.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
55779	Kings Point, Long Island Sound, New York	NOS	8516945	40.8103055555555585	-73.7650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
55780	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933000000000021	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
55781	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5882999999999967	-73.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
55782	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.6450000000000031	-73.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.02999999999999758	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
55783	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.7610000000000028	-73.8503611111111127	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
55786	Brooklyn Bridge, East River, New York	NOS	8517847	40.7032999999999987	-73.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
55787	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617000000000004	-73.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
55788	Throgs Neck, New York	NOS	8518526	40.8049999999999997	-73.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
55789	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8016999999999967	-73.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
55790	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.7999999999999972	-73.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
55791	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7766999999999982	-73.9416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.52999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
55792	Queensboro Bridge, East River, New York	NOS	8518687	40.7582999999999984	-73.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.39999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
55793	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117000000000004	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
55794	The Battery, New York Harbor, New York	NOS	8518750	40.7005556000000013	-74.0141667000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
55795	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8682999999999979	-73.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
55798	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2182999999999993	-73.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
55799	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
55800	Hyde Park, Hudson River, New York	NOS	8518951	41.783299999999997	-73.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
55801	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.0139007568359375	-73.9392013549804688	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.27000000000000313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point Hudson River NERRS	NY
55802	Albany, Hudson River, New York	NOS	8518995	42.6499999999999986	-73.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
55803	USCG Station, The Narrows, New York	NOS	8519050	40.6120000000000019	-74.059861111111104	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
55804	Great Kills Harbor, New Jersey	NOS	8519436	40.5433000000000021	-74.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.72999999999999687	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NJ
55805	Bergen Point West Reach, Kill Van Kull, New York	NOS	8519483	40.6366944444444371	-74.1416944444444397	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.76999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
55806	Sandy Hook, New Jersey	NOS	8531680	40.4669444000000027	-74.0094444000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
55807	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365000000000002	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
55808	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.9500007629394531	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.490000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
55809	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.8449999999999989	-74.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.440000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
55810	Barnegat Inlet, USCG Station, Barnegat Bay, New Jersey	NOS	8533615	39.7616999999999976	-74.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
55811	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.5082999999999984	-74.3250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
55812	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483000000000033	-74.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
55813	Atlantic City, New Jersey	NOS	8534720	39.3549999999999969	-74.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
55814	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.3350000000000009	-74.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
55815	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083000000000027	-74.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.03000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
55816	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.2950000000000017	-74.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
55817	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.121699999999997	-74.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.19999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
55818	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.1099999999999994	-74.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
55819	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.9750000000000014	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
55820	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.9677777777777834	-74.9597222222222257	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
55821	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.128300000000003	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
55822	Fortescue Creek, New Jersey	NOS	8536931	39.2383000000000024	-75.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
55823	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.3049999999999997	-75.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
55824	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.8350000000000009	-75.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
55825	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.0119400000000027	-75.0429999997880657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
55826	Burlington, Delaware River, New Jersey	NOS	8539094	40.0799999999999983	-74.8733333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
55827	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1366999999999976	-74.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
55828	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1882999999999981	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.47000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
55829	Marcus Hook, Pennsylvania	NOS	8540433	39.8116667000000035	-75.4094443999999982	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
55830	Philadelphia (USCG Station), Delaware River, Pennsylvania	NOS	8545240	39.93333333333333	-75.1416666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
55831	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9532999999999987	-75.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.49999999999999956	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
55832	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.9833333333333272	-75.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
55833	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.1373000000000033	-74.7519000000000062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
55834	Delaware City, Delaware River, Delaware	NOS	8551762	39.5816999999999979	-75.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.95000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
55835	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583000000000027	-75.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.91999999999999948	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
55836	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.1850000000000023	-75.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
55837	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.9866699999999966	-75.1133333333333297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61000000000000298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
55838	Lewes, Fort Miles, Delaware	NOS	8557380	38.7827796936035156	-75.1191635131835938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.22999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
55839	Inlet (Coast Guard Station), Indian River, Delaware	NOS	8558690	38.6099999999999994	-75.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
55840	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267000000000024	-75.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
55841	Ocean City Inlet, Maryland	NOS	8570283	38.3283300000000011	-75.0916666666666686	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
55842	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.2150000000000034	-75.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
55843	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.148299999999999	-75.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
55844	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.1389444444444479	-75.1835277777777833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
55845	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.976700000000001	-75.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
55846	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.9949999999999974	-76.0317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
55847	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.1783300000000025	-75.3966666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
55848	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.2203888888888912	-76.0386666666666713	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
55849	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.2999999999999972	-76.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
55850	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.341700000000003	-76.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
55851	Salisbury, Wicomico River, Maryland	NOS	8571616	38.365000000000002	-75.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
55852	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.4283300000000025	-76.2366666666666646	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.850000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
55853	Vienna, Nanticoke River, Maryland	NOS	8571773	38.4833300000000023	-75.818333333333328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
55854	Cambridge, Choptank River, Maryland	NOS	8571892	38.5741666999999993	-76.0722221999999988	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
55855	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.7583333333333329	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
55857	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367000000000004	-76.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.769999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
55858	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9166999999999987	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
55859	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9566999999999979	-76.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
55860	Love Point, Chester River, Maryland	NOS	8572955	39.0317000000000007	-76.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
55861	Crumpton, Chester River, Maryland	NOS	8573349	39.2449999999999974	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
55862	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.2133299999999991	-76.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
55863	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.371699999999997	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
55864	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.503300000000003	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
55865	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5266999999999982	-75.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
55866	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367000000000033	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
55867	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.388300000000001	-76.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000782	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
55868	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.2666699999999977	-76.5783333333333331	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore	MD
55869	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2616999999999976	-76.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.799999999999999822	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
55870	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.9832800000000006	-76.4815555551317061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
55871	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.4650000000000034	-76.4732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.679999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
55872	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917000000000002	-76.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
55873	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.3172222000000033	-76.4508332999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
55874	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.6550000000000011	-76.6833333333333371	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
55875	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333000000000027	-76.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
55876	Washington, Potomac River, DC	NOS	8594900	38.8733300000000028	-77.0216666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
55877	Jesters Island, Virginia	NOS	8630111	37.9817008972167969	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
55878	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
55879	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
55880	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.6077777777777769	-75.6858333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28999999999999959	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
55881	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.1651900000000026	-75.9884444443384837	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
55883	Rappahannock Light, Virginia	NOS	8632837	37.5382999999999996	-76.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.939999999999997726	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
55884	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5566999999999993	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
55885	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8282999999999987	-75.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.849999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
55886	Saxis, Starling Creek, Virginia	NOS	8633777	37.9216995239257812	-75.728302001953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
55887	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.3197499999999991	-77.0366111111111138	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000001279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
55888	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2516999999999996	-76.9599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.969999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
55889	Rappahannock Bend, Virginia	NOS	8635257	38.2132999999999967	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
55890	Lewisetta, Potomac River, Virginia	NOS	8635750	37.9961111111111123	-76.4644444444444389	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000675	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
55891	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733000000000004	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
55892	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.6161999999999992	-76.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.700000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
55893	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833000000000013	-76.9899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.72999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
55894	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.4595555555555535	-77.4207777777777721	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
55897	Gloucester Point, York River, Virginia	NOS	8637624	37.246699999999997	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29000000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
55898	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265000000000015	-76.4788000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
55899	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.2201111111111089	-76.7914166666666631	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown	VA
55900	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.1382222222222325	-76.6227499999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27999999999999758	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
55901	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.8232222222222205	-76.399111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
55903	Kingsmill, James River, Virginia	NOS	8638424	37.2199999999999989	-76.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
55904	Scotland, James River, Virginia	NOS	8638433	37.1850000000000023	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
55905	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033000000000015	-76.9116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
55906	Tettington, James River, Virginia	NOS	8638450	37.240000000000002	-76.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
55907	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.3149999999999977	-77.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.30999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
55908	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3132999999999981	-77.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
55909	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667000000000002	-77.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.72000000000000064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
55910	Richmond River Locks, James River, Virginia	NOS	8638495	37.5249999999999986	-77.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92000000000000015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
55911	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.9466666666666725	-76.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
55912	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8216999999999999	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
55913	Lafayette River, Virginia	NOS	8638671	36.8842222222222205	-76.275858333333332	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
55914	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.966700000000003	-76.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42000000000000171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
55916	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8316999999999979	-75.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.80000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
55917	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.778305555555562	-76.3016944444444505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
55918	FRF Pier, Duck, North Carolina	NOS	8651370	36.1833055555555632	-75.7466944444444437	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.77000000000000313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
55919	Manns Harbor, outer coast, North Carolina	NOS	8652247	35.9033000000000015	-75.769999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.219999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
55920	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.8449999999999989	-75.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
55921	Roanoke Marshes Light, outer coast, North Carolina	NOS	8652547	35.8117000000000019	-75.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
55922	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.7950000000000017	-75.5480555999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.580000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
55923	Oregon Inlet (USCG Station), North Carolina	NOS	8652678	35.7683000000000035	-75.5267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
55924	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.3501388888888926	-75.5120277777777744	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.289999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
55925	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233000000000018	-75.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
55926	Hatteras (USCG Station), North Carolina	NOS	8654467	35.2086388888888919	-75.7041666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.300000000000000711	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
55927	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115000000000002	-75.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
55928	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.390000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
55929	Davis, Core Sound, North Carolina	NOS	8656201	34.796750000000003	-76.4554722222222267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.630000000000002558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Core Sound	NC
55930	Spooner Creek, North Carolina	NOS	8656467	34.7250000000000014	-76.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.980000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
55931	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.7199999999999989	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.70999999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort	NC
55932	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933000000000007	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
55933	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133000000000024	-76.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
55934	Wilmington, North Carolina	NOS	8658120	34.2274999999999991	-77.9536111000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
55935	Wrightsville Beach, North Carolina	NOS	8658163	34.2133055555555572	-77.7866944444444499	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.15000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
55936	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.023299999999999	-77.946700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
55937	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.9500000000000028	-77.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
55938	Southport, Cape Fear River, North Carolina	NOS	8659084	33.9149999999999991	-78.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
55939	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9016999999999982	-78.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
55940	Sunset Beach Pier, North Carolina	NOS	8659897	33.865000000000002	-78.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
55941	Springmaid Pier, South Carolina	NOS	8661070	33.6550000000000011	-78.9183055555555626	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
55942	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467000000000027	-79.0949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
55943	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5782999999999987	-79.0032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2799999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
55944	Garden City Pier (ocean), South Carolina	NOS	8661437	33.5750000000000028	-78.9967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
55945	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5116999999999976	-79.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.51000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
55946	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067000000000021	-79.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
55947	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.4350000000000023	-79.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
55948	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4316999999999993	-79.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
55949	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117000000000033	-79.1350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.91999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
55950	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.351700000000001	-79.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
55951	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333000000000013	-79.1932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71000000000000041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
55952	South Island Plantation (C.G. Station), Winyah Bay, South Carolina	NOS	8662746	33.2349999999999994	-79.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
55953	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.2549972534179688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9900000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
55954	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.4149999999999991	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.95999999999999952	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
55955	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0082999999999984	-79.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
55956	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9266999999999967	-79.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.54000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
55957	Army Depot, Cooper River, South Carolina	NOS	8664662	32.9099999999999966	-79.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
55958	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8566999999999965	-79.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.57999999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
55959	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367000000000004	-80.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
55960	Charleston, Cooper River Entrance, South Carolina	NOS	8665530	32.7808332999999976	-79.9236111000000022	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.92000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston, Cooper River Entrance	SC
55961	Clarendon Plantation, South Carolina	NOS	8667633	32.5024999999999977	-80.7840999999999951	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
55962	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.4299999999999997	-80.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
55963	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
55964	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667000000000002	-80.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
55965	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.1433000000000035	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
55967	Fort Pulaski, Savannah River Entrance, Georgia	NOS	8670870	32.0367000000000033	-80.9017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
55968	Bear River, (Range 'A' Light), Georgia	NOS	8672667	31.7932999999999986	-81.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
55969	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667000000000002	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
55970	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
55971	South Newport River (Daymark 135), Georgia	NOS	8674301	31.5749999999999993	-81.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
55972	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.486699999999999	-81.3199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
55973	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.3738611111111112	-81.333944444444441	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
55974	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1316999999999986	-81.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
55975	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.1445555555555593	-81.4968055555555537	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.00999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
55976	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.0148055555555509	-81.4559722222222291	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
55977	Bailey Cut, 0.8 mile west of, Satilla River, Georgia	NOS	8678322	30.9849999999999994	-81.591700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
55978	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967000000000013	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
55979	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.763300000000001	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
55980	St. Marys, St. Marys River, Georgia	NOS	8679964	30.7199999999999989	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
55981	Crandall, St. Marys River, Florida	NOS	8720004	30.7216999999999985	-81.6217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
55982	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083000000000013	-81.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
55984	Chester, Bells River, Florida	NOS	8720023	30.6832999999999991	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
55985	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.6713889000000002	-81.4658332999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
55986	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
55987	Vaughns Landing, Florida	NOS	8720059	30.629999999999999	-81.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.82999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
55988	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683000000000007	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
55989	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5016999999999996	-81.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
55990	Cedar Heights, Broward River, Florida	NOS	8720189	30.4366999999999983	-81.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
55991	Sisters Creek, Florida	NOS	8720196	30.4166999999999987	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38000000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
55992	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067000000000007	-81.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
55993	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida	NOS	8720211	30.3999999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
55994	Sherwood Forest, Trout River, Florida	NOS	8720213	30.4200000000000017	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
55995	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3966999999999992	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
55996	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.3981666666666683	-81.4278888888888872	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.46999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
55997	Dame Point, St. Johns River, Florida	NOS	8720219	30.3867000000000012	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
55998	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
55999	Mayport, St. Johns River, Florida	NOS	8720224	30.3949999999999996	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
56000	Phoenix Park, Florida	NOS	8720225	30.3832999999999984	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
56001	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.3200000000000003	-81.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
56002	Jacksonville, Long Branch, Florida	NOS	8720242	30.3599999999999994	-81.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longbranch	FL
56003	Jacksonville Beach, Florida	NOS	8720291	30.2833000000000006	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
56004	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.1917000000000009	-81.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.530000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Bridge, St Johns River	FL
56005	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.120000000000001	-81.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.419999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
56006	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.0799999999999983	-81.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.439999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
56007	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.9816666666666691	-81.6341666666666725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999999916	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
56008	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9166999999999987	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
56021	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.023299999999999	-80.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
56022	Packwood Place, Florida	NOS	8721222	28.9400000000000013	-80.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.540000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
56009	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667000000000016	-81.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
56010	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
56011	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017000000000003	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.660000000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
56012	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
56013	State Road A1A Bridge, Florida	NOS	8720692	29.7045305555555608	-81.2278555555555499	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.93999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
56014	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.6149999999999984	-81.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.940000000000000058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
56015	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.5949999999999989	-81.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.580000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
56016	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.631699999999995	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.719999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
56017	Welaka, St. Johns River, Florida	NOS	8720832	29.476700000000001	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
56019	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1466999999999992	-80.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
56020	Ponce De Leon Inlet South, Florida	NOS	8721147	29.0633000000000017	-80.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
56024	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.4158332999999992	-80.5930555999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
56026	Cocoa Beach, Florida	NOS	8721649	28.3683000000000014	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
56027	Vero Beach, Indian River, Florida	NOS	8722125	27.6316999999999986	-80.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
56028	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4716999999999985	-80.3250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.950000000000000067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
56029	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.4682999999999993	-80.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
56030	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567000000000014	-80.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
56031	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8432999999999993	-80.0666999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
56032	Port of West Palm Beach, Florida	NOS	8722588	26.7699999999999996	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
56033	Lake Worth ICW, Florida	NOS	8722669	26.6132999999999988	-80.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
56034	Lake Worth Pier, Florida	NOS	8722670	26.6127777999999999	-80.0341667000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
56036	Ocean Ridge, ICWW, Florida	NOS	8722718	26.5266990661621094	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
56037	South Delray Beach, ICWW, Florida	NOS	8722761	26.4466999999999999	-80.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
56038	Lake Wyman, ICWW, Florida	NOS	8722802	26.370000000000001	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
56039	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.3432998657226562	-80.0766983032226562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.26000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
56040	Hillsboro Inlet Marina, Florida	NOS	8722859	26.2600002288818359	-80.0849990844726562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
56041	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.1882991790771484	-80.0932998657226562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45999999999999952	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
56042	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033000000000015	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
56043	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783000000000015	-80.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
56044	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
56045	Government Cut, Miami Harbor Entrance, Florida	NOS	8723178	25.763300000000001	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.30000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
56046	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.7314000000000007	-80.1617999999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key, Biscayne Bay	FL
56047	Cutler, Biscayne Bay, Florida	NOS	8723289	25.6149999999999984	-80.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
56048	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.523299999999999	-80.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
56049	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4532999999999987	-80.196700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
56050	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4366999999999983	-80.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.879999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
56051	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733000000000004	-80.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.510000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
56052	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.3249999999999993	-80.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
56053	Little Card Sound bridge, Florida	NOS	8723534	25.2882999999999996	-80.3700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
56054	Key Colony Beach, Florida	NOS	8723962	24.7182999999999993	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
56055	Vaca Key, Florida Bay, Florida	NOS	8723970	24.7109999999999985	-81.1064999999999969	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
56056	Boca Chica Marina, Florida	NOS	8724493	24.5749999999999993	-81.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.649999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
56057	Fleming Key, north end, Florida	NOS	8724571	24.5916999999999994	-81.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.710000000000000853	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
56058	Key West, Florida	NOS	8724580	24.5557000000000016	-81.8079000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
56059	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4532999999999987	-81.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000000098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
56060	Smith Shoal Light, Florida	NOS	8724671	24.7182777777777787	-81.9215277777777828	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
56061	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6316999999999986	-82.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
56062	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.8949999999999996	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
56063	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8966999999999992	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
56064	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083000000000006	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67999999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
56065	Marco, Big Marco River, Florida	NOS	8724991	25.9716999999999985	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.50000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
56066	McIlvaine Bay, Florida	NOS	8724996	25.9849999999999994	-81.7017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.43999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
56067	Keewaydin Island (inside), Florida	NOS	8725019	26.0249999999999986	-81.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
56068	Naples, Gulf Of Mexico, Florida	NOS	8725110	26.1316666666666713	-81.8074722222222164	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
56069	Coconut Point, Estero Bay, Florida	NOS	8725319	26.3999999999999986	-81.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.36999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
56070	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383000000000017	-81.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
56071	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433000000000007	-82.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
56072	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.4699999999999989	-81.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
56073	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.4882999999999988	-82.013300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
56074	North Captiva Island, Florida	NOS	8725488	26.6050000000000004	-82.2182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.04000000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
56075	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.6477000000000004	-81.8712000000000018	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers, Caloosahatchee River	FL
56076	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.7066993713378906	-82.163299560546875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.920000000000000373	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
56077	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.7199999999999989	-82.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999885	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
56078	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967000000000013	-82.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
56079	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.8550000000000004	-82.303299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.790000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
56080	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.9299999999999997	-82.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
56081	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9882999999999988	-81.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
56082	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117000000000012	-82.4099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
56083	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.0450000000000017	-82.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
56084	Venice Municipal Airport, Florida	NOS	8725858	27.0716999999999999	-82.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
56085	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.601700000000001	-82.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
56086	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.6149999999999984	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.10999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
56087	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.6383332999999993	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
56088	Little Manatee River, Florida	NOS	8726436	27.7049999999999983	-82.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
56089	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.7606000000000002	-82.6269000000000062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.20000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Petersburg, Tampa Bay	FL
56090	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833000000000006	-82.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.39999999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
56091	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.8577778000000009	-82.5527778000000012	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
56092	Ballast Point, Tampa, Florida	NOS	8726639	27.8900000000000006	-82.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
56093	CSX Rockport, Mckay Bay Entrance, Florida	NOS	8726667	27.9133333333333304	-82.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
56094	Clearwater Beach, Gulf Of Mexico, Florida	NOS	8726724	27.9783000000000008	-82.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
56095	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9882999999999988	-82.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
56096	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.1649999999999991	-82.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.69999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
56097	Bayport, Florida	NOS	8727151	28.5333000000000006	-82.6500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
56098	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917000000000009	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
56099	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.7149999999999999	-82.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.259999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
56100	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617000000000012	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.59000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
56101	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7716999999999992	-82.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
56102	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8000000000000007	-82.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.329999999999999849	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
56103	Ozello, St. Martin's River, Florida	NOS	8727306	28.8249999999999993	-82.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.349999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
56104	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8632999999999988	-82.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.840000000000000302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
56105	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.870000000000001	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
56106	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8816999999999986	-82.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
56107	Crystal River, Kings Bay, Florida	NOS	8727343	28.898299999999999	-82.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.16999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
56108	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.9050000000000011	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.23999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
56109	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233000000000011	-82.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
56110	Cedar Key, Gulf Of Mexico, Florida	NOS	8727520	29.1336111111111116	-83.0308888888888958	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
56111	Horseshoe Point, Florida	NOS	8727648	29.4366999999999983	-83.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.89000000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
56112	Spring Warrior Creek, Florida	NOS	8727843	29.9200000000000017	-83.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
56113	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0782999999999987	-84.178299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
56114	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.0599999999999987	-84.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
56115	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.9149999999999991	-84.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
56116	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.8099999999999987	-84.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
56117	Lanark, St. George Sound, Florida	NOS	8728412	29.8782997131347656	-84.595001220703125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
56118	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.8500000000000014	-84.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
56119	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.7667007446289062	-84.6999969482421875	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
56120	South Carrabelle Beach, Florida	NOS	8728488	29.8017005920410156	-84.7367019653320312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.40000000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
56121	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.7232999999999983	-84.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
56122	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533000000000015	-84.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
56123	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.6133003234863281	-84.9582977294921875	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
56124	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.726700000000001	-84.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.910000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
56125	White Beach, East Bay, Florida	NOS	8728694	29.7850000000000001	-84.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
56126	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.763300000000001	-85.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
56127	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.7700004577636719	-85.0849990844726562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.700000000000000067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
56128	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.7066993713378906	-85.1532974243164062	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999467	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
56129	White City, ICWW, Florida	NOS	8728853	29.8806944444444404	-85.2214444444444439	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
56130	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.8150000000000013	-85.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
56132	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.8733005523681641	-85.3899993896484375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
56133	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.1522777777777797	-85.6669444444444395	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.669999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
56134	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.2133055555555607	-85.8783055555555563	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.670000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
56135	Valparaiso, Florida	NOS	8729501	30.5032999999999994	-86.493300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.279999999999999361	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
56136	Navarre Beach, Florida	NOS	8729678	30.3766999999999996	-86.8649999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.660000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
56137	Pensacola, Florida	NOS	8729840	30.4043888888888887	-87.2111944444444447	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
56138	Millview, Perdido Bay, Florida	NOS	8729905	30.4182999999999986	-87.3567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
56139	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.386944444444449	-87.4288055555555559	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
56140	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.2786111111111111	-87.5550003051757812	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
56141	Gulf Shores, ICWW, Alabama	NOS	8731439	30.2798888888888911	-87.6842777777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
56142	Weeks Bay, Vermilion Bay, Louisiana	NOS	8732828	30.4168888888888915	-87.8253888888888952	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	LA
56143	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.4866388888888906	-87.9345277777777738	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
56144	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.6671666666666702	-87.9364444444444473	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
56145	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.0750000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.560000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
56146	Dauphin Island Hydro, Alabama	NOS	8735181	30.2513194444444409	-88.0794861111111089	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.590000000000000302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
56147	Dog River Bridge, Alabama	NOS	8735391	30.5651666666666699	-88.0879999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
56148	East Fowl River Bridge, Alabama	NOS	8735523	30.4436943999999983	-88.1139167000000043	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
56149	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.6483055555555595	-88.0583055555555489	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.799999999999997158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
56150	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.7083000000000013	-88.0433000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.809999999999999831	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
56151	Chickasaw Creek, Alabama	NOS	8737138	30.78188888888889	-88.0736111111111057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.839999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
56152	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783000000000008	-87.8733000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.930000000000003268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
56153	West Fowl River Bridge, Alabama	NOS	8738043	30.3766388888888912	-88.1585555555555516	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.859999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
56154	Bayou La Batre Bridge, Alabama	NOS	8739803	30.4056666666666686	-88.2476944444444484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.779999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
56155	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.4131944444444393	-88.4028888888888957	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.769999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
56156	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2032999999999987	-88.4416999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.709999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
56157	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477777999999994	-88.5058333000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.769999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
56158	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.3399999999999999	-88.533299999999997	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
56159	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.3677777777777784	-88.5630555555555503	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
56160	Gautier, Mississippi	NOS	8741798	30.3832999999999984	-88.6099999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.720000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
56161	Graveline Bayou entrance, Mississippi	NOS	8742205	30.361699999999999	-88.6633000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
56162	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2382999999999988	-88.6667000000000058	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
56163	North Shore, Mississippi	NOS	8742523	30.3733000000000004	-88.7049999999999983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999662	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
56164	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867000000000012	-88.7733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.909999999999999698	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
56165	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217000000000013	-88.7883000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
56166	Ocean Springs, Mississippi	NOS	8743281	30.3917000000000002	-88.7982999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
56167	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.4299999999999997	-88.7999999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.859999999999999876	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
56168	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.4200000000000017	-88.8282999999999987	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.93000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
56169	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383000000000017	-88.8449999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.929999999999999938	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
56170	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.3900000000000006	-88.8567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
56171	Deer Island, Mississippi	NOS	8743812	30.3832999999999984	-88.8666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
56172	Langley Point, Mississippi	NOS	8743838	30.4250000000000007	-88.8700000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
56173	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4116999999999997	-88.9033000000000015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.900000000000002132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
56176	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4132999999999996	-88.9749999999999943	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.01000000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
56177	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133000000000003	-88.9716999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999591	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
56178	Biloxi River, lower end, Mississippi	NOS	8744934	30.4349999999999987	-89.0083000000000055	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
56179	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067000000000007	-89.0267000000000053	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
56180	Landon, Mississippi	NOS	8745555	30.4316999999999993	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
56181	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.3599999999999994	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
56182	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.3099999999999987	-89.2450000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.869999999999999885	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
56183	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.3249999999999993	-89.3250000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999999911	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
56184	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817000000000007	-89.3666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.800000000000000711	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
56185	Devon Energy Facility, Louisiana	NOS	8760417	29.2007499999999993	-89.0444666666666649	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.590000000000003411	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
56186	South Pass, Louisiana	NOS	8760551	28.9899999999999984	-89.1400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.609999999999999876	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
56187	Grand Pass, Louisiana	NOS	8760668	30.1266999999999996	-89.2216999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
56188	Pilottown, Louisiana	NOS	8760721	29.1783055555555606	-89.2583055555555518	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.459999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
56190	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.3865555555555602	-89.3801388888888937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.679999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
56212	Stouts Pass At Six Mile Lake, Louisiana	NOS	8764025	29.7433000000000014	-91.230000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.420000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
56213	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675000000000004	-91.2376111111111072	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.299999999999997158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
56191	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322000000000017	-89.4074999999999989	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.600000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, SW Pass	LA
56192	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.9250000000000007	-89.4183000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.640000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
56193	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.8681111111111086	-89.6732499999999959	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
56194	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.0687500000000014	-89.8020829999999961	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.579999999999998295	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
56195	The Rigolets, U.S. Highway 90, Louisiana	NOS	8761402	30.1666999999999987	-89.736699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
56196	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.9450000000000003	-89.8349999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.679999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
56198	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.2633333333333283	-89.9566666666666634	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.540000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
56199	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.3183000000000007	-89.980000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
56200	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017000000000017	-90.0383000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.469999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
56201	Caminada Pass (bridge), Louisiana	NOS	8761826	29.2100000000000009	-90.0400000000000063	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
56202	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6666999999999987	-90.111699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.169999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
56203	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.0272222222222211	-90.1133333333333297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
56204	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.1142499999999984	-90.1992500000000064	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.650000000000002132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
56205	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483000000000004	-90.2116999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.469999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
56206	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0766999999999989	-90.2849999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
56207	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.0503333333333309	-90.367999999999995	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.260000000000005116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
56208	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.0678611111111103	-90.3899722222222266	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.270000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
56209	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0716999999999999	-90.6400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
56210	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245000000000001	-90.6616999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.560000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
56211	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.1747777777777806	-90.9764444444444393	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
56214	Lawma, Amerada Pass, Louisiana	NOS	8764227	29.4496111111111105	-91.3381111111111181	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.859999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
56216	Eugene Island, north of, Louisiana	NOS	8764314	29.3674999999999997	-91.3838888888888903	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of , Gulf of Mexico	LA
56217	Weeks Bay, Louisiana	NOS	8765148	29.8372222222222199	-91.8375000000000057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.890000000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
56218	Cypremort Point, Louisiana	NOS	8765251	29.7133611111111087	-91.8799999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.899999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
56219	Freshwater Canal Locks, Louisiana	NOS	8766072	29.5516944444444398	-92.3051944444444388	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
56220	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.2236388888888889	-93.221666666666664	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.789999999999999147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
56221	Bulk Terminal, Louisiana	NOS	8767961	30.1901944444444403	-93.3008055555555558	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
56222	Calcasieu Pass, East Jetty, Louisiana	NOS	8768094	29.7681666666666693	-93.3428888888888935	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.18999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
56223	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.8670833333333299	-93.9309999999999974	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.599999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
56224	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.9811944444444407	-93.8846944444444489	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.580000000000000515	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
56225	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667000000000002	-93.894999999999996	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
56226	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133000000000003	-94.6899999999999977	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
56227	Sabine Pass (north), Texas	NOS	8770570	29.7284000000000006	-93.8700999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
56228	Orange (Old Navy Base), Texas	NOS	8770597	30.0982999999999983	-93.7216999999999985	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
56229	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.6816944444444495	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.709999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point	TX
56230	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.6799999999999997	-94.868300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.700000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
56231	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.7648611111111094	-95.0788611111111095	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
56232	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.7566999999999986	-95.0900000000000034	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
56233	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.7262222222222192	-95.265777777777771	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000000782	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
56234	High Island (TCOON), Texas	NOS	8770808	29.5945277777777811	-94.3895833333333343	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.779999999999999361	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island	TX
56235	Texas Point, Sabine Pass, Texas	NOS	8770822	29.6893888888888888	-93.8419166666666626	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
56236	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633000000000017	-95.0666999999999973	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
56237	Rollover Pass, Texas	NOS	8770971	29.515555599999999	-94.5105556000000036	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.799999999999999822	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
56238	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.4800000000000004	-94.9183055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	TX
56240	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.3649999999999984	-94.7800000000000011	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.840000000000000746	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
56241	Galveston Bay Entrance, North Jetty, Texas	NOS	8771341	29.3573333333333295	-94.7248333333333363	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000000639	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
56242	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.3099999999999987	-94.7933055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.830000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
56253	Matagorda Bay Entrance Channel, Texas	NOS	8773767	28.4268888888888895	-96.3301111111111084	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel, TX	TX
56279	Los Angeles (outer harbor), California	NOS	9410660	33.7199444444444367	-118.272861111111098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.82000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
56243	Galveston Railroad Bridge, Texas	NOS	8771486	29.3023888888888884	-94.8965277777777771	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
56244	Galveston Pleasure Pier, Gulf Of Mexico, Texas	NOS	8771510	29.2852999999999994	-94.7894000000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.11000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
56245	San Luis Pass (TCOON), Texas	NOS	8771972	29.0809722222222184	-95.1313333333333304	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.669999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
56246	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9482999999999997	-95.3083000000000027	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.950000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
56247	USCG Freeport, Texas	NOS	8772447	28.9433055555555505	-95.3024999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.970000000000002416	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
56248	Sargent (TCOON), Texas	NOS	8772985	28.7714166666666706	-95.6171666666666624	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.350000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
56249	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.4068611111111089	-96.7124444444444435	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.189999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
56270	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683000000000007	-97.1567000000000007	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.879999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
56250	Matagorda City (TCOON), Texas	NOS	8773146	28.7100555555555594	-95.9140000000000015	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
56251	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.6405555555555509	-96.6097777777777793	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
56252	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.4458611111111104	-96.3955555555555605	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.400000000000000355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
56254	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.2275555555555506	-96.7965555555555568	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.149999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge, San Antonio Bay	TX
56255	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.1144444444444517	-97.0243888888888932	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.200000000000000178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
56256	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216999999999992	-97.0467000000000013	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.189999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
56257	White Point Bay, Texas	NOS	8775188	27.8582999999999998	-97.4749999999999943	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
56258	Port Aransas, Texas	NOS	8775237	27.8397222222222211	-97.0725000000000051	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.650000000000000355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
56259	Aransas, Aransas Pass, Texas	NOS	8775241	27.8365993499755859	-97.0391006469726562	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\nThese data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
56260	Nueces Bay (TCOON), Texas	NOS	8775244	27.8327500000000008	-97.4859444444444421	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.359999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
56261	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.8267002105712891	-97.0500030517578125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.919999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
56262	Port Ingleside, Corpus Christi Bay, Texas	NOS	8775283	27.8216999999999999	-97.2032999999999987	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Ingleside	TX
56263	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.8149166666666687	-97.389166666666668	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington	TX
56264	Corpus Christi Naval Air Station, Texas	NOS	8775421	27.7049999999999983	-97.2800000000000011	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
56265	Packery Channel, Texas	NOS	8775792	27.6333055555555589	-97.2366944444444385	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.189999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
56266	Corpus Christi, Gulf Of Mexico, Texas	NOS	8775870	27.5799999999999983	-97.216700000000003	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.929999999999999716	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
56267	Realitos Peninsula, Texas	NOS	8779280	26.2623999999999995	-97.2853000000000065	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
56268	Coast Guard Station, South Padre Island, Texas	NOS	8779748	26.073055555555559	-97.167500000000004	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.779999999999999805	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
56269	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.0673888888888889	-97.154777777777781	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\nThese data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.839999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
56271	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.0611666666666686	-97.2155277777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
56272	Avalon, Santa Catalina Island, California	NOS	9410079	33.3449999999999989	-118.325000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
56273	South San Diego Bay, California	NOS	9410135	32.6291390000000021	-117.108000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
56274	Ballast Point, California	NOS	9410155	32.6867000000000019	-117.233000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
56275	San Diego, San Diego Bay, California	NOS	9410170	32.7141900000000021	-117.173583333227398	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.94000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego	CA
56276	Mission Bay, California	NOS	9410196	32.7937200000000004	-117.223799999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.81000000000000227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
56277	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.8668888888888873	-117.257138888888903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.72999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
56278	Newport Beach, Newport Bay Entrance, Corona del Mar, California	NOS	9410580	33.6032999999999973	-117.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
56280	Long Beach, Terminal Island, California	NOS	9410680	33.7516999999999996	-118.227000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
56281	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0082999999999984	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79000000000000048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
56282	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483000000000018	-119.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
56283	Santa Barbara, California	NOS	9411340	34.4031111111111088	-119.692805555555594	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
56284	Gaviota State Park, California	NOS	9411399	34.4693888888888935	-120.228305555555593	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
56285	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.4691666666666734	-120.681944444444397	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
56286	Port San Luis, California	NOS	9412110	35.1688055555555579	-120.754194444444494	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
56287	Mansfield Cone, California	NOS	9412802	35.9495277777777673	-121.481944444444494	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.73999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
56288	Monterey, Monterey Harbor, California	NOS	9413450	36.6049995422363281	-121.888053894042969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
56289	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.8566700000000012	-121.754999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.93000000000000327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
56290	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5024999999999977	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.98999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
56291	San Francisco, San Francisco Bay, California	NOS	9414290	37.8063055555555465	-122.465888888888898	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
56293	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.7899999999999991	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
56294	Hunters Point, San Francisco Bay, California	NOS	9414358	37.7299999999999969	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
56295	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.6649999999999991	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.77000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
56296	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.5799999999999983	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.10999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
56298	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067000000000021	-122.114999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
56299	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.5067777777777778	-122.211527777777803	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
56300	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.4650000000000034	-122.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.91999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
56301	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.6950000000000003	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92000000000000082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
56302	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717000000000027	-122.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38000000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
56303	Alameda, San Francisco Bay, California	NOS	9414750	37.7717000000000027	-122.299999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
56304	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.7950000000000017	-122.281999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
56305	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933000000000021	-122.314999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
56306	Sausalito, San Francisco Bay, California	NOS	9414806	37.8466999999999985	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
56307	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833000000000027	-121.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
56308	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865000000000002	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
56309	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.9230000000000018	-122.409583333333302	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
56310	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.9077796936035156	-122.678611755371094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
56311	Drakes Bay, Point Reyes, California	NOS	9415020	37.9961128234863281	-122.976669311523438	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
56312	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.9946944444444412	-121.419044444444395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.84000000000003183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
56313	Pinole Point, San Pablo Bay, California	NOS	9415056	38.0150000000000006	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
56314	Antioch, San Joaquin River, California	NOS	9415064	38.0200000000000031	-121.814999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
56315	Martinez-Amorco Pier, California	NOS	9415102	38.0346388888888924	-122.125194444444503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
56316	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.0500252777777774	-121.496855555555598	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
56317	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433000000000021	-121.918000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
56318	Crockett, Carquinez Strait, California	NOS	9415143	38.0583000000000027	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
56319	Port Chicago, Suisun Bay, California	NOS	9415144	38.0559999999999974	-122.039500000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
56320	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.0867000000000004	-121.685000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.75999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
56321	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.0700000000000003	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
56322	Korths Harbor, San Joaquin River, California	NOS	9415229	38.0976100000000031	-121.568382999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
56323	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.1153055555555582	-122.505666666666698	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
56324	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.128300000000003	-122.072999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.60999999999999988	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
56325	Rio Vista, Sacramento River, California	NOS	9415316	38.1450000000000031	-121.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.12999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
56326	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567000000000007	-122.406999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
56327	Lakeville, Petaluma River, California	NOS	9415423	38.1983000000000033	-122.546999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
56328	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2282999999999973	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
56329	Green Cove, California	NOS	9416409	38.7043333333333308	-123.449388888888905	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
56330	Arena Cove, California	NOS	9416841	38.9145555555555589	-123.711083333333306	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.13999999999999702	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
56331	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.4257777777777818	-123.805111111111103	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2799999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
56332	Shelter Cove, California	NOS	9418024	40.0250015258789062	-124.057998657226562	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.30000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
56333	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233000000000018	-124.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
56334	North Spit, Humboldt Bay, California	NOS	9418767	40.7663000000000011	-124.217200000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
56335	Samoa, Humboldt Bay, California	NOS	9418817	40.8267000000000024	-124.180000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
56336	Crescent City, California	NOS	9419750	41.7449999999999974	-124.183000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
56337	Pyramid Point, Smith River, California	NOS	9419945	41.9452500000000015	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.41999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
56338	Gold Beach, Rogue River, Oregon	NOS	9431011	42.4216388888888929	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.90999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
56339	Port Orford, Oregon	NOS	9431647	42.7389700000000019	-124.498277777565846	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.92999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
56340	Charleston, Coos Bay, Oregon	NOS	9432780	43.3449999999999989	-124.322000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
56341	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.6749999999999972	-124.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
56342	Florence USCG Pier, Suislaw River, Oregon	NOS	9434098	44.0021111111111125	-124.123000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Suislaw River	OR
56343	Waldport, Alsea Bay, Oregon	NOS	9434939	44.4343611111111088	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
56344	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5932999999999993	-124.007999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
56345	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.625	-124.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.44999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
56346	Depoe Bay, Oregon	NOS	9435827	44.8100000000000023	-124.058000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
56347	Cascade Head, Salmon River, Oregon	NOS	9436381	45.0479444444444468	-124.007305555555604	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.60000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
56348	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4816999999999965	-123.902000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.30999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
56349	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.5545299999999997	-123.918944444391457	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
56350	North Jetty, Tillamook Bay, Oregon	NOS	9437585	45.5699996948242188	-123.964996337890625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27000000000000313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
56351	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.1242500000000035	-123.804333333333304	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
56352	Hammond, Oregon	NOS	9439011	46.2017000000000024	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
56353	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.207305555555557	-123.7683055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.50999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
56354	Wauna, Columbia River, Oregon	NOS	9439099	46.1616668701171875	-123.408889770507812	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
56355	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6966999999999999	-122.867999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.41999999999999971	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
56356	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8633000000000024	-122.796199999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
56357	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.509999999999998	-122.673000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
56358	Washougal, Columbia River, Washington	NOS	9440047	45.5783004760742188	-122.382003784179688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.810000000000000497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
56359	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.020301818847656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.780000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
56360	Vancouver, Columbia River, Washington	NOS	9440083	45.6316944444444417	-122.697000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.34999999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
56362	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.9866981506347656	-122.836700439453125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
56363	Longview, Columbia River, Washington	NOS	9440422	46.1061388888888928	-122.954194444444397	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.05000000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
56364	Cape Horn, Columbia River, Washington	NOS	9440482	46.1516990661621094	-123.290000915527344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.98999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
56365	Barlow Point, Columbia River, Washington	NOS	9440483	46.1521987915039062	-123.039199829101562	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
56366	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.2667000000000002	-123.451999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
56367	Cape Disappointment, Washington	NOS	9440581	46.2810277777777799	-124.046277777777803	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
56368	Greenhead Slough, Washington	NOS	9440650	46.3722000122070312	-123.950302124023438	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.89000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
56369	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5016999999999996	-124.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
56370	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6632999999999996	-123.798000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
56371	Toke Point, Willapa Bay, Washington	NOS	9440910	46.7074700000000007	-123.96691666666004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.78000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
56372	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.9043100000000024	-124.105083333121399	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
56373	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9682999999999993	-123.852999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.60000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
56375	La Push, Quillayute River, Washington	NOS	9442396	47.9132999999999996	-124.637	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5099999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push	WA
56376	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.1711006164550781	-124.736900329589844	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
56377	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.3702777999999967	-124.601944399999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
56378	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.263300000000001	-124.296999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
56379	Jim Creek, Washington	NOS	9443551	48.1871986389160156	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.05999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
56380	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.1247222222222319	-123.441138888888901	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
56381	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.1129000000000033	-122.759500000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
56382	Foulweather Bluff, Washington	NOS	9445016	47.9266999999999967	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
56383	Bangor Wharf, Washington	NOS	9445133	47.7483000000000004	-122.727000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
56384	Union, Hood Canal, Washington	NOS	9445478	47.3582999999999998	-123.097999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
56385	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.3782997131347656	-122.634002685546875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
56386	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.2666699999999977	-122.413333333333327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.83999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
56387	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.1799999999999997	-122.674999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
56388	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.1529998779296875	-122.675102233886719	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.61999999999999922	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
56389	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983000000000018	-122.894999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
56390	Seattle, Puget Sound, Washington	NOS	9447130	47.602640000000001	-122.339305555555597	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
56391	Everett, Washington	NOS	9447659	47.9799999999999969	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
56392	Priest Point, Washington	NOS	9447717	48.0349444444444416	-122.227194444444507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
56393	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.0649999999999977	-122.287999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
56394	Greenbank, Whidbey Island, Washington	NOS	9447883	48.1049999999999969	-122.569999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.60999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
56395	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.3428001403808594	-122.685798645019531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.43999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
56396	Spee-Bi-Dah, Washington	NOS	9448009	48.0882500000000022	-122.322333333333304	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
56397	Tulare Beach, Port Susan, Washington	NOS	9448043	48.1068055555555532	-122.347277777777805	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4599999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
56398	Sneeoosh Point, Washington	NOS	9448576	48.3999999999999986	-122.548000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
56400	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.4150009155273438	-122.652000427246094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.63000000000000078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
56401	Turner Bay, Similk Bay, Washington	NOS	9448657	48.4450000000000003	-122.555000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
56402	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.4583015441894531	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.0400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
56403	Village Point, Lummi Island, Washington	NOS	9449161	48.716700000000003	-122.707999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.01000000000000068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
56404	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.8633000000000024	-122.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
56405	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.9749984741210938	-123.083000183105469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
56406	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917000000000016	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
56407	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
56408	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.6467018127441406	-122.870002746582031	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
56409	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5816999999999979	-123.170000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
56410	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.4850006103515625	-123.083000183105469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
56411	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.5453055555555579	-123.012888888888895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.55000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
56412	Upright Head, Lopez Island, Washington	NOS	9449911	48.5717010498046875	-122.885002136230469	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62000000000000099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
56413	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.5349999999999966	-122.796999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.66000000000000103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
56414	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4466999999999999	-122.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
56415	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.805000305175781	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.70999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
56416	Windy Cove entrance, Alaska	NOS	9450251	55.0354000000000028	-133.023799999999994	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
56437	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2766999999999982	-132.985000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
56417	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0878999999999976	-132.815830000000005	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
56418	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1000000000000014	-131.217000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
56419	Metlakatla, Port Chester, Alaska	NOS	9450314	55.128300000000003	-131.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
56420	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.2016983032226562	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
56421	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.3318299999999965	-131.62619444423251	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
56422	Trocadero Bay, Alaska	NOS	9450463	55.3516666666666666	-132.938055555555593	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
56423	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883000000000024	-133.141999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
56425	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.601700000000001	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.20999999999999908	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
56426	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.6289999999999978	-131.362694000000005	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.14999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
56427	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.7216666666666569	-133.349999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
56428	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.7882833333333323	-132.190883333333403	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
56429	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0382999999999996	-131.094999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
56430	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1182999999999979	-132.078000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
56431	El Capitan Passage, Alaska	NOS	9450997	56.1632999999999996	-133.330000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
56432	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1632999999999996	-133.413000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
56433	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783000000000001	-132.697000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
56434	Bradfield Canal, Alaska	NOS	9451012	56.1833000000000027	-131.572000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
56435	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.2199999999999989	-132.296999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
56436	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.246699999999997	-134.646999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
56438	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3532999999999973	-132.552999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
56439	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922000000000025	-132.169000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
56440	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.4699999999999989	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
56441	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.5349999999999966	-133.766999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
56442	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583000000000027	-132.962999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.72999999999999865	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
56443	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.5949999999999989	-132.986999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.90000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
56444	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.638300000000001	-132.926999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.19999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
56445	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6766999999999967	-132.932999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.54000000000000092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
56446	The Summit, Keku Strait, Alaska	NOS	9451349	56.6824222222222218	-133.736908333333304	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.03999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
56447	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867000000000033	-135.393000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
56448	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7882999999999996	-132.50200000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
56449	Turn Point, Alaska	NOS	9451434	56.7999999999999972	-132.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
56450	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117000000000019	-133.787000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
56451	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8566999999999965	-134.723000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.78999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
56452	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.9033333333333431	-134.303055555555602	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
56453	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.9483055555555566	-133.894722222222214	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.50999999999999801	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
56454	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.0516944444444434	-135.342000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29000000000000092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
56455	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.0883333333333312	-134.824999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.25999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
56456	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.31999999999999673	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
56457	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.2950000000000017	-133.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
56458	Scraggy Island, Alaska	NOS	9451805	57.3400000000000034	-135.706999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
56459	Sergius Narrows, Alaska	NOS	9451853	57.4099999999999966	-135.62700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
56460	Provorotni Island, Alaska	NOS	9451936	57.5150000000000006	-135.555000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
56461	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.533299999999997	-134.417000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.71000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
56462	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2982999999999976	-134.412000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
56463	Hawk Inlet Entrance, Alaska	NOS	9452294	58.0850000000000009	-134.776999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
56464	False Bay, Chatham Strait, Alaska	NOS	9452328	57.966700000000003	-134.935000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
56465	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.4500000000000028	-135.326999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway	AK
56466	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.1700000000000017	-135.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
56467	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.1075555555555567	-135.444194444444406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.89999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
56469	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.9577777777777783	-136.226777777777812	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
56470	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.1947199999999967	-136.346944444444432	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.74000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
56471	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.9647777777777833	-136.877583333333291	:America/Juneau	USA	feet	\N	\N	\N	NOS uses UTC-8 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.75999999999999979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
56472	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5484999999999971	-139.733399999999989	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
56473	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5583000000000027	-145.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.73999999999999932	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
56474	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.361999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
56475	Perch Point, Montague Island, Alaska	NOS	9454561	60.1266999999999996	-147.39500000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
56476	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.402999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
56477	Seal Island, Alaska	NOS	9454564	60.4249999999999972	-147.409999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.29999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
56479	Montague Island, Alaska	NOS	9454616	60.0249999999999986	-147.592000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
56480	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667000000000016	-147.699999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
56481	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
56482	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.4750000000000014	-147.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
56483	South Bay, Perry Island, Alaska	NOS	9454721	60.6717000000000013	-147.931999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
56484	Guguak, Alaska	NOS	9454751	60.1000000000000014	-148.038000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.09999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
56485	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9382999999999981	-148.227000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6800000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
56486	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783000000000015	-148.664999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
56487	Seward, Resurrection Bay, Alaska	NOS	9455090	60.1199999999999974	-149.426666699999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.55999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
56488	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.773299999999999	-149.587999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
56489	Aialik Bay, north end, Alaska	NOS	9455145	59.9532999999999987	-149.715000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.53000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
56490	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.884999999999998	-149.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.55999999999999872	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
56491	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933000000000007	-149.74799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
56492	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7132999999999967	-149.787000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57000000000000028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
56493	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.7899999999999991	-150.032000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.66999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
56494	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.4405277777777812	-151.719944444444508	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.51999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
56495	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.4683055555555526	-151.564999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.58999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
56496	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.7250000000000014	-151.022999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.80000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
56497	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.7719722222222316	-151.867027777777793	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.67999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
56498	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.0549999999999997	-151.681999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
56499	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367000000000004	-151.379999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
56500	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.5116999999999976	-151.951999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.1699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
56501	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.503300000000003	-151.282999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
56502	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.6833055555555632	-151.397999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.2900000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
56503	Point Possession, Alaska	NOS	9455866	61.0367000000000033	-150.413000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.2600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
56504	North Foreland, Alaska	NOS	9455869	61.0433055555555626	-151.163000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.5000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
56505	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1732999999999976	-150.212999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
56506	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2374999999999972	-149.8904	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.4699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
56507	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2683000000000035	-149.917000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
56508	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933000000000035	-149.847000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
56509	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917000000000002	-153.957999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
56510	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.2899999999999991	-154.27000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
56511	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217000000000013	-152.49799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.61000000000000032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
56512	Kodiak, Women's Bay, Alaska	NOS	9457292	57.7302777777777791	-152.513888888888914	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.49000000000000199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
56513	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283000000000001	-152.812000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
56514	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.8734722222222189	-152.867111111111086	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.78000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
56516	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9782999999999973	-152.925000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26999999999999957	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
56517	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.7440277777777808	-153.195472222222207	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
56518	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.9657199999999975	-153.252194000000003	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32999999999999829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
56519	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.2027777777777828	-153.303888888888906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
56520	West Raspberry Island, Alaska	NOS	9457535	58.1071666666666573	-153.340111111111099	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.35000000000000053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
56521	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.9600000000000009	-153.687000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.37000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
56522	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.533299999999997	-153.990000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.14000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
56523	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.5946939999999969	-153.996027999999995	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.60000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
56525	Alitak, Lazy Bay, Alaska	NOS	9457804	56.8973999999999975	-154.24799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.14000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
56526	Puale Bay, Alaska	NOS	9458209	57.7066999999999979	-155.393000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
56527	Chirikof Island, Alaska	NOS	9458293	55.8083000000000027	-155.740000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.59999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
56528	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0516999999999967	-156.698000000000008	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
56530	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2316999999999965	-158.347000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
56531	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133000000000024	-158.598000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
56532	Mitrofania Island, Alaska	NOS	9459016	55.8900000000000006	-158.819999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
56533	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.0655555555555623	-159.418666666666695	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
56534	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.835222222222221	-159.759555555555607	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.79999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
56535	Sand Point, Popof Island, Alaska	NOS	9459450	55.3366944444444471	-160.50200000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
56537	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.121699999999997	-161.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
56538	King Cove, Deer Passage, Alaska	NOS	9459881	55.0598888888888922	-162.326111111111089	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
56539	Cold Bay, Alaska	NOS	9459949	55.2083000000000013	-162.698000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
56540	Attu, Massacre Bay, Alaska	NOS	9460150	52.8400000000000034	173.194999999999993	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Station 9460150 Massacre Bay, Attu Island is a historic station with tidal\nharmonic constants and tidal datums based upon a 06/1943 - 06/1944\ninstallation. Due to the remote nature of this area, there are no plans to\ncollect updated water level values in the vicinity of Attu Island, AK.  During\nthe 1943-1944 installation of this station NOAA was able to obtain and compute\na full suite of harmonic constants.  Therefore, this station is used as a\ncontrol station for predictions at other subordinate harmonic stations in the\nfar western Aleutian Islands.In order to provide tidal predictions\n(http://tidesandcurrents.noaa.gov/tide_predictions.shtml) for this station and\nits subordinate stations, it is necessary to provide the separation between\nMean Sea Level (MSL) and Mean Lower Low Water (MLLW) only.Therefore, MSL has\nbeen held fixed as station datum and MLLW referenced to MSL in order to remove\nany reference to the terrestrial system.  The removal of a terrestrial\nreference frame enables the relationship between MSL and MLLW to remain\nconsistent over time and not require a periodic National Tidal Datum Epoch\n(NTDE) update to accountant for sea level rise.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.93999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
56541	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.8633055555555629	-176.632000000000005	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
56542	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.2319999999999993	-174.172599999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.96999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
56543	Nikolski, Umnak Island, Alaska	NOS	9462450	52.9406099999999995	-168.871305555767492	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
56544	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.8791944444444368	-166.540305555555591	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07999999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
56545	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.8289166666666716	-166.216250000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
56546	Reef Bight, Alaska	NOS	9462662	54.1307222222222322	-166.099333333333306	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.00999999999999091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
56547	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.0645833333333314	-165.937055555555588	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.17999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
56548	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.1332777777777778	-165.777305555555614	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.15999999999999659	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
56549	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.1102777777777817	-165.661388888888894	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
56550	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.1508333333333312	-165.615000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18999999999999773	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
56551	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2332999999999998	-165.532999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
56552	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.1400000000000006	-165.526999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
56553	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.0522222222222197	-165.514166666666711	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
56554	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.1199999999999974	-164.977000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.61999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
56555	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.1018055555555577	-164.941583333333313	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.96000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
56556	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6000000000000014	-164.927999999999997	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.97999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
56557	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.3936388888888871	-164.745722222222213	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
56558	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.0642777777777823	-163.534166666666692	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.28999999999999204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
56559	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.966700000000003	-163.439999999999998	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
56560	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8582999999999998	-163.407000000000011	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.44000000000000039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
56561	Isanotski Strait Entrance, Aleutian Islands, Alaska	NOS	9462961	54.7784444444444532	-163.364277777777801	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59999999999999787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
56562	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.985694444444448	-160.573888888888888	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.83000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
56563	Village Cove, St. Paul Island, Bering Sea, Alaska	NOS	9464212	57.1253055555555633	-170.285166666666697	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.96000000000000019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
56564	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.711999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
56567	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483000000000018	-158.551999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
56568	Snag Point, Dillingham, Alaska	NOS	9465374	59.0399999999999991	-158.447000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
56569	Platinum, Alaska	NOS	9465396	59.0467000000000013	-161.818000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83999999999999631	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum, AK	AK
56570	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.3780166666666673	-162.029333333333312	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.70000000000000107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
56571	Quinhagak (Kwinak), Kushkokwin River, Alaska	NOS	9465831	59.7505527777777772	-161.915436111111092	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.44999999999999574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
56572	Kinak Bay, Alaska	NOS	9465953	59.9475279999999984	-164.210700000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
56573	Eastern Nunivak Island, Alaska	NOS	9466012	60.0429400000000015	-165.680583000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.77000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
56574	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.1232777777777798	-162.50036111111109	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
56575	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.2702777777777783	-162.410166666666697	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.76000000000000156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
56576	Mekoryuk, Mekoryuk River Entrance, Alaska	NOS	9466217	60.4166999999999987	-166.167000000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.86999999999999744	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
56577	Tooksook Bay, Nelson Island, Alaska	NOS	9466298	60.5167000000000002	-165.13300000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
56578	Lomavik, Alaska	NOS	9466328	60.5542777777777772	-162.297138888888895	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.87999999999999901	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
56579	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.7999999999999972	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
56580	Dall Point, Hooper Bay, Alaska	NOS	9466931	61.5317000000000007	-166.147999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.83999999999999631	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
56581	Nunam Iqua (Sheldon Point), Alaska	NOS	9467551	62.5329444444444533	-164.845277777777795	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.05000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
56582	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3166999999999973	-168.967000000000013	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
56584	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.679083333333331	-170.537111111111102	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28000000000000114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
56586	Unalakleet, Alaska	NOS	9468333	63.875	-160.788000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
56587	Shaktoolik, Alaska	NOS	9468691	64.3802222222222156	-161.235138888888912	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.66999999999999815	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
56588	Nome, Norton Sound, Alaska	NOS	9468756	64.4946111111111122	-165.439638888888908	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
56589	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.256699999999995	-166.847000000000008	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.729999999999999538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
56590	Teller, Port Clarence, Alaska	NOS	9469239	65.2667000000000002	-166.353000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.599999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
56591	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.3900000000000006	-167.14500000000001	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.520000000000000462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
56592	Tin City, Bering Sea, Alaska	NOS	9469439	65.5583333333333371	-167.974999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.469999999999999751	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
56613	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.3606666666666705	-64.8035277777777736	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.489999999999998437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
56593	Outside Lopp Lagoon, Alaska	NOS	9469515	65.7288060000000058	-168.032139000000001	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000003979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
56594	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.0971666666666664	-162.740472222222195	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.949999999999999289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
56595	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.2303009033203125	-163.904098510742188	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.880000000000002558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
56596	Shishmaref Inlet 2, Alaska	NOS	9469854	66.263300000000001	-166.02000000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.510000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
56597	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.5856944444444423	-164.250833333333304	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.530000000000001137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
56598	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017000000000053	-162.581999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
56599	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.0541944444444482	-163.321277777777794	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.230000000000003979	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
56600	Red Dog Dock, Alaska	NOS	9491094	67.5758055555555615	-164.064388888888914	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.439999999999999503	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
56601	Kivalina, Alaska	NOS	9491253	67.7266999999999939	-164.592000000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.440000000000000391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
56602	Point Hope, Alaska	NOS	9491873	68.341700000000003	-166.807999999999993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.329999999999999627	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
56603	Barrow (offshore), Alaska	NOS	9494935	71.3601111111111095	-156.729861111111092	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.310000000000002274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
56604	Prudhoe Bay, Alaska	NOS	9497645	70.4114166666666677	-148.531777777777791	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999996305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
56607	Barter Island, Alaska	NOS	9499176	70.1285555555555504	-143.611027777777792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.280000000000000249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
56608	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.3676111111111098	-64.7207222222222214	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
56609	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.75	-64.7049999999999983	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
56610	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.3482999999999983	-64.716700000000003	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.419999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
56611	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.318249999947021	-64.7242222224341504	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.390000000000000568	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
56612	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.6947222222222216	-64.7538055555555587	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000004547	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lime Tree Bay. St. Croix	VI
56614	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.2971388888888917	-64.8177500000000038	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000000995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
56616	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.3489444444444487	-64.8641666666666623	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.559999999999998721	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
56617	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133000000000003	-64.8833000000000055	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.339999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
56618	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.3358333333333334	-64.9200000000000017	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999893	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
56619	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.3712499999999999	-64.9634722222222223	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.579999999999998295	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
56620	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3632999999999988	-65.0349999999999966	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.59000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
56621	Culebra, Puerto Rico	NOS	9752235	18.3008611111111108	-65.3024722222222209	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999997584	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
56622	Isabel Segunda, Vieques Island, Puerto Rico	NOS	9752619	18.1525277777777809	-65.4438055555555565	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.589999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
56623	Esperanza, Vieques Island, Puerto Rico	NOS	9752695	18.0938611111111101	-65.4713611111111078	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.399999999999998579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
56624	Isla Palominos, Puerto Rico	NOS	9752962	18.3449722222222213	-65.569500000000005	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
55666	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167000000000016	-70.8117000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.69999999999999929	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
55785	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.5811996459960938	-73.9337997436523438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.64999999999999858	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
56625	Fajardo, Puerto Rico	NOS	9753216	18.335222222222221	-65.6311111111111103	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.730000000000000426	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
56626	Naguabo, Puerto Rico	NOS	9753641	18.1870555555555597	-65.7113888888888908	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
56627	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.0550833333333287	-65.8329999999999984	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.349999999999999645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
56628	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.4591666666666683	-66.116388888888892	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.760000000000000231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
56629	Las Mareas, Puerto Rico	NOS	9755679	17.9283000000000001	-66.158299999999997	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
56630	Santa Isabel, Puerto Rico	NOS	9756639	17.9549999999999983	-66.4067000000000007	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.359999999999999432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
56631	Arecibo, Puerto Rico	NOS	9757809	18.4805555999999989	-66.7025000000000006	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.820000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
56632	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.9725277777777812	-66.7617777777777803	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.350000000000001421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
56633	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.9699999999999989	-67.0463888999999966	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.330000000000000071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
56634	Puerto Real, Puerto Rico	NOS	9759189	18.0748055555555602	-67.1887777777777728	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.420000000000001705	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
56635	Baha Salinas, Puerto Rico	NOS	9759197	17.9514444444444408	-67.1965833333333364	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.320000000000000284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
56636	Mayagez, Puerto Rico	NOS	9759394	18.2175555555555597	-67.1588333333333338	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.63999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
56637	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.4566388888888895	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla	PR
56638	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.1649999999999991	-67.1817000000000064	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.529999999999999805	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJABO, MAYAGUES	PR
56639	Mona Island, Puerto Rico	NOS	9759938	18.0899166668785902	-67.9385000001059609	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.410000000000000142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
55915	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.0329017639160156	-76.0832977294921875	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47999999999999954	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
56361	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.754997253417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
55643	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.1700000000000017	-68.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.53000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
55654	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.3200000000000003	-69.7702799999999996	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.900000000000000022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
55728	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2282999999999973	-71.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
56646	Lower Marlboro, Patuxent River, Maryland (sub)	NOS	8579542	38.6550000000000011	-76.6833333333333371	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:51:00	\N	0.770000000000000018	-02:44:00	\N	1.43999999999999995	\N	\N	Lower Marlboro	MD
55742	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0716999999999999	-71.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
55746	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.0349999999999966	-72.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34000000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
55784	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.783299999999997	-73.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
55796	Spuyten Duyvil Creek Entrance, Hudson River, New York	NOS	8518903	40.878300000000003	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
55797	Riverdale, Hudson River, New York	NOS	8518905	40.9033000000000015	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.06999999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
55856	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867000000000033	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.869999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
55882	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia	NOS	8632366	37.263300000000001	-76.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
55895	New Point, Virginia	NOS	8637289	37.3466999999999985	-76.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.849999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
55896	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567000000000021	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
56661	Waianae, Oahu Island, Hawaii	NOS	1612482	21.4450000000000003	-158.192000000000007	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:18:00	\N	1	00:20:00	\N	0.930000000000000049	\N	\N	Waianae	HI
55902	Burwell Bay, James River, Virginia	NOS	8638421	37.0566999999999993	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
55966	Savannah (Bull Street), Georgia	NOS	8670681	32.0816999999999979	-81.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.30999999999999961	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
55983	Cut 2N front range, St. Marys River, Florida	NOS	8720012	30.7166999999999994	-81.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.97999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	FL
56018	Daytona Beach (ocean), Florida	NOS	8721020	29.2283000000000008	-81.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.12999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
56025	Canaveral Harbor Entrance, Florida	NOS	8721608	28.4083000000000006	-80.6016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.95999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
56647	Snow Hill, city park, Pocomoke River, Maryland (sub)	NOS	8571359	38.1783300000000025	-75.3966666666666612	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	08:54:00	\N	1.33000000000000007	08:44:00	\N	0.57999999999999996	\N	\N	Snowhill, city park	MD
56035	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.5482997894287109	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.30000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
56131	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.6900000000000013	-85.3632999999999953	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.689999999999999947	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
56174	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4182999999999986	-88.9249999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.729999999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
56175	Tchoutacabouffa River Entrance, Mississippi	NOS	8744663	30.4417000000000009	-88.9732999999999947	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.790000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
56189	Venice, Grand Pass, Louisiana	NOS	8760849	29.273299999999999	-89.3516999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.330000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
56197	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.254999999999999	-89.9682999999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.510000000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
56215	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717000000000006	-91.3850000000000051	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
56239	Sabine (offshore), Texas	NOS	8771081	29.4983000000000004	-93.6400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.28000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	TX
56292	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.8100000000000023	-122.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.2200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT [PIER 41] S.F.BAY	CA
56297	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.533299999999997	-122.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
56374	Taholah, Washington	NOS	9441644	47.3481700000000032	-124.284750000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
56399	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4132999999999996	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.95000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
56424	Big Salt Lake, Alaska	NOS	9450623	55.6000000000000014	-132.949999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.44999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Salt Lake	AK
56468	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9132999999999996	-136.108000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.64000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
56478	Storey Island (north side), Alaska	NOS	9454571	60.7316999999999965	-147.437000000000012	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.42999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
56515	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394000000000034	-152.874719999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87000000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
56524	Uyak, Uyak Bay, Alaska	NOS	9457728	57.634999999999998	-154.007000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.13999999999999968	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
56529	Sutwik Island, West End, Alaska	NOS	9458665	56.5399999999999991	-157.326999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
56536	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.3350000000000009	-160.61699999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.93999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
56565	Hagemeister Island (north end), Alaska	NOS	9465234	58.7766999999999982	-160.776999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.59999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
56566	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083000000000027	-161.099999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.95000000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
56583	St. Michael, Norton Sound, Alaska	NOS	9468132	63.4750000000000014	-162.026999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.6399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
56585	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7184999999999988	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
56605	Prudhoe Bay #2, Alaska	NOS	9497649	70.388300000000001	-148.509999999999991	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.349999999999999978	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
56606	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4916999999999945	-147.949999999999989	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9\n	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.299999999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
56615	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.3200000000000003	-64.8700000000000045	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over The Epoch.\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.369999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
56640	Westport, Point Chehalis, Grays Harbor, Washington (sub)	NOS	9441102	46.9043100000000024	-124.105083333121399	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:29:00	\N	1.01000000000000001	-00:11:00	\N	1.03000000000000003	\N	\N	Westport, Point Chehalis	WA
56641	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.8413299999999992	-121.745277777777773	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	00:08:00	\N	0.959999999999999964	00:26:00	\N	1.02000000000000002	\N	\N	Kirby Park, Elkhorn Slough	CA
56642	Ocean City Inlet, Maryland (sub)	NOS	8570283	38.3283300000000011	-75.0916666666666686	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:14:00	\N	1	00:28:00	\N	0.650000000000000022	\N	\N	Ocean City Inlet	MD
56643	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland (sub)	NOS	8571702	38.4283300000000025	-76.2366666666666646	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:49:00	\N	0.819999999999999951	-02:26:00	\N	1.01000000000000001	\N	\N	Smithville Road Bridge, Beaverdam Creek	MD
56644	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland (sub)	NOS	8571559	38.2999999999999972	-76.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:22:00	\N	1.16999999999999993	05:49:00	\N	0.819999999999999951	\N	\N	McCreedy's Creek, Fishing Bay	MD
56645	Crumpton, Chester River, Maryland (sub)	NOS	8573349	39.2449999999999974	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	01:04:00	\N	0.910000000000000031	01:10:00	\N	1.82000000000000006	\N	\N	Crumpton	MD
56648	Vienna, Nanticoke River, Maryland (sub)	NOS	8571773	38.4833300000000023	-75.818333333333328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	08:32:00	\N	1.33000000000000007	08:25:00	\N	0.790000000000000036	\N	\N	Vienna	MD
56649	Tolchester Beach, Chesapeake Bay, Maryland (sub)	NOS	8573364	39.2133299999999991	-76.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	00:11:00	\N	0.949999999999999956	00:18:00	\N	1.04000000000000004	\N	\N	Tolchester Beach	MD
56650	Brandywine Shoal Light, Delaware Bay, New Jersey (sub)	NOS	8555889	38.9866699999999966	-75.1133333333333297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	00:23:00	\N	1.06000000000000005	-00:01:00	\N	1.15999999999999992	\N	\N	Brandywine Shoal Light	NJ
56651	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington (sub)	NOS	9446484	47.2666699999999977	-122.413333333333327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:04:00	\N	1	00:04:00	\N	1.04000000000000004	\N	\N	Tacoma, Commencement Bay, Sitcum Waterway	WA
56652	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.870000000000001	-160.235000000000014	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:11:00	\N	0.770000000000000018	-00:16:00	\N	0.770000000000000018	\N	\N	Nonopapa, Niihau Island	HI
56653	Port Allen, Hanapepe Bay, Kauai Island, Hawaii (sub)	NOS	1611347	21.9033000000000015	-159.592000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55615	-00:10:00	\N	1	-00:15:00	\N	1.01000000000000001	\N	\N	Port Allen, Hanapepe Bay	HI
56654	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567000000000014	-159.673000000000002	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55615	00:18:00	\N	0.910000000000000031	00:07:00	\N	0.859999999999999987	\N	\N	Waimea Bay	HI
56655	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995000000000001	-159.335000000000008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55615	00:04:00	\N	0.910000000000000031	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
56656	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.2149999999999999	-159.50200000000001	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55615	-01:22:00	\N	0.910000000000000031	-01:01:00	\N	1.07000000000000006	\N	\N	Hanalei Bay	HI
56657	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.2749999999999986	-157.697000000000003	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
56658	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii (sub)	NOS	1612366	21.3299999999999983	-157.967000000000013	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:06:00	\N	0.880000000000000004	00:15:00	\N	1	\N	\N	Pearl Harbor Entrance, Bishop Point	HI
56659	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.3350000000000009	-157.693000000000012	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55619	00:05:00	\N	0.75	00:11:00	\N	0.880000000000000004	\N	\N	Waimanalo	HI
56660	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii (sub)	NOS	1612404	21.3683000000000014	-157.939999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:08:00	\N	0.880000000000000004	00:16:00	\N	1.03000000000000003	\N	\N	Pearl Harbor, Ford Island Ferry	HI
56662	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5982999999999983	-158.108000000000004	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-02:05:00	\N	0.800000000000000044	-01:02:00	\N	0.800000000000000044	\N	\N	Haleiwa, Waialua Bay	HI
56663	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483000000000011	-156.87700000000001	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:16:00	0	\N	-00:37:00	0.100000000000000006	\N	\N	\N	Kamalo Harbor	HI
56664	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0716999999999999	-156.800000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:48:00	0	\N	-01:03:00	0.100000000000000006	\N	\N	\N	Pukoo Harbor	HI
56665	Kaunakakai Harbor, Molokai Island, Hawaii (sub)	NOS	1613198	21.0850000000000009	-157.032000000000011	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:14:00	\N	1.25	-00:10:00	\N	1.12999999999999989	\N	\N	Kaunakakai	HI
56666	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0932999999999993	-157.197000000000003	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
56667	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.7899999999999991	-156.995000000000005	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:03:00	0	\N	00:02:00	0.200000000000000011	\N	\N	\N	Kaumalapau, Lanai Island	HI
56668	Makena, Maui Island, Hawaii	NOS	1615202	20.6567000000000007	-156.444999999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55621	01:09:00	\N	0.540000000000000036	01:21:00	\N	0.729999999999999982	\N	\N	Makena	HI
56669	Hana, Maui Island, Hawaii	NOS	1615395	20.7617000000000012	-155.986999999999995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55621	00:18:00	\N	0.540000000000000036	00:40:00	\N	1.05000000000000004	\N	\N	Hana	HI
56670	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.5949999999999989	-156.606999999999999	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	-00:09:00	0	\N	-00:09:00	0.200000000000000011	\N	\N	\N	Kuheia Bay	HI
56671	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1866999999999983	-155.902999999999992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55623	00:42:00	\N	0.67000000000000004	00:38:00	\N	0.800000000000000044	\N	\N	Mahukona	HI
56672	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55623	00:37:00	\N	0.67000000000000004	00:38:00	\N	0.800000000000000044	\N	\N	Kailua Kona	HI
56673	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.476700000000001	-155.921999999999997	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55623	00:47:00	\N	0.67000000000000004	00:48:00	\N	0.800000000000000044	\N	\N	Napoopoo, Kealakekua Bay	HI
56674	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883000000000003	-155.552999999999997	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55623	00:33:00	\N	1	00:38:00	\N	1.01000000000000001	\N	\N	Honuapo	HI
56675	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.7833000000000006	-166.207999999999998	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:08:00	\N	0.729999999999999982	00:03:00	\N	0.729999999999999982	\N	\N	East Island, French Frigate Shoals	HI
56676	Laysan Island, Hawaii	NOS	1619645	25.7667000000000002	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	01:12:00	\N	0.5	01:02:00	\N	0.530000000000000027	\N	\N	Laysan Island	HI
56677	Coffin Point, Coffin Neck, Maine (sub)	NOS	8410714	44.8699999999999974	-67.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	00:33:00	\N	0.770000000000000018	00:31:00	\N	0.939999999999999947	\N	\N	Coffins Point	ME
56678	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine (sub)	NOS	8410715	44.9232999999999976	-67.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	00:14:00	\N	1	00:11:00	\N	1.04000000000000004	\N	\N	Garnet Point, Pennamquan River	ME
56679	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	01:13:00	\N	0.75	00:59:00	\N	0.939999999999999947	\N	\N	Birch Islands	ME
56680	Cutler Naval Base, Machias Bay, Maine (sub)	NOS	8411250	44.6417000000000002	-67.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	-00:15:00	\N	0.699999999999999956	-00:06:00	\N	0.699999999999999956	\N	\N	Cutler, Naval Radio Station	ME
56681	Stone Island, Machias Bay, Maine	NOS	8411411	44.6032999999999973	-67.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	-00:28:00	\N	0.680000000000000049	-00:11:00	\N	0.680000000000000049	\N	\N	Stone Island, Machias Bay	ME
56682	Machiasport, Machias River, Maine	NOS	8411467	44.6983000000000033	-67.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	-00:09:00	\N	0.689999999999999947	00:01:00	\N	0.689999999999999947	\N	\N	Machiasport, Machias River	ME
56683	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615000000000002	-67.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	-00:13:00	\N	0.660000000000000031	-00:05:00	\N	0.660000000000000031	\N	\N	Shoppee Point, Englishman Bay	ME
56684	Steele Harbor Island, Maine	NOS	8411801	44.4932999999999979	-67.5433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:20:00	\N	1.27000000000000002	-00:28:00	\N	1.27000000000000002	\N	\N	Steele Harbor Island	ME
56708	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4266999999999967	-69.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:04:00	\N	1.03000000000000003	00:09:00	\N	0.969999999999999973	\N	\N	Belfast	ME
56685	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.371699999999997	-67.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:24:00	\N	1.15999999999999992	-00:28:00	\N	1.15999999999999992	\N	\N	Green Island, Petit Manan Bar	ME
56686	Milbridge, Narraguagus River, Maine (sub)	NOS	8412581	44.5399999999999991	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:05:00	\N	1.09000000000000008	-00:15:00	\N	1.22999999999999998	\N	\N	Millbridge, Narraguagus River, Maine	ME
56687	Prospect Harbor, Maine	NOS	8412932	44.3999999999999986	-68.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:15:00	\N	1.14999999999999991	-00:24:00	\N	1.14999999999999991	\N	\N	Prospect Harbor	ME
56688	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.388300000000001	-68.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:10:00	\N	0.949999999999999956	-00:01:00	\N	0.949999999999999956	\N	\N	Winter Harbor, Frenchman Bay	ME
56689	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.2749999999999986	-68.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	-00:27:00	\N	0.949999999999999956	00:00:00	\N	0.959999999999999964	\N	\N	Southwest Harbor	ME
56690	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417000000000016	-68.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	-00:27:00	\N	0.930000000000000049	00:04:00	\N	0.930000000000000049	\N	\N	Bass Harbor	ME
56691	Ellsworth, Union River, Blue Hill Bay, Maine (sub)	NOS	8413801	44.5349999999999966	-68.4217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:16:00	\N	0.969999999999999973	00:15:00	\N	1	\N	\N	Ellsworth, Union River	ME
56692	Mackerel Cove, Swans Island, Blue Hill Bay, Maine (sub)	NOS	8413825	44.1700000000000017	-68.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	-00:27:00	\N	0.930000000000000049	00:02:00	\N	0.939999999999999947	\N	\N	Mackerel Cove	ME
56693	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.1450000000000031	-68.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:06:00	\N	0.880000000000000004	-00:01:00	\N	0.890000000000000013	\N	\N	Burnt Coat Harbor, Swans Island	ME
56694	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.408299999999997	-68.5632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:11:00	\N	0.949999999999999956	00:09:00	\N	0.949999999999999956	\N	\N	Blue Hill Harbor	ME
56695	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.263300000000001	-68.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:12:00	\N	0.949999999999999956	00:09:00	\N	0.949999999999999956	\N	\N	Center Harbor	ME
56696	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733000000000033	-68.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	-00:27:00	\N	0.880000000000000004	-00:01:00	\N	0.869999999999999996	\N	\N	Isle Au Haut	ME
56697	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533000000000015	-68.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:06:00	\N	0.900000000000000022	00:08:00	\N	0.910000000000000031	\N	\N	Stonington, Deer Isle	ME
56698	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2916999999999987	-68.6932999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:14:00	\N	0.930000000000000049	00:16:00	\N	0.939999999999999947	\N	\N	Little Deer Isle	ME
56699	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367000000000033	-68.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:10:00	\N	0.979999999999999982	-00:06:00	\N	0.989999999999999991	\N	\N	Gross Point, Eastern Channel	ME
56700	Bangor, Penobscot River, Maine (sub)	NOS	8414612	44.7849999999999966	-68.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:18:00	\N	0.869999999999999996	-00:06:00	\N	1.25	\N	\N	Bangor	ME
56701	Castine, Penobscot Bay, Maine	NOS	8414672	44.3866999999999976	-68.7967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:11:00	\N	1	00:15:00	\N	0.949999999999999956	\N	\N	Castine	ME
56702	Bucksport, Penobscot River, Maine	NOS	8414684	44.5716999999999999	-68.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:11:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Bucksport	ME
56703	Sandy Point, Penobscot River, Maine	NOS	8414692	44.5050000000000026	-68.8050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:08:00	\N	0.979999999999999982	00:06:00	\N	0.989999999999999991	\N	\N	Sandy Point	ME
56704	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433000000000021	-68.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:10:00	\N	0.880000000000000004	00:09:00	\N	0.869999999999999996	\N	\N	Vinalhaven, Vinalhaven Island	ME
56705	Winterport, Penobscot River, Maine	NOS	8414781	44.6366999999999976	-68.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:04:00	\N	0.92000000000000004	-00:09:00	\N	1.1100000000000001	\N	\N	Winterport	ME
56706	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1266999999999996	-68.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:10:00	\N	0.900000000000000022	00:13:00	\N	0.910000000000000031	\N	\N	North Haven	ME
56707	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.861699999999999	-68.881699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	-00:27:00	\N	0.849999999999999978	00:05:00	\N	0.849999999999999978	\N	\N	Matinicus Harbor, Wheaton Island	ME
56709	Rockland, Penobscot River, Maine (sub)	NOS	8415490	44.1049999999999969	-69.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55641	00:06:00	\N	1.03000000000000003	00:09:00	\N	0.930000000000000049	\N	\N	Rockland	ME
56710	Thomaston, St. George River, Maine (sub)	NOS	8415709	44.0716999999999999	-69.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:03:00	\N	1.03000000000000003	-00:04:00	\N	1.03000000000000003	\N	\N	Thomaston	ME
56711	Tenants Harbor, Maine	NOS	8415809	43.9650000000000034	-69.216700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:11:00	\N	1.02000000000000002	-00:11:00	\N	1.02000000000000002	\N	\N	Tenants Harbor	ME
56712	Otis Cove, St. George River, Maine	NOS	8415867	43.986699999999999	-69.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
56713	Port Clyde, St. George River, Maine	NOS	8415933	43.9249999999999972	-69.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:07:00	\N	0.979999999999999982	-00:11:00	\N	0.979999999999999982	\N	\N	Port Clyde	ME
56714	Burnt Island, Georges Islands, Maine	NOS	8416028	43.871699999999997	-69.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:12:00	\N	0.979999999999999982	-00:13:00	\N	0.979999999999999982	\N	\N	Burnt Island, Georges Islands	ME
56715	Monhegan Island, Maine	NOS	8416092	43.7650000000000006	-69.321700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:09:00	\N	0.969999999999999973	-00:13:00	\N	0.969999999999999973	\N	\N	Monhegan Island	ME
56716	Friendship Harbor, Maine	NOS	8416141	43.9699999999999989	-69.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:11:00	\N	0.989999999999999991	-00:18:00	\N	0.989999999999999991	\N	\N	Friendship Harbor	ME
56717	Waldoboro, Medomak River, Maine	NOS	8416224	44.0932999999999993	-69.3766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:04:00	\N	1.04000000000000004	-00:16:00	\N	1.04000000000000004	\N	\N	Waldoboro	ME
56718	Jones Neck, Medomak River, Maine	NOS	8416232	44.0150000000000006	-69.3799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
56719	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.966700000000003	-69.4416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:03:00	\N	0.989999999999999991	-00:09:00	\N	0.989999999999999991	\N	\N	Muscongus Harbor, Muscongus Sound	ME
56720	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:08:00	\N	0.969999999999999973	-00:10:00	\N	0.969999999999999973	\N	\N	New Harbor, Muscongus Bay	ME
56721	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8766999999999996	-69.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:04:00	\N	0.969999999999999973	-00:05:00	\N	0.969999999999999973	\N	\N	Pemaquid Harbor, Johns Bay	ME
56722	Newcastle, Damariscotta River, Maine	NOS	8416608	44.033299999999997	-69.5366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:25:00	\N	1.02000000000000002	00:16:00	\N	1.02000000000000002	\N	\N	Newcastle	ME
56723	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865000000000002	-69.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	East Boothbay	ME
56724	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7582999999999984	-69.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:10:00	\N	0.969999999999999973	-00:09:00	\N	0.969999999999999973	\N	\N	Damariscove Harbor, Damariscove Island	ME
56725	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.0499999999999972	-69.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:20:00	\N	1.05000000000000004	00:20:00	\N	1.05000000000000004	\N	\N	Sheepscot (below rapids)	ME
56726	Boothbay Harbor, Maine	NOS	8416828	43.8500000000000014	-69.6282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:08:00	\N	0.969999999999999973	-00:06:00	\N	0.969999999999999973	\N	\N	Boothbay Harbor	ME
56727	Southport, Townsend Gut, Maine	NOS	8416908	43.8466999999999985	-69.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.979999999999999982	00:01:00	\N	0.979999999999999982	\N	\N	Southport, Townsend Gut	ME
56728	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:04:00	\N	1.03000000000000003	00:16:00	\N	1.03000000000000003	\N	\N	Wiscasset	ME
56729	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.9249999999999972	-69.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
56730	Back River, Sheepscot River, Maine	NOS	8416961	43.9583000000000013	-69.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
56731	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.8599999999999994	-69.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:04:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	Isle of Springs	ME
56755	Cow Island, Casco Bay, Maine	NOS	8418009	43.6899999999999977	-70.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
56732	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8532999999999973	-69.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:14:00	\N	0.969999999999999973	00:14:00	\N	0.969999999999999973	\N	\N	Robinhood, Sasanoa River	ME
56733	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8866999999999976	-69.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:43:00	\N	0.969999999999999973	00:35:00	\N	0.969999999999999973	\N	\N	Mill Point, Sasanoa River	ME
56734	Fort Popham, Hunniwell Point, Kennebec River, Maine (sub)	NOS	8417177	43.7550000000000026	-69.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:04:00	\N	0.92000000000000004	00:09:00	\N	0.92000000000000004	\N	\N	Fort Popham, Hunniwell Point	ME
56735	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183000000000007	-69.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:28:00	\N	0.880000000000000004	00:26:00	\N	0.880000000000000004	\N	\N	Phippsburg	ME
56736	Bath, Kennebec River, Maine (sub)	NOS	8417227	43.9249999999999972	-69.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:17:00	\N	0.699999999999999956	01:01:00	\N	0.699999999999999956	\N	\N	Bath	ME
56737	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9816999999999965	-69.8349999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	02:04:00	\N	0.57999999999999996	02:00:00	\N	0.57999999999999996	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
56738	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.8900000000000006	-69.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.989999999999999991	-00:05:00	\N	0.989999999999999991	\N	\N	Howard Point, New Meadows River	ME
56739	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.9500000000000028	-69.888300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	03:26:00	\N	0.520000000000000018	02:24:00	\N	0.520000000000000018	\N	\N	Androscoggin River entrance	ME
56740	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7882999999999996	-69.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:02:00	\N	0.979999999999999982	-00:01:00	\N	0.979999999999999982	\N	\N	Cundy Harbor, New Meadows River	ME
56741	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0082999999999984	-69.894999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	02:42:00	\N	0.630000000000000004	02:34:00	\N	0.630000000000000004	\N	\N	Bowdoinham, Cathance River	ME
56742	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217000000000013	-69.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	04:36:00	\N	0.419999999999999984	02:35:00	\N	0.419999999999999984	\N	\N	Brunswick, Androscoggin River	ME
56743	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.8250000000000028	-69.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
56744	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383000000000024	-70.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.979999999999999982	00:02:00	\N	0.979999999999999982	\N	\N	South Harpswell, Potts Harbor	ME
56745	South Freeport, Casco Bay, Maine	NOS	8417801	43.8200000000000003	-70.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:10:00	\N	0.989999999999999991	00:12:00	\N	0.989999999999999991	\N	\N	South Freeport	ME
56746	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.6950000000000003	-70.1099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
56747	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7516999999999996	-70.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:03:00	\N	0.880000000000000004	-00:02:00	\N	1	\N	\N	Doyle Point	ME
56748	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7216999999999985	-70.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:02:00	\N	1.03000000000000003	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
56749	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6766999999999967	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	1.03000000000000003	00:05:00	\N	0.979999999999999982	\N	\N	Vaill Island	ME
56750	Long Island, Casco Bay, Maine	NOS	8417941	43.6899999999999977	-70.1700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
56751	Prince Point, Casco Bay, Maine	NOS	8417948	43.7616999999999976	-70.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.989999999999999991	00:00:00	\N	1	\N	\N	Prince Point	ME
56752	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.6700000000000017	-70.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:00:00	\N	1.03000000000000003	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
56753	Cushing Island, Casco Bay, Maine	NOS	8417997	43.6450000000000031	-70.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	1.03000000000000003	00:01:00	\N	0.989999999999999991	\N	\N	Cushing Island	ME
56754	Peak Island, Casco Bay, Maine	NOS	8418001	43.6550000000000011	-70.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:08:00	\N	0.989999999999999991	-00:04:00	\N	0.989999999999999991	\N	\N	Peak Island	ME
56756	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7316999999999965	-70.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.969999999999999973	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
56757	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233000000000004	-70.2066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:01:00	\N	1	-00:02:00	\N	0.969999999999999973	\N	\N	Portland Head Light	ME
56758	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867000000000019	-70.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:04:00	\N	1.06000000000000005	00:01:00	\N	1.01000000000000001	\N	\N	Presumpscot River Bridge	ME
56759	Back Cove, Casco Bay, Maine	NOS	8418175	43.6766999999999967	-70.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:06:00	\N	0.969999999999999973	00:02:00	\N	0.969999999999999973	\N	\N	Back Cove	ME
56760	Fore River, Casco Bay, Maine	NOS	8418268	43.6417000000000002	-70.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:02:00	\N	1.03000000000000003	00:02:00	\N	1	\N	\N	Fore River	ME
56761	Old Orchard Beach, Maine	NOS	8418557	43.5167000000000002	-70.3666999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:06:00	\N	0.969999999999999973	00:00:00	\N	0.969999999999999973	\N	\N	Old Orchard Beach	ME
56762	Camp Ellis, Saco River Entrance, Maine (sub)	NOS	8418606	43.4617000000000004	-70.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:10:00	\N	1	00:03:00	\N	0.969999999999999973	\N	\N	Camp Ellis, Saco River Entrance	ME
56763	Cape Porpoise, Maine	NOS	8418772	43.3667000000000016	-70.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:14:00	\N	0.949999999999999956	00:12:00	\N	0.949999999999999956	\N	\N	Cape Porpoise	ME
56764	Biddeford, Saco River, Maine (sub)	NOS	8418828	43.4917000000000016	-70.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:26:00	\N	0.969999999999999973	00:12:00	\N	0.989999999999999991	\N	\N	Biddeford, Saco River	ME
56765	Kennebunkport, Kennebunk River, Maine (sub)	NOS	8418911	43.3582999999999998	-70.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:05:00	\N	1	00:07:00	\N	0.969999999999999973	\N	\N	Kennebunkport	ME
56766	Cape Neddick, Maine	NOS	8419399	43.1666999999999987	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:08:00	\N	1	00:02:00	\N	0.949999999999999956	\N	\N	Cape Neddick	ME
56767	York Harbor, Maine	NOS	8419518	43.1317000000000021	-70.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:13:00	\N	0.949999999999999956	00:03:00	\N	0.949999999999999956	\N	\N	York Harbor	ME
56768	Fort Point, York Harbor, Maine	NOS	8419528	43.1300000000000026	-70.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:10:00	\N	0.939999999999999947	-00:04:00	\N	0.949999999999999956	\N	\N	Fort Point, York Harbor	ME
56769	Seapoint, Cutts Island, Maine	NOS	8419590	43.0850000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:04:00	\N	0.959999999999999964	00:01:00	\N	0.959999999999999964	\N	\N	Seapoint, Cutts Island	ME
56770	Gerrish Island, Portsmouth Harbor, New Hampshire	NOS	8419688	43.0666999999999973	-70.696700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:03:00	\N	0.949999999999999956	-00:02:00	\N	0.949999999999999956	\N	\N	Gerrish Island	NH
56771	Kittery Point, Portsmouth Harbor, New Hampshire	NOS	8419807	43.0816999999999979	-70.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:01:00	\N	0.959999999999999964	-00:07:00	\N	0.959999999999999964	\N	\N	Kittery Point	NH
56772	Seavey Island, Portsmouth Harbor, New Hampshire (sub)	NOS	8419870	43.0799999999999983	-70.7416999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:18:00	\N	0.890000000000000013	00:20:00	\N	0.890000000000000013	\N	\N	Seavey Island	NH
56773	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1916999999999973	-70.8250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
56774	Dover, Cocheco River, Piscataqua River, New Hampshire (sub)	NOS	8420411	43.1983000000000033	-70.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:39:00	\N	0.760000000000000009	01:45:00	\N	0.770000000000000018	\N	\N	Dover, Cocheco River	NH
56775	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.121699999999997	-70.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:27:00	\N	0.699999999999999956	01:33:00	\N	0.699999999999999956	\N	\N	Dover Point	NH
56776	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533000000000001	-70.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
56777	Atlantic Heights, Piscataqua River, New Hampshire	NOS	8423635	43.0900000000000034	-70.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:28:00	\N	0.819999999999999951	00:37:00	\N	0.819999999999999951	\N	\N	Atlantic Heights	NH
56778	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0782999999999987	-70.7516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:17:00	\N	0.859999999999999987	00:22:00	\N	0.859999999999999987	\N	\N	Portsmouth	NH
56779	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0566999999999993	-70.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:05:00	\N	0.949999999999999956	-00:03:00	\N	0.949999999999999956	\N	\N	Jaffrey Point	NH
56780	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9782999999999973	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	-00:02:00	\N	0.930000000000000049	00:02:00	\N	0.930000000000000049	\N	\N	Gosport Harbor, Isles of Shoals	NH
56781	Hampton Harbor, New Hampshire	NOS	8429489	42.8950000000000031	-70.8166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:32:00	\N	0.910000000000000031	00:14:00	\N	0.910000000000000031	\N	\N	Hampton Harbor	NH
56782	Salisbury Point, Merrimack River, Massachusetts (sub)	NOS	8440273	42.8382999999999967	-70.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:18:00	\N	0.560000000000000053	00:55:00	\N	0.82999999999999996	\N	\N	Salisbury Point	MA
56783	Merrimacport, Merrimack River, Massachusetts (sub)	NOS	8440369	42.8250000000000028	-70.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	02:08:00	\N	0.5	01:26:00	\N	0.760000000000000009	\N	\N	Merrimacport	MA
56784	Plum Island, Merrimack River Entrance, Merrimack River, Massachusetts (sub)	NOS	8440452	42.8166999999999973	-70.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:29:00	\N	0.880000000000000004	00:06:00	\N	0.880000000000000004	\N	\N	Plum Island, Merrimack River Entrance	MA
56785	Newburyport, Merrimack River, Massachusetts (sub)	NOS	8440466	42.8149999999999977	-70.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	01:11:00	\N	0.859999999999999987	00:31:00	\N	0.859999999999999987	\N	\N	Newburyport	MA
56786	Riverside, Merrimack River, Massachusetts (sub)	NOS	8440889	42.763300000000001	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	03:30:00	\N	0.349999999999999978	01:56:00	\N	0.619999999999999996	\N	\N	Riverside	MA
56787	Rockport Harbor, Massachusetts (sub)	NOS	8441551	42.658299999999997	-70.6149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:06:00	\N	0.969999999999999973	00:06:00	\N	0.949999999999999956	\N	\N	Rockport	MA
56788	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.6550000000000011	-70.6766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:03:00	\N	0.969999999999999973	00:11:00	\N	0.969999999999999973	\N	\N	Annisquam, Lobster Cove	MA
56789	Essex, Essex River, Massachusetts (sub)	NOS	8441771	42.6317000000000021	-70.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:31:00	\N	0.939999999999999947	00:22:00	\N	1	\N	\N	Essex	MA
56790	Gloucester Harbor, Massachusetts	NOS	8441841	42.6099999999999994	-70.6599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:04:00	\N	0.969999999999999973	00:00:00	\N	0.930000000000000049	\N	\N	Gloucester Harbor	MA
56791	Salem, Salem Harbor, Massachusetts (sub)	NOS	8442645	42.523299999999999	-70.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:05:00	\N	0.969999999999999973	-00:02:00	\N	0.939999999999999947	\N	\N	Salem, Salem Harbor	MA
56792	Lynn, Lynn Harbor, Massachusetts (sub)	NOS	8443187	42.4583000000000013	-70.9432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:03:00	\N	1	00:01:00	\N	0.969999999999999973	\N	\N	Lynn, Lynn Harbor	MA
56793	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts (sub)	NOS	8443662	42.3950000000000031	-71.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:02:00	\N	0.969999999999999973	00:01:00	\N	1.01000000000000001	\N	\N	Amelia Earhart Dam, Mystic River	MA
56794	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts (sub)	NOS	8443725	42.3866999999999976	-71.0233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:06:00	\N	1.01000000000000001	00:01:00	\N	1.01000000000000001	\N	\N	Chelsea St. Bridge, Chelsea River	MA
56795	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.371699999999997	-71.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
56796	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483000000000018	-70.9599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:00:00	\N	0.969999999999999973	00:01:00	\N	0.969999999999999973	\N	\N	Deer Island (south end)	MA
56797	Boston Light, Boston Harbor, Massachusetts (sub)	NOS	8444162	42.3282999999999987	-70.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:02:00	\N	0.969999999999999973	-00:01:00	\N	0.949999999999999956	\N	\N	Boston Light	MA
56798	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083000000000027	-70.9916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:04:00	\N	0.989999999999999991	00:01:00	\N	0.989999999999999991	\N	\N	Moon Head	MA
56799	Hull, Massachusetts	NOS	8444351	42.3033000000000001	-70.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:07:00	\N	0.969999999999999973	00:05:00	\N	0.969999999999999973	\N	\N	Hull	MA
56800	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.2849999999999966	-71.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
56801	Nut Island, Quincy Bay, Massachusetts (sub)	NOS	8444525	42.2800000000000011	-70.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:01:00	\N	1	00:01:00	\N	0.989999999999999991	\N	\N	Nut Island, Quincy Bay	MA
56802	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.2700000000000031	-70.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:07:00	\N	0.989999999999999991	00:06:00	\N	0.989999999999999991	\N	\N	Nantasket Beach, Weir River	MA
56803	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2616999999999976	-70.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:05:00	\N	0.989999999999999991	00:02:00	\N	0.989999999999999991	\N	\N	Crow Point, Hingham Harbor entrance	MA
56804	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483000000000004	-70.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:02:00	\N	0.92000000000000004	00:04:00	\N	0.92000000000000004	\N	\N	Cohasset Harbor (White Head)	MA
56805	Hingham, Massachusetts	NOS	8444775	42.246699999999997	-70.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
56806	Shipyard Point, Weymouth Fore River, Massachusetts (sub)	NOS	8444788	42.2483000000000004	-70.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:06:00	\N	1	00:09:00	\N	1	\N	\N	Weymouth Fore River Bridge	MA
56807	Scituate, Scituate Harbor, Massachusetts (sub)	NOS	8445138	42.2017000000000024	-70.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:01:00	\N	1.03000000000000003	00:03:00	\N	0.949999999999999956	\N	\N	Scituate, Scituate Harbor	MA
56808	Damons Point, North River, Massachusetts	NOS	8445425	42.1599999999999966	-70.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:36:00	\N	0.890000000000000013	00:20:00	\N	0.890000000000000013	\N	\N	Damons Point, North River	MA
56809	Brant Rock, Green Harbor River, Massachusetts (sub)	NOS	8446009	42.0833000000000013	-70.6466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:03:00	\N	1.03000000000000003	00:05:00	\N	0.959999999999999964	\N	\N	Brant Rock, Green Harbor River	MA
56832	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.6649999999999991	-70.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:25:00	\N	0.390000000000000013	00:52:00	\N	0.390000000000000013	\N	\N	Wychmere Harbor	MA
56810	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts (sub)	NOS	8446166	42.0382999999999996	-70.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:33:00	\N	1.03000000000000003	00:06:00	\N	1.04000000000000004	\N	\N	Duxbury, Duxbury Harbor	MA
56811	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts (sub)	NOS	8446493	41.9600000000000009	-70.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:18:00	\N	1	00:04:00	\N	1.03000000000000003	\N	\N	Plymouth	MA
56812	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.9299999999999997	-70.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:30:00	\N	1.05000000000000004	00:14:00	\N	1.05000000000000004	\N	\N	Wellfleet	MA
56813	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts (sub)	NOS	8447173	41.7749999999999986	-70.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:06:00	\N	0.880000000000000004	-00:15:00	\N	0.82999999999999996	\N	\N	Cape Cod Canal, Sagamore	MA
56814	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts (sub)	NOS	8447180	41.7717000000000027	-70.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:03:00	\N	0.680000000000000049	-00:01:00	\N	0.910000000000000031	\N	\N	Sandwich Marina, Cape Cod Canal, east entrance	MA
56815	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts (sub)	NOS	8447191	41.7700000000000031	-70.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:21:00	\N	0.790000000000000036	-00:29:00	\N	0.660000000000000031	\N	\N	Cape Cod Canal, Bournedale	MA
56816	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts (sub)	NOS	8447241	41.7516999999999996	-70.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:01:00	\N	0.819999999999999951	00:02:00	\N	1.02000000000000002	\N	\N	Sesuit Harbor, East Dennis	MA
56817	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts (sub)	NOS	8447259	41.7449999999999974	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:24:00	\N	0.790000000000000036	-01:13:00	\N	0.46000000000000002	\N	\N	Cape Cod Canal, Bourne Bridge	MA
56818	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts (sub)	NOS	8447270	41.7417000000000016	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	02:50:00	\N	1.01000000000000001	01:17:00	\N	1.01000000000000001	\N	\N	Cape Cod Canal, RR. bridge	MA
56819	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417000000000016	-70.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:25:00	\N	1.03000000000000003	00:41:00	\N	1.03000000000000003	\N	\N	Onset Beach, Onset Bay	MA
56820	Steep Brook, Taunton River, Narragansett Bay, Rhode Island	NOS	8447281	41.740000000000002	-71.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:05:00	\N	1.29000000000000004	00:26:00	\N	1.30000000000000004	\N	\N	Steep Brook, Taunton River	RI
56821	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.736699999999999	-69.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	03:27:00	\N	0.340000000000000024	02:28:00	\N	0.340000000000000024	\N	\N	Pleasant Bay	MA
56822	Gray Gables, Buzzards Bay, Massachusetts (sub)	NOS	8447295	41.7349999999999994	-70.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:16:00	\N	1.20999999999999996	00:37:00	\N	1.05000000000000004	\N	\N	Gray Gables	MA
56823	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7216999999999985	-70.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
56824	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.7150000000000034	-70.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:30:00	\N	1.14999999999999991	00:16:00	\N	1.14999999999999991	\N	\N	Monument Beach	MA
56825	Great Hill, Buzzards Bay, Massachusetts (sub)	NOS	8447368	41.7117000000000004	-70.7150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:12:00	\N	1.20999999999999996	00:12:00	\N	1.1399999999999999	\N	\N	Great Hill	MA
56826	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.7049999999999983	-70.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:12:00	\N	1.29000000000000004	00:10:00	\N	1.12999999999999989	\N	\N	Marion, Sippican Harbor	MA
56827	Piney Point, Buzzards Bay, Massachusetts (sub)	NOS	8447416	41.6950000000000003	-70.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:10:00	\N	1.20999999999999996	00:10:00	\N	1.12999999999999989	\N	\N	Piney Point	MA
56828	Texas Tower, Georges Shoal	NOS	8447436	41.6882999999999981	-67.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:43:00	\N	0.440000000000000002	-00:47:00	\N	0.440000000000000002	\N	\N	Georges Shoal, Texas Tower	\N
56829	Saquatucket Harbor, Nantucket Sound, Massachusetts (sub)	NOS	8447495	41.6683000000000021	-70.0567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:16:00	\N	0.409999999999999976	00:46:00	\N	0.409999999999999976	\N	\N	Saquatucket Harbor	MA
56830	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.6649999999999991	-70.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	01:46:00	\N	0.28999999999999998	01:48:00	\N	0.28999999999999998	\N	\N	South Yarmouth, Bass River	MA
56831	Chatham, Stage Harbor, Cape Cod, Massachusetts (sub)	NOS	8447505	41.6666999999999987	-69.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:19:00	\N	0.429999999999999993	00:46:00	\N	0.429999999999999993	\N	\N	Chatham, Stage Harbor	MA
56833	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.658299999999997	-70.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:38:00	\N	0.359999999999999987	01:03:00	\N	0.359999999999999987	\N	\N	Dennisport	MA
56834	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567000000000007	-70.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:20:00	\N	1	00:11:00	\N	1.09000000000000008	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
56835	New Bedford, Buzzards Bay, Massachusetts	NOS	8447584	41.6400000000000006	-70.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:07:00	\N	1.05000000000000004	00:07:00	\N	1.05000000000000004	\N	\N	New Bedford	MA
56836	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6082999999999998	-70.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:47:00	\N	0.260000000000000009	01:17:00	\N	0.260000000000000009	\N	\N	Cotuit Highlands	MA
56837	Clarks Point, New Bedford, Buzzards Bay, Massachusetts (sub)	NOS	8447712	41.5932999999999993	-70.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:23:00	\N	1.07000000000000006	00:14:00	\N	1.03000000000000003	\N	\N	Clarks Point	MA
56838	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867000000000004	-70.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	01:52:00	\N	0.239999999999999991	02:03:00	\N	0.239999999999999991	\N	\N	Poponesset Island, Poponesset Bay	MA
56839	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.5700000000000003	-71.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	02:30:00	\N	0.770000000000000018	01:40:00	\N	0.770000000000000018	\N	\N	Hix Bridge, East Branch	MA
56840	Round Hill Point, Buzzards Bay, Massachusetts (sub)	NOS	8447842	41.5382999999999996	-70.928299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:22:00	\N	1	00:14:00	\N	0.989999999999999991	\N	\N	Round Hill Point	MA
56841	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.5450000000000017	-70.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	-00:09:00	\N	0.140000000000000013	-00:16:00	\N	0.140000000000000013	\N	\N	Falmouth Heights	MA
56842	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.5200000000000031	-70.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	02:21:00	\N	0.400000000000000022	00:32:00	\N	0.400000000000000022	\N	\N	Little Harbor	MA
56843	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.5200000000000031	-70.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:22:00	\N	1.02000000000000002	00:12:00	\N	1.02000000000000002	\N	\N	Uncatena Island (south side)	MA
56844	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5082999999999984	-71.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:33:00	\N	0.849999999999999978	00:09:00	\N	0.849999999999999978	\N	\N	Westport Harbor	MA
56845	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583000000000013	-70.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	03:47:00	\N	0.709999999999999964	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
56983	New Rochelle, New York	NOS	8518490	40.8933000000000035	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	-00:18:00	\N	0.930000000000000049	-00:16:00	\N	1.01000000000000001	\N	\N	New Rochelle	NY
56846	Penikese Island, Buzzards Bay, Massachusetts (sub)	NOS	8448248	41.4500000000000028	-70.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:16:00	\N	0.969999999999999973	-00:17:00	\N	0.969999999999999973	\N	\N	Penikese Island	MA
56847	Quicks Hole, North side, Massachusetts	NOS	8448251	41.4483000000000033	-70.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:08:00	\N	0.989999999999999991	-00:08:00	\N	0.989999999999999991	\N	\N	Quicks Hole, North side	MA
56848	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.4350000000000023	-70.696700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:32:00	\N	0.619999999999999996	00:10:00	\N	0.619999999999999996	\N	\N	Cedar Tree Neck	MA
56849	Cuttyhunk, Massachusetts	NOS	8448376	41.4249999999999972	-70.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:15:00	\N	0.930000000000000049	01:20:00	\N	0.969999999999999973	\N	\N	Cuttyhunk	MA
56850	Edgartown, Martha's Vineyard, Massachusetts (sub)	NOS	8448558	41.388300000000001	-70.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:18:00	\N	0.200000000000000011	00:57:00	\N	0.200000000000000011	\N	\N	Edgartown	MA
56851	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3866999999999976	-70.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:28:00	\N	0.320000000000000007	00:43:00	\N	0.320000000000000007	\N	\N	Great Point	MA
56852	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633000000000024	-70.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	03:20:00	\N	0.309999999999999998	02:02:00	\N	0.309999999999999998	\N	\N	Wasque Point, Chappaquiddick Island	MA
56853	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3532999999999973	-70.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:45:00	\N	0.819999999999999951	-00:06:00	\N	0.819999999999999951	\N	\N	Gay Head	MA
56854	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367000000000004	-70.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:15:00	\N	0.209999999999999992	00:25:00	\N	0.209999999999999992	\N	\N	Muskeget Island, north side	MA
56855	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117000000000019	-70.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:02:00	\N	0.819999999999999951	-00:45:00	\N	0.819999999999999951	\N	\N	Squibnocket Point	MA
56856	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2916999999999987	-70.2082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:07:00	\N	0.239999999999999991	00:39:00	\N	0.239999999999999991	\N	\N	Eel Point	MA
56857	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2616999999999976	-70.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:18:00	\N	0.849999999999999978	-00:19:00	\N	0.849999999999999978	\N	\N	Nomans Land	MA
56858	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6516999999999982	-71.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:01:00	\N	1.07000000000000006	00:20:00	\N	1.19999999999999996	\N	\N	North End, Bay Oil pier	RI
56859	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.638300000000001	-71.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:01:00	\N	1.09000000000000008	00:00:00	\N	1.09000000000000008	\N	\N	Anthony Point	RI
56860	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6182999999999979	-71.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:13:00	\N	1.01000000000000001	-00:12:00	\N	1.01000000000000001	\N	\N	Nannaquaket Neck	RI
56861	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583000000000027	-71.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:03:00	\N	1	-00:13:00	\N	0.979999999999999982	\N	\N	The Glen	RI
56862	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.486699999999999	-71.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:15:00	\N	0.930000000000000049	-00:05:00	\N	0.900000000000000022	\N	\N	Sachuest, Flint Point	RI
56863	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683000000000021	-71.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:00:00	\N	1.1399999999999999	00:13:00	\N	1.15999999999999992	\N	\N	Bristol, Bristol Harbor	RI
56864	Prudence Island, (south end), Narragansett Bay, Rhode Island	NOS	8452555	41.5799999999999983	-71.321700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:03:00	\N	1.1399999999999999	00:08:00	\N	1.08000000000000007	\N	\N	Prudence Island, (south end)	RI
56865	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.7516999999999996	-71.3516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:01:00	\N	1.20999999999999996	00:12:00	\N	1.21999999999999997	\N	\N	Bay Spring, Bullock Cove	RI
56866	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4632999999999967	-71.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:13:00	\N	1	-00:05:00	\N	0.939999999999999947	\N	\N	Castle Hill	RI
56867	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.8400000000000034	-71.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:06:00	\N	1.29000000000000004	00:12:00	\N	1.34000000000000008	\N	\N	Rumford, Seekonk River	RI
56868	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733000000000033	-71.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:06:00	\N	1.07000000000000006	00:07:00	\N	1.07000000000000006	\N	\N	Conanicut Point	RI
56869	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8682999999999979	-71.3799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:09:00	\N	1.29000000000000004	00:18:00	\N	1.31000000000000005	\N	\N	Pawtucket, Seekonk River	RI
56870	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island (sub)	NOS	8453742	41.496699999999997	-71.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:04:00	\N	1	00:05:00	\N	1	\N	\N	West Jamestown, Dutch Island Harbor	RI
56871	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.7616999999999976	-71.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:11:00	\N	1.29000000000000004	00:06:00	\N	1.25	\N	\N	Pawtuxet, Pawtuxet Cove	RI
56872	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517000000000024	-71.4017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:04:00	\N	0.979999999999999982	-00:05:00	\N	0.979999999999999982	\N	\N	Beavertail Point	RI
56873	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.4600000000000009	-71.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:16:00	\N	0.930000000000000049	-00:03:00	\N	0.959999999999999964	\N	\N	Watson Pier, Boston Neck	RI
56874	Wickford, Narragansett Bay, Rhode Island (sub)	NOS	8454538	41.5716999999999999	-71.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	-00:06:00	\N	1.07000000000000006	00:03:00	\N	1.07000000000000006	\N	\N	Wickford	RI
56875	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217000000000013	-71.4549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:11:00	\N	0.930000000000000049	-00:11:00	\N	0.910000000000000031	\N	\N	Narragansett Pier	RI
56876	Point Judith, Harbor of Refuge, Rhode Island (sub)	NOS	8455083	41.3633000000000024	-71.4899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:33:00	\N	0.930000000000000049	00:00:00	\N	0.869999999999999996	\N	\N	Point Judith, Harbor of Refuge	RI
56877	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817000000000021	-71.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:03:00	\N	1	-00:21:00	\N	1.02000000000000002	\N	\N	Westerly, Pawcatuck River	RI
56878	Weekapaug Point, Block Island Sound, Rhode Island (sub)	NOS	8458022	41.3282999999999987	-71.7617000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:06:00	\N	0.930000000000000049	00:41:00	\N	0.739999999999999991	\N	\N	Weekapaug Point, Block Island Sound	RI
56879	Watch Hill Point, Rhode Island	NOS	8458694	41.3049999999999997	-71.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	01:16:00	\N	0.709999999999999964	00:41:00	\N	0.739999999999999991	\N	\N	Watch Hill Point	RI
56880	Block Island (Old Harbor), Rhode Island (sub)	NOS	8459338	41.1732999999999976	-71.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:15:00	\N	0.859999999999999987	-00:13:00	\N	0.819999999999999951	\N	\N	Block Island (Old Harbor)	RI
56881	Block Island (SW end), Block Island Sound, Rhode Island (sub)	NOS	8459681	41.1632999999999996	-71.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:42:00	\N	0.790000000000000036	00:05:00	\N	0.75	\N	\N	Southwest Point, Block Island	RI
56882	Norwich, Thames River, Connecticut	NOS	8461392	41.523299999999999	-72.0782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:19:00	\N	1.20999999999999996	00:24:00	\N	1.17999999999999994	\N	\N	Norwich	CT
56883	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.4299999999999997	-72.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:10:00	\N	1.1100000000000001	00:14:00	\N	1.07000000000000006	\N	\N	Yale boathouse	CT
56884	Niantic, Niantic River, Connecticut	NOS	8461925	41.3250000000000028	-72.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:57:00	\N	0.839999999999999969	00:52:00	\N	0.989999999999999991	\N	\N	Niantic, Niantic River	CT
56885	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.263300000000001	-72.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:45:00	\N	1.35000000000000009	01:11:00	\N	1.3600000000000001	\N	\N	Saybrook Jetty	CT
56886	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.283299999999997	-72.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:53:00	\N	1.25	01:11:00	\N	1.23999999999999999	\N	\N	Saybrook Point	CT
56887	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3216999999999999	-72.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	01:09:00	\N	0.949999999999999956	01:36:00	\N	1.26000000000000001	\N	\N	Lyme, highway bridge	CT
56888	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483000000000018	-72.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	01:38:00	\N	1.14999999999999991	01:39:00	\N	1.15999999999999992	\N	\N	Essex	CT
56889	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.4200000000000017	-72.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	02:23:00	\N	1.05000000000000004	02:19:00	\N	1.05000000000000004	\N	\N	Hadlyme	CT
56890	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517000000000024	-72.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	02:51:00	\N	1.02000000000000002	02:38:00	\N	1.02000000000000002	\N	\N	Tylerville	CT
56891	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.273299999999999	-72.4749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:32:00	\N	0.599999999999999978	-00:24:00	\N	0.609999999999999987	\N	\N	Westbrook, Duck Island Roads	CT
56892	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4816999999999965	-72.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	03:08:00	\N	0.949999999999999956	02:48:00	\N	0.969999999999999973	\N	\N	Haddam	CT
56893	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5416999999999987	-72.5516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	04:01:00	\N	0.910000000000000031	03:25:00	\N	0.910000000000000031	\N	\N	Maromas	CT
56894	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.503300000000003	-72.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	03:40:00	\N	0.910000000000000031	03:08:00	\N	0.910000000000000031	\N	\N	Higganum Creek	CT
56895	Madison, Connecticut	NOS	8464041	41.2700000000000031	-72.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:30:00	\N	0.719999999999999973	-00:21:00	\N	0.729999999999999982	\N	\N	Madison	CT
56896	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6632999999999996	-72.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	05:36:00	\N	0.630000000000000004	04:30:00	\N	0.719999999999999973	\N	\N	Rocky Hill	CT
56897	Middletown, Connecticut River, Connecticut	NOS	8464336	41.5600000000000023	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	04:39:00	\N	0.82999999999999996	03:54:00	\N	0.82999999999999996	\N	\N	Middletown	CT
56898	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.7550000000000026	-72.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	06:54:00	\N	0.57999999999999996	05:24:00	\N	0.739999999999999991	\N	\N	South Hartford	CT
56899	Guilford Harbor, Connecticut	NOS	8464445	41.2717000000000027	-72.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:21:00	\N	0.959999999999999964	-00:11:00	\N	0.770000000000000018	\N	\N	Guilford Harbor	CT
56900	Hartford, Connecticut River, Connecticut	NOS	8464464	41.7700000000000031	-72.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	06:52:00	\N	0.75	05:30:00	\N	0.739999999999999991	\N	\N	Hartford	CT
56901	Sachem Head, Connecticut	NOS	8464687	41.2449999999999974	-72.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:15:00	\N	0.800000000000000044	-00:11:00	\N	0.800000000000000044	\N	\N	Sachem Head	CT
56902	Branford, Branford River, Connecticut	NOS	8465233	41.2616999999999976	-72.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:13:00	\N	0.959999999999999964	-00:05:00	\N	0.869999999999999996	\N	\N	Branford, Branford River	CT
56903	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2516999999999996	-72.9050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:07:00	\N	0.959999999999999964	-00:04:00	\N	0.910000000000000031	\N	\N	Lighthouse Point, New Haven Harbor	CT
56904	New Haven Harbor, New Haven Reach, Connecticut (sub)	NOS	8465705	41.283299999999997	-72.908299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:06:00	\N	1	-00:01:00	\N	0.92000000000000004	\N	\N	New Haven Harbor, New Haven Reach	CT
56905	Gulf Beach, Connecticut	NOS	8466375	41.2049999999999983	-73.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:08:00	\N	1.04000000000000004	-00:05:00	\N	0.939999999999999947	\N	\N	Gulf Beach	CT
56906	Milford Harbor, Connecticut	NOS	8466442	41.2182999999999993	-73.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:03:00	\N	1.04000000000000004	-00:02:00	\N	0.939999999999999947	\N	\N	Milford Harbor	CT
56907	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3016999999999967	-73.071700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	01:19:00	\N	0.959999999999999964	00:46:00	\N	1.04000000000000004	\N	\N	Shelton	CT
56908	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.2749999999999986	-73.0883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	01:13:00	\N	1.04000000000000004	00:43:00	\N	1.02000000000000002	\N	\N	Long Hill	CT
56909	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867000000000019	-73.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:09:00	\N	1	00:10:00	\N	0.959999999999999964	\N	\N	Sniffens Point	CT
56910	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2032999999999987	-73.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:23:00	\N	1	00:23:00	\N	0.979999999999999982	\N	\N	Stratford, I-95 bridge	CT
56911	South Norwalk, Norwalk River, Connecticut (sub)	NOS	8468448	41.0966999999999985	-73.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:15:00	\N	1.04000000000000004	00:09:00	\N	1.05000000000000004	\N	\N	South Norwalk	CT
56912	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.0649999999999977	-73.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:05:00	\N	1.08000000000000007	00:00:00	\N	1.05000000000000004	\N	\N	Rowayton, Fivemile River	CT
56913	Long Neck Point, Long Island Sound, Connecticut (sub)	NOS	8468799	41.0382999999999996	-73.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:01:00	\N	0.959999999999999964	-00:09:00	\N	1.06000000000000005	\N	\N	Long Neck Point	CT
56914	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167000000000002	-73.5966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:11:00	\N	1.08000000000000007	00:05:00	\N	1.07000000000000006	\N	\N	Cos Cob Harbor	CT
56915	Lake Montauk, Long Island, New York (sub)	NOS	8510448	41.0733000000000033	-71.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	-00:22:00	\N	0.890000000000000013	-00:26:00	\N	0.770000000000000018	\N	\N	Lake Montauk	NY
56916	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.0750000000000028	-71.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	-00:16:00	\N	0.75	-00:24:00	\N	0.739999999999999991	\N	\N	Montauk Harbor entrance	NY
56917	Silver Eel Pond, Fishers Island, New York (sub)	NOS	8510719	41.2567000000000021	-72.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	-00:04:00	\N	1	-00:04:00	\N	0.910000000000000031	\N	\N	Silver Eel Pond, Fishers Island, N.Y.	NY
56918	Little Gull Island, Long Island, New York	NOS	8510884	41.2066999999999979	-72.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	-00:22:00	\N	0.849999999999999978	00:13:00	\N	0.849999999999999978	\N	\N	Little Gull Island	NY
56919	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.0349999999999966	-72.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:19:00	\N	1	00:39:00	\N	0.959999999999999964	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
56920	Plum Gut Harbor, Plum Island, Long Island, New York (sub)	NOS	8511236	41.1717000000000013	-72.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:16:00	\N	1.01000000000000001	00:28:00	\N	1.01000000000000001	\N	\N	Plum Gut Harbor, Plum Island	NY
56921	Orient Harbor, Orient, Shelter Island Sound, New York (sub)	NOS	8511671	41.1366999999999976	-72.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	00:36:00	\N	0.969999999999999973	00:37:00	\N	0.969999999999999973	\N	\N	Orient	NY
56922	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.9949999999999974	-72.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	01:44:00	\N	0.890000000000000013	02:06:00	\N	0.890000000000000013	\N	\N	Noyack Bay	NY
56923	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.0949999999999989	-72.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:13:00	\N	0.640000000000000013	00:03:00	\N	0.640000000000000013	\N	\N	Hashamomuck Beach	NY
56924	Southold, Shelter Island Sound, New York	NOS	8512114	41.0600000000000023	-72.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	01:33:00	\N	0.890000000000000013	01:44:00	\N	0.890000000000000013	\N	\N	Southold	NY
56925	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917000000000016	-72.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	02:11:00	\N	1	02:27:00	\N	1.01000000000000001	\N	\N	New Suffolk	NY
56926	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.8200000000000003	-72.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:51:00	\N	0.369999999999999996	01:12:00	\N	0.510000000000000009	\N	\N	Shinnecock Bay entrance	NY
56927	South Jamesport, Great Peconic Bay, New York (sub)	NOS	8512735	40.9350000000000023	-72.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55731	02:43:00	\N	0.949999999999999956	02:34:00	\N	1.07000000000000006	\N	\N	South Jamesport	NY
56928	Northville, Long Island, New York (sub)	NOS	8512987	40.9816999999999965	-72.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	-00:03:00	\N	0.92000000000000004	00:05:00	\N	0.800000000000000044	\N	\N	Northville	NY
56929	Moriches Inlet, New York	NOS	8513387	40.7650000000000006	-72.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-01:09:00	\N	0.599999999999999978	-00:57:00	\N	0.619999999999999996	\N	\N	Moriches Inlet	NY
56930	Smith Point Bridge, Narrow Bay, Long Island, New York (sub)	NOS	8513825	40.7383000000000024	-72.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:34:00	\N	0.599999999999999978	01:58:00	\N	0.270000000000000018	\N	\N	Smith Point Bridge, Narrow Bay	NY
56931	Patchogue, Patchogue River, Great South Bay, New York (sub)	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:33:00	\N	0.530000000000000027	03:14:00	\N	0.25	\N	\N	Patchogue	NY
56932	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9632999999999967	-73.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:18:00	\N	0.880000000000000004	00:04:00	\N	0.890000000000000013	\N	\N	Mount Sinai Harbor	NY
56933	Cedar Beach, Long Island, New York (sub)	NOS	8514422	40.9650000000000034	-73.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:05:00	\N	1	00:07:00	\N	0.959999999999999964	\N	\N	Cedar Beach	NY
56934	Port Jefferson, Long Island, New York	NOS	8514560	40.9500000000000028	-73.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:05:00	\N	0.92000000000000004	00:04:00	\N	0.979999999999999982	\N	\N	Port Jefferson	NY
56935	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9716999999999985	-73.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:01:00	\N	0.979999999999999982	00:02:00	\N	0.979999999999999982	\N	\N	Port Jefferson Harbor entrance	NY
56936	Point o' Woods, New York	NOS	8514733	40.6516999999999982	-73.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:35:00	\N	0.149999999999999994	02:27:00	\N	0.149999999999999994	\N	\N	Point o' Woods	NY
56937	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233000000000018	-73.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:32:00	\N	0.149999999999999994	03:19:00	\N	0.149999999999999994	\N	\N	Great River, Connetquot River	NY
56938	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567000000000007	-73.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:18:00	\N	0.130000000000000004	02:10:00	\N	0.130000000000000004	\N	\N	West Fire Island	NY
56939	Fire Island Light, Great South Bay, New York	NOS	8515014	40.634999999999998	-73.2199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:22:00	\N	0.149999999999999994	00:46:00	\N	0.149999999999999994	\N	\N	Fire Island Light	NY
56940	Bay Shore, Watchogue Creek Entrance, Great South Bay, New York	NOS	8515102	40.716700000000003	-73.2399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:27:00	\N	0.369999999999999996	02:15:00	\N	0.220000000000000001	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
56941	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6332999999999984	-73.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:27:00	\N	0.550000000000000044	-00:39:00	\N	0.560000000000000053	\N	\N	Democrat Point, Fire Island Inlet	NY
56942	Oak Beach, Great South Bay, New York	NOS	8515336	40.6400000000000006	-73.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:58:00	\N	0.149999999999999994	02:23:00	\N	0.149999999999999994	\N	\N	Oak Beach	NY
56943	Babylon, Great South Bay, New York	NOS	8515421	40.6850000000000023	-73.3149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:41:00	\N	0.149999999999999994	02:11:00	\N	0.130000000000000004	\N	\N	Babylon	NY
56944	Northport, Northport Bay, Long Island, New York (sub)	NOS	8515586	40.8999999999999986	-73.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:04:00	\N	0.92000000000000004	-00:05:00	\N	1.07000000000000006	\N	\N	Northport, Northport Bay	NY
56945	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.6199999999999974	-73.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:58:00	\N	0.25	02:22:00	\N	0.239999999999999991	\N	\N	Gilgo Heading	NY
56946	Eatons Neck Point, Long Island, New York (sub)	NOS	8515786	40.9532999999999987	-73.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:08:00	\N	1.04000000000000004	00:02:00	\N	1.05000000000000004	\N	\N	Eatons Neck Point	NY
56947	Amityville, Great South Bay, New York	NOS	8515864	40.6550000000000011	-73.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:05:00	\N	0.25	02:20:00	\N	0.260000000000000009	\N	\N	Amityville	NY
56948	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York (sub)	NOS	8515921	40.9099999999999966	-73.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:07:00	\N	0.880000000000000004	-00:01:00	\N	1.04000000000000004	\N	\N	Lloyd Harbor, Huntington Bay	NY
56949	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6666999999999987	-73.4682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:32:00	\N	0.299999999999999989	02:04:00	\N	0.299999999999999989	\N	\N	Biltmore Shores, South Oyster Bay	NY
56950	Cold Spring Harbor, Oyster Bay, New York (sub)	NOS	8516061	40.8733000000000004	-73.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:02:00	\N	0.92000000000000004	-00:07:00	\N	1.07000000000000006	\N	\N	Cold Spring Harbor	NY
56951	Green Island, Hempstead Bay, New York (sub)	NOS	8516155	40.6233000000000004	-73.5016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:31:00	\N	0.400000000000000022	01:21:00	\N	0.409999999999999976	\N	\N	Green Island	NY
56952	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667000000000016	-73.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:13:00	\N	1.08000000000000007	00:07:00	\N	1.08000000000000007	\N	\N	Oyster Bay Harbor	NY
56953	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6632999999999996	-73.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:58:00	\N	0.450000000000000011	01:28:00	\N	0.429999999999999993	\N	\N	Bellmore, Bellmore Creek	NY
56954	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.6199999999999974	-73.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:22:00	\N	0.5	01:07:00	\N	0.489999999999999991	\N	\N	Cuba Island	NY
56955	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6032999999999973	-73.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:11:00	\N	0.5	01:01:00	\N	0.510000000000000009	\N	\N	Deep Creek Meadow	NY
56956	Bayville Bridge, Oyster Bay, New York (sub)	NOS	8516299	40.9033000000000015	-73.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55734	00:04:00	\N	1.04000000000000004	-00:06:00	\N	1.09000000000000008	\N	\N	Bayville Bridge	NY
56957	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233000000000004	-73.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:54:00	\N	0.599999999999999978	00:49:00	\N	0.57999999999999996	\N	\N	Neds Creek	NY
56958	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867000000000004	-73.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:25:00	\N	0.75	-00:20:00	\N	0.770000000000000018	\N	\N	Jones Inlet (Point Lookout)	NY
56959	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6332999999999984	-73.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:55:00	\N	0.650000000000000022	00:37:00	\N	0.640000000000000013	\N	\N	Freeport, Baldwin Bay	NY
56960	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6000000000000014	-73.6500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:02:00	\N	0.849999999999999978	00:18:00	\N	0.839999999999999969	\N	\N	Long Beach (Inside)	NY
56961	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York (sub)	NOS	8516614	40.8633000000000024	-73.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	-00:26:00	\N	0.819999999999999951	-00:22:00	\N	1.01000000000000001	\N	\N	Glen Cove, Hempstead Harbor	NY
56962	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.6199999999999974	-73.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:50:00	\N	0.849999999999999978	00:34:00	\N	0.839999999999999969	\N	\N	Woodmere, Brosewere Bay	NY
56963	Port Washington, Manhasset Bay, Long Island, New York (sub)	NOS	8516761	40.8316999999999979	-73.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	-00:12:00	\N	0.959999999999999964	-00:12:00	\N	1.02000000000000002	\N	\N	Port Washington, Manhasset Bay	NY
56964	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167000000000016	-73.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:48:00	\N	1.14999999999999991	00:39:00	\N	1.15999999999999992	\N	\N	Motts Basin	NY
56965	Willets Point, Little Bay, East River, New York (sub)	NOS	8516990	40.7933000000000021	-73.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:00:00	\N	1.04000000000000004	-00:01:00	\N	1	\N	\N	Willets Point	NY
56966	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233000000000004	-73.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:45:00	\N	1.14999999999999991	00:25:00	\N	1.1399999999999999	\N	\N	J.F.K. International Airport	NY
56967	Whitestone, East River, New York	NOS	8517125	40.7982999999999976	-73.8132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:09:00	\N	1.04000000000000004	00:07:00	\N	1	\N	\N	Whitestone	NY
56968	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5882999999999967	-73.8199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:24:00	\N	1.10000000000000009	00:37:00	\N	1.09000000000000008	\N	\N	Beach Channel (bridge)	NY
56969	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.783299999999997	-73.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:16:00	\N	1.04000000000000004	00:17:00	\N	0.949999999999999956	\N	\N	College Point, Flushing Bay	NY
56970	Canarsie, Jamaica Bay, New York	NOS	8517381	40.6300000000000026	-73.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:08:00	\N	1.10000000000000009	00:27:00	\N	1.12000000000000011	\N	\N	Canarsie	NY
56971	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5782999999999987	-73.888300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:04:00	\N	1.05000000000000004	-00:01:00	\N	1.07000000000000006	\N	\N	Barren Island, Rockaway Inlet	NY
56972	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867000000000033	-73.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	03:45:00	\N	1.59000000000000008	02:58:00	\N	1.33000000000000007	\N	\N	Hell Gate, Wards Island	NY
56973	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6082999999999998	-73.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:04:00	\N	1.10000000000000009	00:28:00	\N	1.12000000000000011	\N	\N	Mill Basin	NY
56974	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.5850000000000009	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:03:00	\N	1.05000000000000004	00:02:00	\N	1.05000000000000004	\N	\N	Plumb Beach Channel	NY
56975	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.740000000000002	-73.9616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:56:00	\N	0.900000000000000022	01:22:00	\N	0.890000000000000013	\N	\N	Hunters Point, Newtown Creek	NY
56976	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7066999999999979	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:22:00	\N	1.05000000000000004	00:32:00	\N	0.939999999999999947	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
56977	Coney Island, New York	NOS	8517741	40.5700000000000003	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:17:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Coney Island	NY
56978	Norton Point, Gravesend Bay, New York	NOS	8517811	40.5900000000000034	-73.9983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:03:00	\N	1.14999999999999991	-00:01:00	\N	1.02000000000000002	\N	\N	Norton Point, Gravesend Bay	NY
56979	Brooklyn Bridge, East River, New York (sub)	NOS	8517847	40.7032999999999987	-73.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	-00:04:00	\N	1	00:24:00	\N	0.989999999999999991	\N	\N	Brooklyn Bridge	NY
56980	Gowanus Bay, New York	NOS	8517921	40.6649999999999991	-74.013300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	-00:12:00	\N	0.949999999999999956	-00:18:00	\N	1.03000000000000003	\N	\N	Gowanus Bay	NY
56981	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6082999999999998	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:07:00	\N	1	00:02:00	\N	1.01000000000000001	\N	\N	Fort Hamilton, The Narrows	NY
56982	Rye Beach (Amusement Park), New York (sub)	NOS	8518091	40.9617000000000004	-73.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	-00:27:00	\N	0.859999999999999987	-00:20:00	\N	1	\N	\N	Rye Beach	NY
56984	Hunts Point, East River, New York	NOS	8518621	40.7999999999999972	-73.8733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:10:00	\N	1.07000000000000006	00:12:00	\N	0.969999999999999973	\N	\N	Hunts Point	NY
56985	North Brother Island, East River, New York	NOS	8518635	40.7982999999999976	-73.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:18:00	\N	1.1100000000000001	00:18:00	\N	0.930000000000000049	\N	\N	North Brother Island	NY
56986	Port Morris (Stony Point), East River, New York (sub)	NOS	8518639	40.8016999999999967	-73.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55779	00:10:00	\N	0.959999999999999964	00:07:00	\N	0.869999999999999996	\N	\N	Port Morris (Stony Point)	NY
56987	Horns Hook, East 90th Street, East River, New York, New York (sub)	NOS	8518668	40.7766999999999982	-73.9416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:34:00	\N	0.900000000000000022	01:54:00	\N	1.03000000000000003	\N	\N	Horns Hook, East 90th Street	NY
56988	Queensboro Bridge, East River, New York (sub)	NOS	8518687	40.7582999999999984	-73.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:57:00	\N	1	01:23:00	\N	0.959999999999999964	\N	\N	Queensboro Bridge	NY
56989	East 41st Street, New York City, East River, New York	NOS	8518695	40.746699999999997	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:46:00	\N	1.09000000000000008	01:03:00	\N	0.949999999999999956	\N	\N	East 41st Street, New York City	NY
56990	Williamsburg Bridge, East River, New York (sub)	NOS	8518699	40.7117000000000004	-73.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:28:00	\N	0.949999999999999956	00:45:00	\N	0.930000000000000049	\N	\N	Williamsburg Bridge	NY
56991	Spuyten Duyvil Creek Entrance, Hudson River, New York (sub)	NOS	8518903	40.878300000000003	-73.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:48:00	\N	0.839999999999999969	00:52:00	\N	0.839999999999999969	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
56992	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033000000000015	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:49:00	\N	0.849999999999999978	00:48:00	\N	0.849999999999999978	\N	\N	Riverdale, N.Y.	NY
56993	Tarrytown, Hudson River, New York	NOS	8518919	41.0782999999999987	-73.8700000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:57:00	\N	0.699999999999999956	01:49:00	\N	0.699999999999999956	\N	\N	Tarrytown	NY
56994	Haverstraw Bay, Hudson River, New York (sub)	NOS	8518924	41.2182999999999993	-73.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	02:42:00	\N	0.810000000000000053	02:15:00	\N	0.719999999999999973	\N	\N	Haverstraw	NY
56995	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	04:03:00	\N	0.640000000000000013	03:46:00	\N	0.619999999999999996	\N	\N	Newburgh	NY
56996	New Hamburg, Hudson River, New York	NOS	8518939	41.5833000000000013	-73.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	04:28:00	\N	0.640000000000000013	04:04:00	\N	0.640000000000000013	\N	\N	New Hamburg	NY
56997	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7000000000000028	-73.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	04:46:00	\N	0.680000000000000049	04:34:00	\N	0.680000000000000049	\N	\N	Poughkeepsie	NY
56998	Peekskill, Hudson River, New York	NOS	8518949	41.2882999999999996	-73.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	03:03:00	\N	0.640000000000000013	02:28:00	\N	0.640000000000000013	\N	\N	Peekskill	NY
56999	Tivoli, Hudson River, New York	NOS	8518964	42.0583000000000027	-73.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	06:04:00	\N	0.859999999999999987	05:50:00	\N	0.859999999999999987	\N	\N	Tivoli	NY
57000	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.7999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	07:12:00	\N	0.859999999999999987	06:58:00	\N	0.880000000000000004	\N	\N	Hudson	NY
57001	Castleton, Hudson River, New York	NOS	8518989	42.533299999999997	-73.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55802	-00:29:00	0.100000000000000006	\N	-00:17:00	-0.200000000000000011	\N	\N	\N	Castleton	NY
57002	Kingston, Hudson River, New York	NOS	8518993	41.9183000000000021	-73.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	05:34:00	\N	0.819999999999999951	05:20:00	\N	0.810000000000000053	\N	\N	Kingston	NY
57003	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6066999999999965	-74.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:06:00	\N	1.05000000000000004	00:06:00	\N	0.979999999999999982	\N	\N	Fort Wadsworth, The Narrows	NY
57004	St. George, Staten Island, New York	NOS	8519112	40.6433000000000035	-74.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	-00:15:00	\N	0.989999999999999991	-00:17:00	\N	0.989999999999999991	\N	\N	St. George, Staten Island	NY
57005	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.6450000000000031	-74.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:39:00	\N	1.09000000000000008	00:27:00	\N	1.09000000000000008	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
57006	Princes Bay, New Jersey	NOS	8519726	40.5116999999999976	-74.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:06:00	\N	1.05000000000000004	00:00:00	\N	1.05000000000000004	\N	\N	Princes Bay	NJ
57007	Rossville, Arthur Kill, New York	NOS	8519789	40.5566999999999993	-74.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:29:00	\N	1.12000000000000011	00:20:00	\N	1.12000000000000011	\N	\N	Rossville, N.Y.	NY
57008	Alpine, Hudson River, New Jersey	NOS	8530095	40.9450000000000003	-73.9183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:02:00	\N	0.900000000000000022	01:05:00	\N	0.82999999999999996	\N	\N	Alpine, N.J.	NJ
57009	New Millford, Hackensack River, New Jersey	NOS	8530186	40.9350000000000023	-74.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	02:49:00	\N	1.02000000000000002	01:17:00	\N	1.02000000000000002	\N	\N	New Millford	NJ
57010	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.8800000000000026	-74.0400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:00:00	\N	1.37999999999999989	01:06:00	\N	1.33000000000000007	\N	\N	Hackensack	NJ
57011	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.8500000000000014	-74.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:00:00	\N	1.26000000000000001	01:00:00	\N	1.26000000000000001	\N	\N	Ridgefield Park	NJ
57012	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8466999999999985	-74.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:06:00	\N	1.29000000000000004	00:09:00	\N	1.29000000000000004	\N	\N	East Rutherford	NJ
57013	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8132999999999981	-73.9783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:28:00	\N	0.930000000000000049	00:31:00	\N	0.930000000000000049	\N	\N	Edgewater, N.J.	NJ
57014	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8066999999999993	-74.0600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:45:00	\N	1.29000000000000004	00:59:00	\N	1.26000000000000001	\N	\N	Carlstadt, Garretts Reach	NJ
57061	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483000000000033	-74.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:21:00	\N	0.0800000000000000017	04:00:00	\N	0.0800000000000000017	\N	\N	Coates Point	NJ
57015	North Secaucus, Garretts Reach, Hackensack River, New York	NOS	8530531	40.8049999999999997	-74.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:57:00	\N	1.22999999999999998	00:57:00	\N	1.22999999999999998	\N	\N	North Secaucus, Garretts Reach	NY
57016	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933000000000021	-74.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	01:00:00	\N	1	01:02:00	\N	1.15999999999999992	\N	\N	Fish Creek, Berrys Creek	NJ
57017	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867000000000033	-74.1466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:49:00	\N	1.18999999999999995	00:09:00	\N	1.22999999999999998	\N	\N	Belleville	NJ
57018	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.7650000000000006	-74.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:15:00	\N	0.959999999999999964	00:13:00	\N	0.959999999999999964	\N	\N	Weehawken, Union City, N.J.	NJ
57019	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7516999999999996	-74.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:39:00	\N	1.10000000000000009	00:33:00	\N	1.15999999999999992	\N	\N	Amtrak RR. swing bridge	NJ
57020	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7316999999999965	-74.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:22:00	\N	1.04000000000000004	00:00:00	\N	1.14999999999999991	\N	\N	Point No Point	NJ
57021	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7282999999999973	-74.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:22:00	\N	1.1399999999999999	00:11:00	\N	1.14999999999999991	\N	\N	Kearny Point	NJ
57022	Port Elizabeth, New Jersey	NOS	8530882	40.6732999999999976	-74.1400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:13:00	\N	0.949999999999999956	-00:02:00	\N	1.1100000000000001	\N	\N	Port Elizabeth	NJ
57023	Port Newark Terminal, New Jersey	NOS	8530884	40.6899999999999977	-74.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	00:21:00	\N	1.12000000000000011	00:03:00	\N	1.12000000000000011	\N	\N	Port Newark Terminal	NJ
57024	Constable Hook, Kill Van Kull, New York	NOS	8530985	40.6550000000000011	-74.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55794	-00:08:00	\N	1.02000000000000002	-00:18:00	\N	1.02000000000000002	\N	\N	Constable Hook	NY
57025	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983000000000018	-74.2317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:30:00	\N	1.15999999999999992	00:17:00	\N	1.1399999999999999	\N	\N	Rahway River, RR. Bridge	NJ
57026	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867000000000004	-74.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:33:00	\N	1.09000000000000008	00:22:00	\N	1.09000000000000008	\N	\N	Carteret	NJ
57027	Woodbridge Creek, 0.8 n.mi. above entrance, Arthur Kill, New Jersey	NOS	8531156	40.5450000000000017	-74.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:21:00	\N	1	00:09:00	\N	1.10000000000000009	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
57028	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4532999999999987	-74.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:13:00	\N	1.05000000000000004	00:12:00	\N	1.09000000000000008	\N	\N	Cheesequake Creek, Garden State Parkway	NJ
57029	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917000000000016	-74.2817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:08:00	\N	1.09000000000000008	-00:04:00	\N	1.09000000000000008	\N	\N	South Amboy	NJ
57030	Keasbey, Raritan River, New Jersey	NOS	8531262	40.5082999999999984	-74.3117000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:18:00	\N	1	00:06:00	\N	1.10000000000000009	\N	\N	Keasbey	NJ
57031	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.4166999999999987	-74.3632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:59:00	\N	1.15999999999999992	00:48:00	\N	1.17999999999999994	\N	\N	Old Bridge, South River	NJ
57032	Sayreville, Raritan River, New Jersey	NOS	8531390	40.4782999999999973	-74.3567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:25:00	\N	1.20999999999999996	00:11:00	\N	1.1399999999999999	\N	\N	Sayreville	NJ
57033	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.4883000000000024	-74.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:48:00	\N	1.15999999999999992	00:32:00	\N	1.20999999999999996	\N	\N	New Brunswick	NJ
57034	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333000000000027	-74.2182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:07:00	\N	1.08000000000000007	-00:01:00	\N	1.08000000000000007	\N	\N	Matawan Creek, Route 35 bridge	NJ
57035	Keyport, New Jersey	NOS	8531545	40.4399999999999977	-74.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:06:00	\N	1.10000000000000009	-00:04:00	\N	1.08000000000000007	\N	\N	Keyport	NJ
57036	Waackaack Creek, New Jersey	NOS	8531592	40.4483000000000033	-74.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:21:00	\N	0.989999999999999991	-00:06:00	\N	0.989999999999999991	\N	\N	Waackaack Creek	NJ
57037	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183000000000021	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:10:00	\N	1.01000000000000001	-00:10:00	\N	1.01000000000000001	\N	\N	Atlantic Highlands	NJ
57038	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967000000000027	-73.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:14:00	\N	0.900000000000000022	00:17:00	\N	0.900000000000000022	\N	\N	Highlands, Route 36 bridge	NJ
57039	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3766999999999996	-74.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:45:00	\N	0.630000000000000004	01:13:00	\N	0.719999999999999973	\N	\N	Oceanic Bridge, Navesink River	NJ
57040	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365000000000002	-73.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:07:00	\N	0.680000000000000049	01:15:00	\N	0.680000000000000049	\N	\N	Sea Bright	NJ
57041	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.3549999999999969	-74.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:57:00	\N	0.630000000000000004	01:17:00	\N	0.739999999999999991	\N	\N	Red Bank, Navesink River	NJ
57042	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267000000000024	-74.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:41:00	\N	0.550000000000000044	02:18:00	\N	0.550000000000000044	\N	\N	Gooseneck Point, bridge	NJ
57043	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.3250000000000028	-73.9967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:41:00	\N	0.630000000000000004	02:18:00	\N	0.560000000000000053	\N	\N	Long Branch Reach	NJ
57044	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033000000000001	-73.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:36:00	\N	1	-00:26:00	\N	0.939999999999999947	\N	\N	Long Branch (fishing pier)	NJ
57045	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1916999999999973	-74.0383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:09:00	\N	0.939999999999999947	-00:13:00	\N	0.939999999999999947	\N	\N	Shark River Hills	NJ
57046	Belmar (ocean), New Jersey	NOS	8532337	40.1850000000000023	-74.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:45:00	\N	0.949999999999999956	-00:35:00	\N	0.949999999999999956	\N	\N	Belmar, Atlantic Ocean	NJ
57047	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867000000000019	-74.0267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:08:00	\N	0.930000000000000049	-00:13:00	\N	0.930000000000000049	\N	\N	Shark River Island, fixed RR. bridge	NJ
57048	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783000000000001	-74.0467000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:07:00	\N	0.949999999999999956	-00:13:00	\N	0.949999999999999956	\N	\N	New Bedford	NJ
57049	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.1049999999999969	-74.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:20:00	\N	0.82999999999999996	-00:06:00	\N	0.82999999999999996	\N	\N	Brielle, Route 35 bridge	NJ
57050	Manasquan Inlet, USCG Station, New Jersey	NOS	8532591	40.101700000000001	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:24:00	\N	0.949999999999999956	-00:12:00	\N	0.859999999999999987	\N	\N	Manasquan Inlet, USCG Station	NJ
57051	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0966999999999985	-74.0866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:38:00	\N	0.729999999999999982	00:08:00	\N	0.729999999999999982	\N	\N	Riviera Beach	NJ
57052	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.0649999999999977	-74.1350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:07:00	\N	0.0700000000000000067	02:17:00	\N	0.0700000000000000067	\N	\N	Forge Pond	NJ
57053	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617000000000019	-74.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:40:00	\N	0.369999999999999996	02:41:00	\N	0.0700000000000000067	\N	\N	Beaverdam Creek entrance	NJ
57054	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617000000000019	-74.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:47:00	\N	0.0599999999999999978	02:49:00	\N	0.0599999999999999978	\N	\N	Beaverdam Creek, inside	NJ
57055	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583000000000027	-74.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:24:00	\N	0.0599999999999999978	02:23:00	\N	0.0599999999999999978	\N	\N	Tall Pines Camp	NJ
57056	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367000000000033	-74.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:39:00	\N	0.0700000000000000067	04:28:00	\N	0.0700000000000000067	\N	\N	Mantoloking	NJ
57057	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.013300000000001	-74.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:41:00	\N	0.0800000000000000017	04:23:00	\N	0.0800000000000000017	\N	\N	Kettle Creek, Green Island	NJ
57058	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883000000000024	-74.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:36:00	\N	0.0800000000000000017	04:17:00	\N	0.0800000000000000017	\N	\N	Ocean Beach	NJ
57059	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.996699999999997	-74.1483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:39:00	\N	0.0800000000000000017	04:26:00	\N	0.0800000000000000017	\N	\N	Silver Bay, Silver Bay Marina	NJ
57060	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9632999999999967	-74.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:29:00	\N	0.0800000000000000017	04:06:00	\N	0.0800000000000000017	\N	\N	Goose Creek entrance	NJ
57062	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433000000000007	-74.0349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	-00:32:00	\N	0.92000000000000004	-00:30:00	\N	0.92000000000000004	\N	\N	Seaside Heights, ocean	NJ
57063	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217000000000013	-74.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:05:00	\N	0.0800000000000000017	03:40:00	\N	0.0800000000000000017	\N	\N	Seaside Park	NJ
57064	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183000000000021	-74.1099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:55:00	\N	0.0800000000000000017	03:35:00	\N	0.0800000000000000017	\N	\N	Barnegat Pier	NJ
57065	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.9050000000000011	-74.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:01:00	\N	0.0800000000000000017	03:38:00	\N	0.0800000000000000017	\N	\N	Sloop Creek	NJ
57066	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.8699999999999974	-74.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:45:00	\N	0.0800000000000000017	03:23:00	\N	0.0800000000000000017	\N	\N	Cedar Creek	NJ
57067	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.851700000000001	-74.0883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:28:00	\N	0.0800000000000000017	03:04:00	\N	0.0800000000000000017	\N	\N	Island Beach	NJ
57068	Stouts Creek, Barnegat Bay, New Jersey (sub)	NOS	8533365	39.8449999999999989	-74.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:33:00	\N	0.0599999999999999978	03:16:00	\N	0.0599999999999999978	\N	\N	Stouts Creek	NJ
57069	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.8250000000000028	-74.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:20:00	\N	0.0700000000000000067	03:08:00	\N	0.0700000000000000067	\N	\N	Forked River	NJ
57070	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083000000000027	-74.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:36:00	\N	0.0599999999999999978	03:30:00	\N	0.0599999999999999978	\N	\N	Oyster Creek	NJ
57071	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7882999999999996	-74.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:56:00	\N	0.0700000000000000067	03:00:00	\N	0.0700000000000000067	\N	\N	Island Beach, Sedge Islands	NJ
57072	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7916999999999987	-74.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:00:00	\N	0.0700000000000000067	02:43:00	\N	0.0700000000000000067	\N	\N	Waretown	NJ
57073	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567000000000021	-74.1282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:55:00	\N	0.119999999999999996	01:04:00	\N	0.119999999999999996	\N	\N	High Bar	NJ
57074	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.7449999999999974	-74.2017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:33:00	\N	0.0700000000000000067	03:03:00	\N	0.0700000000000000067	\N	\N	Double Creek	NJ
57075	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.7250000000000014	-74.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:39:00	\N	0.100000000000000006	03:02:00	\N	0.100000000000000006	\N	\N	Loveladies Harbor	NJ
57076	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7066999999999979	-74.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:35:00	\N	0.179999999999999993	03:33:00	\N	0.179999999999999993	\N	\N	Flat Creek	NJ
57077	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.6749999999999972	-74.1599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:07:00	\N	0.220000000000000001	03:02:00	\N	0.220000000000000001	\N	\N	North Beach	NJ
57078	Mill Creek, 1 n.mi. above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.6649999999999991	-74.2317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:33:00	\N	0.349999999999999978	02:32:00	\N	0.349999999999999978	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
57079	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6666999999999987	-74.2150000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:51:00	\N	0.270000000000000018	02:50:00	\N	0.270000000000000018	\N	\N	Manahawkin Creek	NJ
57080	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533000000000015	-74.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:39:00	\N	0.270000000000000018	02:47:00	\N	0.270000000000000018	\N	\N	Manahawkin Drawbridge	NJ
57081	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533000000000015	-74.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:56:00	\N	0.400000000000000022	02:10:00	\N	0.400000000000000022	\N	\N	Cedar Run	NJ
57082	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567000000000007	-74.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:17:00	\N	0.400000000000000022	02:41:00	\N	0.400000000000000022	\N	\N	Dinner Point Creek, upper end	NJ
57083	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317000000000021	-74.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:40:00	\N	0.469999999999999973	02:10:00	\N	0.440000000000000002	\N	\N	West Creek, Westecunk Creek	NJ
57084	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	04:21:00	\N	0.560000000000000053	03:23:00	\N	0.560000000000000053	\N	\N	Sweetwater, Mullica River Marina	NJ
57085	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6182999999999979	-74.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:44:00	\N	0.790000000000000036	02:48:00	\N	0.640000000000000013	\N	\N	Wading River (town), Wading River	NJ
57086	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133000000000024	-74.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:40:00	\N	0.469999999999999973	02:00:00	\N	0.419999999999999984	\N	\N	Westecunk Creek entrance	NJ
57087	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133000000000024	-74.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:59:00	\N	0.320000000000000007	02:13:00	\N	0.380000000000000004	\N	\N	Beach Haven Crest	NJ
57088	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167000000000016	-74.3100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:39:00	\N	0.469999999999999973	02:05:00	\N	0.450000000000000011	\N	\N	Parker Run, upper end	NJ
57089	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.601700000000001	-74.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:15:00	\N	0.469999999999999973	01:45:00	\N	0.450000000000000011	\N	\N	Tuckerton, Tuckerton Creek	NJ
57090	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.591700000000003	-74.4416999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:06:00	\N	0.739999999999999991	01:52:00	\N	0.660000000000000031	\N	\N	New Gretna, Bass River	NJ
57091	Green Bank, Mullica River, New Jersey	NOS	8534117	39.611699999999999	-74.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	03:16:00	\N	0.660000000000000031	02:59:00	\N	0.660000000000000031	\N	\N	Green Bank	NJ
57092	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767000000000024	-74.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:59:00	\N	0.450000000000000011	01:32:00	\N	0.450000000000000011	\N	\N	Tuckerton Creek entrance	NJ
57093	Beach Haven Coast Guard Station, Little Egg Harbor, New Jersey	NOS	8534208	39.5482999999999976	-74.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:23:00	\N	0.57999999999999996	01:18:00	\N	0.46000000000000002	\N	\N	Beach Haven Coast Guard Station	NJ
57094	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5482999999999976	-74.4616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	02:01:00	\N	0.790000000000000036	01:27:00	\N	0.630000000000000004	\N	\N	Chestnut Neck Boat Yard	NJ
57095	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.5399999999999991	-74.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:14:00	\N	0.680000000000000049	00:44:00	\N	0.680000000000000049	\N	\N	Graveling Point	NJ
57096	Nacote Creek, U.S. Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.5349999999999966	-74.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:55:00	\N	0.680000000000000049	01:34:00	\N	0.660000000000000031	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
57097	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217000000000027	-74.3199999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:44:00	\N	0.680000000000000049	00:35:00	\N	0.660000000000000031	\N	\N	Little Sheepshead Creek	NJ
57098	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167000000000002	-74.3366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:28:00	\N	0.729999999999999982	00:32:00	\N	0.729999999999999982	\N	\N	Seven Island, Newmans Thorofare	NJ
57099	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4782999999999973	-74.3833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:52:00	\N	0.760000000000000009	01:10:00	\N	0.800000000000000044	\N	\N	Main Marsh Thorofare	NJ
57100	Mays Landing, Great Egg Harbor River, New Jersey (sub)	NOS	8534468	39.4483000000000033	-74.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	03:10:00	\N	1.12000000000000011	02:50:00	\N	1.01000000000000001	\N	\N	Mays Landing, Great Egg Harbor River	NJ
57101	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.4350000000000023	-74.3632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:58:00	\N	0.880000000000000004	00:59:00	\N	0.900000000000000022	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
57102	Absecon, Absecon Creek, U.S. Hwy. 30 bridge, New Jersey	NOS	8534540	39.4232999999999976	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:37:00	\N	0.939999999999999947	01:28:00	\N	0.959999999999999964	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
57103	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.384999999999998	-74.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:26:00	\N	1.12999999999999989	00:38:00	\N	0.959999999999999964	\N	\N	Absecon Channel, State Route 87 bridge	NJ
57104	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817000000000021	-74.5182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:37:00	\N	0.819999999999999951	01:00:00	\N	0.979999999999999982	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
57105	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3682999999999979	-74.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	02:25:00	\N	1	02:12:00	\N	0.869999999999999996	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
57106	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.351700000000001	-74.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:00:00	\N	0.939999999999999947	00:55:00	\N	0.979999999999999982	\N	\N	Dock Thorofare, Risley Channel	NJ
57107	Ventnor City, ocean pier, New Jersey (sub)	NOS	8534770	39.3350000000000009	-74.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Ventnor City, ocean pier	NJ
57108	Steelmanville, Patcong Ck., 2.5 n.mi. above ent, Great Egg Harbor Bay, New Jersey	NOS	8534778	39.3350000000000009	-74.5966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:50:00	\N	0.939999999999999947	01:28:00	\N	0.92000000000000004	\N	\N	Steelmanville, Patcong Ck., 2.5 nm above ent.	NJ
57109	Longport, Risely Channel, New Jersey (sub)	NOS	8534836	39.3083000000000027	-74.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:32:00	\N	0.880000000000000004	00:26:00	\N	0.939999999999999947	\N	\N	Longport (inside), Great Egg Harbor Inlet	NJ
57110	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey (sub)	NOS	8534883	39.2950000000000017	-74.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	02:40:00	\N	1.25	02:12:00	\N	0.859999999999999987	\N	\N	Tuckahoe, Tuckahoe River	NJ
57111	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2882999999999996	-74.6282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:32:00	\N	1	00:55:00	\N	0.869999999999999996	\N	\N	Beesleys Point	NJ
57112	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.246699999999997	-74.7182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	03:03:00	\N	1.53000000000000003	03:14:00	\N	0.780000000000000027	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
57113	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.2150000000000034	-74.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:30:00	\N	0.939999999999999947	00:31:00	\N	0.949999999999999956	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
57114	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2000000000000028	-74.6567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:38:00	\N	1	00:31:00	\N	0.949999999999999956	\N	\N	Strathmere, Strathmere Bay	NJ
57115	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1766999999999967	-74.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:12:00	\N	0.939999999999999947	00:56:00	\N	0.979999999999999982	\N	\N	Ludlam Bay, west side	NJ
57116	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467000000000027	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:39:00	\N	0.589999999999999969	01:08:00	\N	0.900000000000000022	\N	\N	Townsend Sound	NJ
57117	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.1199999999999974	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:04:00	\N	1	00:49:00	\N	0.969999999999999973	\N	\N	Stites Sound	NJ
57118	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.1099999999999994	-74.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:50:00	\N	1	00:44:00	\N	0.959999999999999964	\N	\N	Ingram Thorofare	NJ
57119	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.101700000000001	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:11:00	\N	1.06000000000000005	01:06:00	\N	0.979999999999999982	\N	\N	Long Reach, Ingram Thorofare	NJ
57120	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.0566999999999993	-74.7650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:12:00	\N	1	01:01:00	\N	1.08000000000000007	\N	\N	Stone Harbor, Great Channel	NJ
57121	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283000000000015	-74.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
57122	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183000000000035	-74.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:10:00	\N	1	00:56:00	\N	1.06000000000000005	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
57123	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.0050000000000026	-74.8267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	01:11:00	\N	1	00:57:00	\N	1.04000000000000004	\N	\N	West Wildwood, Grassy Sound	NJ
57124	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.9799999999999969	-74.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:40:00	\N	1.06000000000000005	00:55:00	\N	1.09000000000000008	\N	\N	Swain Channel, Taylor Sound	NJ
57125	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9782999999999973	-74.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:47:00	\N	1.06000000000000005	00:52:00	\N	1.10000000000000009	\N	\N	Wildwood Crest, Sunset Lake	NJ
57126	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483000000000033	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:19:00	\N	1.06000000000000005	00:33:00	\N	1.10000000000000009	\N	\N	Cape May Harbor	NJ
57127	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9466999999999999	-74.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:20:00	\N	1.18999999999999995	00:40:00	\N	1.1100000000000001	\N	\N	Cape Island Creek, Cape May	NJ
57128	Cape May (ocean), New Jersey	NOS	8535962	38.9299999999999997	-74.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55813	00:21:00	\N	1.06000000000000005	00:34:00	\N	1.12000000000000011	\N	\N	Cape May, Atlantic Ocean	NJ
57129	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9466999999999999	-74.9716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	-00:08:00	\N	1.15999999999999992	-00:05:00	\N	1.15999999999999992	\N	\N	Cape May Point, Sunset Beach	NJ
57130	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183000000000035	-74.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	00:14:00	\N	1.26000000000000001	00:04:00	\N	1.26000000000000001	\N	\N	North Highlands Beach	NJ
57131	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833000000000013	-74.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	03:18:00	\N	0.46000000000000002	01:09:00	\N	0.46000000000000002	\N	\N	Dias Creek, Route 47 bridge	NJ
57132	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1182999999999979	-74.868300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	00:48:00	\N	1.3600000000000001	00:36:00	\N	1.3600000000000001	\N	\N	Bidwell Creek, Route 47 bridge	NJ
57133	Bidwell Creek entrance, Delaware Bay, New Jersey (sub)	NOS	8536581	39.128300000000003	-74.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	00:46:00	\N	1.18999999999999995	00:15:00	\N	1.3899999999999999	\N	\N	Bidwell Creek entrance	NJ
57134	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617000000000033	-74.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:36:00	\N	1.21999999999999997	01:49:00	\N	1.21999999999999997	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
57135	Dennis Creek, 2.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783000000000001	-74.8516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:17:00	\N	1.26000000000000001	00:55:00	\N	1.26000000000000001	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
57136	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833000000000027	-74.821700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:30:00	\N	1.19999999999999996	02:01:00	\N	1.19999999999999996	\N	\N	Dennis Creek, Route 47 bridge	NJ
57137	West Creek, 0.7 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1882999999999981	-74.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:31:00	\N	1.14999999999999991	00:20:00	\N	1.14999999999999991	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
57138	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2000000000000028	-75.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:08:00	\N	1.3899999999999999	00:40:00	\N	1.3899999999999999	\N	\N	East Point, Maurice River Cove	NJ
57139	Riggins Ditch, 0.5 n.mi. above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2000000000000028	-74.9699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:29:00	\N	1.23999999999999999	00:29:00	\N	1.23999999999999999	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
57140	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083000000000013	-74.9017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	02:24:00	\N	0.939999999999999947	01:46:00	\N	0.939999999999999947	\N	\N	East Creek, Route 47 bridge	NJ
57141	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.216700000000003	-75.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-02:10:00	\N	1.02000000000000002	-01:51:00	\N	1.02000000000000002	\N	\N	Fishing Creek entrance	NJ
57142	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.216700000000003	-75.1033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:05:00	\N	1.35000000000000009	00:29:00	\N	1.35000000000000009	\N	\N	Dividing Creek entrance	NJ
57143	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.216700000000003	-74.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	03:17:00	\N	0.57999999999999996	02:20:00	\N	0.57999999999999996	\N	\N	West Creek, Route 47 bridge	NJ
57144	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2182999999999993	-74.980000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:40:00	\N	1.12000000000000011	01:36:00	\N	1.12000000000000011	\N	\N	Riggins Ditch, Heislerville	NJ
57145	Bivalve, Maurice River, New Jersey	NOS	8536889	39.2299999999999969	-75.0366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:14:00	\N	1.35000000000000009	00:39:00	\N	1.35000000000000009	\N	\N	Bivalve	NJ
57146	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1282999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	02:33:00	\N	0.709999999999999964	01:38:00	\N	0.709999999999999964	\N	\N	Weir Creek bridge, Dividing Creek	NJ
57147	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.2749999999999986	-75.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:13:00	\N	0.209999999999999992	01:45:00	\N	0.209999999999999992	\N	\N	Hollywood Beach, The Glades	NJ
57148	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.2849999999999966	-75.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-01:58:00	\N	1.10000000000000009	-01:43:00	\N	1.10000000000000009	\N	\N	Money Island, Nantuxent Creek entrance	NJ
57149	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.2849999999999966	-74.9916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	02:30:00	\N	1.05000000000000004	02:17:00	\N	1.05000000000000004	\N	\N	Mauricetown	NJ
57150	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2916999999999987	-75.1983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:28:00	\N	0.739999999999999991	-00:03:00	\N	0.739999999999999991	\N	\N	Newport Landing, Nantuxent Creek	NJ
57151	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2982999999999976	-75.2467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-01:51:00	\N	1.08000000000000007	-01:37:00	\N	1.08000000000000007	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
57152	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.3049999999999997	-75.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-01:34:00	\N	1.07000000000000006	-01:29:00	\N	1.07000000000000006	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
57153	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3132999999999981	-74.9849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	02:58:00	\N	1.05000000000000004	02:52:00	\N	1.05000000000000004	\N	\N	Port Elizabeth, Manumuskin River	NJ
57154	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3432999999999993	-75.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	03:09:00	\N	1.10000000000000009	03:06:00	\N	1.10000000000000009	\N	\N	Menantico Creek entrance	NJ
57155	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.378300000000003	-75.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:02:00	\N	1.09000000000000008	01:01:00	\N	1.09000000000000008	\N	\N	Tindalls Wharf, Cohansey River	NJ
57156	Millville, Maurice River, New Jersey	NOS	8537359	39.3917000000000002	-75.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	03:36:00	\N	1.20999999999999996	03:33:00	\N	1.20999999999999996	\N	\N	Millville	NJ
57157	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3832999999999984	-75.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:54:00	\N	0.989999999999999991	-00:42:00	\N	0.989999999999999991	\N	\N	Greenwich Pier, Cohansey River	NJ
57158	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:37:00	\N	0.880000000000000004	-00:22:00	\N	0.880000000000000004	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
57159	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217000000000013	-75.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:18:00	\N	0.92000000000000004	00:21:00	\N	0.92000000000000004	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
57160	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217000000000013	-75.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:33:00	\N	0.760000000000000009	01:08:00	\N	0.760000000000000009	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
57161	1 n.mi. above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4316999999999993	-75.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:47:00	\N	1.07000000000000006	-00:20:00	\N	1.07000000000000006	\N	\N	1 n.mi. above entrance, N.J.	NJ
57162	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617000000000004	-75.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:45:00	\N	0.800000000000000044	01:36:00	\N	0.800000000000000044	\N	\N	Canton, Stow Creek, N.J.	NJ
57163	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.4600000000000009	-75.5317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:33:00	\N	1.08000000000000007	-00:35:00	\N	1.08000000000000007	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
57164	Hope Creek, 0.6 n.mi. above entrance, Delaware River, New Jersey	NOS	8537667	39.4583000000000013	-75.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:36:00	\N	1.05000000000000004	-00:25:00	\N	1.05000000000000004	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
57165	0.8 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537731	39.496699999999997	-75.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:10:00	\N	0.989999999999999991	00:21:00	\N	0.989999999999999991	\N	\N	0.8 n.mi. above entrance	NJ
57166	2.5 n.mi. above entrance, Alloway Creek, New Jersey	NOS	8537753	39.5050000000000026	-75.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:15:00	\N	0.900000000000000022	00:51:00	\N	0.900000000000000022	\N	\N	2.5 n.mi. above entrance	NJ
57167	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5116999999999976	-75.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:12:00	\N	0.939999999999999947	00:44:00	\N	0.939999999999999947	\N	\N	Abbots Meadow	NJ
57168	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.513300000000001	-75.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:00:00	\N	0.780000000000000027	01:51:00	\N	0.780000000000000027	\N	\N	Coopers Creek bridge	NJ
57169	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5482999999999976	-75.4150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:30:00	\N	0.689999999999999947	02:24:00	\N	0.689999999999999947	\N	\N	Quinton	NJ
57170	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.5700000000000003	-75.4983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:19:00	\N	0.969999999999999973	00:04:00	\N	0.969999999999999973	\N	\N	Sinnickson Landing	NJ
57171	Salem, Salem River, New Jersey	NOS	8537979	39.5767000000000024	-75.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:41:00	\N	0.760000000000000009	00:49:00	\N	0.760000000000000009	\N	\N	Salem	NJ
57172	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833000000000027	-75.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
57173	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.7150000000000034	-75.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	03:30:00	\N	0.550000000000000044	04:12:00	\N	0.550000000000000044	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
57174	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7616999999999976	-75.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
57175	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.7950000000000017	-75.1766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:56:00	\N	0.709999999999999964	01:28:00	\N	0.709999999999999964	\N	\N	Mantua, Mantua Creek, N.J.	NJ
57176	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8066999999999993	-75.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:50:00	\N	1	-01:11:00	\N	0.910000000000000031	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
57177	Woodbury Creek, New Jersey	NOS	8538548	39.8599999999999994	-75.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:14:00	\N	0.949999999999999956	-00:13:00	\N	0.959999999999999964	\N	\N	Woodbury Creek, N.J.	NJ
57178	Billingsport, New Jersey	NOS	8538552	39.8500000000000014	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:28:00	\N	0.949999999999999956	-00:35:00	\N	0.930000000000000049	\N	\N	Billingsport, N.J.	NJ
57179	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733000000000004	-75.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:03:00	\N	1	00:02:00	\N	0.969999999999999973	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
57180	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9466999999999999	-75.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:23:00	\N	1	00:14:00	\N	1.04000000000000004	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
57181	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9782999999999973	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	03:05:00	\N	0.619999999999999996	02:58:00	\N	0.619999999999999996	\N	\N	Hainesport, South Branch	NJ
57182	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983000000000004	-74.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	03:29:00	\N	0.599999999999999978	02:58:00	\N	0.479999999999999982	\N	\N	North Branch	NJ
57183	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9932999999999979	-75.0283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:03:00	\N	0.890000000000000013	00:51:00	\N	0.890000000000000013	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
57184	Pompeston Creek, New Jersey	NOS	8538875	40.013300000000001	-75.0083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:43:00	\N	1.05000000000000004	00:21:00	\N	1.05000000000000004	\N	\N	Pompeston Creek, N.J.	NJ
57185	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283000000000015	-74.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:18:00	\N	1	01:15:00	\N	1.06000000000000005	\N	\N	Bridgeboro	NJ
57391	Chester, James River, Virginia	NOS	8638491	37.3832999999999984	-77.3782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-03:59:00	\N	0.67000000000000004	-03:39:00	\N	1.02000000000000002	\N	\N	Chester	VA
57186	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733000000000033	-74.8482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:31:00	\N	0.849999999999999978	01:04:00	\N	1.12000000000000011	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
57187	Fieldsboro, Delaware River, New Jersey (sub)	NOS	8539487	40.1366999999999976	-74.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:39:00	\N	1.10000000000000009	01:07:00	\N	1.29000000000000004	\N	\N	Fieldsboro, N.J.	NJ
57188	Trenton Marine Terminal, Trenton, New Jersey (sub)	NOS	8539993	40.1882999999999981	-74.7549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:54:00	\N	1	01:13:00	\N	1.35000000000000009	\N	\N	Trenton, N.J.	NJ
57189	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8766999999999996	-75.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:34:00	\N	0.949999999999999956	-00:46:00	\N	0.949999999999999956	\N	\N	Wanamaker Bridge	PA
57190	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.8800000000000026	-75.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:35:00	\N	1	-00:42:00	\N	0.969999999999999973	\N	\N	Norwood City	PA
57191	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.878300000000003	-75.2767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:08:00	\N	0.900000000000000022	-00:22:00	\N	0.910000000000000031	\N	\N	Tinicum National Wildlife Refuge	PA
57192	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8866999999999976	-75.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:27:00	\N	0.739999999999999991	-00:24:00	\N	0.739999999999999991	\N	\N	Tinicum National Wildlife Refuge	PA
57193	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.898299999999999	-75.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-00:11:00	\N	0.849999999999999978	-00:22:00	\N	0.959999999999999964	\N	\N	Penrose Avenue Bridge	PA
57801	Ankona, Indian River, Florida	NOS	8722274	27.3550000000000004	-80.2733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:03:00	\N	0.849999999999999978	02:16:00	\N	0.520000000000000018	\N	\N	Ankona	FL
57194	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.9549999999999983	-75.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:00:00	\N	0.800000000000000044	-00:20:00	\N	0.989999999999999991	\N	\N	Market Street Bridge	PA
57195	Philadelphia, Municipal Pier 11, Pennsylvania (sub)	NOS	8545530	39.9532999999999987	-75.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:05:00	\N	0.949999999999999956	00:02:00	\N	1.04000000000000004	\N	\N	Philadelphia, Municipal Pier 11, Pa.	PA
57196	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683000000000007	-74.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:58:00	\N	1	00:46:00	\N	1.16999999999999993	\N	\N	Cornwells Heights, Pa.	PA
57197	Edgely, Pennsylvania	NOS	8549424	40.128300000000003	-74.8233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:28:00	\N	1.14999999999999991	01:08:00	\N	1.27000000000000002	\N	\N	Edgely, Pa.	PA
57198	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:11:00	\N	1.16999999999999993	00:52:00	\N	1.02000000000000002	\N	\N	Edgemoor, Del.	DE
57199	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.7250000000000014	-75.5600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:19:00	\N	1.06000000000000005	01:08:00	\N	0.989999999999999991	\N	\N	Millside, RR. bridge	DE
57200	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7182999999999993	-75.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	01:06:00	\N	1.1100000000000001	00:50:00	\N	0.989999999999999991	\N	\N	Wilmington Marine Terminal	DE
57201	New Castle, Delaware River, Delaware	NOS	8551201	39.6567000000000007	-75.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:40:00	\N	1	00:29:00	\N	0.979999999999999982	\N	\N	New Castle, Delaware	DE
57202	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833000000000013	-75.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:00:00	\N	1	00:03:00	\N	1.05000000000000004	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
57203	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.5700000000000003	-75.5900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:05:00	\N	0.890000000000000013	00:00:00	\N	1.02000000000000002	\N	\N	Delaware City Branch Channel bridge	DE
57204	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.5549999999999997	-75.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:17:00	\N	1	-00:16:00	\N	0.82999999999999996	\N	\N	St. Georges, Delaware	DE
57205	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.533299999999997	-75.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-00:52:00	\N	0.560000000000000053	-00:28:00	\N	0.650000000000000022	\N	\N	Summit Bridge, Delaware	DE
57206	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.4050000000000011	-75.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:57:00	\N	0.560000000000000053	01:53:00	\N	0.540000000000000036	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
57207	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333000000000013	-75.466700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-01:10:00	\N	1.1100000000000001	-01:07:00	\N	1.1100000000000001	\N	\N	Woodland Beach, Del.	DE
57208	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.2449999999999974	-75.5182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	03:49:00	\N	0.630000000000000004	03:35:00	\N	0.849999999999999978	\N	\N	Leipsic, Leipsic River	DE
57209	Mahon River entrance, Delaware Bay, Delaware (sub)	NOS	8554399	39.1850000000000023	-75.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:29:00	\N	1.12999999999999989	00:58:00	\N	1.30000000000000004	\N	\N	Mahon River entrance	DE
57210	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583000000000027	-75.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	01:11:00	\N	0.939999999999999947	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
57211	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.9450000000000003	-75.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	00:50:00	\N	1	00:22:00	\N	1.12999999999999989	\N	\N	Mispillion River entrance	DE
57212	Rehoboth Beach, Delaware	NOS	8557863	38.7199999999999989	-75.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:08:00	\N	1.33000000000000007	00:15:00	\N	1.12999999999999989	\N	\N	Rehoboth Beach	DE
57213	Inlet (Coast Guard Station), Indian River, Delaware (sub)	NOS	8558690	38.6099999999999994	-75.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:45:00	\N	1	01:14:00	\N	0.760000000000000009	\N	\N	Indian River Inlet (Coast Guard Station)	DE
57214	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.341700000000003	-75.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:54:00	\N	0.810000000000000053	-00:57:00	\N	0.469999999999999973	\N	\N	Keydash, Isle of Wight Bay	MD
57215	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3316999999999979	-75.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:23:00	\N	0.939999999999999947	00:25:00	\N	0.67000000000000004	\N	\N	Ocean City (Isle of Wight Bay)	MD
57216	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland (sub)	NOS	8570536	38.2150000000000034	-75.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	05:02:00	\N	0.160000000000000003	05:16:00	\N	0.160000000000000003	\N	\N	South Point, Sinepuxent Neck	MD
57217	Public Landing, Chincoteague Bay, Maryland (sub)	NOS	8570649	38.148299999999999	-75.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	05:21:00	\N	0.179999999999999993	04:41:00	\N	0.179999999999999993	\N	\N	Public Landing	MD
57218	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.9617000000000004	-75.821700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:58:00	\N	0.82999999999999996	04:27:00	\N	0.900000000000000022	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
57219	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland (sub)	NOS	8571091	37.976700000000001	-75.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:51:00	\N	1	04:34:00	\N	0.75	\N	\N	Crisfield, Little Annemessex River	MD
57220	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.9799999999999969	-75.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:16:00	\N	1	04:32:00	\N	0.939999999999999947	\N	\N	Shelltown	MD
57221	Ewell, Smith Island, Chesapeake Bay, Maryland (sub)	NOS	8571117	37.9949999999999974	-76.0317000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:19:00	\N	1	04:56:00	\N	0.609999999999999987	\N	\N	Ewell, Smith Island	MD
57222	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0482999999999976	-75.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:30:00	\N	1.16999999999999993	04:59:00	\N	0.780000000000000027	\N	\N	Colburn Creek, Big Annemessex River	MD
57223	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0566999999999993	-75.803299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:47:00	\N	0.82999999999999996	05:19:00	\N	0.819999999999999951	\N	\N	Long Point, Big Annemessex River	MD
57224	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683000000000007	-76.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:30:00	\N	0.57999999999999996	05:16:00	\N	0.560000000000000053	\N	\N	Holland Island Bar Light	MD
57225	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1082999999999998	-75.8383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:05:00	\N	0.82999999999999996	05:38:00	\N	0.819999999999999951	\N	\N	Teague Creek, Manokin River	MD
57226	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717000000000013	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:57:00	\N	1.16999999999999993	05:29:00	\N	0.780000000000000027	\N	\N	Chance	MD
57227	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017000000000024	-75.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:06:00	\N	0.92000000000000004	05:46:00	\N	0.859999999999999987	\N	\N	Sharkfin Shoal Light	MD
57228	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.226700000000001	-76.0767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	05:51:00	\N	1.16999999999999993	05:26:00	\N	0.609999999999999987	\N	\N	Hooper Strait Light	MD
57229	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.216700000000003	-75.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:22:00	\N	0.92000000000000004	06:00:00	\N	0.900000000000000022	\N	\N	Great Shoals Light, Monie Bay	MD
57230	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2616999999999976	-75.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:35:00	\N	0.92000000000000004	06:00:00	\N	0.900000000000000022	\N	\N	Roaring Point	MD
57231	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683000000000035	-75.7883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:46:00	\N	1	06:26:00	\N	0.939999999999999947	\N	\N	Whitehaven	MD
57232	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967000000000013	-76.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:39:00	\N	1.5	-04:40:00	\N	1.32000000000000006	\N	\N	Middle Hooper Island	MD
57233	Barren Island, Chesapeake Bay, Maryland (sub)	NOS	8571579	38.341700000000003	-76.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:56:00	\N	0.680000000000000049	-04:45:00	\N	1.01000000000000001	\N	\N	Barren Island	MD
57234	Salisbury, Wicomico River, Maryland (sub)	NOS	8571616	38.365000000000002	-75.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	07:24:00	\N	1.25	07:21:00	\N	1.19999999999999996	\N	\N	Salisbury	MD
57235	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.466700000000003	-76.2950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-03:00:00	\N	1.17999999999999994	-03:15:00	\N	1.10000000000000009	\N	\N	Taylors Island, Slaughter Creek	MD
57236	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067000000000021	-76.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:55:00	\N	1.40999999999999992	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
57237	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.5450000000000017	-75.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	09:28:00	\N	1	09:19:00	\N	0.969999999999999973	\N	\N	Sharptown	MD
57238	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617000000000019	-76.2082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:57:00	\N	1.27000000000000002	-03:07:00	\N	1.17999999999999994	\N	\N	Cherry Island, Beckwiths Creek	MD
57239	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.7100000000000009	-76.3349999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:48:00	\N	1.3600000000000001	-02:54:00	\N	1.17999999999999994	\N	\N	Avalon, Dogwood Harbor	MD
57240	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567000000000021	-75.9983000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:41:00	\N	1.67999999999999994	-00:18:00	\N	1.54000000000000004	\N	\N	Dover Bridge	MD
57241	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.7650000000000006	-76.3282999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:42:00	\N	1	-02:33:00	\N	0.979999999999999982	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
57242	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933000000000007	-76.1732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:45:00	\N	1.40999999999999992	-02:50:00	\N	1.25	\N	\N	Oxford	MD
57243	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7316999999999965	-76.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:47:00	\N	1.40999999999999992	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
57244	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683000000000035	-76.0949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:35:00	\N	1.59000000000000008	-02:45:00	\N	1.46999999999999997	\N	\N	Easton Point	MD
57245	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.7749999999999986	-76.2332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:52:00	\N	1.40999999999999992	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
57246	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867000000000033	-76.2216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:02:00	\N	1.17999999999999994	-02:12:00	\N	1.21999999999999997	\N	\N	St. Michaels, Miles River	MD
57247	Kent Point Marina, Chesapeake Bay, Maryland (sub)	NOS	8572467	38.8367000000000004	-76.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:29:00	\N	0.949999999999999956	-02:21:00	\N	0.969999999999999973	\N	\N	Kent Point Marina	MD
57248	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367000000000004	-76.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:28:00	\N	1.09000000000000008	-02:26:00	\N	0.959999999999999964	\N	\N	Claiborne, Eastern Bay	MD
57249	Hillsboro, Tuckahoe Creek, Maryland (sub)	NOS	8572669	38.9166999999999987	-75.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	01:18:00	\N	0.859999999999999987	01:21:00	\N	1.83000000000000007	\N	\N	Hillsboro, Tuckahoe Creek	MD
57250	Matapeake, Kent Island, Chesapeake Bay, Maryland (sub)	NOS	8572770	38.9566999999999979	-76.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-01:49:00	\N	0.949999999999999956	-01:30:00	\N	0.900000000000000022	\N	\N	Matapeake, Kent Island	MD
57251	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.966700000000003	-76.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-01:23:00	\N	1.17999999999999994	-01:30:00	\N	1.10000000000000009	\N	\N	Kent Island Narrows	MD
57252	Queenstown, Chester River, Maryland	NOS	8572867	38.996699999999997	-76.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:08:00	\N	1.27000000000000002	00:05:00	\N	1.17999999999999994	\N	\N	Queenstown	MD
57253	Love Point, Chester River, Maryland (sub)	NOS	8572955	39.0317000000000007	-76.3016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:41:00	\N	0.949999999999999956	-00:25:00	\N	1.03000000000000003	\N	\N	Love Point	MD
57254	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533000000000001	-76.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	00:14:00	\N	1.8899999999999999	00:20:00	\N	1.46999999999999997	\N	\N	Centreville Landing, Corsica River	MD
57255	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1066999999999965	-76.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:02:00	\N	1.5	00:12:00	\N	1.32000000000000006	\N	\N	Cliffs Point	MD
57256	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.1099999999999994	-76.138300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:08:00	\N	1.27000000000000002	00:09:00	\N	1.33000000000000007	\N	\N	Cliffs Wharf	MD
57257	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.1450000000000031	-76.2600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:04:00	\N	1.09000000000000008	00:02:00	\N	0.959999999999999964	\N	\N	Deep Landing, Swan Creek	MD
57258	Chestertown, Chester River, Maryland	NOS	8573343	39.2066999999999979	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	00:36:00	\N	1.77000000000000002	01:03:00	\N	1.62000000000000011	\N	\N	Chestertown	MD
57259	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967000000000013	-76.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	01:19:00	\N	1.27000000000000002	01:22:00	\N	1.17999999999999994	\N	\N	Worton Creek entrance	MD
57260	Sassafras River, Betterton, Chesapeake Bay, Maryland (sub)	NOS	8573704	39.371699999999997	-76.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	02:15:00	\N	1	02:35:00	\N	1.34000000000000008	\N	\N	Sassafras River, Betterton	MD
57261	Town Point Wharf, Elk River, Maryland (sub)	NOS	8573903	39.503300000000003	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	02:59:00	\N	0.859999999999999987	03:18:00	\N	1.73999999999999999	\N	\N	Town Point Wharf	MD
57262	Chesapeake City, Chesapeake and Delaware Canal, Maryland (sub)	NOS	8573927	39.5266999999999982	-75.8100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	-01:12:00	\N	1.28000000000000003	-00:45:00	\N	0.560000000000000053	\N	\N	Chesapeake City, Maryland	MD
57263	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733000000000033	-75.9699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	04:03:00	\N	1.8600000000000001	03:52:00	\N	1.68999999999999995	\N	\N	Charlestown, Northeast River	MD
57264	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.5750000000000028	-75.8432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	03:00:00	\N	2.27000000000000002	03:13:00	\N	2.06000000000000005	\N	\N	Old Frenchtown Wharf	MD
57265	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6032999999999973	-76.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	03:49:00	\N	1.1399999999999999	03:24:00	\N	1.51000000000000001	\N	\N	Port Deposit	MD
57266	Havre de Grace, Susquehanna River, Maryland (sub)	NOS	8574070	39.5367000000000033	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	03:27:00	\N	0.949999999999999956	03:13:00	\N	1.55000000000000004	\N	\N	Havre de Grace	MD
57267	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland (sub)	NOS	8574459	39.388300000000001	-76.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	01:31:00	\N	0.859999999999999987	01:52:00	\N	1.06000000000000005	\N	\N	Pond Point, Bush River	MD
57268	Fort McHenry Marsh, Patapsco River, Maryland (sub)	NOS	8574683	39.2616999999999976	-76.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Fort McHenry Marsh	MD
57269	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083000000000013	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	00:06:00	\N	0.949999999999999956	00:00:00	\N	1.03000000000000003	\N	\N	Hawkins Point	MD
57270	North Point, Patapsco River, Maryland	NOS	8574857	39.1966999999999999	-76.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	00:04:00	\N	1.09000000000000008	00:12:00	\N	0.930000000000000049	\N	\N	North Point	MD
57271	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1632999999999996	-76.5267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:05:00	\N	0.910000000000000031	00:03:00	\N	0.949999999999999956	\N	\N	Stony Creek	MD
57272	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1000000000000014	-76.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:38:00	\N	0.949999999999999956	-00:29:00	\N	0.890000000000000013	\N	\N	Cornfield Creek, Magothy River	MD
57273	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617000000000019	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:04:00	\N	0.770000000000000018	-00:04:00	\N	0.739999999999999991	\N	\N	Mountain Point, Magothy River	MD
57274	Brewer Point, Severn River, Maryland	NOS	8575331	39.0266999999999982	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-00:54:00	\N	0.910000000000000031	-00:45:00	\N	0.739999999999999991	\N	\N	Brewer Point	MD
57275	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583000000000013	-76.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:06:00	\N	1	-02:01:00	\N	0.92000000000000004	\N	\N	Gingerville Creek, South River	MD
57276	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.9500000000000028	-76.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:07:00	\N	0.910000000000000031	-01:51:00	\N	0.810000000000000053	\N	\N	Edgewater, South River	MD
57277	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.8999999999999986	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:11:00	\N	0.910000000000000031	-01:56:00	\N	0.810000000000000053	\N	\N	Thomas Point Shoal Light	MD
57278	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8866999999999976	-76.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:17:00	\N	1	-02:07:00	\N	0.880000000000000004	\N	\N	Rhode River (County Wharf)	MD
57279	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.841700000000003	-76.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-01:34:00	\N	0.910000000000000031	-01:39:00	\N	0.810000000000000053	\N	\N	Galesville, West River	MD
57280	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.7250000000000014	-76.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:44:00	\N	0.910000000000000031	-02:37:00	\N	0.810000000000000053	\N	\N	Rose Haven	MD
57281	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7000000000000028	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-03:05:00	\N	1	-02:47:00	\N	0.880000000000000004	\N	\N	Chesapeake Beach	MD
57282	Long Beach, Chesapeake Bay, Maryland (sub)	NOS	8577004	38.4650000000000034	-76.4732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:04:00	\N	0.770000000000000018	-03:47:00	\N	0.869999999999999996	\N	\N	Long Beach	MD
57283	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.4149999999999991	-76.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:19:00	\N	1.3600000000000001	-04:13:00	\N	1.17999999999999994	\N	\N	Broomes Island	MD
57284	Cove Point, Chesapeake Bay, Maryland (sub)	NOS	8577188	38.3917000000000002	-76.3983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:25:00	\N	0.82999999999999996	-04:10:00	\N	0.82999999999999996	\N	\N	Cove Point	MD
57285	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.0600000000000023	-76.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-07:35:00	\N	0.530000000000000027	-06:16:00	\N	0.479999999999999982	\N	\N	Cornfield Harbor, Md.	MD
57286	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.0399999999999991	-76.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-05:37:00	\N	0.770000000000000018	-05:28:00	\N	1.02000000000000002	\N	\N	Point Lookout	MD
57287	Piney Point, Potomac River, Maryland	NOS	8578240	38.1332999999999984	-76.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-07:16:00	\N	0.599999999999999978	-05:54:00	\N	0.510000000000000009	\N	\N	Piney Point, Md.	MD
57288	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233000000000018	-76.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-06:43:00	\N	0.729999999999999982	-05:18:00	\N	0.650000000000000022	\N	\N	Colton Point, Md.	MD
57289	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267000000000024	-76.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-06:05:00	\N	0.729999999999999982	-05:05:00	\N	0.650000000000000022	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
57290	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.341700000000003	-76.9766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-05:56:00	\N	0.599999999999999978	-04:48:00	\N	0.540000000000000036	\N	\N	Lower Cedar Point, Md.	MD
57291	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4532999999999987	-77.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-05:07:00	\N	0.599999999999999978	-04:08:00	\N	0.540000000000000036	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
57292	Riverside, Potomac River, Maryland	NOS	8578853	38.3866999999999976	-77.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:24:00	\N	0.530000000000000027	-03:23:00	\N	0.479999999999999982	\N	\N	Riverside, Md.	MD
57293	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.4600000000000009	-77.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-01:58:00	\N	0.67000000000000004	-00:39:00	\N	0.440000000000000002	\N	\N	Liverpool Point, Md.	MD
57294	Benedict, Patuxent River, Maryland	NOS	8579135	38.513300000000001	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-03:54:00	\N	1.82000000000000006	-03:54:00	\N	1.46999999999999997	\N	\N	Benedict	MD
57295	Indian Head, Potomac River, Maryland	NOS	8579381	38.601700000000001	-77.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-01:33:00	\N	0.729999999999999982	-00:14:00	\N	0.650000000000000022	\N	\N	Indian Head, Md.	MD
57296	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867000000000019	-77.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-00:55:00	\N	0.930000000000000049	00:10:00	\N	0.819999999999999951	\N	\N	Marshall Hall, Md.	MD
57297	Bladensburg, Anacostia River, Maryland (sub)	NOS	8579997	38.9333000000000027	-76.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	00:25:00	\N	1.12999999999999989	00:31:00	\N	1.06000000000000005	\N	\N	Bladensburg, Md.	MD
57298	Bellevue, Potomac River, DC	NOS	8590111	38.8267000000000024	-77.0267000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-00:11:00	\N	1.33000000000000007	00:34:00	\N	1.02000000000000002	\N	\N	Bellevue, D.C.	DC
57299	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.871699999999997	-76.9950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-00:06:00	\N	1.19999999999999996	00:18:00	\N	1.01000000000000001	\N	\N	Washington Naval Yard	DC
57300	Kingman Lake, Anacostia River, DC	NOS	8593545	38.8950000000000031	-76.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	00:04:00	\N	1.19999999999999996	00:22:00	\N	1.03000000000000003	\N	\N	Kingman Lake	DC
57301	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.9099999999999966	-76.9549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	00:10:00	\N	1.07000000000000006	00:29:00	\N	1.05000000000000004	\N	\N	Kenilworth Aquatic Garden	DC
57302	Franklin City, Virginia	NOS	8630055	38.0067000000000021	-75.381699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	03:00:00	\N	0.630000000000000004	02:20:00	\N	0.220000000000000001	\N	\N	Franklin City	VA
57303	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517000000000024	-75.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	02:32:00	\N	0.560000000000000053	01:51:00	\N	0.280000000000000027	\N	\N	Chincoteague Island, Blake Cove	VA
57304	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9416999999999973	-75.3466999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	02:05:00	\N	0.560000000000000053	01:44:00	\N	0.46000000000000002	\N	\N	Chincoteague Island, Oyster Bay	VA
57305	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9382999999999981	-75.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:38:00	\N	0.630000000000000004	01:17:00	\N	0.400000000000000022	\N	\N	Chincoteague Island, Lewis Creek	VA
57306	Chincoteague Channel (south end), Chincoteague Bay, Virginia (sub)	NOS	8630308	37.9067000000000007	-75.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:47:00	\N	0.689999999999999947	00:39:00	\N	0.640000000000000013	\N	\N	Chincoteague Channel (south end)	VA
57307	Harbor of Refuge, Virginia	NOS	8630316	37.9033000000000015	-75.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:35:00	\N	0.880000000000000004	00:31:00	\N	0.729999999999999982	\N	\N	Harbor of Refuge	VA
57308	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817000000000021	-75.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:13:00	\N	0.630000000000000004	00:52:00	\N	0.770000000000000018	\N	\N	Wishart Point, Bogues Bay	VA
57309	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865000000000002	-75.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:48:00	\N	1.25	00:35:00	\N	1.08000000000000007	\N	\N	Assateague Beach, Toms Cove	VA
57310	Wallops Island, Virginia	NOS	8630440	37.841700000000003	-75.4783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	-00:04:00	\N	0.309999999999999998	00:04:00	\N	1.06000000000000005	\N	\N	Wallops Island	VA
57311	Gargathy Neck, Virginia	NOS	8630637	37.7766999999999982	-75.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:27:00	\N	0.630000000000000004	01:31:00	\N	0.880000000000000004	\N	\N	Gargathy Neck	VA
57312	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6966999999999999	-75.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:12:00	\N	0.630000000000000004	01:24:00	\N	0.969999999999999973	\N	\N	Folly Creek, Metompkin Inlet	VA
57313	Metompkin Inlet, Virginia	NOS	8630901	37.6717000000000013	-75.5949999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:44:00	\N	1.25	01:01:00	\N	1.08000000000000007	\N	\N	Metompkin Inlet	VA
57314	Revel Island, Revel Creek, Virginia	NOS	8631234	37.496699999999997	-75.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:27:00	\N	1	00:35:00	\N	1.18999999999999995	\N	\N	Revel Creek, Revel Island	VA
57315	Upshur Neck, south end, Virginia	NOS	8631287	37.466700000000003	-75.7999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:14:00	\N	1.25	01:09:00	\N	1.31000000000000005	\N	\N	Upshur Neck, south end	VA
57316	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933000000000035	-75.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:56:00	\N	1.25	01:05:00	\N	1.15999999999999992	\N	\N	Great Machipongo Inlet (inside)	VA
57317	Sand Shoal Inlet (Coast Guard Station), Virginia	NOS	8631542	37.3016999999999967	-75.7783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:17:00	\N	1	00:32:00	\N	1.17999999999999994	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
57318	Oyster Harbor, Virginia	NOS	8631591	37.2882999999999996	-75.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:36:00	\N	1.12999999999999989	01:00:00	\N	1.34000000000000008	\N	\N	Oyster Harbor	VA
57319	Smith Island (Coast Guard Station), Virginia	NOS	8631874	37.1233000000000004	-75.9116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	01:29:00	\N	1.25	00:52:00	\N	1.05000000000000004	\N	\N	Smith Island (Coast Guard Station)	VA
57320	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0966999999999985	-75.9832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	00:11:00	\N	1.25	00:02:00	\N	1.18999999999999995	\N	\N	Fishermans Island	VA
57321	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2332999999999998	-76.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	00:52:00	\N	0.82999999999999996	00:33:00	\N	0.92000000000000004	\N	\N	Old Plantation Light	VA
57322	Cape Charles Harbor (USCG Wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.263300000000001	-76.019999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	01:03:00	\N	0.92000000000000004	00:45:00	\N	0.900000000000000022	\N	\N	Cape Charles Harbor	VA
57323	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia (sub)	NOS	8632869	37.5566999999999993	-75.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	03:13:00	\N	0.82999999999999996	02:35:00	\N	0.660000000000000031	\N	\N	Gaskins Point, Occohannock Creek	VA
57324	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6666999999999987	-75.8332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	03:33:00	\N	0.82999999999999996	03:11:00	\N	0.699999999999999956	\N	\N	Harborton, Pungoteague Creek	VA
57325	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117000000000004	-75.756699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:19:00	\N	0.82999999999999996	03:55:00	\N	0.709999999999999964	\N	\N	Onancock, Onancock Creek	VA
57326	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.763300000000001	-75.7733000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	03:59:00	\N	1.25	03:41:00	\N	0.780000000000000027	\N	\N	Chesconessex Creek, Schooner Bay	VA
57327	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7982999999999976	-75.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:12:00	\N	0.82999999999999996	04:02:00	\N	0.640000000000000013	\N	\N	Watts Island	VA
57328	Tangier Island, Chesapeake Bay, Virginia (sub)	NOS	8633532	37.8282999999999987	-75.993300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:16:00	\N	0.75	03:58:00	\N	0.599999999999999978	\N	\N	Tangier Island	VA
57329	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.8500000000000014	-75.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:47:00	\N	0.82999999999999996	04:06:00	\N	0.900000000000000022	\N	\N	Guard Shore	VA
57330	Muddy Creek Entrance, Chesapeake Bay, Virginia	NOS	8633604	37.8549999999999969	-75.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:51:00	\N	0.82999999999999996	04:14:00	\N	0.859999999999999987	\N	\N	Muddy Creek Entrance	VA
57331	Alexandria, Potomac River, Virginia	NOS	8634214	38.8049999999999997	-77.0383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-00:11:00	\N	1.33000000000000007	00:18:00	\N	0.959999999999999964	\N	\N	Alexandria, Va.	VA
57332	Quantico, Potomac River, Virginia	NOS	8634689	38.5200000000000031	-77.2866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-02:04:00	\N	0.67000000000000004	-00:52:00	\N	0.510000000000000009	\N	\N	Quantico, Va.	VA
57333	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183000000000021	-77.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-02:32:00	\N	0.67000000000000004	-01:28:00	\N	0.479999999999999982	\N	\N	Aquia Creek, Va.	VA
57334	Mathias Point, Potomac River, Virginia	NOS	8634892	38.398299999999999	-77.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:56:00	\N	0.67000000000000004	-04:00:00	\N	0.440000000000000002	\N	\N	Mathias Point, Va.	VA
57335	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.2550000000000026	-77.4099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-00:41:00	\N	1.33000000000000007	-00:39:00	\N	0.880000000000000004	\N	\N	Massaponax	VA
57336	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2432999999999979	-77.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-01:57:00	\N	0.67000000000000004	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
57337	Rappahannock Bend, Virginia (sub)	NOS	8635257	38.2132999999999967	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-02:30:00	\N	0.200000000000000011	-01:35:00	\N	0.729999999999999982	\N	\N	Park Turn	VA
57338	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1732999999999976	-77.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-03:02:00	\N	0.67000000000000004	-02:19:00	\N	0.680000000000000049	\N	\N	Port Royal	VA
57339	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983000000000018	-76.7349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-06:14:00	\N	0.67000000000000004	-04:51:00	\N	0.540000000000000036	\N	\N	Mount Holly, Nomini Creek, Va.	VA
57340	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417000000000002	-76.6132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-07:03:00	\N	0.67000000000000004	-05:35:00	\N	0.540000000000000036	\N	\N	Ragged Point, Coles Neck, Va.	VA
57341	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.0900000000000034	-77.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:41:00	\N	0.660000000000000031	-03:53:00	\N	0.540000000000000036	\N	\N	Saunders Wharf	VA
57342	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317000000000007	-76.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-06:53:00	\N	0.67000000000000004	-05:46:00	\N	0.440000000000000002	\N	\N	Kinsale, Yeocomico River, Va.	VA
57343	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.996699999999997	-76.466700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-07:05:00	\N	0.67000000000000004	-06:00:00	\N	0.440000000000000002	\N	\N	Travis Point, Coan River, Va.	VA
57344	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.9299999999999997	-76.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	05:18:00	\N	0.82999999999999996	04:40:00	\N	0.709999999999999964	\N	\N	Tappahannock	VA
57345	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8866999999999976	-76.2667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:45:00	\N	0.299999999999999989	06:41:00	\N	0.299999999999999989	\N	\N	Sunnybank, Little Wicomico River	VA
57346	Wares Wharf, Rappahannock River, Virginia (sub)	NOS	8635985	37.8733000000000004	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	04:34:00	\N	0.330000000000000016	04:04:00	\N	0.75	\N	\N	Wares Wharf	VA
57347	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8466999999999985	-76.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:37:00	\N	0.82999999999999996	04:15:00	\N	0.489999999999999991	\N	\N	Glebe Point, Great Wicomico River	VA
57348	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8132999999999981	-76.2750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:14:00	\N	0.409999999999999976	03:58:00	\N	0.409999999999999976	\N	\N	Fleeton Point	VA
57349	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.8049999999999997	-76.2682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:11:00	\N	0.409999999999999976	03:58:00	\N	0.409999999999999976	\N	\N	Great Wicomico River Light	VA
57350	Bayport, Rappahannock River, Virginia	NOS	8636261	37.7550000000000026	-76.6732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:51:00	\N	0.82999999999999996	03:22:00	\N	0.67000000000000004	\N	\N	Bayport	VA
57351	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683000000000021	-76.486699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:05:00	\N	0.82999999999999996	02:37:00	\N	0.550000000000000044	\N	\N	Millenbeck, Corrotoman River	VA
57352	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.6499999999999986	-76.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:57:00	\N	1.66999999999999993	03:34:00	\N	1.40999999999999992	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
57353	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.6499999999999986	-76.5750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:09:00	\N	0.82999999999999996	02:50:00	\N	0.589999999999999969	\N	\N	Urbanna	VA
57354	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	06:18:00	\N	1.66999999999999993	06:03:00	\N	1.37000000000000011	\N	\N	Northbury	VA
57355	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5966999999999985	-76.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	03:12:00	\N	0.409999999999999976	02:48:00	\N	0.409999999999999976	\N	\N	Windmill Point Light	VA
57356	Lester Manor, Pamunkey River, Virginia (sub)	NOS	8636653	37.5833000000000013	-76.9899999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	05:00:00	\N	0.82999999999999996	04:45:00	\N	1.05000000000000004	\N	\N	Lester Manor	VA
57357	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833000000000013	-76.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:42:00	\N	0.82999999999999996	02:28:00	\N	0.550000000000000044	\N	\N	Mill Creek (Grey Point)	VA
57358	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5482999999999976	-76.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:04:00	\N	0.82999999999999996	01:36:00	\N	0.510000000000000009	\N	\N	Jackson Creek, Deltaville	VA
57359	West Point, York River, Virginia	NOS	8636769	37.5349999999999966	-76.7933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:38:00	\N	0.82999999999999996	02:12:00	\N	1.1399999999999999	\N	\N	West Point	VA
57360	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067000000000021	-76.4167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:14:00	\N	0.82999999999999996	01:34:00	\N	0.550000000000000044	\N	\N	Dixie	VA
57361	Roane Point, York River, Virginia	NOS	8636969	37.4466999999999999	-76.7082999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	01:50:00	\N	0.82999999999999996	01:47:00	\N	1.1399999999999999	\N	\N	Roane Point	VA
57362	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117000000000033	-76.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:00:00	\N	0.82999999999999996	-00:06:00	\N	1.02000000000000002	\N	\N	Belleville	VA
57363	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.3900000000000006	-76.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:32:00	\N	0.82999999999999996	-00:02:00	\N	0.67000000000000004	\N	\N	Wolf Trap Light	VA
57364	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733000000000004	-76.3466999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:02:00	\N	0.82999999999999996	-00:17:00	\N	0.979999999999999982	\N	\N	Mobjack, East River	VA
57365	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.2999999999999972	-76.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	-00:03:00	\N	1.58000000000000007	-00:11:00	\N	0.979999999999999982	\N	\N	Browns Bay	VA
57366	Cheatham Annex, York River, Virginia	NOS	8637472	37.2916999999999987	-76.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:40:00	\N	0.82999999999999996	00:48:00	\N	1.02000000000000002	\N	\N	Cheatham Annex	VA
57367	Gloucester Point, York River, Virginia (sub)	NOS	8637624	37.246699999999997	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:11:00	\N	1	00:10:00	\N	0.979999999999999982	\N	\N	Gloucester Point	VA
57368	Tue Marshes Light, York River, Virginia	NOS	8637663	37.2349999999999994	-76.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:03:00	\N	0.82999999999999996	00:03:00	\N	0.900000000000000022	\N	\N	Tue Marshes Light	VA
57369	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.2299999999999969	-76.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:15:00	\N	0.82999999999999996	00:18:00	\N	0.900000000000000022	\N	\N	Yorktown, Goodwin Neck	VA
57370	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1082999999999998	-76.3182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:02:00	\N	0.969999999999999973	-00:07:00	\N	0.969999999999999973	\N	\N	Messick Point, Back River	VA
57371	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.003300000000003	-76.3149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:09:00	\N	0.82999999999999996	00:01:00	\N	1.02000000000000002	\N	\N	Old Point Comfort	VA
57372	Newport News, James River, Virginia	NOS	8638379	36.9733000000000018	-76.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:28:00	\N	0.82999999999999996	00:29:00	\N	1.08000000000000007	\N	\N	Newport News	VA
57373	Huntington Park, James River, Virginia	NOS	8638401	37.013300000000001	-76.4582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:39:00	\N	0.92000000000000004	00:38:00	\N	1.07000000000000006	\N	\N	Huntington Park	VA
57374	Town Point, Nansemond River, Virginia	NOS	8638406	36.8832999999999984	-76.5083000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:44:00	\N	0.82999999999999996	00:37:00	\N	1.21999999999999997	\N	\N	Town Point	VA
57375	Menchville, James River, Virginia	NOS	8638407	37.0816999999999979	-76.5250000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	01:19:00	\N	0.82999999999999996	01:03:00	\N	1.06000000000000005	\N	\N	Menchville	VA
57376	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8382999999999967	-76.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	01:03:00	\N	1.66999999999999993	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
57377	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9832999999999998	-76.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	01:38:00	\N	0.82999999999999996	01:34:00	\N	1.1399999999999999	\N	\N	Smithfield, Pagan River	VA
57378	Mulberry Point, Fort Eustis, Virginia	NOS	8638419	37.1366999999999976	-76.6333000000000055	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:26:00	\N	0.82999999999999996	02:05:00	\N	0.979999999999999982	\N	\N	Mulberry Point, Fort Eustis	VA
57379	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0566999999999993	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	01:39:00	\N	1.16999999999999993	01:17:00	\N	1	\N	\N	Burwell Bay	VA
57380	Kingsmill, James River, Virginia (sub)	NOS	8638424	37.2199999999999989	-76.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:26:00	\N	1.33000000000000007	02:05:00	\N	0.939999999999999947	\N	\N	Kingsmill	VA
57381	Jamestown Island, Church Point, Virginia	NOS	8638432	37.2066999999999979	-76.7783000000000015	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:36:00	\N	0.82999999999999996	03:03:00	\N	0.819999999999999951	\N	\N	Jamestown Island, Church Point	VA
57382	Scotland, James River, Virginia (sub)	NOS	8638433	37.1850000000000023	-76.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	03:13:00	\N	1.08000000000000007	02:44:00	\N	0.780000000000000027	\N	\N	Scotland	VA
57383	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.3449999999999989	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	05:03:00	\N	0.82999999999999996	04:44:00	\N	0.900000000000000022	\N	\N	Wright Island Landing	VA
57384	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.263300000000001	-76.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	04:26:00	\N	0.82999999999999996	04:01:00	\N	0.780000000000000027	\N	\N	Ferry Point (bridge)	VA
57385	Claremont, James River, Virginia	NOS	8638449	37.2316999999999965	-76.9483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	04:25:00	\N	1.16999999999999993	03:51:00	\N	0.760000000000000009	\N	\N	Claremont	VA
57386	Sturgeon Point, James River, Virginia	NOS	8638455	37.3066999999999993	-77.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	05:09:00	\N	0.82999999999999996	04:37:00	\N	0.859999999999999987	\N	\N	Sturgeon Point	VA
57387	Jordan Point, James River, Virginia	NOS	8638476	37.3132999999999981	-77.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	06:39:00	\N	0.82999999999999996	06:16:00	\N	1.02000000000000002	\N	\N	Jordan Point	VA
57388	Haxall, James River, Virginia	NOS	8638478	37.3733000000000004	-77.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:53:00	\N	1.33000000000000007	-04:10:00	\N	0.989999999999999991	\N	\N	Haxall	VA
57389	Meadowville, James River, Virginia	NOS	8638486	37.378300000000003	-77.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:17:00	\N	1.33000000000000007	-03:46:00	\N	1.05000000000000004	\N	\N	Meadowville	VA
57390	Puddledock Sand & Gravel, Appomattox River, Virginia (sub)	NOS	8638489	37.2667000000000002	-77.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-04:32:00	\N	1.07000000000000006	-03:49:00	\N	1	\N	\N	Puddledock, Appomattox River	VA
57392	Richmond River Locks, James River, Virginia (sub)	NOS	8638495	37.5249999999999986	-77.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-03:26:00	\N	1.33000000000000007	-03:16:00	\N	1.15999999999999992	\N	\N	Richmond (river locks)	VA
57393	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9166999999999987	-76.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:40:00	\N	0.82999999999999996	00:42:00	\N	1.05000000000000004	\N	\N	Pig Point	VA
57394	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917000000000002	-76.3383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:04:00	\N	0.82999999999999996	00:18:00	\N	1.06000000000000005	\N	\N	Craney Island Light	VA
57395	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.851700000000001	-76.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:20:00	\N	0.82999999999999996	00:23:00	\N	1.1399999999999999	\N	\N	Norfolk	VA
57396	Portsmouth, Naval Shipyard, Elizabeth River, Virginia (sub)	NOS	8638660	36.8216999999999999	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:10:00	\N	1.16999999999999993	00:08:00	\N	1.12999999999999989	\N	\N	Portsmouth, Naval Shipyard	VA
57397	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117000000000033	-76.1749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	00:09:00	\N	1.16999999999999993	00:08:00	\N	1.01000000000000001	\N	\N	Little Creek, NAB	VA
57398	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.861699999999999	-76.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	02:56:00	\N	0.82999999999999996	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
58317	Selby, California	NOS	9415142	38.0583000000000027	-122.242999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:04:00	0	\N	01:29:00	0.599999999999999978	\N	\N	\N	Selby	CA
57399	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933000000000035	-76.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	02:48:00	\N	0.82999999999999996	01:52:00	\N	0.67000000000000004	\N	\N	Bayville	VA
57400	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067000000000007	-76.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	00:38:00	\N	1.08000000000000007	00:40:00	\N	0.880000000000000004	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
57401	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033000000000015	-76.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	01:15:00	\N	1.08000000000000007	01:15:00	\N	0.680000000000000049	\N	\N	Long Creek	VA
57402	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	02:43:00	\N	0.82999999999999996	02:05:00	\N	0.650000000000000022	\N	\N	Brown Cove	VA
57403	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9016999999999982	-76.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	02:00:00	\N	0.92000000000000004	02:05:00	\N	0.560000000000000053	\N	\N	Broad Bay Canal	VA
57404	Cape Henry, Virginia	NOS	8638999	36.9299999999999997	-76.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:36:00	\N	0.930000000000000049	00:31:00	\N	0.959999999999999964	\N	\N	Cape Henry	VA
57405	Virginia Beach, Virginia	NOS	8639168	36.8432999999999993	-75.9716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:16:00	\N	1.07000000000000006	00:15:00	\N	1.07000000000000006	\N	\N	Virginia Beach	VA
57406	Inside channel, Rudee Inlet, Virginia (sub)	NOS	8639207	36.8316999999999979	-75.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:16:00	\N	1	00:17:00	\N	1.02000000000000002	\N	\N	Rudee Inlet, interior channel	VA
57407	Rudee Inlet entrance, Virginia	NOS	8639208	36.8316999999999979	-75.9682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:02:00	\N	0.859999999999999987	00:02:00	\N	1.01000000000000001	\N	\N	Rudee Inlet entrance	VA
57408	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.8250000000000028	-75.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:16:00	\N	1	00:18:00	\N	1.03000000000000003	\N	\N	Rudee Heights, Lake Wesley	VA
57409	Lake Rudee, south end, Virginia	NOS	8639219	36.8250000000000028	-75.9817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:19:00	\N	1.07000000000000006	00:20:00	\N	1.05000000000000004	\N	\N	Lake Rudee, south end	VA
57410	Deep Creek Entrance, Elizabeth River, Virginia	NOS	8639414	36.7550000000000026	-76.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:18:00	\N	1.25	00:22:00	\N	1.20999999999999996	\N	\N	Deep Creek Entrance	VA
57411	Sandbridge, Virginia	NOS	8639428	36.6916999999999973	-75.9200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:07:00	\N	1.04000000000000004	00:07:00	\N	1.04000000000000004	\N	\N	Sandbridge	VA
57412	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.101700000000001	-75.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:02:00	\N	1.42999999999999994	-00:01:00	\N	1.01000000000000001	\N	\N	Kitty Hawk (ocean)	NC
57413	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.9099999999999966	-75.591700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55918	00:01:00	\N	1.42999999999999994	-00:05:00	\N	1.04000000000000004	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
57414	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7982999999999976	-75.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	01:17:00	\N	0.140000000000000013	01:37:00	\N	0.469999999999999973	\N	\N	Roanoke Sound Channel	NC
57415	Old House Channel, North Carolina	NOS	8652648	35.7766999999999982	-75.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	00:28:00	\N	0.209999999999999992	00:34:00	\N	0.660000000000000031	\N	\N	Old House Channel	NC
57416	Oregon Inlet Channel, North Carolina	NOS	8652657	35.773299999999999	-75.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	-00:34:00	\N	0.429999999999999993	-00:09:00	\N	1.22999999999999998	\N	\N	Oregon Inlet Channel	NC
57417	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.773299999999999	-75.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	-00:55:00	\N	0.640000000000000013	-00:17:00	\N	1.8899999999999999	\N	\N	Oregon Inlet Bridge	NC
57418	Davis Slough, North Carolina	NOS	8652737	35.7483000000000004	-75.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	-00:01:00	\N	0.28999999999999998	00:09:00	\N	0.849999999999999978	\N	\N	Davis Slough	NC
57419	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.5949999999999989	-75.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	01:36:00	\N	0.689999999999999947	02:03:00	\N	0.790000000000000036	\N	\N	Rodanthe, Pamlico Sound	NC
57420	Ocracoke, Ocracoke Island, North Carolina (sub)	NOS	8654792	35.115000000000002	-75.9882999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:47:00	\N	0.5	00:15:00	\N	0.340000000000000024	\N	\N	Ocracoke, Ocracoke Island	NC
57421	Core Creek Bridge, North Carolina	NOS	8656084	34.8250000000000028	-76.6899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:46:00	\N	0.82999999999999996	01:26:00	\N	0.680000000000000049	\N	\N	Core Creek Bridge	NC
57422	North River Bridge, North Carolina	NOS	8656225	34.7916999999999987	-76.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	03:08:00	\N	0.67000000000000004	02:25:00	\N	0.589999999999999969	\N	\N	North River Bridge	NC
57423	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683000000000035	-76.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:13:00	\N	1	01:03:00	\N	1.03000000000000003	\N	\N	Newport River (Yacht Club)	NC
57424	Gallant Channel, North Carolina	NOS	8656451	34.7282999999999973	-76.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:44:00	\N	1.25	00:49:00	\N	1.01000000000000001	\N	\N	Gallant Channel	NC
57425	Morehead City, North Carolina	NOS	8656496	34.7182999999999993	-76.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:27:00	\N	1.25	00:26:00	\N	1.04000000000000004	\N	\N	Morehead City	NC
57426	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7182999999999993	-76.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:02:00	\N	0.82999999999999996	00:48:00	\N	0.790000000000000036	\N	\N	Atlantic Beach Bridge	NC
57427	Harkers Island Bridge, North Carolina	NOS	8656503	34.7150000000000034	-76.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	02:31:00	\N	0.67000000000000004	02:08:00	\N	0.520000000000000018	\N	\N	Harkers Island Bridge	NC
57428	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117000000000004	-76.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:48:00	\N	1.16999999999999993	00:52:00	\N	0.949999999999999956	\N	\N	Beaufort, Taylor Creek	NC
57429	Lenoxville Point, North Carolina	NOS	8656539	34.7083000000000013	-76.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:11:00	\N	1	01:18:00	\N	0.800000000000000044	\N	\N	Lenoxville Point	NC
57430	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7032999999999987	-76.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:27:00	\N	0.82999999999999996	01:25:00	\N	0.660000000000000031	\N	\N	Channel Marker Lt. 59	NC
57431	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7000000000000028	-76.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	02:14:00	\N	0.82999999999999996	01:47:00	\N	0.530000000000000027	\N	\N	Coral Bay, Atlantic Beach	NC
57432	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983000000000033	-76.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:11:00	\N	1.66999999999999993	00:07:00	\N	1.07000000000000006	\N	\N	Beaufort Inlet Channel Range	NC
57433	Fort Macon, USCG Station, North Carolina	NOS	8656571	34.6983000000000033	-76.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:18:00	\N	1.25	00:17:00	\N	1.03000000000000003	\N	\N	Fort Macon, USCG Station	NC
57434	Triple S Marina, Bogue Sd., North Carolina	NOS	8656583	34.6950000000000003	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:28:00	\N	1.16999999999999993	00:35:00	\N	0.930000000000000049	\N	\N	Triple ESS Marina, Bogue Sd.	NC
57435	Triple S Pier, Atlantic Beach, North Carolina (sub)	NOS	8656590	34.6933000000000007	-76.7116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:01:00	\N	1.25	-00:02:00	\N	1.22999999999999998	\N	\N	Atlantic Beach	NC
57436	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6082999999999998	-76.5283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	-00:22:00	\N	1.25	-00:22:00	\N	1.14999999999999991	\N	\N	Cape Lookout (ocean)	NC
57437	New River Inlet, North Carolina	NOS	8657167	34.533299999999997	-77.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:17:00	\N	0.82999999999999996	00:16:00	\N	0.979999999999999982	\N	\N	New River Inlet	NC
57438	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517000000000024	-77.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	-00:01:00	\N	1.33000000000000007	00:03:00	\N	1.39999999999999991	\N	\N	Ocean City Beach (fishing pier)	NC
57439	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0566999999999993	-77.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-00:58:00	\N	1	-00:36:00	\N	0.979999999999999982	\N	\N	Orton Point	NC
57440	Wilmington Beach, North Carolina	NOS	8658559	34.0317000000000007	-77.8932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:10:00	\N	1.25	00:18:00	\N	1.39999999999999991	\N	\N	Wilmington Beach	NC
57441	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.003300000000003	-77.9549999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-01:18:00	\N	1.07000000000000006	-00:54:00	\N	0.959999999999999964	\N	\N	Reaves Point	NC
57442	Sunny Point Army Base, Wharf no.1, Cape Fear River, North Carolina	NOS	8658654	33.990000000000002	-77.9566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-01:45:00	\N	0.930000000000000049	-01:03:00	\N	0.949999999999999956	\N	\N	Sunny Point Army Base, Wharf no.1	NC
57443	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617000000000004	-77.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-01:52:00	\N	0.930000000000000049	-01:17:00	\N	0.939999999999999947	\N	\N	Federal Point	NC
57444	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.8800000000000026	-78.0016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-02:43:00	\N	1.12999999999999989	-02:06:00	\N	1.05000000000000004	\N	\N	Bald Head	NC
57445	Southport, Cape Fear River, North Carolina (sub)	NOS	8659084	33.9149999999999991	-78.0182999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-02:22:00	\N	1	-01:49:00	\N	0.989999999999999991	\N	\N	Southport	NC
57446	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967000000000027	-78.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	-02:45:00	\N	1.25	-02:02:00	\N	1.03000000000000003	\N	\N	Fort Caswell	NC
57447	Oak Island, Yaupon Beach, North Carolina (sub)	NOS	8659182	33.9016999999999982	-78.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	-00:05:00	\N	0.839999999999999969	-00:05:00	\N	0.939999999999999947	\N	\N	Oak Island, Yaupon Beach	NC
57448	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.9149999999999991	-78.3733000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:55:00	\N	1	00:43:00	\N	0.910000000000000031	\N	\N	Shallotte Inlet (Bowen Point)	NC
57449	Sunset Beach Pier, North Carolina (sub)	NOS	8659897	33.865000000000002	-78.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	-00:03:00	\N	1.1100000000000001	00:02:00	\N	0.969999999999999973	\N	\N	Sunset Beach Pier	NC
57450	Little River Neck, north end, South Carolina	NOS	8660098	33.8699999999999974	-78.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:46:00	\N	0.839999999999999969	00:32:00	\N	0.92000000000000004	\N	\N	Little River Neck, north end	SC
57451	Little River (town), South Carolina	NOS	8660121	33.8699999999999974	-78.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:39:00	\N	0.790000000000000036	00:13:00	\N	0.839999999999999969	\N	\N	Little River (town)	SC
57452	Dunn Sound, north end, South Carolina	NOS	8660147	33.8599999999999994	-78.5799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:40:00	\N	0.839999999999999969	00:25:00	\N	0.930000000000000049	\N	\N	Dunn Sound, north end	SC
57453	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8582999999999998	-78.5699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:41:00	\N	0.800000000000000044	00:15:00	\N	0.910000000000000031	\N	\N	Dunn Sound, Little River Inlet	SC
57454	Nixon Crossroads, South Carolina	NOS	8660166	33.8549999999999969	-78.6483000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:51:00	\N	0.680000000000000049	00:27:00	\N	0.780000000000000027	\N	\N	Nixon Crossroads	SC
57455	Dunn Sound, west end, South Carolina	NOS	8660195	33.851700000000001	-78.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:36:00	\N	1	00:29:00	\N	0.959999999999999964	\N	\N	Dunn Sound, west end	SC
57456	Cherry Grove (inside), South Carolina	NOS	8660265	33.8350000000000009	-78.6333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:44:00	\N	0.739999999999999991	00:40:00	\N	0.92000000000000004	\N	\N	Cherry Grove (inside)	SC
57457	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367000000000004	-78.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	-00:07:00	\N	0.900000000000000022	-00:06:00	\N	0.989999999999999991	\N	\N	Hog Inlet Pier	SC
57458	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.8350000000000009	-79.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	07:28:00	\N	0.739999999999999991	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
57459	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.8299999999999983	-78.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	08:32:00	\N	0.57999999999999996	08:17:00	\N	0.200000000000000011	\N	\N	Grahamville	SC
57460	Myrtle Beach Airport, South Carolina	NOS	8660401	33.8200000000000003	-78.7182999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:47:00	\N	0.839999999999999969	01:09:00	\N	0.560000000000000053	\N	\N	Myrtle Beach Airport	SC
57461	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.7999999999999972	-79.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	07:30:00	\N	0.739999999999999991	07:25:00	\N	0.200000000000000011	\N	\N	Pitch Landing	SC
57462	North Myrtle Beach, South Carolina	NOS	8660642	33.7667007446289062	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:12:00	\N	0.839999999999999969	02:15:00	\N	0.359999999999999987	\N	\N	North Myrtle Beach, ICWW	SC
57463	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.7449999999999974	-79.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	06:20:00	\N	0.890000000000000013	06:09:00	\N	0.280000000000000027	\N	\N	Keysfield	SC
57464	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7132999999999967	-78.9217000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:18:00	\N	0.890000000000000013	02:56:00	\N	0.349999999999999978	\N	\N	Myrtle Beach, Combination Bridge	SC
57465	Socastee Bridge, South Carolina	NOS	8660983	33.6867000000000019	-79.0049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:41:00	\N	0.739999999999999991	03:27:00	\N	0.409999999999999976	\N	\N	Socastee Bridge	SC
57466	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6666999999999987	-79.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	05:35:00	\N	0.369999999999999996	05:01:00	\N	0.380000000000000004	\N	\N	Enterprise Landing	SC
57467	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.6599999999999966	-79.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	05:24:00	\N	0.680000000000000049	04:33:00	\N	0.330000000000000016	\N	\N	Yauhannah Bridge	SC
57468	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.601700000000001	-79.118300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:43:00	\N	0.839999999999999969	03:59:00	\N	0.46000000000000002	\N	\N	Little Bull Creek entrance, Bull Creek	SC
57469	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6082999999999998	-79.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	05:20:00	\N	0.530000000000000027	04:48:00	\N	0.200000000000000011	\N	\N	Lower Topsaw Landing	SC
57470	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5966999999999985	-79.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:22:00	\N	0.790000000000000036	03:36:00	\N	0.479999999999999982	\N	\N	Bull Creek entrance	SC
57471	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6032999999999973	-79.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	06:13:00	\N	1.05000000000000004	06:00:00	\N	0.359999999999999987	\N	\N	Rhems, Black Mingo Creek, Black River	SC
57472	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.5600000000000023	-79.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:00:00	\N	0.839999999999999969	03:11:00	\N	0.530000000000000027	\N	\N	Wachesaw Landing	SC
57473	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5516999999999967	-79.0366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	01:28:00	\N	0.680000000000000049	00:57:00	\N	0.849999999999999978	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
57474	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5516999999999967	-79.1766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:12:00	\N	0.680000000000000049	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
57475	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.5450000000000017	-79.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	01:36:00	\N	0.949999999999999956	01:01:00	\N	0.859999999999999987	\N	\N	Smith's Dock	SC
57476	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5416999999999987	-79.0283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	01:18:00	\N	0.839999999999999969	00:40:00	\N	0.839999999999999969	\N	\N	Divine's Dock	SC
57477	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.5349999999999966	-79.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:39:00	\N	0.839999999999999969	04:23:00	\N	0.469999999999999973	\N	\N	Winea Plantation, Black River	SC
57478	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317000000000007	-79.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	01:32:00	\N	0.949999999999999956	00:52:00	\N	0.839999999999999969	\N	\N	Allston Creek	SC
57479	Oaks Creek, 0.5 mi. above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.5300000000000011	-79.0433000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	01:03:00	\N	0.949999999999999956	00:38:00	\N	0.849999999999999978	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
57480	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5116999999999976	-79.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:09:00	\N	0.890000000000000013	03:29:00	\N	0.469999999999999973	\N	\N	Black River (south of Dunbar)	SC
57481	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.4949999999999974	-79.4616999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	06:04:00	\N	1.05000000000000004	05:38:00	\N	0.369999999999999996	\N	\N	Mt. Pleasant Plantation, Black River	SC
57482	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4832999999999998	-79.178299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:39:00	\N	0.790000000000000036	02:38:00	\N	0.530000000000000027	\N	\N	Arundel Plantation	SC
57483	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4682999999999993	-79.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:06:00	\N	0.680000000000000049	02:21:00	\N	0.689999999999999947	\N	\N	South of Sam Worth Game Management Area	SC
57484	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4716999999999985	-79.1016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	03:02:00	\N	0.75	01:10:00	\N	0.57999999999999996	\N	\N	Litchfield Beach bridge	SC
57485	Carr Creek, 1 mile above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.4650000000000034	-79.1867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:00:00	\N	0.839999999999999969	02:13:00	\N	0.689999999999999947	\N	\N	Carr Creek, 1 mile above entrance	SC
57486	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.4549999999999983	-79.2049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:02:00	\N	0.890000000000000013	02:16:00	\N	0.680000000000000049	\N	\N	Weymouth Plantation	SC
57487	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483000000000033	-79.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:42:00	\N	1	00:16:00	\N	0.869999999999999996	\N	\N	Midway Inlet North, Pawleys Island	SC
57488	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.4350000000000023	-79.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:53:00	\N	0.790000000000000036	01:58:00	\N	0.67000000000000004	\N	\N	Hagley Landing	SC
57489	Cumberland, Sampit River, South Carolina	NOS	8662216	33.3699999999999974	-79.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:29:00	\N	0.739999999999999991	02:42:00	\N	0.770000000000000018	\N	\N	Cumberland	SC
57490	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633000000000024	-79.355000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:22:00	\N	0.739999999999999991	02:15:00	\N	0.729999999999999982	\N	\N	Jacobs Wharf	SC
57491	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.3049999999999997	-79.678299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	06:30:00	\N	0.369999999999999996	04:15:00	\N	0.220000000000000001	\N	\N	Jamestown Bridge, Santee River	SC
57492	South Island Ferry, Intracoastal Waterway, South Carolina	NOS	8662549	33.2516999999999996	-79.2682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:25:00	\N	0.739999999999999991	00:54:00	\N	0.709999999999999964	\N	\N	South Island Ferry, Intracoastal Waterway	SC
57493	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.2449999999999974	-79.5216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:47:00	\N	0.739999999999999991	02:28:00	\N	0.450000000000000011	\N	\N	Pleasant Hill Landing, Santee River	SC
57494	South Island Plantation (C.G. Station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.2349999999999994	-79.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:36:00	\N	0.839999999999999969	00:35:00	\N	0.739999999999999991	\N	\N	South Island Plantation (C.G. Station)	SC
57495	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233000000000018	-79.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:25:00	\N	1.05000000000000004	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
57496	North Santee Bridge, South Carolina	NOS	8662793	33.2100000000000009	-79.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:54:00	\N	0.739999999999999991	01:09:00	\N	0.719999999999999973	\N	\N	North Santee Bridge	SC
57497	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.1950000000000003	-79.2750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:00:00	\N	0.949999999999999956	00:16:00	\N	0.770000000000000018	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
57498	U.S. Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.1850000000000023	-79.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:43:00	\N	0.949999999999999956	00:43:00	\N	0.780000000000000027	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
57499	Georgetown, Sampit River, South Carolina	NOS	8662926	33.361699999999999	-79.2800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:09:00	\N	0.790000000000000036	01:25:00	\N	0.709999999999999964	\N	\N	Georgetown	SC
57500	Cape Romain, South Carolina	NOS	8663101	33.0249999999999986	-79.3482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:17:00	\N	0.890000000000000013	-00:22:00	\N	0.890000000000000013	\N	\N	Cape Romain	SC
57501	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.1400000000000006	-79.2450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:17:00	\N	0.949999999999999956	-00:03:00	\N	0.800000000000000044	\N	\N	Cedar Island, North Santee Bay	SC
57502	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.1199999999999974	-79.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:08:00	\N	0.790000000000000036	-00:16:00	\N	0.780000000000000027	\N	\N	Cedar Island Point, South Santee River	SC
57503	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1082999999999998	-79.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:53:00	\N	0.790000000000000036	00:40:00	\N	0.869999999999999996	\N	\N	Casino Creek, ICWW	SC
57504	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.0949999999999989	-79.8083000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	04:12:00	\N	1.41999999999999993	04:37:00	\N	0.560000000000000053	\N	\N	Quinby Creek bridge, East Branch	SC
57505	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.0949999999999989	-79.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:53:00	\N	0.890000000000000013	03:19:00	\N	0.340000000000000024	\N	\N	Pimlico, West Branch	SC
57506	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0782999999999987	-79.4599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:24:00	\N	0.890000000000000013	00:31:00	\N	0.930000000000000049	\N	\N	McClellanville, Jeremy Creek	SC
57507	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0782999999999987	-79.9249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:51:00	\N	1.62999999999999989	02:56:00	\N	0.530000000000000027	\N	\N	Old Rice Mill, West Branch	SC
57508	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767000000000024	-79.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:43:00	\N	1.37000000000000011	03:43:00	\N	0.540000000000000036	\N	\N	Richmond Plantation, East Branch	SC
57509	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0716999999999999	-79.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:49:00	\N	1.79000000000000004	03:14:00	\N	0.630000000000000004	\N	\N	Bonneau Ferry, East Branch	SC
57510	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583000000000027	-79.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:07:00	\N	1.58000000000000007	02:21:00	\N	0.680000000000000049	\N	\N	Dupont, Dean Hall	SC
57511	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.0549999999999997	-79.8799999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:20:00	\N	1.32000000000000006	03:24:00	\N	0.560000000000000053	\N	\N	Blessing Plantation, East Branch	SC
57512	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.0399999999999991	-79.5600000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:37:00	\N	1	00:22:00	\N	0.949999999999999956	\N	\N	Buck Hall, Awendaw Creek	SC
57513	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.033299999999997	-79.5349999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:36:00	\N	0.949999999999999956	00:03:00	\N	0.930000000000000049	\N	\N	Harbor River entrance	SC
57514	General Dynamics Pier, Cooper River, South Carolina (sub)	NOS	8664022	33.0082999999999984	-79.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:24:00	\N	1.1100000000000001	01:40:00	\N	0.839999999999999969	\N	\N	General Dynamics Pier	SC
57515	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:07:00	\N	0.949999999999999956	-00:06:00	\N	0.930000000000000049	\N	\N	Five Fathom Creek entrance	SC
57516	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.9949999999999974	-79.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	05:57:00	\N	0.790000000000000036	05:44:00	\N	0.170000000000000012	\N	\N	Back River Reservoir, West Branch	SC
57517	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367000000000019	-79.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:08:00	\N	1	00:11:00	\N	0.959999999999999964	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
57518	Snow Point, 0.4 mi. North of, Cooper River, South Carolina	NOS	8664515	32.9483000000000033	-79.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:45:00	\N	1.05000000000000004	00:59:00	\N	1.02000000000000002	\N	\N	Snow Point, 0.4 mi. North of	SC
57519	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583000000000013	-80.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	03:41:00	\N	0.160000000000000003	02:45:00	\N	0.390000000000000013	\N	\N	Bacon Bridge	SC
57520	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9316999999999993	-80.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:42:00	\N	1.15999999999999992	02:06:00	\N	1.14999999999999991	\N	\N	Greggs Landing, Mateeba Gardens	SC
57521	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.9249999999999972	-79.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:31:00	\N	1.37000000000000011	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
57522	Cainhoy, Wando River, South Carolina (sub)	NOS	8664545	32.9266999999999967	-79.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:31:00	\N	1	00:49:00	\N	1.14999999999999991	\N	\N	Cainhoy	SC
57523	Woodville, Wando River, South Carolina	NOS	8664582	32.9200000000000017	-79.7332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:22:00	\N	1.18999999999999995	02:07:00	\N	1.18999999999999995	\N	\N	Woodville	SC
57524	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183000000000021	-80.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:13:00	\N	0.790000000000000036	02:51:00	\N	0.900000000000000022	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
57525	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.9149999999999991	-79.7467000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:52:00	\N	1.1100000000000001	01:24:00	\N	1.23999999999999999	\N	\N	Big Paradise Island	SC
57526	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9132999999999996	-79.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:08:00	\N	0.949999999999999956	00:12:00	\N	0.969999999999999973	\N	\N	Wharf Creek entrance	SC
57527	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067000000000007	-79.9350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:33:00	\N	1	00:45:00	\N	1.04000000000000004	\N	\N	Clouter Creek, north entrance	SC
57528	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.8999999999999986	-79.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:23:00	\N	1.05000000000000004	00:47:00	\N	1.12999999999999989	\N	\N	Nowell Creek	SC
57529	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.884999999999998	-79.8449999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:27:00	\N	1.1100000000000001	00:43:00	\N	1.09000000000000008	\N	\N	Parker Island, Horlbeck Creek	SC
57530	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817000000000021	-79.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:21:00	\N	0.890000000000000013	-00:01:00	\N	0.92000000000000004	\N	\N	Price Creek, North Capers Island	SC
57531	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8766999999999996	-80.0832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:54:00	\N	1.05000000000000004	01:02:00	\N	1.10000000000000009	\N	\N	Magnolia Gardens	SC
57532	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.8699999999999974	-79.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:09:00	\N	0.839999999999999969	00:21:00	\N	0.939999999999999947	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
57533	Capers Creek, South Capers Island, South Carolina (sub)	NOS	8664941	32.8566999999999965	-79.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:15:00	\N	0.949999999999999956	00:04:00	\N	0.939999999999999947	\N	\N	Capers Creek, South Capers Island	SC
57534	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.8599999999999994	-79.9382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:19:00	\N	1	00:25:00	\N	1.02000000000000002	\N	\N	Clouter Creek, south entrance	SC
57535	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.8500000000000014	-79.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:11:00	\N	0.949999999999999956	-00:02:00	\N	0.910000000000000031	\N	\N	North Dewees Island, Capers Inlet	SC
57536	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483000000000018	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:39:00	\N	1.05000000000000004	00:41:00	\N	1.09000000000000008	\N	\N	Drayton, Bee's Ferry	SC
57537	I-526 bridge, Ashley River, South Carolina (sub)	NOS	8665099	32.8367000000000004	-80.0216999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:29:00	\N	1.1100000000000001	00:30:00	\N	1.08000000000000007	\N	\N	I-526 bridge	SC
57538	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.8350000000000009	-79.986699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:17:00	\N	1.05000000000000004	00:25:00	\N	1.07000000000000006	\N	\N	Cosgrove Bridge	SC
57539	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333000000000013	-79.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:17:00	\N	0.890000000000000013	-00:01:00	\N	0.939999999999999947	\N	\N	South Dewees Island, Dewees Inlet	SC
57540	Duck Island, Ashley River, South Carolina	NOS	8665145	32.8299999999999983	-79.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:17:00	\N	1.06000000000000005	00:23:00	\N	1.06000000000000005	\N	\N	Duck Island	SC
57541	Hamlin Sound, South Carolina	NOS	8665167	32.8267000000000024	-79.7866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:13:00	\N	1	00:13:00	\N	0.989999999999999991	\N	\N	Hamlin Sound	SC
57542	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8216999999999999	-79.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:13:00	\N	0.949999999999999956	00:19:00	\N	1.03000000000000003	\N	\N	Hobcaw Point	SC
57543	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8132999999999981	-80.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	05:34:00	\N	0.320000000000000007	04:20:00	\N	0.130000000000000004	\N	\N	Canaday Landing, south of, Edisto River	SC
57544	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867000000000033	-79.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:12:00	\N	1	00:06:00	\N	0.969999999999999973	\N	\N	Hamlin Creek, Isle of Palms	SC
57545	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.6749999999999972	-79.9517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:06:00	\N	1	00:25:00	\N	1.04000000000000004	\N	\N	Folly Creek, Hwy. 171 bridge	SC
57546	Shem Creek, South Carolina	NOS	8665426	32.7933000000000021	-79.881699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:03:00	\N	1	-00:02:00	\N	0.989999999999999991	\N	\N	Shem Creek	SC
57547	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867000000000033	-80.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:34:00	\N	1.08000000000000007	01:43:00	\N	1.08000000000000007	\N	\N	Limehouse Bridge	SC
57548	Isle of Palms Pier, South Carolina	NOS	8665494	32.783299999999997	-79.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:28:00	\N	0.890000000000000013	-00:25:00	\N	0.949999999999999956	\N	\N	Isle of Palms Pier	SC
57549	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.783299999999997	-79.9566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:07:00	\N	1.05000000000000004	00:04:00	\N	1.01000000000000001	\N	\N	South Ashley Bridge	SC
57550	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7766999999999982	-79.8117000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:14:00	\N	1.05000000000000004	-00:05:00	\N	0.949999999999999956	\N	\N	Breach Inlet, Isle of Palms	SC
57551	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.773299999999999	-79.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:12:00	\N	1	00:06:00	\N	0.969999999999999973	\N	\N	Ben Sawyer Bridge, ICWW	SC
57552	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.7700000000000031	-80.0632999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:18:00	\N	1.02000000000000002	01:30:00	\N	1.02000000000000002	\N	\N	Sandblasters, Pennys Creek	SC
57553	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683000000000035	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:20:00	\N	1.32000000000000006	01:23:00	\N	1.03000000000000003	\N	\N	Pennys Creek, west entrance	SC
57554	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667000000000002	-79.9732999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:22:00	\N	0.989999999999999991	00:22:00	\N	0.989999999999999991	\N	\N	Wappoo Creek, highway bridge	SC
57555	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.763300000000001	-79.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:10:00	\N	0.949999999999999956	-00:01:00	\N	0.969999999999999973	\N	\N	The Cove, Fort Moultrie	SC
58546	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.5349999999999966	-132.396999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:03:00	\N	1.01000000000000001	00:05:00	\N	1.02000000000000002	\N	\N	Kasaan	AK
57556	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.763300000000001	-80.0016999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:52:00	\N	1.15999999999999992	00:48:00	\N	0.989999999999999991	\N	\N	Elliott Cut entrance	SC
57557	Fort Johnson, South Carolina	NOS	8665726	32.7516999999999996	-79.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:02:00	\N	1	-00:05:00	\N	0.969999999999999973	\N	\N	Fort Johnson	SC
57558	Fort Sumter, South Carolina	NOS	8665728	32.753300000000003	-79.8766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:01:00	\N	0.949999999999999956	00:02:00	\N	0.969999999999999973	\N	\N	Fort Sumter	SC
57559	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.753300000000003	-80.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:34:00	\N	0.859999999999999987	02:46:00	\N	0.589999999999999969	\N	\N	Jacksonboro Camp	SC
57560	Church Flats, Stono River, South Carolina	NOS	8665763	32.746699999999997	-80.1650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:14:00	\N	1.15999999999999992	01:51:00	\N	1.21999999999999997	\N	\N	Church Flats	SC
57561	James Island Creek, 1 mi. above ent., Ashley River, South Carolina	NOS	8665775	32.7449999999999974	-79.9483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:07:00	\N	1.05000000000000004	00:17:00	\N	1.02000000000000002	\N	\N	James Island Creek, 1 mi. above ent.	SC
57562	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7432999999999979	-80.5567000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	04:00:00	\N	1.05000000000000004	04:18:00	\N	0.340000000000000024	\N	\N	Ashepoo	SC
57563	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.7150000000000034	-80.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:43:00	\N	1.17999999999999994	02:10:00	\N	0.729999999999999982	\N	\N	Penny Creek, south of, Edisto River	SC
57564	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.7150000000000034	-80.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:58:00	\N	1	01:58:00	\N	1.30000000000000004	\N	\N	Church Creek bridge	SC
57565	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7066999999999979	-80.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:00:00	\N	1.15999999999999992	01:43:00	\N	1.30000000000000004	\N	\N	Johns Island, Church Creek	SC
57566	Lower Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666131	32.7032999999999987	-80.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:47:00	\N	1.26000000000000001	01:26:00	\N	1.29000000000000004	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
57567	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7132999999999967	-80.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	04:12:00	\N	1.72999999999999998	04:45:00	\N	0.510000000000000009	\N	\N	Cuckolds Creek	SC
57568	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7000000000000028	-80.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:13:00	\N	1.05000000000000004	01:46:00	\N	0.819999999999999951	\N	\N	Hope Creek, Edisto River	SC
57569	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.6950000000000003	-80.2232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:45:00	\N	1.15999999999999992	01:22:00	\N	1.23999999999999999	\N	\N	Yonges Island	SC
57570	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833000000000027	-80.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:57:00	\N	1.15999999999999992	01:39:00	\N	1.26000000000000001	\N	\N	Oak Branch, Bohicket Creek	SC
57571	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6766999999999967	-80.006699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:02:00	\N	0.949999999999999956	00:17:00	\N	1.01000000000000001	\N	\N	Abbapoola Creek entrance	SC
57572	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833000000000027	-80.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:51:00	\N	1.59000000000000008	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
57573	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6816999999999993	-80.4167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:03:00	\N	1	01:34:00	\N	0.82999999999999996	\N	\N	Willtown Bluff, Edisto River	SC
57574	Toogoodoo Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683000000000021	-80.2933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:38:00	\N	1.05000000000000004	01:06:00	\N	1.20999999999999996	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
57575	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.6700000000000017	-79.9167000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:05:00	\N	0.949999999999999956	00:24:00	\N	1.03000000000000003	\N	\N	Folly River, north, Folly Island	SC
57576	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.6649999999999991	-80.3166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:34:00	\N	1.20999999999999996	01:19:00	\N	1.20999999999999996	\N	\N	Park Island, Tom Point Creek	SC
57577	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567000000000007	-80.3917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:31:00	\N	0.949999999999999956	01:07:00	\N	0.890000000000000013	\N	\N	Dawho River	SC
57578	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617000000000033	-79.9449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:03:00	\N	0.949999999999999956	00:21:00	\N	1.01000000000000001	\N	\N	Folly River Bridge, Folly Island	SC
57579	U.S. 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6516999999999982	-80.6833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:29:00	\N	1.1399999999999999	03:00:00	\N	0.709999999999999964	\N	\N	U.S. 17 Bridge	SC
57580	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467000000000027	-80.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:31:00	\N	1.1100000000000001	00:58:00	\N	1.16999999999999993	\N	\N	Bluff Point	SC
57581	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317000000000021	-80.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:59:00	\N	1	01:57:00	\N	0.599999999999999978	\N	\N	Airy Hall Plantation	SC
57582	Snake Island, Stono River, South Carolina	NOS	8666767	32.6400000000000006	-80.0150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:12:00	\N	1	00:01:00	\N	1.01000000000000001	\N	\N	Snake Island	SC
57583	Leadenwah Creek, 3 mi. above entrance, North Edisto River, South Carolina	NOS	8666775	32.6366999999999976	-80.2017000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:23:00	\N	1.1100000000000001	00:54:00	\N	1.14999999999999991	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
57584	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6366999999999976	-80.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:47:00	\N	1.1100000000000001	00:56:00	\N	1.17999999999999994	\N	\N	Dawho Bridge, Dawho River	SC
57585	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:30:00	\N	1.1100000000000001	00:49:00	\N	1.12999999999999989	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
57586	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133000000000024	-80.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:34:00	\N	0.859999999999999987	01:27:00	\N	0.709999999999999964	\N	\N	Brickyard Ferry, swing bridge	SC
57587	Kiawah River Bridge, South Carolina	NOS	8667062	32.6032999999999973	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:06:00	\N	0.890000000000000013	00:14:00	\N	1.07000000000000006	\N	\N	Kiawah River Bridge	SC
57588	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6032999999999973	-80.388300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:45:00	\N	0.949999999999999956	00:29:00	\N	0.92000000000000004	\N	\N	Pine Landing	SC
57589	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.601700000000001	-80.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:20:00	\N	1.17999999999999994	01:45:00	\N	0.880000000000000004	\N	\N	Wiggins, Chehaw River	SC
57590	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6032999999999973	-80.2866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:25:00	\N	1.1100000000000001	00:45:00	\N	1.14999999999999991	\N	\N	Steamboat Landing, Steamboat Creek	SC
57591	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.601700000000001	-80.9033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:31:00	\N	0.729999999999999982	03:24:00	\N	0.729999999999999982	\N	\N	Tulifiny River, I-95 bridge	SC
57592	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983000000000018	-80.1949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:07:00	\N	1.1100000000000001	00:19:00	\N	1.09000000000000008	\N	\N	Rockville, Bohicket Creek	SC
57593	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983000000000018	-80.3449999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:35:00	\N	1.1100000000000001	01:16:00	\N	1.20999999999999996	\N	\N	Windsor Plantation, Russel Creek	SC
57594	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617000000000019	-80.9099999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:10:00	\N	1.1399999999999999	02:34:00	\N	1.12000000000000011	\N	\N	North Dawson Landing, Coosawhatchie River	SC
57595	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833000000000013	-80.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:52:00	\N	0.770000000000000018	02:11:00	\N	1.15999999999999992	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
57596	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.5850000000000009	-80.2283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:11:00	\N	1.05000000000000004	00:15:00	\N	1.08000000000000007	\N	\N	Point of Pines	SC
57597	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5782999999999987	-80.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:24:00	\N	0.949999999999999956	02:06:00	\N	0.930000000000000049	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
57598	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5782999999999987	-80.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:04:00	\N	0.910000000000000031	00:46:00	\N	0.839999999999999969	\N	\N	Bluff Islands	SC
57599	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5782999999999987	-80.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:57:00	\N	0.910000000000000031	01:21:00	\N	0.900000000000000022	\N	\N	Musselboro Island, Mosquito Creek	SC
57600	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683000000000007	-80.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:52:00	\N	0.910000000000000031	00:42:00	\N	0.910000000000000031	\N	\N	Fields Point	SC
57601	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.5649999999999977	-80.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:42:00	\N	1	01:02:00	\N	0.959999999999999964	\N	\N	Bowles Island, New Chehaw River	SC
57602	Ocella Creek, 2 mi. above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617000000000019	-80.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:09:00	\N	1.08000000000000007	00:32:00	\N	1.08000000000000007	\N	\N	Ocella Creek, 2 mi. above entrance	SC
57603	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.5600000000000023	-80.4183000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:25:00	\N	1.09000000000000008	00:15:00	\N	0.900000000000000022	\N	\N	Fenwick Island	SC
57604	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5516999999999967	-80.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:44:00	\N	0.910000000000000031	00:31:00	\N	0.869999999999999996	\N	\N	Hutchinson Island	SC
57605	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733000000000033	-80.7450000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:28:00	\N	0.949999999999999956	01:40:00	\N	1.1100000000000001	\N	\N	Lobeco, Whale Branch	SC
57606	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.5399999999999991	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:09:00	\N	0.949999999999999956	00:22:00	\N	0.880000000000000004	\N	\N	Peters Point, St. Pierre Creek	SC
57607	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.5249999999999986	-80.4517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:23:00	\N	0.910000000000000031	00:15:00	\N	0.900000000000000022	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
57608	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.5249999999999986	-80.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:20:00	\N	0.949999999999999956	01:27:00	\N	1.06000000000000005	\N	\N	Whale Branch entrance	SC
57609	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5266999999999982	-80.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	0.949999999999999956	00:55:00	\N	0.959999999999999964	\N	\N	Summerhouse Point, Bull River	SC
57610	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217000000000027	-80.8383000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:24:00	\N	1.05000000000000004	01:39:00	\N	1.16999999999999993	\N	\N	RR. Bridge, Hall Island	SC
57611	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.523299999999999	-80.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:18:00	\N	0.910000000000000031	00:11:00	\N	0.900000000000000022	\N	\N	Seabrook	SC
57612	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.5050000000000026	-80.8632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:24:00	\N	0.910000000000000031	01:50:00	\N	1.14999999999999991	\N	\N	Pilot Island, West Branch Boyds Creek	SC
57613	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4932999999999979	-80.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:19:00	\N	0.949999999999999956	01:27:00	\N	1.08000000000000007	\N	\N	Brickyard Point, Brickyard Creek	SC
57769	Piney Point, Florida	NOS	8720333	30.2283000000000008	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	03:36:00	\N	0.400000000000000022	02:39:00	\N	0.200000000000000011	\N	\N	Piney Point	FL
57614	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5016999999999996	-80.2967000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:29:00	\N	0.949999999999999956	-00:21:00	\N	0.839999999999999969	\N	\N	Edisto Beach, Edisto Island	SC
57615	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4932999999999979	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:13:00	\N	0.910000000000000031	-00:06:00	\N	0.859999999999999987	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
57616	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4932999999999979	-80.3267000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:07:00	\N	0.910000000000000031	00:08:00	\N	0.869999999999999996	\N	\N	Carters Dock, Big Bay Creek	SC
57617	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4832999999999998	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:45:00	\N	0.910000000000000031	00:55:00	\N	0.969999999999999973	\N	\N	Sams Point, Lucy Point Creek	SC
57618	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.476700000000001	-80.4200000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:07:00	\N	0.949999999999999956	00:04:00	\N	0.869999999999999996	\N	\N	Otter Island	SC
57619	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.4650000000000034	-80.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:11:00	\N	0.949999999999999956	01:27:00	\N	1.10000000000000009	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
57620	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517000000000024	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:33:00	\N	0.880000000000000004	00:53:00	\N	0.900000000000000022	\N	\N	Lucy Point Creek entrance	SC
57621	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.4500000000000028	-80.7317000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:02:00	\N	0.450000000000000011	01:48:00	\N	0.979999999999999982	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
57622	Village Creek Entrance, Morgan River, South Carolina	NOS	8667927	32.4450000000000003	-80.5032999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:07:00	\N	1	00:17:00	\N	0.930000000000000049	\N	\N	Village Creek Entrance	SC
57623	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4466999999999999	-80.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:14:00	\N	0.949999999999999956	00:31:00	\N	0.930000000000000049	\N	\N	Edding Point, Edding Creek	SC
57624	Jenkins Creek, 1 mi. above entrance, Morgan River, South Carolina	NOS	8667982	32.4399999999999977	-80.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:17:00	\N	0.949999999999999956	00:41:00	\N	0.979999999999999982	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
57625	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4166999999999987	-80.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:15:00	\N	0.949999999999999956	00:36:00	\N	0.939999999999999947	\N	\N	Village Creek Cemetery	SC
57626	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.4200000000000017	-80.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:27:00	\N	1.05000000000000004	00:55:00	\N	1.01000000000000001	\N	\N	Jenkins Creek, Polawana Island	SC
57627	Battery Creek, 4 mi. above entrance, Beaufort River, South Carolina	NOS	8668092	32.4132999999999996	-80.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	0.910000000000000031	01:14:00	\N	1.10000000000000009	\N	\N	Battery Creek, 4 mi. above entrance	SC
57628	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.4099999999999966	-80.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:30:00	\N	0.819999999999999951	01:34:00	\N	1.10000000000000009	\N	\N	Broughton Point, Hazzard Creek	SC
57629	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033000000000015	-80.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:06:00	\N	0.949999999999999956	00:03:00	\N	0.880000000000000004	\N	\N	Harbor River Bridge	SC
57630	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4016999999999982	-80.6533000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:08:00	\N	0.359999999999999987	01:00:00	\N	0.979999999999999982	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
57631	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.398299999999999	-80.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:58:00	\N	0.550000000000000044	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
57632	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3866999999999976	-80.7767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:45:00	\N	0.910000000000000031	00:51:00	\N	1.06000000000000005	\N	\N	Hwy. 170 bridge	SC
57633	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917000000000002	-80.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:03:00	\N	0.859999999999999987	00:03:00	\N	0.849999999999999978	\N	\N	Johnson Creek Bridge, Hunting Island	SC
57634	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.371699999999997	-80.605000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:34:00	\N	0.949999999999999956	00:58:00	\N	1.08000000000000007	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
57635	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.378300000000003	-80.6333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:27:00	\N	1.05000000000000004	00:43:00	\N	1.06000000000000005	\N	\N	Distant Island, Cowen Creek	SC
57636	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733000000000004	-80.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:48:00	\N	1	01:06:00	\N	1.10000000000000009	\N	\N	Chechessee Bluff, Chechessee River	SC
57637	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.3500000000000014	-80.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:26:00	\N	0.910000000000000031	00:37:00	\N	1.02000000000000002	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
57638	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3466999999999985	-80.8900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:57:00	\N	1.05000000000000004	01:25:00	\N	1.16999999999999993	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
57639	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina (sub)	NOS	8668498	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:22:00	\N	0.910000000000000031	-00:10:00	\N	0.880000000000000004	\N	\N	Fripps Inlet, Hunting Island Bridge	SC
57640	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.341700000000003	-80.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:49:00	\N	1.1399999999999999	01:12:00	\N	1.12999999999999989	\N	\N	Callawassie Island Bridge, Colleton River	SC
57641	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.3350000000000009	-80.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:24:00	\N	1	00:15:00	\N	0.989999999999999991	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
57642	Station Creek, County Landing, South Carolina	NOS	8668601	32.3250000000000028	-80.6016999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:16:00	\N	1	00:27:00	\N	0.989999999999999991	\N	\N	Station Creek, County Landing	SC
57643	Colleton River Entrance, South Carolina	NOS	8668619	32.3216999999999999	-80.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	1.05000000000000004	00:49:00	\N	1.05000000000000004	\N	\N	Colleton River Entrance	SC
57644	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3166999999999973	-80.841700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:53:00	\N	1.1399999999999999	01:15:00	\N	1.12999999999999989	\N	\N	Callawassie Creek, Colleton River	SC
57645	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3132999999999981	-80.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:40:00	\N	1.1100000000000001	01:09:00	\N	1.18999999999999995	\N	\N	Callawassie Island, south, Colleton River	SC
57646	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3066999999999993	-80.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:17:00	\N	0.640000000000000013	00:19:00	\N	0.949999999999999956	\N	\N	Fort Fremont	SC
57647	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033000000000001	-81.1217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:38:00	\N	0.409999999999999976	02:14:00	\N	0.440000000000000002	\N	\N	Purrysburg Landing, S.C.	SC
57648	Station Creek, west end, South Carolina	NOS	8668836	32.2800000000000011	-80.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:13:00	\N	0.910000000000000031	00:16:00	\N	0.959999999999999964	\N	\N	Station Creek, west end	SC
57649	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.273299999999999	-80.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:18:00	\N	0.949999999999999956	-00:01:00	\N	0.930000000000000049	\N	\N	Capers Island, Trenchards Inlet	SC
57650	Skull Creek, Ribaut Island, South Carolina (sub)	NOS	8668918	32.2667000000000002	-80.736699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:16:00	\N	0.910000000000000031	00:15:00	\N	0.989999999999999991	\N	\N	Skull Creek, north entrance, Hilton Head Island	SC
57651	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.259999999999998	-80.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:25:00	\N	0.910000000000000031	00:36:00	\N	1.04000000000000004	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
57652	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.236699999999999	-81.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:53:00	\N	0.510000000000000009	04:12:00	\N	0.510000000000000009	\N	\N	Rt. 170 bridge	SC
57653	Bluffton, May River, South Carolina	NOS	8669103	32.2299999999999969	-80.861699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	1.05000000000000004	01:00:00	\N	1.15999999999999992	\N	\N	Bluffton	SC
57654	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233000000000018	-80.7716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:23:00	\N	1.05000000000000004	00:34:00	\N	1.05000000000000004	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
57655	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.2199999999999989	-80.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:11:00	\N	1	00:01:00	\N	0.880000000000000004	\N	\N	Port Royal Plantation, Hilton Head Island	SC
57656	Bull Island North, May River, South Carolina	NOS	8669262	32.2000000000000028	-80.8149999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:25:00	\N	1.05000000000000004	00:40:00	\N	1.09000000000000008	\N	\N	Bull Island North	SC
57657	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.1950000000000003	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:00:00	\N	1.40999999999999992	03:09:00	\N	0.689999999999999947	\N	\N	Cook Landing Cemetery	SC
57658	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.1850000000000023	-80.8599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:19:00	\N	1	00:46:00	\N	1.10000000000000009	\N	\N	Savage I., Savage Creek, Bull Creek	SC
57659	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.1850000000000023	-80.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:17:00	\N	1.05000000000000004	00:33:00	\N	1.08000000000000007	\N	\N	Broad Creek, Hilton Head Island	SC
57660	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1766999999999967	-80.966700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:06:00	\N	1.55000000000000004	02:19:00	\N	0.849999999999999978	\N	\N	Good Hope Landing, south of	SC
57661	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.1749999999999972	-80.8917000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:23:00	\N	0.770000000000000018	00:49:00	\N	1.1100000000000001	\N	\N	Moreland Cemetery	SC
57662	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.1649999999999991	-80.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:12:00	\N	1.05000000000000004	00:28:00	\N	1.05000000000000004	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
57663	Little Back River, Hwy. 17, Back River, Savannah River, South Carolina	NOS	8669415	32.1649999999999991	-81.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:41:00	\N	1.1399999999999999	01:28:00	\N	1.10000000000000009	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	SC
57664	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533000000000015	-80.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:09:00	\N	1	00:20:00	\N	1.04000000000000004	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
57665	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467000000000027	-80.8366999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:10:00	\N	1	00:20:00	\N	1.02000000000000002	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
57666	Doughboy Island, New River, South Carolina	NOS	8669531	32.138300000000001	-80.9317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:06:00	\N	1.05000000000000004	01:04:00	\N	1.01000000000000001	\N	\N	Doughboy Island	SC
57667	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.128300000000003	-81.0117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:59:00	\N	1.09000000000000008	01:41:00	\N	1.06000000000000005	\N	\N	Turnbridge Landing, Salt Water Creek	SC
57668	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.121699999999997	-80.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:28:00	\N	0.910000000000000031	00:34:00	\N	1.03000000000000003	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
57669	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133000000000024	-80.8299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:02:00	\N	1	00:05:00	\N	0.979999999999999982	\N	\N	Braddock Point, Hilton Head Island	SC
57670	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1032999999999973	-80.894999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:33:00	\N	0.949999999999999956	00:30:00	\N	1.01000000000000001	\N	\N	Daufuskie Landing, Daufuskie Island	SC
57671	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983000000000018	-80.8983000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:27:00	\N	1.05000000000000004	00:19:00	\N	1.01000000000000001	\N	\N	Hargray Pier, Daufuskie Island	SC
57672	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0816999999999979	-80.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:19:00	\N	0.910000000000000031	00:01:00	\N	0.979999999999999982	\N	\N	Bloody Point, Daufuskie Island	SC
57673	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867000000000004	-80.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:29:00	\N	1.05000000000000004	00:16:00	\N	1.02000000000000002	\N	\N	Fields Cut, Wright River	SC
57674	S.C.L. RR. bridge, Savannah River, Georgia	NOS	8670073	32.2316999999999965	-81.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	03:08:00	\N	0.910000000000000031	01:51:00	\N	0.900000000000000022	\N	\N	S.C.L. RR. bridge	GA
57675	Port Wentworth, Savannah River, Georgia (sub)	NOS	8670424	32.1433000000000035	-81.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55966	-00:02:00	\N	0.839999999999999969	00:11:00	\N	1.03000000000000003	\N	\N	Port Wentworth	GA
57676	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0816999999999979	-81.0366999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:42:00	\N	1.09000000000000008	00:29:00	\N	1.09000000000000008	\N	\N	Fort Jackson	GA
57677	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0816999999999979	-81.091700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:33:00	\N	1.1399999999999999	00:44:00	\N	1.1399999999999999	\N	\N	SAVANNAH	GA
57678	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283000000000015	-80.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:12:00	\N	0.989999999999999991	-00:10:00	\N	0.989999999999999991	\N	\N	Tybee Light	GA
57679	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267000000000003	-81.0982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:31:00	\N	1.09000000000000008	00:40:00	\N	1.09000000000000008	\N	\N	Vernon View, Burnside River	GA
57680	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533000000000008	-81.1466999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:46:00	\N	0.910000000000000031	00:34:00	\N	1.05000000000000004	\N	\N	Florida Passage, Ogeechee River	GA
57681	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8216999999999999	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:13:00	\N	0.949999999999999956	00:04:00	\N	1.02000000000000002	\N	\N	Bradley Point, Bradley River	GA
57682	Belfast, Belfast River, Georgia	NOS	8672462	31.8216999999999999	-81.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:10:00	\N	1.1399999999999999	01:23:00	\N	1.12999999999999989	\N	\N	Belfast, Belfast River	GA
57683	Bear River, (Range 'A' Light), Georgia (sub)	NOS	8672667	31.7932999999999986	-81.1817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:39:00	\N	0.949999999999999956	00:43:00	\N	1.09000000000000008	\N	\N	Bear River, (Range 'A' Light)	GA
57684	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7882999999999996	-81.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	0.910000000000000031	00:48:00	\N	1.09000000000000008	\N	\N	Kilkenny Club, Kilkenny Creek	GA
57685	Sunbury, Sunbury Channel, Georgia (sub)	NOS	8672875	31.7667000000000002	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:52:00	\N	0.729999999999999982	00:53:00	\N	1.05000000000000004	\N	\N	Sunbury, Medway River	GA
57686	Halfmoon, Timmons River, Georgia	NOS	8673381	31.6950000000000003	-81.2716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:09:00	\N	1.05000000000000004	01:21:00	\N	1.06000000000000005	\N	\N	Halfmoon, Timmons River	GA
57687	Walburg Creek entrance, Georgia	NOS	8673437	31.6900000000000013	-81.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:21:00	\N	1	00:16:00	\N	1.03000000000000003	\N	\N	Walburg Creek entrance	GA
57688	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6816999999999993	-81.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:31:00	\N	1	00:35:00	\N	1.05000000000000004	\N	\N	North Newport River (Daymark 119)	GA
57689	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:46:00	\N	0.949999999999999956	00:57:00	\N	1.06000000000000005	\N	\N	Thomas Landing, S. Newport River	GA
57690	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.6499999999999986	-81.3050000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:06:00	\N	1	01:16:00	\N	1.09000000000000008	\N	\N	Eagle Neck, South Newport River	GA
57691	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233000000000004	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:32:00	\N	1	00:54:00	\N	1.08000000000000007	\N	\N	Harris Neck, Barbour Island River	GA
57692	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5782999999999987	-81.2399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:24:00	\N	1	00:36:00	\N	1.06000000000000005	\N	\N	Barbour Island, Barbour Island River	GA
57693	South Newport River (Daymark 135), Georgia (sub)	NOS	8674301	31.5749999999999993	-81.1899999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:20:00	\N	1.05000000000000004	00:27:00	\N	1.03000000000000003	\N	\N	South Newport River (Daymark 135)	GA
57694	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483000000000011	-81.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:04:00	\N	1.05000000000000004	01:03:00	\N	1.05000000000000004	\N	\N	Pine Harbor, Sapelo River	GA
57695	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317000000000007	-81.269999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:22:00	\N	0.910000000000000031	00:33:00	\N	1.04000000000000004	\N	\N	Dog Hammock, Sapelo River	GA
57696	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317000000000007	-81.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:02:00	\N	0.859999999999999987	01:12:00	\N	1.08000000000000007	\N	\N	Bellville Point, Sapelo River	GA
57697	Eagle Creek, Mud River, Georgia	NOS	8674801	31.5100000000000016	-81.2783000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:19:00	\N	1.05000000000000004	00:21:00	\N	1.05000000000000004	\N	\N	Eagle Creek, Mud River	GA
57698	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983000000000004	-81.3250000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:37:00	\N	1.09000000000000008	00:49:00	\N	1.08000000000000007	\N	\N	Creighton Narrows Entrance, Crescent River	GA
57699	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4882999999999988	-81.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:47:00	\N	0.949999999999999956	00:19:00	\N	0.939999999999999947	\N	\N	Blackbeard Creek, Blackbeard Island	GA
57700	Hudson Creek entrance, Georgia	NOS	8675245	31.4466999999999999	-81.3432999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:31:00	\N	1.05000000000000004	00:37:00	\N	1.05000000000000004	\N	\N	Hudson Creek entrance	GA
57701	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4316999999999993	-81.3067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:39:00	\N	0.819999999999999951	00:39:00	\N	0.959999999999999964	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
57702	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.3900000000000006	-81.2883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:14:00	\N	0.949999999999999956	00:15:00	\N	0.989999999999999991	\N	\N	Old Tower, Sapelo Island	GA
57703	Darien, Darien River, Georgia	NOS	8675779	31.3683000000000014	-81.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:15:00	\N	1.05000000000000004	01:08:00	\N	1.06000000000000005	\N	\N	Darien, Darien River	GA
57704	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3766999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:55:00	\N	1.05000000000000004	00:44:00	\N	1.03000000000000003	\N	\N	Threemile Cut entrance, Darien River	GA
57705	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317000000000014	-81.4599999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	02:33:00	\N	0.770000000000000018	01:10:00	\N	0.760000000000000009	\N	\N	Champney Island, South Altamaha River	GA
57706	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.2850000000000001	-81.3850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:23:00	\N	1.09000000000000008	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
57707	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.2250000000000014	-81.571700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:02:00	\N	1.17999999999999994	01:32:00	\N	1.15999999999999992	\N	\N	Dillard Creek	GA
57708	Frederica River, Georgia	NOS	8676743	31.2216999999999985	-81.3932999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:56:00	\N	1.05000000000000004	00:48:00	\N	1.05000000000000004	\N	\N	Frederica River	GA
57709	Mackay River (Daymark 239), Georgia	NOS	8676766	31.2100000000000009	-81.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:56:00	\N	1.09000000000000008	00:58:00	\N	1.03000000000000003	\N	\N	Mackay River (Daymark 239)	GA
57710	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.2149999999999999	-81.5832999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:58:00	\N	1.17999999999999994	01:37:00	\N	1.15999999999999992	\N	\N	Buffalo River entrance	GA
57711	Crispen Island, Turtle River, Georgia	NOS	8676808	31.2133000000000003	-81.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:55:00	\N	1.05000000000000004	01:33:00	\N	1.14999999999999991	\N	\N	Crispen Island	GA
57712	Frederick River Bridge, Georgia	NOS	8677045	31.1682999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:45:00	\N	1.09000000000000008	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
57713	Brunswick, East River, Georgia	NOS	8677230	31.148299999999999	-81.4983000000000004	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:51:00	\N	1.09000000000000008	00:59:00	\N	1.05000000000000004	\N	\N	Brunswick, East River	GA
57714	St. Simons Lighthouse, St. Simons Island, Georgia (sub)	NOS	8677344	31.1316999999999986	-81.3966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:16:00	\N	0.910000000000000031	00:14:00	\N	0.949999999999999956	\N	\N	St. Simons Light	GA
57715	8 miles above mouth, Little Satilla River, Georgia	NOS	8677566	31.0982999999999983	-81.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:02:00	\N	1.19999999999999996	00:24:00	\N	1.19999999999999996	\N	\N	8 miles above mouth	GA
57716	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.0949999999999989	-81.5049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:31:00	\N	1.17999999999999994	00:11:00	\N	1.17999999999999994	\N	\N	Jointer Island, Jointer Creek	GA
57717	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0566999999999993	-81.4232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:36:00	\N	1.15999999999999992	00:03:00	\N	1.12999999999999989	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
57718	2.5 miles above mouth, Little Satilla River, Georgia	NOS	8677833	31.0582999999999991	-81.493300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:31:00	\N	1.12000000000000011	-00:04:00	\N	1.12000000000000011	\N	\N	2.5 miles above mouth	GA
57719	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167000000000002	-81.5283000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:31:00	\N	1.14999999999999991	00:06:00	\N	1.14999999999999991	\N	\N	Dover Bluff, Dover Creek	GA
57720	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9716999999999985	-81.519999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:41:00	\N	1.10000000000000009	-00:08:00	\N	1.10000000000000009	\N	\N	Todd Creek entrance	GA
57721	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633000000000003	-81.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:35:00	\N	1.09000000000000008	00:34:00	\N	1.09000000000000008	\N	\N	Ceylon	GA
57722	Floyd Creek, 2.8 miles above entrance, Georgia	NOS	8678642	30.9366999999999983	-81.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:21:00	\N	1.16999999999999993	00:08:00	\N	1.16999999999999993	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
58087	Gulf Harbors, Florida	NOS	8726995	28.2433000000000014	-82.763300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-00:52:00	\N	0.900000000000000022	-01:15:00	\N	0.839999999999999969	\N	\N	Gulf Harbors	FL
57723	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.9299999999999997	-81.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:26:00	\N	1.12000000000000011	00:00:00	\N	1.12000000000000011	\N	\N	Cumberland Wharf, Cumberland River	GA
57724	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.870000000000001	-81.5849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:56:00	\N	1.05000000000000004	01:29:00	\N	1.05000000000000004	\N	\N	Harrietts Bluff, Crooked River	GA
57725	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8432999999999993	-81.486699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:56:00	\N	1.12000000000000011	00:44:00	\N	1.12000000000000011	\N	\N	Crooked River, Cumberland Dividings	GA
57726	Kings Bay, Navy Base, Georgia (sub)	NOS	8679511	30.7967000000000013	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:10:00	\N	1.05000000000000004	00:12:00	\N	1.09000000000000008	\N	\N	Kings Bay, Navy Base	GA
57727	Dungeness, Seacamp Dock, Georgia (sub)	NOS	8679758	30.763300000000001	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:16:00	\N	1.05000000000000004	00:12:00	\N	1.04000000000000004	\N	\N	Seacamp Dock, Cumberland Island	GA
57728	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.726700000000001	-81.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:04:00	\N	0.949999999999999956	00:00:00	\N	0.979999999999999982	\N	\N	Beach Creek ent., Cumberland Island	GA
57729	St. Marys, St. Marys River, Georgia (sub)	NOS	8679964	30.7199999999999989	-81.5482999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:45:00	\N	1.05000000000000004	00:38:00	\N	0.979999999999999982	\N	\N	St. Marys	GA
57730	St. Marys Entrance, North Jetty, Georgia	NOS	8679997	30.7199999999999989	-81.4449999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:03:00	\N	0.959999999999999964	-00:36:00	\N	0.959999999999999964	\N	\N	St. Marys Entrance, North Jetty	GA
57731	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7866999999999997	-81.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	04:09:00	\N	1.15999999999999992	04:05:00	\N	0.489999999999999991	\N	\N	Kings Ferry	FL
57732	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	02:36:00	\N	0.790000000000000036	02:49:00	\N	0.709999999999999964	\N	\N	Little St. Marys River	FL
57733	Roses Bluff, Bells River, Florida	NOS	8720007	30.7032999999999987	-81.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:35:00	\N	0.949999999999999956	00:35:00	\N	1.03000000000000003	\N	\N	Roses Bluff, Bells River	FL
57734	Chester, Bells River, Florida (sub)	NOS	8720023	30.6832999999999991	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:19:00	\N	1.1100000000000001	00:27:00	\N	1.04000000000000004	\N	\N	Chester, Bells River	FL
57735	Lofton, Lanceford Creek, Florida (sub)	NOS	8720051	30.6433	-81.5233000000000061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:01:00	\N	1.05000000000000004	00:18:00	\N	1.05000000000000004	\N	\N	Lofton, Lanceford Creek	FL
57736	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6316999999999986	-81.4766999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:25:00	\N	1	00:27:00	\N	0.989999999999999991	\N	\N	Kingsley Creek, RR. bridge	FL
57737	Boggy Creek, 2 mi. above entrance, Nassau River, Florida	NOS	8720084	30.5883000000000003	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	03:50:00	\N	0.890000000000000013	03:29:00	\N	0.489999999999999991	\N	\N	Boggy Creek, 2 mi. above entrance	FL
57738	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867000000000004	-81.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:42:00	\N	0.890000000000000013	00:21:00	\N	0.890000000000000013	\N	\N	Amelia City, South Amelia River	FL
57739	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5766999999999989	-81.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	02:39:00	\N	1.05000000000000004	02:00:00	\N	0.699999999999999956	\N	\N	Halfmoon Island, highway bridge	FL
57740	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5766999999999989	-81.571700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	02:48:00	\N	1.05000000000000004	02:14:00	\N	0.599999999999999978	\N	\N	Cuno, Lofton Creek	FL
57741	Nassauville, Nassau River East, Florida (sub)	NOS	8720098	30.5683000000000007	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:09:00	\N	1	00:24:00	\N	0.800000000000000044	\N	\N	Nassauville	FL
57742	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5366999999999997	-81.5816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	02:05:00	\N	1.05000000000000004	01:13:00	\N	0.719999999999999973	\N	\N	Mink Creek entrance	FL
57743	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:41:00	\N	1	-00:18:00	\N	0.859999999999999987	\N	\N	entrance	FL
57744	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.513300000000001	-81.4566999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:21:00	\N	1	-00:14:00	\N	0.839999999999999969	\N	\N	Sawpit Creek entrance, bridge	FL
57745	Sawpit Creek, 1 mi. above entrance, Florida	NOS	8720143	30.5032999999999994	-81.4716999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:31:00	\N	0.739999999999999991	00:05:00	\N	0.839999999999999969	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
57746	Edwards Creek, Nassau River, Florida (sub)	NOS	8720145	30.5016999999999996	-81.5417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:51:00	\N	0.849999999999999978	01:24:00	\N	0.770000000000000018	\N	\N	Edwards Creek, 1 mi. above entrance	FL
57747	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5016999999999996	-81.4950000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:46:00	\N	0.949999999999999956	01:22:00	\N	0.819999999999999951	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
57748	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.4649999999999999	-81.4317000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:17:00	\N	0.630000000000000004	00:04:00	\N	0.839999999999999969	\N	\N	Simpson Creek, A1A highway bridge	FL
57749	Fort George Island, Fort George River, Florida	NOS	8720186	30.4400000000000013	-81.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:33:00	\N	0.739999999999999991	00:10:00	\N	0.790000000000000036	\N	\N	Fort George Island, Fort George River	FL
57750	Sisters Creek, Florida (sub)	NOS	8720196	30.4166999999999987	-81.4532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	00:50:00	\N	0.930000000000000049	00:32:00	\N	0.949999999999999956	\N	\N	Sisters Creek	FL
57751	Blount Island Bridge, Florida	NOS	8720203	30.4132999999999996	-81.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:05:00	\N	0.729999999999999982	00:42:00	\N	0.770000000000000018	\N	\N	Blount Island Bridge	FL
57776	St. Augustine, city dock, Florida	NOS	8720576	29.8917000000000002	-81.3100000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:01:00	\N	0.890000000000000013	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
57752	Water Treatment Dock, Mayport Naval Station, St Johns River, Florida (sub)	NOS	8720211	30.3999999999999986	-81.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	-00:06:00	\N	1	-00:12:00	\N	1.03000000000000003	\N	\N	Mayport Naval Station, Water Treatment Dock	FL
57753	Sherwood Forest, Trout River, Florida (sub)	NOS	8720213	30.4200000000000017	-81.7283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	02:13:00	\N	0.67000000000000004	01:42:00	\N	0.57999999999999996	\N	\N	Sherwood Forest	FL
57754	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.3999999999999986	-81.6266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:48:00	\N	0.530000000000000027	01:14:00	\N	0.560000000000000053	\N	\N	Jacksonville, Navy Fuel Depot	FL
57755	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.398299999999999	-81.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	02:10:00	\N	0.599999999999999978	01:13:00	\N	0.57999999999999996	\N	\N	Lake Forest, Ribault River	FL
57756	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917000000000002	-81.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:53:00	\N	0.530000000000000027	01:11:00	\N	0.550000000000000044	\N	\N	Moncrief Creek entrance	FL
57757	Dame Point, St. Johns River, Florida (sub)	NOS	8720219	30.3867000000000012	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:12:00	\N	0.67000000000000004	00:42:00	\N	0.699999999999999956	\N	\N	Dame Point	FL
57758	Fulton, Florida	NOS	8720221	30.3900000000000006	-81.506699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	00:40:00	\N	0.729999999999999982	00:24:00	\N	0.800000000000000044	\N	\N	Fulton	FL
57759	Phoenix Park, Florida (sub)	NOS	8720225	30.3832999999999984	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:47:00	\N	0.599999999999999978	01:02:00	\N	0.560000000000000053	\N	\N	Phoenix Park	FL
57760	Main Street Bridge, St. Johns River, Florida (sub)	NOS	8720226	30.3200000000000003	-81.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	02:09:00	\N	0.729999999999999982	01:39:00	\N	0.400000000000000022	\N	\N	Jacksonville, Main Street Bridge	FL
57761	Pablo Creek entrance, Florida	NOS	8720232	30.3766999999999996	-81.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	00:33:00	\N	0.729999999999999982	00:29:00	\N	0.849999999999999978	\N	\N	Pablo Creek entrance	FL
57762	Jacksonville, Long Branch, Florida (sub)	NOS	8720242	30.3599999999999994	-81.6200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:54:00	\N	0.729999999999999982	01:15:00	\N	0.550000000000000044	\N	\N	Jacksonville, Long Branch	FL
57763	Atlantic Beach, Florida	NOS	8720259	30.3350000000000009	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:23:00	\N	0.859999999999999987	-00:41:00	\N	0.859999999999999987	\N	\N	Atlantic Beach	FL
57764	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3232999999999997	-81.4382999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	01:20:00	\N	1	01:14:00	\N	0.839999999999999969	\N	\N	Pablo Creek, ICWW bridge	FL
57765	Little Pottsburg Creek, Florida	NOS	8720274	30.3099999999999987	-81.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	02:09:00	\N	0.530000000000000027	01:31:00	\N	0.440000000000000002	\N	\N	Little Pottsburg Creek	FL
57766	Jacksonville Beach, Florida (sub)	NOS	8720291	30.2833000000000006	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:27:00	\N	0.839999999999999969	-00:50:00	\N	0.839999999999999969	\N	\N	Jacksonville Beach	FL
57767	Ortega River entrance, Florida	NOS	8720296	30.2783000000000015	-81.7049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	02:47:00	\N	0.469999999999999973	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
57768	Oak Landing, ICWW, Florida	NOS	8720305	30.2532999999999994	-81.4300000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	02:03:00	\N	0.800000000000000044	02:15:00	\N	0.680000000000000049	\N	\N	Oak Landing, ICWW	FL
57770	I-295 Bridge (west end), St. Johns River, Florida (sub)	NOS	8720357	30.1917000000000009	-81.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	03:43:00	\N	0.599999999999999978	02:56:00	\N	0.209999999999999992	\N	\N	I-295 bridge (west end)	FL
57771	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.1683006286621094	-81.6949996948242188	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	04:44:00	\N	0.200000000000000011	03:24:00	\N	0.200000000000000011	\N	\N	Orange Park Landing, Orange Park	FL
57772	Palm Valley, ICWW, Florida	NOS	8720398	30.1332999999999984	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:49:00	\N	0.75	02:00:00	\N	0.790000000000000036	\N	\N	Palm Valley, ICWW	FL
57773	Julington Creek, Florida	NOS	8720409	30.1350002288818359	-81.6299972534179688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	05:13:00	\N	0.200000000000000011	03:58:00	\N	0.200000000000000011	\N	\N	Julington Creek	FL
57774	Green Cove Springs, Florida	NOS	8720496	29.9899999999999984	-81.6633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	05:55:00	\N	0.270000000000000018	04:57:00	\N	0.170000000000000012	\N	\N	Green Cove Springs	FL
57775	Vilano Beach ICWW, Tolomato River, Florida (sub)	NOS	8720554	29.9166999999999987	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:05:00	\N	0.900000000000000022	-00:20:00	\N	0.739999999999999991	\N	\N	Vilano Beach, Tolomato River	FL
57777	St. Augustine Beach, Florida (sub)	NOS	8720587	29.8567	-81.263300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:32:00	\N	0.839999999999999969	-00:51:00	\N	0.770000000000000018	\N	\N	St. Augustine Beach	FL
57778	Tocoi, Florida	NOS	8720596	29.8582999999999998	-81.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	07:03:00	\N	0.270000000000000018	06:02:00	\N	0.209999999999999992	\N	\N	Tocoi	FL
57779	Palmetto Bluff, Florida	NOS	8720653	29.763300000000001	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	07:36:00	\N	0.469999999999999973	06:35:00	\N	0.23000000000000001	\N	\N	Palmetto Bluff	FL
57780	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.7149999999999999	-81.2382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:49:00	\N	0.949999999999999956	00:03:00	\N	0.650000000000000022	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
57781	Buffalo Bluff, St. Johns River, Florida (sub)	NOS	8720767	29.5949999999999989	-81.6817000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	08:58:00	\N	0.400000000000000022	07:27:00	\N	0.209999999999999992	\N	\N	Buffalo Bluff	FL
57782	Palatka, St. Johns River, Florida (sub)	NOS	8720774	29.6433	-81.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	08:38:00	\N	0.530000000000000027	07:11:00	\N	0.25	\N	\N	Palatka	FL
57783	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5716999999999999	-81.6067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	09:05:00	\N	0.200000000000000011	07:35:00	\N	0.179999999999999993	\N	\N	Sutherlands Still, Dunns Creek	FL
57784	Welaka, St. Johns River, Florida (sub)	NOS	8720832	29.476700000000001	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55996	08:07:00	\N	0.270000000000000018	07:16:00	\N	0.100000000000000006	\N	\N	Welaka	FL
57785	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783000000000008	-81.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	05:00:00	\N	0.299999999999999989	04:33:00	\N	0.149999999999999994	\N	\N	Smith Creek, Flagler Beach	FL
57786	Ormond Beach, Halifax River, Florida	NOS	8720954	29.2850000000000001	-81.053299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	04:31:00	\N	0.450000000000000011	03:17:00	\N	0.110000000000000001	\N	\N	Ormond Beach, Halifax River	FL
57787	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1466999999999992	-80.9633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:42:00	\N	0.839999999999999969	-00:56:00	\N	0.650000000000000022	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
57788	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817000000000014	-80.9367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:33:00	\N	1	00:05:00	\N	1.17999999999999994	\N	\N	Ponce Inlet, Halifax River	FL
57789	Ponce De Leon Inlet South, Florida (sub)	NOS	8721147	29.0633000000000017	-80.9150000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:19:00	\N	0.92000000000000004	-00:11:00	\N	1.16999999999999993	\N	\N	Ponce de Leon Inlet	FL
57790	Patrick Air Force Base, Florida	NOS	8721727	28.245000000000001	-80.5999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:38:00	\N	1.42999999999999994	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
57791	Canova Beach, Florida	NOS	8721804	28.138300000000001	-80.5782999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:26:00	\N	1.5	-00:53:00	\N	1.48999999999999999	\N	\N	Canova Beach	FL
57792	Micco, Indian River, Florida	NOS	8721994	27.8733000000000004	-80.4967000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:19:00	\N	0.569999999999999951	01:14:00	\N	0.140000000000000013	\N	\N	Micco	FL
57793	Sebastian Inlet bridge, Florida	NOS	8722004	27.8599999999999994	-80.4483000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:24:00	\N	1	-00:48:00	\N	0.930000000000000049	\N	\N	Sebastian Inlet bridge	FL
57794	Sebastian, Indian River, Florida	NOS	8722029	27.8116999999999983	-80.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:36:00	\N	0.5	01:32:00	\N	0.149999999999999994	\N	\N	Sebastian	FL
57795	Wabasso, Indian River, Florida	NOS	8722059	27.754999999999999	-80.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:24:00	\N	0.419999999999999984	02:20:00	\N	0.170000000000000012	\N	\N	Wabasso	FL
57796	Vero Beach (ocean), Florida	NOS	8722105	27.6700000000000017	-80.3599999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:35:00	\N	1.3600000000000001	-00:55:00	\N	1.44999999999999996	\N	\N	Vero Beach (ocean)	FL
57797	Vero Beach, Indian River, Florida (sub)	NOS	8722125	27.6316999999999986	-80.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:41:00	\N	0.790000000000000036	02:56:00	\N	0.369999999999999996	\N	\N	Vero Beach	FL
57798	Oslo, Indian River, Florida	NOS	8722146	27.5932999999999993	-80.3567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:59:00	\N	0.5	03:00:00	\N	0.340000000000000024	\N	\N	Oslo	FL
57799	St. Lucie, Indian River, Florida	NOS	8722207	27.4800000000000004	-80.3332999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:46:00	\N	1	00:41:00	\N	0.479999999999999982	\N	\N	St. Lucie	FL
57800	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.4699999999999989	-80.2883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:18:00	\N	1.5	-00:31:00	\N	1.1399999999999999	\N	\N	Fort Pierce Inlet, south jetty	FL
57802	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2866999999999997	-80.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:31:00	\N	0.92000000000000004	02:35:00	\N	0.450000000000000011	\N	\N	Eden, Nettles Island	FL
57803	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433000000000014	-80.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:28:00	\N	0.92000000000000004	02:28:00	\N	0.46000000000000002	\N	\N	North Fork	FL
57804	Jensen Beach, Indian River, Florida	NOS	8722338	27.2349999999999994	-80.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:04:00	\N	0.92000000000000004	02:17:00	\N	0.479999999999999982	\N	\N	Jensen Beach	FL
57805	Stuart, St. Lucie River, Florida	NOS	8722357	27.1999999999999993	-80.2583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:30:00	\N	0.859999999999999987	02:13:00	\N	0.400000000000000022	\N	\N	Stuart	FL
57806	Seminole Shores, Florida	NOS	8722366	27.1832999999999991	-80.158299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:35:00	\N	1.28000000000000003	-00:59:00	\N	1.29000000000000004	\N	\N	Seminole Shores	FL
57807	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.1750000000000007	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:10:00	\N	0.930000000000000049	01:13:00	\N	0.429999999999999993	\N	\N	Sewall Point	FL
57808	South Fork, St. Lucie River, Florida	NOS	8722376	27.1649999999999991	-80.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:32:00	\N	0.92000000000000004	02:35:00	\N	0.429999999999999993	\N	\N	South Fork	FL
57809	Great Pocket, Florida	NOS	8722381	27.1550000000000011	-80.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
57810	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517000000000017	-80.1949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:46:00	\N	0.92000000000000004	00:51:00	\N	0.419999999999999984	\N	\N	Port Salerno, Manatee Pocket	FL
57811	Peck Lake, ICWW, Florida	NOS	8722404	27.1132999999999988	-80.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:10:00	\N	1	01:13:00	\N	0.57999999999999996	\N	\N	Peck Lake, ICWW	FL
57812	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0932999999999993	-80.1367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:37:00	\N	1.07000000000000006	01:33:00	\N	0.599999999999999978	\N	\N	Gomez, South Jupiter Narrows	FL
57813	Hobe Sound bridge, Florida	NOS	8722429	27.0650000000000013	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:25:00	\N	1	01:28:00	\N	0.680000000000000049	\N	\N	Hobe Sound bridge	FL
57814	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0366999999999997	-80.1067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
57815	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9882999999999988	-80.0932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:34:00	\N	1.07000000000000006	00:56:00	\N	0.739999999999999991	\N	\N	Conch Bar, Jupiter Sound	FL
57816	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.986699999999999	-80.1417000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:57:00	\N	1.3600000000000001	01:01:00	\N	0.92000000000000004	\N	\N	Boy Scout Dock	FL
57817	North Fork, 2 miles above entrance, Loxahatchee River, Florida	NOS	8722478	26.9750000000000014	-80.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:55:00	\N	1.1399999999999999	01:04:00	\N	0.859999999999999987	\N	\N	North Fork, 2 miles above entrance	FL
57818	3 miles above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.9699999999999989	-80.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:49:00	\N	1.1399999999999999	00:56:00	\N	0.859999999999999987	\N	\N	3 miles above A1A highway bridge	FL
57819	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.9600000000000009	-80.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
57820	Jupiter Sound, south end, Florida	NOS	8722491	26.9516999999999989	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:45:00	\N	1.3600000000000001	00:22:00	\N	0.880000000000000004	\N	\N	Jupiter Sound, south end	FL
57821	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9466999999999999	-80.0900000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:54:00	\N	1.1399999999999999	00:34:00	\N	0.869999999999999996	\N	\N	A1A highway bridge	FL
57822	Southwest Fork, 0.5 mile above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433000000000007	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:35:00	\N	1.41999999999999993	00:41:00	\N	0.890000000000000013	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
57823	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433000000000007	-80.0733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:09:00	\N	1.41999999999999993	-00:10:00	\N	1.08000000000000007	\N	\N	Jupiter Inlet, south jetty	FL
57824	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.9349999999999987	-80.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:45:00	\N	1.28000000000000003	00:52:00	\N	0.859999999999999987	\N	\N	Southwest Fork (spillway)	FL
57825	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.9349999999999987	-80.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:12:00	\N	1.28000000000000003	00:34:00	\N	0.910000000000000031	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
57826	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9116999999999997	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:08:00	\N	1.20999999999999996	00:29:00	\N	0.92000000000000004	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
57827	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8816999999999986	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:50:00	\N	1.20999999999999996	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
57828	PGA Boulevard Bridge, Palm Beach, Florida (sub)	NOS	8722548	26.8432999999999993	-80.0666999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:31:00	\N	1.3600000000000001	-00:02:00	\N	1.15999999999999992	\N	\N	PGA Boulevard Bridge, ICWW	FL
57829	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8266999999999989	-80.0550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:15:00	\N	1.29000000000000004	-00:17:00	\N	1.21999999999999997	\N	\N	North Palm Beach	FL
57830	Port of West Palm Beach, Florida (sub)	NOS	8722588	26.7699999999999996	-80.0516999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:04:00	\N	1.3600000000000001	-00:21:00	\N	1.17999999999999994	\N	\N	Port of Palm Beach	FL
57831	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7332999999999998	-80.0417000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:16:00	\N	1.29000000000000004	-00:11:00	\N	1.16999999999999993	\N	\N	Palm Beach	FL
57832	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.7049999999999983	-80.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:40:00	\N	1.07000000000000006	00:18:00	\N	1.10000000000000009	\N	\N	Palm Beach, Highway 704 bridge	FL
57833	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.6449999999999996	-80.0450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:35:00	\N	1.1399999999999999	00:48:00	\N	1.07000000000000006	\N	\N	West Palm Beach Canal	FL
57834	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.5482997894287109	-80.0532989501953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:07:00	\N	1.07000000000000006	01:05:00	\N	1.06000000000000005	\N	\N	Boynton Beach, Lake Worth	FL
57835	Delray Beach, ICWW, Florida	NOS	8722746	26.4732999999999983	-80.0617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:07:00	\N	1.1399999999999999	01:24:00	\N	1.07000000000000006	\N	\N	Delray Beach, ICWW	FL
57836	Yamato, ICWW, Florida	NOS	8722784	26.4033000000000015	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:57:00	\N	1.1399999999999999	01:22:00	\N	1.02000000000000002	\N	\N	Yamato, ICWW	FL
57837	Lake Wyman, ICWW, Florida (sub)	NOS	8722802	26.370000000000001	-80.0699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:49:00	\N	1.1399999999999999	01:17:00	\N	0.959999999999999964	\N	\N	Lake Wyman, ICWW	FL
57838	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.3133000000000017	-80.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:03:00	\N	1.07000000000000006	00:28:00	\N	1.02000000000000002	\N	\N	Deerfield Beach, Hillsboro River	FL
57839	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.273299999999999	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:34:00	\N	1.07000000000000006	00:02:00	\N	1.06000000000000005	\N	\N	Hillsboro Beach, ICWW	FL
57840	Hillsboro Inlet, Coast Guard Light Station, Florida	NOS	8722861	26.2582999999999984	-80.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:03:00	\N	1.1399999999999999	-00:16:00	\N	1.08000000000000007	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
57841	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2566999999999986	-80.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:00:00	\N	1.20999999999999996	-00:23:00	\N	1.12000000000000011	\N	\N	Hillsboro Inlet (ocean)	FL
57842	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183000000000014	-80.144999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:51:00	\N	1.07000000000000006	00:15:00	\N	0.92000000000000004	\N	\N	Andrews Avenue bridge, New River	FL
57843	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1132999999999988	-80.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:33:00	\N	1.20999999999999996	-00:05:00	\N	1.05000000000000004	\N	\N	Bahia Mar Yacht Club	FL
57844	Mayan Lake, Florida	NOS	8722946	26.1000000000000014	-80.1082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:02:00	\N	1	00:20:00	\N	0.910000000000000031	\N	\N	Mayan Lake	FL
57845	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0916999999999994	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:09:00	\N	1.1399999999999999	-00:29:00	\N	1.09000000000000008	\N	\N	Port Everglades, Turning Basin	FL
57846	South Port Everglades, ICWW, Florida	NOS	8722956	26.0817000000000014	-80.1166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:03:00	\N	1.41999999999999993	-00:23:00	\N	1.10000000000000009	\N	\N	South Port Everglades, ICWW	FL
57847	Whiskey Creek, north end, Florida	NOS	8722957	26.0799999999999983	-80.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:06:00	\N	1.28000000000000003	-00:23:00	\N	1.10000000000000009	\N	\N	Whiskey Creek, north end	FL
57848	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.0599999999999987	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:11:00	\N	1.20999999999999996	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
57849	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.0549999999999997	-80.1132999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:31:00	\N	1.1399999999999999	00:04:00	\N	0.959999999999999964	\N	\N	Whiskey Creek, south entrance, ICWW	FL
57850	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0432999999999986	-80.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:42:00	\N	1.07000000000000006	01:08:00	\N	0.849999999999999978	\N	\N	Hollywood Beach, West Lake, north end	FL
57851	Hollywood Beach, Florida	NOS	8722979	26.0399999999999991	-80.1149999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:41:00	\N	1.1399999999999999	00:37:00	\N	0.910000000000000031	\N	\N	Hollywood Beach	FL
57852	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333000000000006	-80.1233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:45:00	\N	1.1399999999999999	01:02:00	\N	0.880000000000000004	\N	\N	Hollywood Beach, West Lake, south end	FL
57853	Golden Beach, ICWW, Florida	NOS	8723026	25.9666999999999994	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:57:00	\N	1.07000000000000006	01:13:00	\N	0.910000000000000031	\N	\N	Golden Beach, ICWW	FL
57854	Dumfoundling Bay, Florida	NOS	8723044	25.9417000000000009	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:07:00	\N	1	01:17:00	\N	0.880000000000000004	\N	\N	Dumfoundling Bay	FL
57855	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.9299999999999997	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:00:00	\N	1.20999999999999996	-00:22:00	\N	1.08000000000000007	\N	\N	North Miami Beach, Newport Fishing Pier	FL
57856	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033000000000015	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:37:00	\N	0.92000000000000004	00:57:00	\N	0.869999999999999996	\N	\N	Bakers Haulover Inlet (inside)	FL
57857	Haulover Pier, N. Miami Beach, Florida (sub)	NOS	8723080	25.9033000000000015	-80.1200000000000045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:06:00	\N	1	-00:29:00	\N	1.06000000000000005	\N	\N	Haulover Pier, N. Miami Beach	FL
57858	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283000000000001	-80.1299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:24:00	\N	0.709999999999999964	02:00:00	\N	0.770000000000000018	\N	\N	Sunny Isles, Biscayne Creek	FL
57859	Biscayne Creek, ICWW, Florida	NOS	8723089	25.879999999999999	-80.1633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:39:00	\N	1	00:47:00	\N	0.930000000000000049	\N	\N	Biscayne Creek, ICWW	FL
57860	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1432999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:46:00	\N	0.92000000000000004	01:13:00	\N	0.92000000000000004	\N	\N	Indian Creek Golf Club, ICWW	FL
57861	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.7699999999999996	-80.1683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:10:00	\N	1	00:34:00	\N	0.910000000000000031	\N	\N	Dodge Island, Fishermans Channel	FL
57862	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7932999999999986	-80.1633000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:58:00	\N	1	00:37:00	\N	0.92000000000000004	\N	\N	San Marino Island	FL
57863	Miami, Miamarina, Biscayne Bay, Florida (sub)	NOS	8723165	25.7783000000000015	-80.1850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:49:00	\N	0.92000000000000004	00:20:00	\N	0.939999999999999947	\N	\N	Miami Miamarina, Biscayne Bay	FL
57864	Miami Beach (city pier), Florida (sub)	NOS	8723170	25.7683	-80.131699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:02:00	\N	1.1399999999999999	-00:22:00	\N	1.07000000000000006	\N	\N	Miami Harbor Entrance	FL
57865	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.726700000000001	-80.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:48:00	\N	0.92000000000000004	00:54:00	\N	0.839999999999999969	\N	\N	Dinner Key Marina	FL
57866	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6982999999999997	-80.1700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:31:00	\N	0.92000000000000004	00:44:00	\N	0.859999999999999987	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
57867	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517000000000017	-80.1599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:37:00	\N	0.92000000000000004	00:11:00	\N	0.880000000000000004	\N	\N	Coral Shoal, Biscayne Channel	FL
57868	Soldier Key, Florida	NOS	8723303	25.5899999999999999	-80.1616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:16:00	\N	0.709999999999999964	00:30:00	\N	0.810000000000000053	\N	\N	Soldier Key	FL
57869	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333000000000006	-80.1717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:18:00	\N	1	00:43:00	\N	0.729999999999999982	\N	\N	Ragged Keys, Biscayne Bay	FL
57870	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5066999999999986	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:26:00	\N	0.640000000000000013	01:25:00	\N	0.630000000000000004	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
57871	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.4800000000000004	-80.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	02:56:00	\N	0.709999999999999964	01:55:00	\N	0.630000000000000004	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
57872	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.476700000000001	-80.1800000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:05:00	\N	1.03000000000000003	-00:25:00	\N	1.03000000000000003	\N	\N	Sea Grape Point, Elliott Key	FL
57873	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.4149999999999991	-80.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:20:00	\N	0.640000000000000013	02:08:00	\N	0.630000000000000004	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
57874	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3966999999999992	-80.2332999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:08:00	\N	1	01:01:00	\N	0.67000000000000004	\N	\N	Adams Key, south end, Biscayne Bay	FL
57875	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917000000000002	-80.230000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:37:00	\N	1.07000000000000006	00:13:00	\N	0.800000000000000044	\N	\N	Christmas Point, Elliott Key	FL
57876	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3782999999999994	-80.256699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:21:00	\N	0.569999999999999951	02:19:00	\N	0.540000000000000036	\N	\N	Totten Key, west side, Biscayne Bay	FL
57877	Card Sound, western side, Florida	NOS	8723491	25.3449999999999989	-80.3316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:40:00	\N	0.429999999999999993	02:51:00	\N	0.299999999999999989	\N	\N	Card Sound, western side	FL
57878	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.3099999999999987	-80.2982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:30:00	\N	0.569999999999999951	02:38:00	\N	0.340000000000000024	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
57879	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3082999999999991	-80.2767000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:17:00	\N	1.5	-00:08:00	\N	1.02000000000000002	\N	\N	Ocean Reef Harbor, Key Largo	FL
57880	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.2899999999999991	-80.3400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:01:00	\N	0.5	02:45:00	\N	0.320000000000000007	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
57881	Main Key, Barnes Sound, Florida	NOS	8723571	25.2399999999999984	-80.4000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	06:16:00	\N	0.359999999999999987	05:04:00	\N	0.190000000000000002	\N	\N	Main Key, Barnes Sound	FL
57882	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.2349999999999994	-80.4300000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	06:20:00	\N	0.359999999999999987	05:14:00	\N	0.179999999999999993	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
57883	Carysfort Reef, Florida	NOS	8723583	25.2216999999999985	-80.2116999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:39:00	\N	1.3600000000000001	00:19:00	\N	1.03000000000000003	\N	\N	Carysfort Reef	FL
57884	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717000000000013	-80.3666999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:25:00	\N	1.1399999999999999	-00:01:00	\N	0.939999999999999947	\N	\N	Garden Cove, Key Largo	FL
57885	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417000000000002	-80.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	07:20:00	\N	1.08000000000000007	05:28:00	\N	1.46999999999999997	\N	\N	Flamingo, Florida Bay	FL
57886	Largo Sound, Key Largo, Florida	NOS	8723651	25.1400000000000006	-80.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	03:03:00	\N	0.5	02:13:00	\N	0.349999999999999978	\N	\N	Largo Sound, Key Largo	FL
57887	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817000000000014	-80.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:36:00	\N	1.20999999999999996	00:22:00	\N	0.939999999999999947	\N	\N	Rock Harbor, Key Largo	FL
57888	Point Charles, Key Largo, Florida	NOS	8723691	25.0817000000000014	-80.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:53:00	\N	0.640000000000000013	00:25:00	\N	0.770000000000000018	\N	\N	Point Charles, Key Largo	FL
57889	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.004999999999999	-80.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	04:35:00	\N	0.209999999999999992	02:52:00	\N	0.170000000000000012	\N	\N	Crane Keys, north side, Florida Bay	FL
57890	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.004999999999999	-80.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:26:00	\N	1.3600000000000001	00:07:00	\N	0.900000000000000022	\N	\N	Tavernier Harbor, Hawk Channel	FL
57891	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0032999999999994	-80.5300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:52:00	\N	1.07000000000000006	00:25:00	\N	0.599999999999999978	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
57892	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967000000000006	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	04:06:00	\N	0.140000000000000013	02:43:00	\N	0.220000000000000001	\N	\N	East Key, southern end, Florida Bay	FL
57893	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9732999999999983	-80.5499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:12:00	\N	1.20999999999999996	00:05:00	\N	0.959999999999999964	\N	\N	Plantation Key, Hawk Channel	FL
57894	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.9649999999999999	-80.5682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	04:00:00	\N	0.28999999999999998	02:45:00	\N	0.23000000000000001	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
57895	Snake Creek, USCG Station, Plantation Key, Florida	NOS	8723786	24.9532999999999987	-80.5866999999999933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:56:00	\N	0.5	01:08:00	\N	0.359999999999999987	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
57896	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9516999999999989	-80.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:56:00	\N	0.5	00:49:00	\N	0.46000000000000002	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
57897	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.9400000000000013	-80.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:51:00	\N	0.359999999999999987	00:07:00	\N	0.650000000000000022	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
57898	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383000000000017	-80.6099999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:00:00	\N	0.709999999999999964	00:16:00	\N	0.589999999999999969	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
57899	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233000000000011	-80.6717000000000013	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:57:00	\N	0.46000000000000002	00:31:00	\N	0.46000000000000002	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
57900	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.9250000000000007	-80.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:07:00	\N	0.369999999999999996	00:39:00	\N	0.369999999999999996	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
57901	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9132999999999996	-80.6599999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:45:00	\N	0.780000000000000027	-00:20:00	\N	0.780000000000000027	\N	\N	Shell Key Channel, Florida Bay	FL
57902	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.9149999999999991	-80.6400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:15:00	\N	0.609999999999999987	00:08:00	\N	0.609999999999999987	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
57903	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.9149999999999991	-80.631699999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:49:00	\N	1.20999999999999996	00:34:00	\N	0.869999999999999996	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
57904	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033000000000015	-80.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:31:00	\N	0.520000000000000018	00:09:00	\N	0.520000000000000018	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
57905	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.8999999999999986	-80.7049999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:54:00	\N	0.469999999999999973	00:32:00	\N	0.469999999999999973	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
57906	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8966999999999992	-80.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:14:00	\N	0.330000000000000016	-01:00:00	\N	0.979999999999999982	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
57907	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8766999999999996	-80.6766999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:35:00	\N	0.709999999999999964	-00:58:00	\N	1.30000000000000004	\N	\N	Indian Key, Hawk Channel	FL
57908	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683000000000014	-80.7032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:54:00	\N	0.880000000000000004	-01:25:00	\N	1.37999999999999989	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
57909	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.8649999999999984	-80.716700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:33:00	\N	0.380000000000000004	-00:18:00	\N	0.550000000000000044	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
57910	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.8500000000000014	-80.618300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:24:00	\N	1.3600000000000001	00:08:00	\N	0.859999999999999987	\N	\N	Alligator Reef, Hawk Channel	FL
57911	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.851700000000001	-80.7399999999999949	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:23:00	\N	0.330000000000000016	-00:25:00	\N	0.589999999999999969	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
57912	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.8449999999999989	-80.7483000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:42:00	\N	0.540000000000000036	-00:49:00	\N	0.849999999999999978	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
57913	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8416999999999994	-80.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:54:00	\N	0.75	-01:06:00	\N	1.12000000000000011	\N	\N	Channel Two, west side, Hawk Channel	FL
57914	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.8399999999999999	-80.7800000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:41:00	\N	0.67000000000000004	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
57915	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.8383000000000003	-80.7982999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:32:00	\N	0.380000000000000004	-00:11:00	\N	0.419999999999999984	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
57916	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367000000000004	-80.7667000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:42:00	\N	0.57999999999999996	-00:54:00	\N	0.900000000000000022	\N	\N	Channel Five, east side, Hawk Channel	FL
57917	Long Key Bight, Long Key, Florida	NOS	8723879	24.8282999999999987	-80.8083000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:43:00	\N	0.619999999999999996	-00:59:00	\N	1.03000000000000003	\N	\N	Long Key Bight, Long Key	FL
57918	Long Key Lake, Long Key, Florida	NOS	8723887	24.8200000000000003	-80.8166999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:57:00	\N	0.46000000000000002	00:33:00	\N	0.619999999999999996	\N	\N	Long Key Lake, Long Key	FL
57919	Long Key, western end, Florida	NOS	8723899	24.8033000000000001	-80.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:54:00	\N	0.330000000000000016	-01:01:00	\N	0.819999999999999951	\N	\N	Long Key, western end	FL
57920	Conch Key, eastern end, Florida	NOS	8723906	24.7916999999999987	-80.8833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:45:00	\N	0.540000000000000036	-01:09:00	\N	0.849999999999999978	\N	\N	Conch Key, eastern end	FL
57921	Toms Harbor Cut, Florida	NOS	8723912	24.7833000000000006	-80.9067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:30:00	\N	0.380000000000000004	-01:19:00	\N	0.369999999999999996	\N	\N	Toms Harbor Cut	FL
57922	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767000000000017	-80.9232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:49:00	\N	0.380000000000000004	05:07:00	\N	0.380000000000000004	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
57923	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7716999999999992	-80.9399999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	06:48:00	\N	1.04000000000000004	05:40:00	\N	0.729999999999999982	\N	\N	Grassy Key, north side, Florida Bay	FL
57924	Duck Key, Hawk Channel, Florida	NOS	8723927	24.7650000000000006	-80.9133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:40:00	\N	0.550000000000000044	-01:11:00	\N	0.969999999999999973	\N	\N	Duck Key, Hawk Channel	FL
57925	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.754999999999999	-80.9582999999999942	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:26:00	\N	0.709999999999999964	-00:52:00	\N	1.21999999999999997	\N	\N	Grassy Key, south side, Hawk Channel	FL
57926	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7332999999999998	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	06:26:00	\N	0.869999999999999996	05:09:00	\N	0.869999999999999996	\N	\N	Fat Deer Key, Florida Bay	FL
57927	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.7300000000000004	-81.0300000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:36:00	\N	0.709999999999999964	-01:11:00	\N	0.949999999999999956	\N	\N	Vaca Key-Fat Deer Key bridge	FL
57928	Key Colony Beach, Florida (sub)	NOS	8723962	24.7182999999999993	-81.0167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:53:00	\N	0.82999999999999996	-01:17:00	\N	1.21999999999999997	\N	\N	Key Colony Beach	FL
57929	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7032999999999987	-81.105000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:37:00	\N	0.75	-01:03:00	\N	1.12999999999999989	\N	\N	Boot Key Harbor bridge, Boot Key	FL
57930	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6266999999999996	-81.111699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:39:00	\N	0.790000000000000036	-01:03:00	\N	1.17999999999999994	\N	\N	Sombrero Key, Hawk Channel	FL
57931	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067000000000014	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:18:00	\N	0.5	-00:02:00	\N	0.540000000000000036	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
57932	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7032999999999987	-81.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:26:00	\N	0.5	-00:55:00	\N	0.810000000000000053	\N	\N	Pigeon Key, south side, Hawk Channel	FL
57933	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.7049999999999983	-81.1567000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:45:00	\N	0.46000000000000002	-00:10:00	\N	0.46000000000000002	\N	\N	Pigeon Key, north side, Florida Bay	FL
57934	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6832999999999991	-81.1916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:16:00	\N	0.5	-00:56:00	\N	0.790000000000000036	\N	\N	Molasses Key Channel, Molasses Keys	FL
57935	Money Key, Florida	NOS	8724082	24.6832999999999991	-81.216700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:17:00	\N	0.57999999999999996	00:03:00	\N	0.57999999999999996	\N	\N	Money Key	FL
57936	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6816999999999993	-81.2283000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:05:00	\N	0.67000000000000004	-00:49:00	\N	0.67000000000000004	\N	\N	Little Duck Key, east end, Hawk Channel	FL
57937	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.7749999999999986	-81.2266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:49:00	\N	0.689999999999999947	04:04:00	\N	0.689999999999999947	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
57938	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745000000000001	-81.236699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:50:00	\N	0.550000000000000044	03:52:00	\N	0.550000000000000044	\N	\N	Cocoanut Key, Florida Bay	FL
57939	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.6799999999999997	-81.2349999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:36:00	\N	0.46000000000000002	-00:52:00	\N	0.699999999999999956	\N	\N	Missouri Key-Little Duck Key Channel	FL
57940	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733000000000011	-81.243300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:22:00	\N	0.5	-00:47:00	\N	0.770000000000000018	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
57941	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.6700000000000017	-81.2516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:14:00	\N	0.619999999999999996	-00:57:00	\N	0.810000000000000053	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
57942	West Bahia Honda Key, Florida	NOS	8724129	24.7800000000000011	-81.2716999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:01:00	\N	1	03:59:00	\N	0.969999999999999973	\N	\N	West Bahia Honda Key	FL
57943	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.6550000000000011	-81.2817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:28:00	\N	0.630000000000000004	-00:46:00	\N	0.859999999999999987	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
57944	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667000000000002	-81.283299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:09:00	\N	1	03:54:00	\N	0.859999999999999987	\N	\N	Horseshoe Keys, south end	FL
57945	Johnson Keys, south end, Florida	NOS	8724153	24.7433000000000014	-81.2999999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:33:00	\N	0.959999999999999964	03:36:00	\N	0.719999999999999973	\N	\N	Johnson Keys, south end	FL
57946	Little Pine Key, south end, Florida	NOS	8724154	24.7133000000000003	-81.303299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:07:00	\N	0.790000000000000036	01:07:00	\N	0.560000000000000053	\N	\N	Little Pine Key, south end	FL
57947	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6982999999999997	-81.3182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:33:00	\N	0.82999999999999996	01:35:00	\N	0.57999999999999996	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
57948	Johnson Keys, north end, Florida	NOS	8724172	24.7667000000000002	-81.3233000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:22:00	\N	1.37999999999999989	03:35:00	\N	1.31000000000000005	\N	\N	Johnson Keys, north end	FL
57949	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3282999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:28:00	\N	1.20999999999999996	03:38:00	\N	1.05000000000000004	\N	\N	Little Pine Key, north end	FL
57950	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.648299999999999	-81.3299999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:03:00	\N	0.419999999999999984	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
57951	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.7399999999999984	-81.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:37:00	\N	1.04000000000000004	03:23:00	\N	0.810000000000000053	\N	\N	Water Key, west end, Big Spanish Channel	FL
57952	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517000000000017	-81.3499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:49:00	\N	0.5	-00:20:00	\N	0.869999999999999996	\N	\N	Big Pine Key, Coupon Bight	FL
57953	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6966999999999999	-81.3482999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:11:00	\N	0.82999999999999996	02:10:00	\N	0.650000000000000022	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
57954	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7182999999999993	-81.3516999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:29:00	\N	1	03:23:00	\N	0.719999999999999973	\N	\N	Porpoise Key, Big Spanish Channel	FL
57955	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7566999999999986	-81.3582999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:13:00	\N	1.33000000000000007	03:34:00	\N	1.33000000000000007	\N	\N	Crawl Key, Big Spanish Channel	FL
57956	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.6900000000000013	-81.3567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:47:00	\N	0.709999999999999964	00:41:00	\N	0.630000000000000004	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
57957	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7332999999999998	-81.361699999999999	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:01:00	\N	1.08000000000000007	03:35:00	\N	0.92000000000000004	\N	\N	Mayo Key, Big Spanish Channel	FL
57958	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.773299999999999	-81.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:30:00	\N	1.62000000000000011	03:25:00	\N	1.73999999999999999	\N	\N	Little Spanish Key, Spanish Banks	FL
57959	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.6700000000000017	-81.368300000000005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:43:00	\N	0.330000000000000016	00:03:00	\N	0.569999999999999951	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
57960	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6682999999999986	-81.3717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:03:00	\N	0.330000000000000016	-00:13:00	\N	0.67000000000000004	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
57961	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517000000000017	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:44:00	\N	0.46000000000000002	-00:09:00	\N	0.819999999999999951	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
57962	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.6649999999999991	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:57:00	\N	0.330000000000000016	-00:15:00	\N	0.680000000000000049	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
57963	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.6649999999999991	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:54:00	\N	0.380000000000000004	-00:13:00	\N	0.689999999999999947	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
57964	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283000000000008	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:30:00	\N	1.08000000000000007	03:19:00	\N	0.859999999999999987	\N	\N	Big Pine Key, northeast shore	FL
57965	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.6900000000000013	-81.3833000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:52:00	\N	0.419999999999999984	00:21:00	\N	0.520000000000000018	\N	\N	Big Pine Key, west side, Pine Channel	FL
57966	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7582999999999984	-81.3900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:33:00	\N	1.29000000000000004	03:30:00	\N	1.43999999999999995	\N	\N	Annette Key, north end, Big Spanish Channel	FL
57967	Big Pine Key, north end, Florida	NOS	8724231	24.745000000000001	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:56:00	\N	0.82999999999999996	04:24:00	\N	0.959999999999999964	\N	\N	Big Pine Key, north end	FL
57968	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.6649999999999991	-81.394999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:45:00	\N	0.330000000000000016	00:11:00	\N	0.569999999999999951	\N	\N	Little Torch Key, Torch Channel	FL
57969	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6616999999999997	-81.4017000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:29:00	\N	0.380000000000000004	-00:16:00	\N	0.689999999999999947	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
57970	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233000000000004	-81.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:12:00	\N	0.67000000000000004	-00:40:00	\N	0.979999999999999982	\N	\N	Munson Island, Newfound Harbor Channel	FL
57971	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.6499999999999986	-81.4033000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:05:00	\N	0.5	-00:41:00	\N	0.900000000000000022	\N	\N	Ramrod Key, Newfound Harbor	FL
57972	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.7250000000000014	-81.4067000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:49:00	\N	0.619999999999999996	04:43:00	\N	0.719999999999999973	\N	\N	Howe Key, south end, Harbor Channel	FL
57973	Big Spanish Key, Florida	NOS	8724246	24.7882999999999996	-81.4116999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:29:00	\N	1.5	03:19:00	\N	1.96999999999999997	\N	\N	Big Spanish Key	FL
57974	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.6600000000000001	-81.4232999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:12:00	\N	0.46000000000000002	-00:13:00	\N	0.67000000000000004	\N	\N	Ramrod Key, Niles Channel Bridge	FL
57975	Howe Key, northwest end, Florida	NOS	8724257	24.7582999999999984	-81.428299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:22:00	\N	1.33000000000000007	03:29:00	\N	1.67999999999999994	\N	\N	Howe Key, northwest end	FL
57976	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.7049999999999983	-81.4333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:05:00	\N	0.709999999999999964	03:15:00	\N	0.609999999999999987	\N	\N	Big Torch Key, Niles Channel	FL
57977	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517000000000017	-81.4350000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:11:00	\N	0.709999999999999964	-00:36:00	\N	0.849999999999999978	\N	\N	Summerland Key, Niles Channel South	FL
57978	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.6600000000000001	-81.4367000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:56:00	\N	0.57999999999999996	-00:10:00	\N	0.67000000000000004	\N	\N	Summerland Key, Niles Channel Bridge	FL
57979	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467000000000006	-81.4500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:41:00	\N	1	03:42:00	\N	1.52000000000000002	\N	\N	Water Keys, south end, Harbor Channel	FL
57980	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.736699999999999	-81.4432999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:51:00	\N	1.29000000000000004	03:47:00	\N	1.58000000000000007	\N	\N	Big Torch Key, Harbor Channel	FL
57981	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.6499999999999986	-81.446700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:50:00	\N	0.540000000000000036	-00:26:00	\N	0.810000000000000053	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
57982	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6616999999999997	-81.4682999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:04:00	\N	0.46000000000000002	00:47:00	\N	0.57999999999999996	\N	\N	Kemp Channel Viaduct	FL
57983	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.4699999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:45:00	\N	0.75	-01:15:00	\N	1.06000000000000005	\N	\N	Key Lois, southeast end	FL
57984	Knockemdown Key, north end, Florida	NOS	8724302	24.7149999999999999	-81.4783000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:54:00	\N	1.20999999999999996	03:30:00	\N	1.35000000000000009	\N	\N	Knockemdown Key, north end	FL
57985	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417000000000002	-81.4849999999999994	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:17:00	\N	0.709999999999999964	-00:46:00	\N	0.900000000000000022	\N	\N	Gopher Key, Cudjoe Bay	FL
57986	Content Keys, Content Passage, Florida	NOS	8724307	24.7899999999999991	-81.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:49:00	\N	1.83000000000000007	02:46:00	\N	2.12999999999999989	\N	\N	Content Keys, Content Passage	FL
57987	Raccoon Key, east side, Florida	NOS	8724311	24.7417000000000016	-81.4832999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:09:00	\N	1.20999999999999996	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
57988	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.6600000000000001	-81.4916999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:41:00	\N	0.709999999999999964	-00:38:00	\N	0.869999999999999996	\N	\N	Cudjoe Key, Cudjoe Bay	FL
57989	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533000000000015	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:41:00	\N	0.75	-00:48:00	\N	0.589999999999999969	\N	\N	Sugarloaf Key, Pirates Cove	FL
57990	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6282999999999994	-81.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:15:00	\N	0.57999999999999996	-00:41:00	\N	0.890000000000000013	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
57991	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.6999999999999993	-81.5049999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:40:00	\N	1.45999999999999996	03:33:00	\N	1.6100000000000001	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
57992	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6616999999999997	-81.5150000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:54:00	\N	0.790000000000000036	03:50:00	\N	0.770000000000000018	\N	\N	Cudjoe Key, Pirates Cove	FL
57993	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.629999999999999	-81.5167000000000002	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:17:00	\N	0.380000000000000004	-00:29:00	\N	0.349999999999999978	\N	\N	Tarpon Creek	FL
57994	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717000000000013	-81.533299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:24:00	\N	0.709999999999999964	03:47:00	\N	1.01000000000000001	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
57995	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.6550000000000011	-81.5400000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	08:33:00	\N	0.28999999999999998	05:47:00	\N	0.260000000000000009	\N	\N	Park Channel Bridge	FL
57996	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533000000000015	-81.553299999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
57997	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933000000000007	-81.5550000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:20:00	\N	0.75	03:37:00	\N	1.29000000000000004	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
57998	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7582999999999984	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:19:00	\N	0.5	02:37:00	\N	1.42999999999999994	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
57999	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7582999999999984	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:24:00	\N	0.5	02:45:00	\N	1.57000000000000006	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
58000	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7166999999999994	-81.5617000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:39:00	\N	1.16999999999999993	03:17:00	\N	1.56000000000000005	\N	\N	Pumpkin Key, Bow Channel	FL
58001	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.648299999999999	-81.5699999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	08:25:00	\N	0.0800000000000000017	05:37:00	\N	0.280000000000000027	\N	\N	Perky	FL
58002	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.7100000000000009	-81.5932999999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:38:00	\N	0.5	03:26:00	\N	1.10000000000000009	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
58619	Nismeni Cove, Alaska	NOS	9451979	57.5617000000000019	-135.412000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:03:00	-0.100000000000000006	\N	-00:15:00	-1.30000000000000004	\N	\N	\N	Nismeni Cove	AK
58003	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233000000000004	-81.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:10:00	\N	0.209999999999999992	01:44:00	\N	0.429999999999999993	\N	\N	Saddlebunch Keys, Channel No. 3	FL
58004	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583000000000006	-81.6082999999999998	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:39:00	\N	0.82999999999999996	03:25:00	\N	1.28000000000000003	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
58005	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.6149999999999984	-81.6166999999999945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:36:00	\N	0.28999999999999998	04:35:00	\N	0.540000000000000036	\N	\N	Saddlebunch Keys, Channel No. 4	FL
58006	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6000000000000014	-81.6217000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:41:00	\N	0.209999999999999992	00:39:00	\N	0.369999999999999996	\N	\N	Saddlebunch Keys, Similar Sound	FL
58007	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.611699999999999	-81.6233000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	06:58:00	\N	1.12000000000000011	04:32:00	\N	0.660000000000000031	\N	\N	Saddlebunch Keys, Channel No. 5	FL
58008	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6666999999999987	-81.6299999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:54:00	\N	0.67000000000000004	03:44:00	\N	1.02000000000000002	\N	\N	Snipe Keys, Middle Narrows	FL
58009	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883000000000003	-81.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:03:00	\N	0.419999999999999984	-00:21:00	\N	0.589999999999999969	\N	\N	Bird Key, Similar Sound	FL
58010	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033000000000008	-81.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:51:00	\N	0.46000000000000002	00:18:00	\N	0.520000000000000018	\N	\N	Shark Key, southeast end, Similar Sound	FL
58011	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167000000000016	-81.644999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:39:00	\N	0.82999999999999996	03:53:00	\N	1.03000000000000003	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
58012	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6466999999999992	-81.6533000000000015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:33:00	\N	0.959999999999999964	03:53:00	\N	1.03000000000000003	\N	\N	Waltz Key, Waltz Key Basin	FL
58013	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5916999999999994	-81.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	06:06:00	\N	0.880000000000000004	05:02:00	\N	0.760000000000000009	\N	\N	Rockland Key, Rockland Channel Bridge	FL
58014	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917000000000009	-81.6732999999999976	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:33:00	\N	1.29000000000000004	02:15:00	\N	1.68999999999999995	\N	\N	Snipe Keys, Snipe Point	FL
58015	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233000000000004	-81.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	04:57:00	\N	0.959999999999999964	03:27:00	\N	1.18999999999999995	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
58016	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033000000000008	-81.6983000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	05:22:00	\N	0.709999999999999964	03:54:00	\N	0.939999999999999947	\N	\N	Boca Chica Key, Long Point	FL
58017	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.601700000000001	-81.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	06:54:00	\N	0.330000000000000016	04:21:00	\N	0.839999999999999969	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
58018	Boca Chica Key, Southwest end, Florida	NOS	8724499	24.5633000000000017	-81.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:16:00	\N	0.630000000000000004	-00:14:00	\N	0.660000000000000031	\N	\N	Boca Chica Key, Southwest end	FL
58019	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5766999999999989	-81.7216999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:29:00	\N	0.67000000000000004	01:23:00	\N	0.569999999999999951	\N	\N	Boca Chica Channel Bridge	FL
58020	Channel Key, west side, Florida	NOS	8724507	24.6033000000000008	-81.7249999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	03:07:00	\N	0.709999999999999964	03:09:00	\N	0.699999999999999956	\N	\N	Channel Key, west side	FL
58021	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.5799999999999983	-81.7382999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:57:00	\N	0.790000000000000036	02:25:00	\N	0.729999999999999982	\N	\N	Key Haven - Stock Island Channel	FL
58022	Cow Key Channel, Florida	NOS	8724527	24.5700000000000003	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:05:00	\N	0.709999999999999964	01:55:00	\N	0.650000000000000022	\N	\N	Cow Key Channel	FL
58023	Riviera Canal, Key West, Florida	NOS	8724529	24.5650000000000013	-81.7516999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	01:00:00	\N	0.630000000000000004	-00:12:00	\N	0.650000000000000022	\N	\N	Riveria Canal, Key West	FL
58024	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.5850000000000009	-81.7750000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	02:06:00	\N	0.880000000000000004	01:59:00	\N	0.810000000000000053	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
58025	Key West, south side, White Street Pier, Florida	NOS	8724557	24.5450000000000017	-81.783299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:31:00	\N	0.92000000000000004	-00:53:00	\N	1.07000000000000006	\N	\N	Key West, south side, White Street Pier	FL
58026	Sand Key Lighthouse, Sand Key Channel, Florida (sub)	NOS	8724635	24.4532999999999987	-81.8782999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	-00:32:00	\N	0.880000000000000004	-00:43:00	\N	0.949999999999999956	\N	\N	Sand Key Lighthouse, Sand Key Channel	FL
58027	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6266999999999996	-82.8717000000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56058	00:33:00	\N	1.33000000000000007	00:29:00	\N	0.939999999999999947	\N	\N	Garden Key, Dry Tortugas	FL
58028	Shark River entrance, Florida	NOS	8724769	25.3449999999999989	-81.1266999999999996	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:45:00	\N	0.979999999999999982	00:57:00	\N	1.42999999999999994	\N	\N	Shark River entrance	FL
58029	Lostmans River entrance, Florida	NOS	8724842	25.5533000000000001	-81.2133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:59:00	\N	0.979999999999999982	01:09:00	\N	1.33000000000000007	\N	\N	Lostmans River entrance	FL
58030	Onion Key, Lostmans River, Florida	NOS	8724863	25.611699999999999	-81.1333000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	04:53:00	\N	0.160000000000000003	03:09:00	\N	0.260000000000000009	\N	\N	Onion Key, Lostmans River	FL
58031	Chatham River entrance, Florida	NOS	8724891	25.6900000000000013	-81.2849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:53:00	\N	0.660000000000000031	00:59:00	\N	1.42999999999999994	\N	\N	Chatham River entrance	FL
58032	Chokoloskee, Florida	NOS	8724919	25.8133000000000017	-81.3632999999999953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	03:14:00	\N	0.619999999999999996	02:15:00	\N	1.1100000000000001	\N	\N	Chokoloskee	FL
58033	Cape Romano, Florida	NOS	8724947	25.8533000000000008	-81.6749999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:04:00	\N	0.979999999999999982	00:43:00	\N	1.18999999999999995	\N	\N	Cape Romano	FL
58034	Everglades City, Barron River, Florida	NOS	8724948	25.8582999999999998	-81.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	03:26:00	\N	0.569999999999999951	02:25:00	\N	0.989999999999999991	\N	\N	Everglades City, Barron River	FL
58035	Dismal Key, Pumpkin Bay, Florida (sub)	NOS	8724963	25.8949999999999996	-81.5583000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	03:07:00	\N	0.489999999999999991	02:39:00	\N	0.890000000000000013	\N	\N	Pumpkin Bay	FL
58036	Coon Key Pass, Gullivan Bay, Florida (sub)	NOS	8724964	25.8966999999999992	-81.6367000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:31:00	\N	0.979999999999999982	01:15:00	\N	1.18999999999999995	\N	\N	Coon Key	FL
58037	Naples, Naples Bay, north end, Florida	NOS	8725114	26.1367000000000012	-81.7883000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	00:56:00	\N	0.900000000000000022	00:43:00	\N	0.969999999999999973	\N	\N	Naples, Naples Bay, north end	FL
58038	Cocohatchee River, U.S. 41 bridge, Florida	NOS	8725228	26.2817000000000007	-81.8016999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:28:00	\N	0.650000000000000022	01:10:00	\N	0.739999999999999991	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
58039	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.2899999999999991	-81.8182999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	00:59:00	\N	0.729999999999999982	00:44:00	\N	0.770000000000000018	\N	\N	Wiggins Pass, Cocohatchee River	FL
58040	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.3533000000000008	-81.855000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:05:00	\N	1.09000000000000008	-00:58:00	\N	1.09000000000000008	\N	\N	Little Hickory Island	FL
58041	Carlos Point, Estero Bay, Florida	NOS	8725325	26.4050000000000011	-81.8850000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:28:00	\N	1.16999999999999993	-01:08:00	\N	1.16999999999999993	\N	\N	Carlos Point	FL
58042	Estero River, Estero Bay, Florida	NOS	8725346	26.4299999999999997	-81.8567000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:10:00	\N	1.1100000000000001	-00:45:00	\N	1.09000000000000008	\N	\N	Estero River	FL
58043	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567000000000014	-81.9532999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:34:00	\N	1.21999999999999997	-01:10:00	\N	1.21999999999999997	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
58044	Captiva Island (outside), Florida	NOS	8725383	26.4783000000000008	-82.1833000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-02:28:00	\N	1.12999999999999989	-02:20:00	\N	1.12999999999999989	\N	\N	Captiva Island (outside)	FL
58045	St. James City, Pine Island, Florida	NOS	8725393	26.4917000000000016	-82.0816999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:44:00	\N	1.04000000000000004	-00:30:00	\N	1.04000000000000004	\N	\N	St. James City, Pine Island	FL
58046	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.513300000000001	-82.1067000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:16:00	\N	0.910000000000000031	-00:25:00	\N	0.910000000000000031	\N	\N	Galt Island, Pine Island Sound	FL
58047	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5216999999999992	-82.1882999999999981	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:20:00	\N	0.910000000000000031	-00:46:00	\N	0.910000000000000031	\N	\N	Captiva Island, Pine Island Sound	FL
58048	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5216999999999992	-81.9650000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:40:00	\N	0.429999999999999993	01:08:00	\N	0.429999999999999993	\N	\N	Iona Shores	FL
58049	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483000000000011	-82.0799999999999983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:22:00	\N	0.869999999999999996	-00:08:00	\N	0.869999999999999996	\N	\N	Tropical Homesites Landing, Pine Island	FL
58050	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.5500000000000007	-82.196700000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:14:00	\N	0.910000000000000031	-00:55:00	\N	0.910000000000000031	\N	\N	Redfish Pass, Captiva Island (north end)	FL
58051	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.5633000000000017	-81.9333000000000027	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	02:02:00	\N	0.429999999999999993	01:15:00	\N	0.429999999999999993	\N	\N	Cape Coral Bridge	FL
58052	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.6316999999999986	-82.0682999999999936	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:28:00	\N	0.82999999999999996	00:43:00	\N	0.82999999999999996	\N	\N	Matlacha Pass (bascule bridge)	FL
58053	Pineland, Pine Island, Florida	NOS	8725528	26.6600000000000001	-82.1550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:26:00	\N	0.82999999999999996	-00:19:00	\N	0.82999999999999996	\N	\N	Pineland, Pine Island	FL
58054	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333000000000013	-82.2650000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:56:00	\N	0.939999999999999947	-00:43:00	\N	0.589999999999999969	\N	\N	Placida, Gasparilla Sound	FL
58055	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283000000000001	-82.0649999999999977	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:27:00	\N	0.82999999999999996	01:06:00	\N	0.82999999999999996	\N	\N	Punta Gorda, Charlotte Harbor	FL
58056	Englewood, Lemon Bay, Florida	NOS	8725747	26.9332999999999991	-82.3533000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:17:00	\N	0.819999999999999951	-00:17:00	\N	0.660000000000000031	\N	\N	Englewood, Lemon Bay	FL
58057	El Jobean, Myakka River, Florida	NOS	8725769	26.9617000000000004	-82.2099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:56:00	\N	0.82999999999999996	01:38:00	\N	0.82999999999999996	\N	\N	El Jobean, Myakka River	FL
58058	Venice Inlet (inside), Florida	NOS	8725889	27.111699999999999	-82.4633000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:38:00	\N	0.910000000000000031	-02:02:00	\N	0.910000000000000031	\N	\N	Venice Inlet (inside)	FL
58059	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317000000000014	-82.5450000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:58:00	\N	0.910000000000000031	-01:38:00	\N	0.910000000000000031	\N	\N	Sarasota, Sarasota Bay	FL
58060	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4666999999999994	-82.6867000000000019	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:25:00	\N	0.959999999999999964	-02:00:00	\N	0.959999999999999964	\N	\N	Cortez, Sarasota Bay	FL
58061	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967000000000006	-82.7133000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-03:32:00	\N	1	-02:27:00	\N	0.989999999999999991	\N	\N	Anna Maria Key, Bradenton Beach	FL
58062	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733000000000033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:55:00	\N	0.949999999999999956	-01:24:00	\N	0.969999999999999973	\N	\N	Bradenton, Manatee River	FL
58063	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267000000000017	-82.4817000000000036	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:14:00	\N	1	-00:30:00	\N	0.92000000000000004	\N	\N	Redfish Point, Manatee River	FL
58064	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333000000000006	-82.730000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-02:19:00	\N	0.989999999999999991	-02:10:00	\N	0.989999999999999991	\N	\N	Anna Maria Key, city pier	FL
58065	Egmont Key, Egmont Channel, Tampa Bay, Florida (sub)	NOS	8726347	27.601700000000001	-82.7600000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-03:20:00	\N	1	-02:15:00	\N	0.959999999999999964	\N	\N	Egmont Key, Egmont Channel	FL
58066	Mullet Key Channel (Skyway), Tampa Bay, Florida (sub)	NOS	8726364	27.6149999999999984	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-02:01:00	\N	0.92000000000000004	-02:03:00	\N	0.92000000000000004	\N	\N	Mullet Key Channel (Skyway)	FL
58067	Point Pinellas, Florida	NOS	8726454	27.7016999999999989	-82.6400000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:29:00	\N	0.859999999999999987	-00:22:00	\N	0.859999999999999987	\N	\N	Point Pinellas	FL
58068	Shell Point, Florida	NOS	8726468	27.7182999999999993	-82.480000000000004	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:17:00	\N	0.910000000000000031	00:08:00	\N	0.910000000000000031	\N	\N	Shell Point	FL
58069	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.736699999999999	-82.7066999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:05:00	\N	0.959999999999999964	-01:32:00	\N	0.959999999999999964	\N	\N	Gulfport	FL
58070	Long Key, 0.5mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7516999999999996	-82.7532999999999959	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:44:00	\N	1	-01:18:00	\N	0.92000000000000004	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
58071	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.7850000000000001	-82.7817000000000007	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-02:04:00	\N	1.02000000000000002	-02:14:00	\N	0.969999999999999973	\N	\N	Johns Pass	FL
58072	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.7866992950439453	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:32:00	\N	1.19999999999999996	00:53:00	\N	1.10000000000000009	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
58073	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8082999999999991	-82.7950000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:45:00	\N	1.17999999999999994	-01:32:00	\N	1.08000000000000007	\N	\N	Madeira Beach Causeway	FL
58074	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8766999999999996	-82.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-00:53:00	\N	0.630000000000000004	-00:57:00	\N	0.650000000000000022	\N	\N	Indian Rocks Beach (inside)	FL
58075	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:57:00	\N	1.23999999999999999	00:59:00	\N	1.12000000000000011	\N	\N	Gandy Bridge, Old Tampa Bay	FL
58076	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.898299999999999	-82.4266999999999967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:05:00	\N	1.17999999999999994	00:21:00	\N	1.1399999999999999	\N	\N	Pendola Point, Hillsborough Bay	FL
58077	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083000000000006	-82.4517000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:32:00	\N	1.23999999999999999	00:03:00	\N	1.15999999999999992	\N	\N	Davis Island, Hillsborough Bay	FL
58078	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417000000000009	-82.7199999999999989	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:32:00	\N	1.37000000000000011	01:01:00	\N	1.23999999999999999	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
58079	Clearwater, Florida	NOS	8726706	27.9549999999999983	-82.8067000000000064	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:35:00	\N	0.630000000000000004	-01:48:00	\N	0.650000000000000022	\N	\N	Clearwater	FL
58080	Clearwater Beach, Gulf Of Mexico, Florida (sub)	NOS	8726724	27.9783000000000008	-82.8316999999999979	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-02:19:00	\N	0.839999999999999969	-02:07:00	\N	0.689999999999999947	\N	\N	Clearwater Beach	FL
58081	Safety Harbor, Old Tampa Bay, Florida (sub)	NOS	8726738	27.9882999999999988	-82.6850000000000023	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	01:34:00	\N	1.3899999999999999	01:32:00	\N	1.22999999999999998	\N	\N	Safety Harbor, Old Tampa Bay	FL
58082	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.013300000000001	-82.7933000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:45:00	\N	0.790000000000000036	-01:50:00	\N	0.699999999999999956	\N	\N	Dunedin, St. Joseph Sound	FL
58083	Mobbly Bayou, Florida	NOS	8726769	28.0216999999999992	-82.6550000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	02:54:00	\N	0.450000000000000011	02:38:00	\N	0.709999999999999964	\N	\N	Mobbly Bayou	FL
58084	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.1600000000000001	-82.7682999999999964	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:03:00	\N	0.82999999999999996	-01:16:00	\N	0.770000000000000018	\N	\N	Tarpon Springs, Anclote River	FL
58085	Anclote, Anclote River, Florida	NOS	8726924	28.1717000000000013	-82.7849999999999966	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:24:00	\N	0.869999999999999996	-01:28:00	\N	0.780000000000000027	\N	\N	Anclote, Anclote River	FL
58086	North Anclote Key, Florida	NOS	8726942	28.2100000000000009	-82.8400000000000034	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:38:00	\N	0.859999999999999987	-01:55:00	\N	0.800000000000000044	\N	\N	North Anclote Key	FL
58088	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483000000000004	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-00:11:00	\N	0.869999999999999996	-00:58:00	\N	0.880000000000000004	\N	\N	New Port Richey, Pithlachascotee River	FL
58089	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7266999999999939	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-00:40:00	\N	0.839999999999999969	-01:16:00	\N	0.849999999999999978	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
58090	Hudson, Hudson Creek, Florida	NOS	8727061	28.361699999999999	-82.7099999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	-01:02:00	\N	0.890000000000000013	-01:12:00	\N	0.910000000000000031	\N	\N	Hudson, Hudson Creek	FL
58091	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4332999999999991	-82.6683000000000021	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:23:00	\N	0.630000000000000004	-00:37:00	\N	0.810000000000000053	\N	\N	Aripeka, Hammock Creek	FL
58092	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.486699999999999	-82.6616999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:58:00	\N	0.82999999999999996	-00:20:00	\N	0.82999999999999996	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
58093	Johns Island, Chassahowitzka Bay, Florida (sub)	NOS	8727235	28.6917000000000009	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	02:14:00	\N	0.489999999999999991	01:09:00	\N	0.619999999999999996	\N	\N	Johns Island, Chassahowitzka Bay	FL
58094	Chassahowitzka, Chassahowitzka River, Florida (sub)	NOS	8727246	28.7149999999999999	-82.5767000000000024	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	05:45:00	\N	0.160000000000000003	03:59:00	\N	0.140000000000000013	\N	\N	Chassahowitzka, Chassahowitzka River	FL
58095	Mason Creek, Homosassa Bay, Florida (sub)	NOS	8727274	28.7617000000000012	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	04:44:00	\N	0.25	03:09:00	\N	0.320000000000000007	\N	\N	Mason Creek, Homosassa Bay	FL
58096	Tuckers Island, Homosassa River, Florida (sub)	NOS	8727277	28.7716999999999992	-82.6949999999999932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	02:23:00	\N	0.330000000000000016	01:26:00	\N	0.469999999999999973	\N	\N	Tuckers Island, Homosassa River	FL
58097	Halls River bridge, Homosassa River, Florida (sub)	NOS	8727293	28.8000000000000007	-82.6033000000000044	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	05:41:00	\N	0.130000000000000004	04:30:00	\N	0.160000000000000003	\N	\N	Halls River bridge, Homosassa River	FL
58098	Ozello, St. Martin's River, Florida (sub)	NOS	8727306	28.8249999999999993	-82.658299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	05:21:00	\N	0.140000000000000013	04:25:00	\N	0.170000000000000012	\N	\N	Ozello, St. Martins River	FL
58099	Ozello North, Crystal Bay, Florida (sub)	NOS	8727328	28.8632999999999988	-82.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	03:17:00	\N	0.25	01:25:00	\N	0.5	\N	\N	Ozello north, Crystal Bay	FL
58100	Mangrove Pt., Crystal Bay, Florida (sub)	NOS	8727333	28.870000000000001	-82.7232999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:41:00	\N	0.760000000000000009	00:22:00	\N	0.949999999999999956	\N	\N	Mangrove Pt., Crystal Bay	FL
58101	Dixie Bay, Salt River, Crystal Bay, Florida (sub)	NOS	8727336	28.8816999999999986	-82.6350000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	03:06:00	\N	0.330000000000000016	02:00:00	\N	0.550000000000000044	\N	\N	Dixie Bay, Salt River, Crystal Bay	FL
58102	Crystal River, Kings Bay, Florida (sub)	NOS	8727343	28.898299999999999	-82.5982999999999947	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	03:07:00	\N	0.409999999999999976	02:20:00	\N	0.589999999999999969	\N	\N	Kings Bay	FL
58103	Twin Rivers Marina, Crystal River, Florida (sub)	NOS	8727348	28.9050000000000011	-82.638300000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	02:30:00	\N	0.489999999999999991	01:46:00	\N	0.640000000000000013	\N	\N	Twin Rivers Marina	FL
58104	Shell Island, north end, Crystal River, Florida (sub)	NOS	8727359	28.9233000000000011	-82.6916999999999973	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	01:30:00	\N	0.589999999999999969	00:36:00	\N	0.790000000000000036	\N	\N	Shell Island, north end	FL
58105	Florida Power, Crystal River, Florida	NOS	8727386	28.9600000000000009	-82.7249999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:30:00	\N	0.890000000000000013	-00:03:00	\N	1.04000000000000004	\N	\N	Florida Power	FL
58106	Withlacoochee River entrance, Florida	NOS	8727395	29.0016999999999996	-82.7583000000000055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:55:00	\N	0.949999999999999956	00:07:00	\N	0.910000000000000031	\N	\N	Withlacoochee River entrance	FL
58107	Suwannee, Salt Creek, Florida	NOS	8727577	29.3282999999999987	-83.1517000000000053	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:24:00	\N	0.82999999999999996	-00:07:00	\N	0.910000000000000031	\N	\N	Suwannee, Salt Creek	FL
58108	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717000000000013	-83.3900000000000006	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:00:00	\N	1.08000000000000007	00:02:00	\N	1.03000000000000003	\N	\N	Steinhatchee River ent., Deadman Bay	FL
58109	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1266999999999996	-83.9749999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	00:57:00	\N	0.550000000000000044	00:25:00	\N	0.689999999999999947	\N	\N	Mandalay, Aucilla River	FL
58110	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533000000000015	-84.2032999999999987	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	01:04:00	\N	0.910000000000000031	00:36:00	\N	0.930000000000000049	\N	\N	St. Marks, St. Marks River	FL
58111	Shell Point, Walker Creek, Apalachee Bay, Florida (sub)	NOS	8728229	30.0599999999999987	-84.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	-00:03:00	\N	1.08000000000000007	-00:03:00	\N	1.02000000000000002	\N	\N	Shell Point, Walker Creek	FL
58112	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9482999999999997	-84.341700000000003	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	00:19:00	\N	0.699999999999999956	00:33:00	\N	0.849999999999999978	\N	\N	Bald Point, Ochlockonee Bay	FL
58113	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.0283000000000015	-84.3867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	00:20:00	\N	0.819999999999999951	00:16:00	\N	1.01000000000000001	\N	\N	Panacea, Dickerson Bay	FL
58114	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033000000000015	-84.4133000000000067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	00:11:00	\N	0.729999999999999982	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
58115	Turkey Point, Apalachee Bay, St. James Island, Florida (sub)	NOS	8728360	29.9149999999999991	-84.5117000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	-00:21:00	\N	0.979999999999999982	-00:16:00	\N	0.780000000000000027	\N	\N	Turkey Point, St. James Island	FL
58116	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.8500000000000014	-84.6650000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-02:13:00	\N	1.60000000000000009	-01:25:00	\N	1.60000000000000009	\N	\N	Carrabelle, Carrabelle River	FL
58117	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.7850000000000001	-84.6667000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-02:38:00	\N	1.39999999999999991	-01:53:00	\N	1.72999999999999998	\N	\N	Dog Island, west end	FL
58118	St. George Island, East End, St. George Sound, Florida	NOS	8728548	29.6866999999999983	-84.7866999999999962	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-02:48:00	\N	1	-02:02:00	\N	1.12999999999999989	\N	\N	St. George Island, East End	FL
58119	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917000000000009	-84.7917000000000058	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-01:35:00	\N	1.19999999999999996	-01:00:00	\N	1.33000000000000007	\N	\N	St. George Island, Rattlesnake Cove	FL
58120	Cat Point, Apalachicola Bay, Florida (sub)	NOS	8728619	29.7232999999999983	-84.8867000000000047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-01:17:00	\N	0.599999999999999978	-00:40:00	\N	1.07000000000000006	\N	\N	Cat Point	FL
58121	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533000000000015	-84.8966999999999956	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-01:08:00	\N	1.26000000000000001	-00:55:00	\N	1.26000000000000001	\N	\N	St. George Island, 12th St. W (Bayside)	FL
58122	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.763300000000001	-85.033299999999997	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	00:35:00	\N	0.82999999999999996	00:28:00	\N	0.849999999999999978	\N	\N	Apalachicola River (A&N RR bridge)	FL
58123	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6332999999999984	-85.0966999999999985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-00:27:00	\N	1	-00:27:00	\N	0.869999999999999996	\N	\N	West Pass	FL
58124	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0382999999999996	-85.3932999999999964	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	01:40:00	\N	1.10000000000000009	01:01:00	\N	1.10000000000000009	\N	\N	Wetappo Creek, East Bay	FL
58125	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.0300000000000011	-85.4650000000000034	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:01:00	\N	1.14999999999999991	-00:16:00	\N	1.14999999999999991	\N	\N	Allanton, East Bay	FL
58126	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167000000000002	-85.4699999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-00:59:00	\N	1.16999999999999993	-00:16:00	\N	1.16999999999999993	\N	\N	Farmdale, East Bay	FL
58127	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217000000000006	-85.5283000000000015	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:05:00	\N	1.12999999999999989	-00:28:00	\N	1.12999999999999989	\N	\N	Laird Bayou, East Bay	FL
58128	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1266999999999996	-85.611699999999999	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	00:22:00	\N	1.19999999999999996	-00:05:00	\N	1.19999999999999996	\N	\N	Parker	FL
58129	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.254999999999999	-85.6483000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:01:00	\N	1.10000000000000009	-00:31:00	\N	1.10000000000000009	\N	\N	Lynn Haven, North Bay	FL
58130	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.730000000000004	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:50:00	\N	1.02000000000000002	-01:39:00	\N	1.02000000000000002	\N	\N	Channel entrance	FL
58131	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.1700000000000017	-85.7549999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:10:00	\N	1.07000000000000006	-00:47:00	\N	1.07000000000000006	\N	\N	Alligator Bayou	FL
58132	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.2932999999999986	-85.8582999999999998	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-00:47:00	\N	1.12999999999999989	-00:10:00	\N	1.12999999999999989	\N	\N	West Bay Creek, West Bay	FL
58133	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.3949999999999996	-86.513300000000001	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-00:34:00	\N	0.330000000000000016	-00:33:00	\N	0.489999999999999991	\N	\N	East Pass (Destin)	FL
58134	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.4349999999999987	-86.5866999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	03:03:00	\N	0.320000000000000007	03:33:00	\N	0.320000000000000007	\N	\N	Shalimar, Garnier Bayou	FL
58135	Harris, The Narrows, Florida	NOS	8729613	30.4083000000000006	-86.7317000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	02:51:00	\N	1.10000000000000009	01:37:00	\N	1.10000000000000009	\N	\N	Harris, The Narrows	FL
58136	Navarre Beach, Florida (sub)	NOS	8729678	30.3766999999999996	-86.8649999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-02:26:00	\N	1.66999999999999993	-02:07:00	\N	1.07000000000000006	\N	\N	Navarre Beach	FL
58137	East Bay, Pensacola Bay, Florida	NOS	8729702	30.4499999999999993	-86.9183000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	01:17:00	\N	1.19999999999999996	00:44:00	\N	1.19999999999999996	\N	\N	East Bay	FL
58138	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5716999999999999	-87.0049999999999955	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	01:27:00	\N	1.19999999999999996	01:23:00	\N	1.19999999999999996	\N	\N	Bay Point, Blackwater River	FL
58139	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.3367000000000004	-87.1400000000000006	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	00:51:00	\N	1.10000000000000009	00:41:00	\N	1.10000000000000009	\N	\N	Fishing Bend, Santa Rosa Sound	FL
58140	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.5150000000000006	-87.1616999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	01:03:00	\N	1.19999999999999996	00:36:00	\N	1.19999999999999996	\N	\N	Lora Point, Escambia Bay	FL
58141	Warrington, 2 miles south of, Pensacola Bay, Florida	NOS	8729868	30.3449999999999989	-87.2733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
58142	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3266999999999989	-87.3117000000000019	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-00:34:00	\N	0.800000000000000044	-01:23:00	\N	0.800000000000000044	\N	\N	Fort McRee Breakwater	FL
58143	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.4249999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	03:37:00	\N	0.330000000000000016	02:29:00	\N	0.569999999999999951	\N	\N	Nix Point, Perdido Bay	FL
58144	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033000000000001	-87.7349999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56150	-01:17:00	\N	1.07000000000000006	-01:13:00	\N	1.07000000000000006	\N	\N	Bon Secour, Bon Secour River	AL
58145	Great Point Clear, Mobile Bay, Alabama	NOS	8733810	30.4817	-87.9333000000000027	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56150	-00:57:00	\N	0.930000000000000049	-01:03:00	\N	0.930000000000000049	\N	\N	Great Point Clear, Mobile Bay	AL
58146	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2332999999999998	-88.019999999999996	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56150	-01:32:00	\N	0.800000000000000044	-01:46:00	\N	0.800000000000000044	\N	\N	Mobile Point (Fort Morgan)	AL
58147	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183000000000007	-87.9150000000000063	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56150	03:05:00	\N	0.869999999999999996	02:16:00	\N	0.869999999999999996	\N	\N	Lower Hall Landing, Tensaw River	AL
58148	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717000000000006	-88.2750000000000057	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:14:00	\N	1.22999999999999998	01:52:00	\N	1.22999999999999998	\N	\N	Bayou La Batre, Mississippi Sound	AL
58149	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867000000000012	-88.4399999999999977	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
58150	Pascagoula Point, Mississippi Sound, Mississippi (sub)	NOS	8741196	30.3399999999999999	-88.533299999999997	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	00:48:00	\N	1.20999999999999996	01:20:00	\N	1.20999999999999996	\N	\N	Pascagoula, Mississippi Sound	MS
58151	Horn Island, Mississippi Sound, Mississippi (sub)	NOS	8742221	30.2382999999999988	-88.6667000000000058	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	00:59:00	\N	1.25	01:34:00	\N	1.25	\N	\N	Horn Island, Mississippi Sound	MS
58152	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867000000000012	-88.7733000000000061	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:52:00	\N	1.41999999999999993	02:24:00	\N	1.41999999999999993	\N	\N	Hollingsworth Point, Davis Bayou	MS
58153	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.3900000000000006	-88.8567000000000036	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:30:00	\N	1.37999999999999989	02:04:00	\N	1.37999999999999989	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
58154	Ship Island, Mississippi Sound, Mississippi (sub)	NOS	8744756	30.2133000000000003	-88.9716999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:22:00	\N	1.30000000000000004	01:52:00	\N	1.30000000000000004	\N	\N	Ship Island, Mississippi Sound	MS
58155	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267000000000003	-89.053299999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:27:00	\N	1.54000000000000004	03:23:00	\N	1.54000000000000004	\N	\N	Turkey Creek, Bernard Bayou	MS
58156	Gulfport, Gulfport Harbor, Mississippi (sub)	NOS	8745557	30.3599999999999994	-89.0816999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:09:00	\N	1.29000000000000004	02:09:00	\N	1.29000000000000004	\N	\N	Gulfport Harbor, Mississippi Sound	MS
58157	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1166999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:00:00	\N	1.22999999999999998	02:13:00	\N	1.22999999999999998	\N	\N	Cat Island	MS
58158	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.3099999999999987	-89.2450000000000045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:04:00	\N	1.37000000000000011	02:36:00	\N	1.37000000000000011	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
58159	Waveland, Mississipi Sound, Mississippi (sub)	NOS	8747766	30.2817000000000007	-89.3666999999999945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:49:00	\N	1.28000000000000003	03:09:00	\N	1.28000000000000003	\N	\N	Waveland	MS
58160	Pearlington, Pearl River, Mississippi	NOS	8749704	30.2399999999999984	-89.6149999999999949	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	05:31:00	\N	0.989999999999999991	05:51:00	\N	0.989999999999999991	\N	\N	Pearlington, Pearl River	MS
58161	Chandeleur Light, Louisiana	NOS	8760172	30.0483000000000011	-88.8717000000000041	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	01:54:00	\N	0.979999999999999982	01:50:00	\N	0.979999999999999982	\N	\N	Chandeleur Light	LA
58162	North Pass, Mississippi River, Louisiana	NOS	8760412	29.2049999999999983	-89.0366999999999962	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	00:43:00	\N	0.910000000000000031	00:42:00	\N	0.910000000000000031	\N	\N	North Pass, Pass a Loutre	LA
58163	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167000000000016	-89.0450000000000017	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	-00:28:00	\N	0.979999999999999982	00:37:00	\N	0.979999999999999982	\N	\N	Southeast Pass	LA
58164	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283000000000008	-89.0499999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	-00:29:00	\N	0.900000000000000022	00:34:00	\N	0.900000000000000022	\N	\N	Lonesome Bayou (Thomasin)	LA
58165	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.0150000000000006	-89.1599999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	-00:17:00	\N	0.900000000000000022	00:56:00	\N	0.900000000000000022	\N	\N	Port Eads, South Pass	LA
58166	Breton Islands, Louisiana	NOS	8760595	29.4933000000000014	-89.1732999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:08:00	\N	1.1399999999999999	02:07:00	\N	1.1399999999999999	\N	\N	Breton Islands	LA
58167	Grand Pass, Louisiana (sub)	NOS	8760668	30.1266999999999996	-89.2216999999999985	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:36:00	\N	1.17999999999999994	03:01:00	\N	1.17999999999999994	\N	\N	Grand Pass	LA
58168	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0582999999999991	-89.2716999999999956	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	-00:17:00	\N	1.14999999999999991	00:37:00	\N	1.14999999999999991	\N	\N	Joseph Bayou	LA
58169	Comfort Island, Louisiana	NOS	8760742	29.8232999999999997	-89.269999999999996	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:14:00	\N	1.28000000000000003	02:47:00	\N	1.28000000000000003	\N	\N	Comfort Island	LA
58170	Jack Bay, Louisiana	NOS	8760841	29.3667000000000016	-89.3449999999999989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
58171	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9316999999999993	-89.428299999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	-00:13:00	\N	1.07000000000000006	00:35:00	\N	1.07000000000000006	\N	\N	Southwest Pass	LA
58172	Bay Gardene, Louisiana	NOS	8761108	29.5982999999999983	-89.618300000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	04:04:00	\N	1.15999999999999992	04:04:00	\N	1.15999999999999992	\N	\N	Bay Gardene	LA
58173	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6082999999999998	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	-01:45:00	\N	1.22999999999999998	-01:03:00	\N	1.22999999999999998	\N	\N	Empire Jetty	LA
58174	Bastian Island, Louisiana	NOS	8761289	29.2866999999999997	-89.6633000000000067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:12:00	\N	1.12999999999999989	00:41:00	\N	1.12999999999999989	\N	\N	Bastian Island	LA
58175	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2716999999999992	-89.7933000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	11:31:00	\N	0.429999999999999993	11:12:00	\N	0.429999999999999993	\N	\N	Bayou BonFouca, Route 433	LA
58176	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.0650000000000013	-89.7999999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	06:27:00	\N	0.880000000000000004	06:25:00	\N	0.880000000000000004	\N	\N	Chef Menteur, Chef Menteur Pass	LA
58177	Quatre Bayous Pass, Louisiana	NOS	8761557	29.3099999999999987	-89.8533000000000044	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:17:00	\N	1.22999999999999998	02:18:00	\N	1.22999999999999998	\N	\N	Quatre Bayous Pass	LA
58178	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.3099999999999987	-89.9382999999999981	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	01:59:00	\N	0.849999999999999978	02:29:00	\N	0.849999999999999978	\N	\N	Independence Island	LA
58179	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0066999999999986	-89.9367000000000019	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	06:22:00	\N	1.09000000000000008	06:37:00	\N	1.09000000000000008	\N	\N	Michoud Substation, ICWW	LA
58180	Barataria Pass, Louisiana	NOS	8761687	29.2749999999999986	-89.9449999999999932	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	-00:10:00	\N	1.12999999999999989	01:00:00	\N	1.12999999999999989	\N	\N	Barataria Pass	LA
58181	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267000000000003	-89.9766999999999939	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	03:13:00	\N	0.939999999999999947	02:32:00	\N	0.939999999999999947	\N	\N	Manilla	LA
58182	Caminada Pass (bridge), Louisiana (sub)	NOS	8761826	29.2100000000000009	-90.0400000000000063	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:12:00	\N	0.939999999999999947	00:20:00	\N	0.939999999999999947	\N	\N	Caminada Pass (bridge)	LA
58183	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3782999999999994	-90.1599999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	12:21:00	\N	0.479999999999999982	11:36:00	\N	0.479999999999999982	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
58184	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1282999999999994	-90.4232999999999976	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	02:26:00	\N	1.12999999999999989	02:26:00	\N	1.12999999999999989	\N	\N	Pelican Islands, Timbalier Bay	LA
58185	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867000000000004	-90.5267000000000053	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:23:00	\N	1.12999999999999989	00:19:00	\N	1.12999999999999989	\N	\N	Timbalier Island, Timbalier Bay	LA
58186	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0782999999999987	-90.5866999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	01:02:00	\N	1.22999999999999998	01:08:00	\N	1.22999999999999998	\N	\N	Wine Island, Terrebonne Bay	LA
58187	Caillou Boca, Louisiana	NOS	8763206	29.0633000000000017	-90.8067000000000064	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:48:00	\N	1.32000000000000006	00:40:00	\N	1.32000000000000006	\N	\N	Caillou Boca	LA
58188	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633000000000017	-90.9616999999999933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	-00:20:00	\N	1.60000000000000009	-00:03:00	\N	1.60000000000000009	\N	\N	Raccoon Point, Caillou Bay	LA
58189	Ship Shoal Light, Louisiana	NOS	8763719	28.9149999999999991	-91.071700000000007	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	-01:50:00	\N	1.51000000000000001	-01:54:00	\N	1.51000000000000001	\N	\N	Ship Shoal Light	LA
58190	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4732999999999983	-91.3050000000000068	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:39:00	\N	1.07000000000000006	00:54:00	\N	1.07000000000000006	\N	\N	Shell Island	LA
58191	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333000000000013	-91.3533000000000044	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-02:26:00	\N	1.39999999999999991	-00:21:00	\N	1.39999999999999991	\N	\N	Point Au Fer	LA
58192	Eugene Island, Atchafalaya Bay, Louisiana (sub)	NOS	8764311	29.3717000000000006	-91.3850000000000051	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-02:03:00	\N	1.3899999999999999	00:25:00	\N	1.42999999999999994	\N	\N	Eugene Island	LA
58193	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.5550000000000068	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:54:00	\N	1.07000000000000006	01:02:00	\N	1.07000000000000006	\N	\N	Point Chevreuil	LA
58194	Rabbit Island, 5 miles south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.4200000000000017	-91.5932999999999993	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-02:00:00	\N	1.39999999999999991	-00:13:00	\N	1.39999999999999991	\N	\N	Rabbit Island, 5 miles south of	LA
58195	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.7349999999999994	-91.7133000000000038	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
58196	South Point, Marsh Island, Atchafalaya Bay, Louisiana	NOS	8765026	29.4849999999999994	-91.763300000000001	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:57:00	\N	1.30000000000000004	-00:19:00	\N	1.30000000000000004	\N	\N	South Point, Marsh Island	LA
58197	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.5799999999999983	-92.0349999999999966	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:33:00	\N	1.1399999999999999	-00:32:00	\N	1.1399999999999999	\N	\N	Southwest Pass, Vermilion Bay	LA
58198	Lighthouse Point, Atchafalaya Bay, Louisiana	NOS	8765568	29.523299999999999	-92.0433000000000021	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-02:17:00	\N	1.39999999999999991	-01:16:00	\N	1.39999999999999991	\N	\N	Lighthouse Point	LA
58221	Balboa Pier, Newport Beach, California	NOS	9410583	33.6000000000000014	-117.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:00:00	\N	0.959999999999999964	-00:09:00	\N	0.959999999999999964	\N	\N	Balboa Pier, Newport Beach	CA
58199	Mesquite Point, Sabine Pass, Texas (sub)	NOS	8770539	29.7667000000000002	-93.894999999999996	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:25:00	\N	0.930000000000000049	-00:04:00	\N	0.930000000000000049	\N	\N	Mesquite Point, Sabine Pass	TX
58200	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.7399999999999984	-94.8316999999999979	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	04:43:00	\N	0.790000000000000036	05:48:00	\N	0.790000000000000036	\N	\N	Point Barrow, Trinity Bay	TX
58201	Round Point, Trinity Bay, Galveston Bay, Texas (sub)	NOS	8770559	29.7133000000000003	-94.6899999999999977	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	05:15:00	\N	0.709999999999999964	10:39:00	\N	0.709999999999999964	\N	\N	Round Point, Trinity Bay	TX
58202	Sabine Pass (jetty), Texas	NOS	8770701	29.6499999999999986	-93.8282999999999987	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:31:00	\N	1.79000000000000004	-01:26:00	\N	1.79000000000000004	\N	\N	Sabine Pass (jetty)	TX
58203	Clear Lake, Galveston Bay, Texas (sub)	NOS	8770933	29.5633000000000017	-95.0666999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	05:19:00	\N	0.82999999999999996	06:57:00	\N	0.82999999999999996	\N	\N	Clear Lake	TX
58204	Port Bolivar, Galveston Bay, Texas (sub)	NOS	8771328	29.3649999999999984	-94.7800000000000011	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	00:09:00	\N	0.630000000000000004	00:57:00	\N	1	\N	\N	Port Bolivar	TX
58205	Jamaica Beach, West Bay, Galveston Bay, Texas	NOS	8771721	29.1999999999999993	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	03:31:00	\N	0.709999999999999964	02:38:00	\N	0.709999999999999964	\N	\N	Jamaica Beach, West Bay	TX
58206	Alligator Point, West Bay, Texas	NOS	8771801	29.1666999999999987	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	02:33:00	\N	0.640000000000000013	02:39:00	\N	0.640000000000000013	\N	\N	Alligator Point, West Bay	TX
58207	Christmas Bay, Texas	NOS	8772132	29.0416999999999987	-95.1749999999999972	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	02:37:00	\N	0.23000000000000001	04:47:00	\N	0.57999999999999996	\N	\N	Christmas Bay	TX
58208	Freeport, DOW Barge Canal, Texas (sub)	NOS	8772440	28.9482999999999997	-95.3083000000000027	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:08:00	\N	0.900000000000000022	-01:17:00	\N	1.22999999999999998	\N	\N	Freeport Harbor	TX
58209	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0782999999999987	-97.1700000000000017	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56270	00:21:00	\N	0.75	00:24:00	\N	0.869999999999999996	\N	\N	Queen Isabella Causeway (east end)	TX
58210	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0716999999999999	-97.1916999999999973	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56270	00:30:00	\N	0.630000000000000004	00:52:00	\N	0.810000000000000053	\N	\N	Queen Isabella Causeway (west end)	TX
58211	South Bay entrance, Texas	NOS	8779768	26.0517000000000003	-97.1817000000000064	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56270	00:21:00	\N	0.939999999999999947	00:14:00	\N	0.910000000000000031	\N	\N	South Bay entrance	TX
58212	Wilson Cove, San Clemente Island, California	NOS	9410032	33.0050000000000026	-118.557000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	-00:03:00	\N	0.939999999999999947	-00:03:00	\N	0.939999999999999947	\N	\N	Wilson Cove, San Clemente Island	CA
58213	San Nicolas Island, California	NOS	9410068	33.2667000000000002	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:21:00	\N	0.880000000000000004	00:10:00	\N	0.880000000000000004	\N	\N	San Nicolas Island	CA
58214	Avalon, Santa Catalina Island, California (sub)	NOS	9410079	33.3449999999999989	-118.325000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:09:00	\N	0.959999999999999964	00:06:00	\N	0.959999999999999964	\N	\N	Avalon, Santa Catalina Island	CA
58215	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4316999999999993	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:17:00	\N	0.939999999999999947	00:11:00	\N	0.939999999999999947	\N	\N	Catalina Harbor, Santa Catalina Island	CA
58216	Imperial Beach, California	NOS	9410120	32.5782999999999987	-117.135000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	-00:03:00	\N	0.959999999999999964	00:00:00	\N	0.930000000000000049	\N	\N	Imperial Beach	CA
58217	National City, San Diego Bay, California	NOS	9410152	32.6649999999999991	-117.117999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	00:10:00	0	\N	00:04:00	0.200000000000000011	\N	\N	\N	National City, San Diego Bay	CA
58218	San Diego, Quarantine Station, California	NOS	9410166	32.7032999999999987	-117.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	00:02:00	\N	0.959999999999999964	-00:04:00	\N	0.959999999999999964	\N	\N	San Diego, Quarantine Station	CA
58219	Crown Point, Mission Bay, California	NOS	9410191	32.7749999999999986	-117.233000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	00:16:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Crown Point, Mission Bay	CA
58220	Newport Beach, Newport Bay Entrance, Corona del Mar, California (sub)	NOS	9410580	33.6032999999999973	-117.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	-00:04:00	\N	0.979999999999999982	-00:03:00	\N	0.979999999999999982	\N	\N	Newport Bay Entrance, Corona del Mar	CA
58222	Santa Ana River entrance (inside), California	NOS	9410599	33.6300000000000026	-117.957999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	01:47:00	\N	0.200000000000000011	00:23:00	\N	0.540000000000000036	\N	\N	Santa Ana River entrance (inside)	CA
58223	Cabrillo Beach, California	NOS	9410650	33.7066999999999979	-118.272999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
58224	Long Beach, Terminal Island, California (sub)	NOS	9410680	33.7516999999999996	-118.227000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:00:00	\N	1.01000000000000001	-00:01:00	\N	1.01000000000000001	\N	\N	Long Beach, Terminal Island	CA
58225	Long Beach, Inner Harbor, California	NOS	9410686	33.7717000000000027	-118.209999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:05:00	\N	0.959999999999999964	00:04:00	\N	0.959999999999999964	\N	\N	Long Beach, Inner Harbor	CA
58226	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8466999999999985	-118.397999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:07:00	\N	1	00:08:00	\N	0.959999999999999964	\N	\N	King Harbor, Santa Monica Bay	CA
58227	El Segundo, Santa Monica Bay, California	NOS	9410777	33.908299999999997	-118.433000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:13:00	\N	0.959999999999999964	00:13:00	\N	0.959999999999999964	\N	\N	El Segundo, Santa Monica Bay	CA
58228	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0082999999999984	-120.046999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:27:00	\N	1.03000000000000003	00:27:00	\N	0.930000000000000049	\N	\N	Bechers Bay, Santa Rosa Island	CA
58229	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.0200000000000031	-119.683000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:18:00	\N	1.01000000000000001	00:19:00	\N	0.939999999999999947	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
58230	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0566999999999993	-120.355000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:34:00	\N	0.939999999999999947	00:33:00	\N	0.939999999999999947	\N	\N	Cuyler Harbor, San Miguel Island	CA
58231	Port Hueneme, California	NOS	9411065	34.148299999999999	-119.203000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:13:00	0	\N	00:10:00	-0.100000000000000006	\N	\N	\N	Port Hueneme	CA
58232	Ventura, California	NOS	9411189	34.2667000000000002	-119.283000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:16:00	0	\N	00:09:00	-0.100000000000000006	\N	\N	\N	Ventura	CA
58233	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483000000000018	-119.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:18:00	\N	1.05000000000000004	00:20:00	\N	0.989999999999999991	\N	\N	Rincon Island, Mussel Shoals	CA
58234	Gaviota, California	NOS	9411405	34.4682999999999993	-120.204999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:37:00	\N	0.959999999999999964	00:39:00	\N	0.959999999999999964	\N	\N	Gaviota	CA
58235	San Simeon, California	NOS	9412553	35.6417000000000002	-121.188000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56286	00:07:00	\N	1	00:08:00	\N	0.989999999999999991	\N	\N	San Simeon	CA
58236	Carmel Cove, Carmel Bay, California	NOS	9413375	36.5200000000000031	-121.939999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	-00:04:00	\N	0.989999999999999991	-00:03:00	\N	0.969999999999999973	\N	\N	Carmel Cove, Carmel Bay	CA
58237	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8016999999999967	-121.790000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	-00:01:00	\N	0.900000000000000022	-00:01:00	\N	0.949999999999999956	\N	\N	Moss Landing, Ocean Pier	CA
58238	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8016999999999967	-121.787000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	00:01:00	\N	0.949999999999999956	00:01:00	\N	0.979999999999999982	\N	\N	General Fish Company Pier	CA
58239	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.8100000000000023	-121.784999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	-00:02:00	\N	0.900000000000000022	00:03:00	\N	0.949999999999999956	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
58240	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8132999999999981	-121.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	00:07:00	\N	0.979999999999999982	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
58241	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8132999999999981	-121.787000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	00:02:00	\N	0.949999999999999956	00:00:00	\N	0.969999999999999973	\N	\N	Elkhorn Yacht Club	CA
58242	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.8183000000000007	-121.747	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	00:05:00	\N	0.969999999999999973	00:21:00	\N	0.979999999999999982	\N	\N	Elkhorn, Elkhorn Slough	CA
58243	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583000000000013	-122.016999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56288	-00:11:00	\N	0.989999999999999991	-00:06:00	\N	0.969999999999999973	\N	\N	Santa Cruz, Monterey Bay	CA
58378	Depoe Bay, Oregon (sub)	NOS	9435827	44.8100000000000023	-124.058000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:27:00	\N	1.10000000000000009	00:27:00	\N	1.20999999999999996	\N	\N	Depoe Bay	OR
58244	Ano Nuevo Island, California	NOS	9413878	37.1082999999999998	-122.337999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-01:04:00	-0.100000000000000006	\N	-01:24:00	-0.699999999999999956	\N	\N	\N	Ano Nuevo Island	CA
58245	Princeton, Half Moon Bay, California	NOS	9414129	37.5016999999999996	-122.486999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:50:00	0	\N	-01:06:00	-0.299999999999999989	\N	\N	\N	Princeton, Half Moon Bay	CA
58246	Southeast Farallon Island, California	NOS	9414262	37.7000000000000028	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:19:00	0	\N	-00:39:00	-0.299999999999999989	\N	\N	\N	Southeast Farallon Island	CA
58247	Ocean Beach, outer coast, California	NOS	9414275	37.7749999999999986	-122.513000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:35:00	0	\N	-00:49:00	0.100000000000000006	\N	\N	\N	Ocean Beach, outer coast	CA
58248	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.8100000000000023	-122.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:11:00	0	\N	00:13:00	0.200000000000000011	\N	\N	\N	San Francisco, North Point, Pier 41	CA
58249	Rincon Point, Pier 22, San Francisco Bay, California (sub)	NOS	9414317	37.7899999999999991	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:25:00	0	\N	00:23:00	0.400000000000000022	\N	\N	\N	Rincon Point, Pier 22 1/2	CA
58250	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7582999999999984	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
58251	Hunters Point, San Francisco Bay, California (sub)	NOS	9414358	37.7299999999999969	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:39:00	0	\N	00:25:00	0.900000000000000022	\N	\N	\N	Hunters Point	CA
58252	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6666999999999987	-122.390000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:56:00	0	\N	00:38:00	1.19999999999999996	\N	\N	\N	South San Francisco	CA
58253	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.6649999999999991	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:00:00	\N	1	00:41:00	\N	1.22999999999999998	\N	\N	Oyster Point Marina	CA
58254	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.6499999999999986	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:10:00	0.100000000000000006	\N	00:38:00	1.10000000000000009	\N	\N	\N	Point San Bruno	CA
58255	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6366999999999976	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:03:00	0	\N	00:42:00	1.39999999999999991	\N	\N	\N	Seaplane Harbor	CA
58256	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.591700000000003	-122.313000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:08:00	\N	1.01000000000000001	00:42:00	\N	1.29000000000000004	\N	\N	Coyote Point Marina	CA
58257	San Mateo Bridge (west end), San Francisco Bay, California (sub)	NOS	9414458	37.5799999999999983	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:11:00	\N	1.04000000000000004	00:44:00	\N	1.3600000000000001	\N	\N	San Mateo Bridge (west end)	CA
58258	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5516999999999967	-122.242999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:28:00	\N	1	00:48:00	\N	1.35000000000000009	\N	\N	Bay Slough, west end	CA
58259	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.5450000000000017	-122.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:52:00	\N	0.770000000000000018	00:49:00	\N	1.27000000000000002	\N	\N	Bay Slough, east end	CA
58260	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.533299999999997	-122.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:28:00	\N	1.05000000000000004	00:53:00	\N	1.40999999999999992	\N	\N	Redwood Creek Marker 8	CA
58261	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5082999999999984	-122.209999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:42:00	0.100000000000000006	\N	01:03:00	2.20000000000000018	\N	\N	\N	Corkscrew Slough	CA
58262	Newark Slough, San Francisco Bay, California	NOS	9414506	37.513300000000001	-122.079999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:58:00	0.100000000000000006	\N	01:11:00	2.60000000000000009	\N	\N	\N	Newark Slough	CA
58263	West Point Slough, San Francisco Bay, California	NOS	9414507	37.5050000000000026	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:30:00	\N	1.04000000000000004	00:56:00	\N	1.43999999999999995	\N	\N	West Point Slough	CA
58264	Dumbarton Highway Bridge, San Francisco Bay, California (sub)	NOS	9414509	37.5067000000000021	-122.114999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:15:00	\N	1.05000000000000004	00:50:00	\N	1.51000000000000001	\N	\N	Dumbarton Highway Bridge	CA
58265	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5016999999999996	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:58:00	0	\N	01:15:00	2.10000000000000009	\N	\N	\N	Smith Slough	CA
58266	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.4949999999999974	-122.212999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:31:00	\N	1.04000000000000004	00:55:00	\N	1.42999999999999994	\N	\N	Granite Rock, Redwood Creek	CA
58267	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4932999999999979	-122.042000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:07:00	0	\N	01:12:00	2.60000000000000009	\N	\N	\N	Mowry Slough	CA
58268	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583000000000013	-122.105000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:14:00	\N	0.680000000000000049	00:59:00	\N	1.34000000000000008	\N	\N	Palo Alto Yacht Harbor	CA
58269	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.466700000000003	-122.066999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:49:00	0.100000000000000006	\N	01:05:00	2.79999999999999982	\N	\N	\N	Calaveras Point, west of	CA
58270	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.4350000000000023	-122.007000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:13:00	\N	1.12999999999999989	01:14:00	\N	1.65999999999999992	\N	\N	Upper Guadalupe Slough	CA
58271	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4232999999999976	-121.974999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:21:00	\N	0.959999999999999964	01:03:00	\N	1.66999999999999993	\N	\N	Gold Street Bridge, Alviso Slough	CA
58272	Coyote Creek, Tributary no.1, San Francisco Bay, California	NOS	9414561	37.4466999999999999	-121.962999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:45:00	-0.299999999999999989	\N	01:21:00	2.60000000000000009	\N	\N	\N	Coyote Creek, Tributary no.1	CA
58273	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5516999999999967	-122.162000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:37:00	0.100000000000000006	\N	01:02:00	2.20000000000000018	\N	\N	\N	South Bay Wreck	CA
58274	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5632999999999981	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:21:00	\N	0.450000000000000011	00:52:00	\N	1.16999999999999993	\N	\N	Coyote Hills Slough entrance	CA
58275	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.5949999999999989	-122.144999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:25:00	\N	0.270000000000000018	00:57:00	\N	1.05000000000000004	\N	\N	Alameda Creek	CA
58276	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6082999999999998	-122.182000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:19:00	0	\N	00:48:00	1.80000000000000004	\N	\N	\N	San Mateo Bridge (east end)	CA
58277	San Leandro Marina, San Francisco Bay, California (sub)	NOS	9414688	37.6950000000000003	-122.191999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:23:00	\N	1.01000000000000001	00:54:00	\N	1.28000000000000003	\N	\N	San Leandro Marina	CA
58278	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7316999999999965	-122.207999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:45:00	\N	0.959999999999999964	00:40:00	\N	1.14999999999999991	\N	\N	Oakland Airport	CA
58279	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483000000000004	-122.234999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:52:00	\N	0.979999999999999982	00:42:00	\N	1.15999999999999992	\N	\N	San Leandro Channel, San Leandro Bay	CA
58280	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.7950000000000017	-122.283000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:42:00	0	\N	00:33:00	0.400000000000000022	\N	\N	\N	Oakland Harbor, Grove Street	CA
58281	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.7950000000000017	-122.329999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:48:00	0	\N	00:33:00	0.200000000000000011	\N	\N	\N	Oakland Pier	CA
58282	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933000000000021	-122.314999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:33:00	\N	1	00:24:00	\N	1.1100000000000001	\N	\N	Alameda Naval Air Station	CA
58283	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.8049999999999997	-122.337999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:31:00	\N	0.959999999999999964	00:21:00	\N	1.07000000000000006	\N	\N	Oakland Middle Harbor	CA
58284	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.8100000000000023	-122.326999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:36:00	0	\N	00:28:00	0.299999999999999989	\N	\N	\N	Oakland, Matson Wharf	CA
58285	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.8100000000000023	-122.359999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:33:00	\N	0.989999999999999991	00:25:00	\N	1.06000000000000005	\N	\N	Yerba Buena Island	CA
58286	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.8200000000000003	-121.447000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	06:20:00	\N	0.680000000000000049	06:14:00	\N	0.760000000000000009	\N	\N	Grant Line Canal (drawbridge)	CA
58287	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267000000000024	-122.417000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
58288	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8466999999999985	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:14:00	\N	1	00:10:00	\N	0.969999999999999973	\N	\N	Sausalito	CA
58289	Nurse Slough, Bradmoor Island, Suisun Bay, California (sub)	NOS	9414811	38.1833000000000027	-121.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:06:00	\N	0.989999999999999991	00:59:00	\N	1.07000000000000006	\N	\N	Bradmoor Island, Nurse Slough	CA
58290	Berkeley, San Francisco Bay, California	NOS	9414816	37.865000000000002	-122.307000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:38:00	0	\N	00:21:00	0.100000000000000006	\N	\N	\N	Berkeley	CA
58291	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.8599999999999994	-122.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:21:00	0	\N	00:13:00	-0.200000000000000011	\N	\N	\N	Angel Island (west side)	CA
58292	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633000000000024	-122.420000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:20:00	\N	1.04000000000000004	00:16:00	\N	1.02000000000000002	\N	\N	Angel Island, East Garrison	CA
58293	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865000000000002	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:21:00	\N	1	00:10:00	\N	0.979999999999999982	\N	\N	Sausalito, Corps of Engineers Dock	CA
58294	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917000000000002	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:54:00	\N	0.619999999999999996	04:50:00	\N	0.67000000000000004	\N	\N	Borden Highway Bridge, Middle River	CA
58295	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8832999999999984	-121.576999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:35:00	\N	0.609999999999999987	04:40:00	\N	0.640000000000000013	\N	\N	Borden Highway Bridge, Old River	CA
58296	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917000000000002	-122.442999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:32:00	\N	0.959999999999999964	00:28:00	\N	0.979999999999999982	\N	\N	Point Chauncey	CA
58297	Point Isabel, San Francisco Bay, California	NOS	9414843	37.898299999999999	-122.319999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:33:00	0	\N	00:23:00	0.100000000000000006	\N	\N	\N	Point Isabel	CA
58298	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.9099999999999966	-122.358000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:30:00	\N	0.979999999999999982	00:16:00	\N	1.04000000000000004	\N	\N	Richmond Inner Harbor	CA
58299	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.9350000000000023	-121.435000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:39:00	\N	0.680000000000000049	04:18:00	\N	0.800000000000000044	\N	\N	Holt, Whiskey Slough	CA
58300	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9382999999999981	-121.560000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:33:00	\N	0.680000000000000049	04:32:00	\N	0.760000000000000009	\N	\N	Orwood, Old River	CA
58301	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.9450000000000003	-122.474999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:50:00	\N	0.930000000000000049	00:42:00	\N	0.989999999999999991	\N	\N	Point San Quentin	CA
58302	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.9433000000000007	-122.513000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:51:00	\N	0.949999999999999956	00:36:00	\N	0.989999999999999991	\N	\N	Corte Madera Creek	CA
58303	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583000000000013	-122.424999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:52:00	\N	0.959999999999999964	00:50:00	\N	1.03000000000000003	\N	\N	Point Orient	CA
58304	Stockton, San Joaquin River, California	NOS	9414883	37.9583000000000013	-121.290000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:33:00	\N	0.660000000000000031	04:06:00	\N	0.810000000000000053	\N	\N	Stockton	CA
58305	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183000000000007	-122.528000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:10:00	0	\N	-00:17:00	0.299999999999999989	\N	\N	\N	Point Bonita, Bonita Cove	CA
58306	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9932999999999979	-122.447000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:07:00	\N	0.92000000000000004	01:02:00	\N	1.01000000000000001	\N	\N	Point San Pedro	CA
58307	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.0150000000000006	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:25:00	\N	0.890000000000000013	01:18:00	\N	1.02000000000000002	\N	\N	Gallinas, Gallinas Creek	CA
58308	Davis Slough, San Joaquin River, California	NOS	9415053	38.0116999999999976	-121.638000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	02:46:00	\N	0.719999999999999973	02:33:00	\N	0.680000000000000049	\N	\N	Dutch Slough	CA
58309	Antioch, San Joaquin River, California (sub)	NOS	9415064	38.0200000000000031	-121.814999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:26:00	\N	0.780000000000000027	01:12:00	\N	0.770000000000000018	\N	\N	Antioch	CA
58310	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.023299999999999	-122.292000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:39:00	\N	0.849999999999999978	01:15:00	\N	1.05000000000000004	\N	\N	Hercules, Refugio Landing	CA
58311	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.033299999999997	-121.582999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	03:34:00	\N	0.680000000000000049	03:29:00	\N	0.729999999999999982	\N	\N	Irish Landing, Sand Mound Slough	CA
58312	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367000000000033	-121.879999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:05:00	\N	0.839999999999999969	00:59:00	\N	0.82999999999999996	\N	\N	Pittsburg, New York Slough	CA
58313	Suisun Point, California	NOS	9415103	38.0349999999999966	-122.123000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	-00:30:00	\N	1.09000000000000008	-00:24:00	\N	1.07000000000000006	\N	\N	Suisun Point	CA
58314	Benicia, California	NOS	9415111	38.0433000000000021	-122.129999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	-00:33:00	\N	1.17999999999999994	-00:24:00	\N	1.09000000000000008	\N	\N	Benicia	CA
58315	Mallard Island Ferry Wharf, Suisun Bay, California (sub)	NOS	9415112	38.0433000000000021	-121.918000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:57:00	\N	0.810000000000000053	00:54:00	\N	0.82999999999999996	\N	\N	Mallard Island Ferry Wharf	CA
58316	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.0450000000000017	-121.420000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:12:00	\N	0.660000000000000031	04:12:00	\N	0.790000000000000036	\N	\N	Bishop Cut, Disappointment Slough	CA
58318	Crockett, Carquinez Strait, California (sub)	NOS	9415143	38.0583000000000027	-122.222999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	-01:05:00	\N	1.31000000000000005	-00:58:00	\N	1.21999999999999997	\N	\N	Crockett	CA
58319	False River, San Joaquin River, California	NOS	9415145	38.0549999999999997	-121.656999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	02:45:00	\N	0.640000000000000013	02:45:00	\N	0.660000000000000031	\N	\N	False River	CA
58320	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617000000000019	-121.555000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	03:29:00	\N	0.689999999999999947	03:25:00	\N	0.729999999999999982	\N	\N	Prisoners Point	CA
58321	Vallejo, Mare Island Strait, California	NOS	9415165	38.111699999999999	-122.272999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:12:00	\N	0.839999999999999969	01:47:00	\N	1.02000000000000002	\N	\N	Vallejo, Mare Island Strait	CA
58322	Collinsville, Sacramento River, California	NOS	9415176	38.0733000000000033	-121.847999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:20:00	\N	0.800000000000000044	01:11:00	\N	0.800000000000000044	\N	\N	Collinsville	CA
58323	Threemile Slough entrance, San Joaquin River, California (sub)	NOS	9415193	38.0867000000000004	-121.685000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	02:52:00	\N	0.680000000000000049	02:27:00	\N	0.709999999999999964	\N	\N	Threemile Slough entrance	CA
58324	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767000000000024	-121.885000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:27:00	\N	0.819999999999999951	01:16:00	\N	0.839999999999999969	\N	\N	Montezuma Slough	CA
58325	Mare Island Naval Shipyard, Carquinez Strait, California (sub)	NOS	9415218	38.0700000000000003	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:58:00	\N	0.839999999999999969	01:32:00	\N	1.01000000000000001	\N	\N	Mare Island	CA
58326	Point Buckler, Suisun Bay, California	NOS	9415227	38.1000000000000014	-122.033000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:22:00	\N	1.08000000000000007	00:13:00	\N	1.12000000000000011	\N	\N	Point Buckler	CA
58327	Inverness, Tomales Bay, California	NOS	9415228	38.1133000000000024	-122.867999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:08:00	\N	0.910000000000000031	00:29:00	\N	0.939999999999999947	\N	\N	Inverness, Tomales Bay	CA
58328	Threemile Slough, Sacramento River, California	NOS	9415236	38.1066999999999965	-121.700000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:58:00	\N	0.780000000000000027	01:49:00	\N	0.819999999999999951	\N	\N	Threemile Slough	CA
58329	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.1099999999999994	-121.498000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:11:00	\N	0.589999999999999969	03:53:00	\N	0.699999999999999956	\N	\N	Terminous, South Fork	CA
58330	Suisun Slough entrance, Suisun Bay, California (sub)	NOS	9415265	38.128300000000003	-122.072999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:26:00	\N	0.930000000000000049	00:13:00	\N	0.969999999999999973	\N	\N	Suisun Slough entrance	CA
58331	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1266999999999996	-122.099999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:41:00	\N	0.959999999999999964	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
58561	Fitzgibbon Cove, Alaska	NOS	9450879	55.9832999999999998	-131.175000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:01:00	\N	0.959999999999999964	-00:05:00	\N	1.02000000000000002	\N	\N	Fitzgibbon Cove	AK
58332	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	03:41:00	\N	0.589999999999999969	03:29:00	\N	0.67000000000000004	\N	\N	Georgiana Slough entrance	CA
58333	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1366999999999976	-121.906999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:11:00	\N	0.930000000000000049	00:57:00	\N	1.01000000000000001	\N	\N	Meins Landing, Montezuma Slough	CA
58334	Rio Vista, Sacramento River, California (sub)	NOS	9415316	38.1450000000000031	-121.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	02:02:00	\N	0.780000000000000027	01:51:00	\N	0.880000000000000004	\N	\N	Rio Vista	CA
58335	Reynolds, Tomales Bay, California	NOS	9415320	38.1467000000000027	-122.882999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:59:00	\N	0.82999999999999996	00:26:00	\N	0.890000000000000013	\N	\N	Reynolds, Tomales Bay	CA
58336	Marshall, Tomales Bay, California	NOS	9415339	38.1617000000000033	-122.893000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:16:00	-0.100000000000000006	\N	00:38:00	-0.599999999999999978	\N	\N	\N	Marshall, Tomales Bay	CA
58337	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617000000000033	-122.549999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:36:00	\N	0.790000000000000036	01:47:00	\N	1.07000000000000006	\N	\N	Hog Island, San Antonio Creek	CA
58338	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.1799999999999997	-122.045000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:41:00	\N	1	00:21:00	\N	1.07000000000000006	\N	\N	Joice Island, Suisun Slough	CA
58339	Blakes Landing, Tomales Bay, California	NOS	9415396	38.1899999999999977	-122.917000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:15:00	\N	0.790000000000000036	00:32:00	\N	0.859999999999999987	\N	\N	Blakes Landing, Tomales Bay	CA
58340	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867000000000019	-121.980000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	00:46:00	\N	0.949999999999999956	00:37:00	\N	1.01000000000000001	\N	\N	Montezuma Slough Bridge	CA
58341	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833000000000027	-121.655000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	02:48:00	\N	0.650000000000000022	02:24:00	\N	0.800000000000000044	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
58342	Edgerley Island, Napa River, California	NOS	9415415	38.1916999999999973	-122.311999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:29:00	\N	0.760000000000000009	02:02:00	\N	1.06000000000000005	\N	\N	Edgerley Island, Napa River	CA
58343	Brazos Drawbridge, Napa River, California	NOS	9415446	38.2100000000000009	-122.307000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:29:00	\N	0.859999999999999987	02:02:00	\N	1.1399999999999999	\N	\N	Brazos Drawbridge, Napa River	CA
58344	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.2100000000000009	-122.427000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	03:11:00	-0.299999999999999989	\N	02:12:00	0.100000000000000006	\N	\N	\N	Wingo, Sonoma Creek	CA
58345	Tomales Bay entrance, California	NOS	9415469	38.2282999999999973	-122.977000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:20:00	\N	0.910000000000000031	-00:12:00	\N	0.869999999999999996	\N	\N	Tomales Bay entrance	CA
58346	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.226700000000001	-121.489999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:56:00	\N	0.680000000000000049	04:22:00	\N	0.729999999999999982	\N	\N	New Hope Bridge	CA
58347	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.236699999999999	-122.030000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	01:01:00	\N	1	00:36:00	\N	1.1100000000000001	\N	\N	Suisun City, Suisun Slough	CA
58348	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2766999999999982	-121.495000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	05:36:00	\N	0.390000000000000013	05:00:00	\N	0.489999999999999991	\N	\N	Snodgrass Slough	CA
58349	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2282999999999973	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:59:00	\N	0.819999999999999951	02:11:00	\N	1.14999999999999991	\N	\N	Upper drawbridge, Petaluma River	CA
58350	Napa, Napa River, California	NOS	9415623	38.2982999999999976	-122.280000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:37:00	\N	0.900000000000000022	02:05:00	\N	1.21999999999999997	\N	\N	Napa, Napa River	CA
58351	Bodega Harbor entrance, California	NOS	9415625	38.3083000000000027	-123.055000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:16:00	0.100000000000000006	\N	-00:38:00	-0.200000000000000011	\N	\N	\N	Bodega Harbor entrance	CA
58352	Clarksburg, Sacramento River, California	NOS	9415846	38.4166999999999987	-121.522999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	05:02:00	\N	0.409999999999999976	03:58:00	\N	0.599999999999999978	\N	\N	Clarksburg	CA
58353	Fort Ross, California	NOS	9416024	38.513300000000001	-123.245000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:30:00	\N	0.959999999999999964	-00:51:00	\N	0.959999999999999964	\N	\N	Fort Ross	CA
58354	Sacramento, Sacramento River, California	NOS	9416174	38.5799999999999983	-121.507000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	06:32:00	\N	0.409999999999999976	05:07:00	\N	0.599999999999999978	\N	\N	Sacramento	CA
58355	Fort Bragg Landing, California	NOS	9417439	39.4433000000000007	-123.813000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56330	00:02:00	\N	0.949999999999999956	00:15:00	\N	1	\N	\N	Fort Bragg Landing	CA
58356	Westport, California	NOS	9417624	39.6332999999999984	-123.783000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56330	00:00:00	\N	0.949999999999999956	00:14:00	\N	0.979999999999999982	\N	\N	Westport	CA
58357	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867000000000019	-124.221999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:15:00	\N	0.979999999999999982	00:06:00	\N	1.01000000000000001	\N	\N	Hookton Slough	CA
58358	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567000000000021	-124.192999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	01:32:00	\N	0.309999999999999998	00:19:00	\N	0.709999999999999964	\N	\N	Elk River Railroad Bridge	CA
58359	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783000000000015	-124.197000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:16:00	\N	1	00:17:00	\N	1.01000000000000001	\N	\N	Bucksport	CA
58360	Eureka, Humboldt Bay, California	NOS	9418801	40.8066999999999993	-124.167000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:13:00	\N	1.03000000000000003	00:26:00	\N	1.06000000000000005	\N	\N	Eureka	CA
58361	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8066999999999993	-124.141999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:19:00	\N	1.02000000000000002	00:33:00	\N	1.08000000000000007	\N	\N	Eureka Slough Bridge	CA
58362	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.8500000000000014	-124.117000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:54:00	0.100000000000000006	\N	00:48:00	0.100000000000000006	\N	\N	\N	Arcata Wharf	CA
58363	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865000000000002	-124.147999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56334	00:35:00	\N	1.07000000000000006	00:43:00	\N	1.12000000000000011	\N	\N	Mad River Slough, Arcata Bay	CA
58364	Trinidad Harbor, California	NOS	9419059	41.0566999999999993	-124.147000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	-00:03:00	\N	0.979999999999999982	-00:02:00	\N	0.969999999999999973	\N	\N	Trinidad Harbor	CA
58365	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433000000000021	-124.284999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
58366	Bandon, Coquille River, Oregon	NOS	9432373	43.1199999999999974	-124.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	00:02:00	\N	0.939999999999999947	-00:05:00	\N	0.92000000000000004	\N	\N	Bandon, Coquille River	OR
58367	Coos Bay, Oregon	NOS	9432845	43.3800000000000026	-124.215000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	01:28:00	\N	0.880000000000000004	01:26:00	\N	0.959999999999999964	\N	\N	Coos Bay	OR
58368	Empire, Coos Bay, Oregon	NOS	9432864	43.3917000000000002	-124.280000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	00:50:00	\N	0.880000000000000004	00:37:00	\N	0.859999999999999987	\N	\N	Empire	OR
58369	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3766999999999996	-124.296999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	00:08:00	\N	1.01000000000000001	00:07:00	\N	1.01000000000000001	\N	\N	Sitka Dock, Coos Bay	OR
58370	Florence, Siuslaw River, Oregon	NOS	9434032	43.966700000000003	-124.102999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	00:58:00	\N	0.800000000000000044	00:44:00	\N	0.859999999999999987	\N	\N	Florence	OR
58371	Siuslaw River entrance, Oregon	NOS	9434132	44.0167000000000002	-124.129999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	00:03:00	\N	0.959999999999999964	-00:06:00	\N	0.959999999999999964	\N	\N	Suislaw River Entrance	OR
58372	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4132999999999996	-123.989999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	01:51:00	\N	0.530000000000000027	00:44:00	\N	0.82999999999999996	\N	\N	Drift Creek, Alsea River	OR
58373	Yaquina, Oregon	NOS	9435328	44.6032999999999973	-124.010000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:55:00	\N	1.08000000000000007	00:55:00	\N	1.18999999999999995	\N	\N	Yaquina	OR
58375	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167000000000016	-123.936999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:17:00	\N	1.02000000000000002	01:02:00	\N	1.31000000000000005	\N	\N	TOLEDO	OR
58376	South Beach, Yaquina Bay and River, Oregon (sub)	NOS	9435380	44.625	-124.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:34:00	\N	1.10000000000000009	00:41:00	\N	1.22999999999999998	\N	\N	Southbeach	OR
58377	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6266999999999996	-124.055000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:35:00	\N	1.1100000000000001	00:39:00	\N	1.21999999999999997	\N	\N	YAQUINA USCG STA, NEWPORT	OR
58379	Kernville, Siletz River, Oregon	NOS	9436031	44.8967000000000027	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:53:00	\N	0.67000000000000004	01:24:00	\N	0.859999999999999987	\N	\N	Kernville, Siletz River	OR
58380	Taft, Siletz Bay, Oregon	NOS	9436101	44.9266999999999967	-124.013000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:13:00	\N	0.75	00:48:00	\N	0.939999999999999947	\N	\N	Taft, Siletz Bay	OR
58381	Netarts, Netarts Bay, Oregon	NOS	9437262	45.4299999999999997	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:38:00	\N	0.849999999999999978	01:17:00	\N	0.979999999999999982	\N	\N	Netarts, Netarts Bay	OR
58382	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.4600000000000009	-123.844999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	03:15:00	\N	0.57999999999999996	01:52:00	\N	0.939999999999999947	\N	\N	Tillamook, Hoquarten Slough	OR
58383	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683000000000007	-123.942999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:56:00	\N	0.92000000000000004	00:42:00	\N	1.08000000000000007	\N	\N	Barview	OR
58384	Brighton, Nehalem River, Oregon	NOS	9437815	45.6700000000000017	-123.924999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:54:00	\N	1	00:51:00	\N	1.12999999999999989	\N	\N	Brighton	OR
58385	Nehalem, Nehalem River, Oregon	NOS	9437908	45.7100000000000009	-123.890000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:56:00	\N	0.75	01:17:00	\N	1.03000000000000003	\N	\N	Nehalem	OR
58386	Seaside, 12th Avenue bridge, Necanicum River, Oregon	NOS	9438478	46	-123.921999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	02:07:00	\N	0.369999999999999996	00:47:00	\N	0.810000000000000053	\N	\N	Seaside, 12th Avenue bridge, Necanicum River	OR
58387	Astoria (Port Docks), Oregon	NOS	9439023	46.1867000000000019	-123.859999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
58388	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717000000000013	-123.841999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:14:00	0.100000000000000006	\N	-00:13:00	0.100000000000000006	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
58389	Settlers Point, Oregon	NOS	9439054	46.1749999999999972	-123.677999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	00:53:00	-0.100000000000000006	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
58390	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867000000000019	-123.587999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	00:58:00	\N	0.859999999999999987	00:29:00	\N	0.969999999999999973	\N	\N	Knappa, Knappa Slough	OR
58391	Hungry Harbor, Washington	NOS	9440563	46.2582999999999984	-123.847999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:09:00	0.100000000000000006	\N	00:04:00	-0.200000000000000011	\N	\N	\N	Hungry Harbor, Wash.	WA
58392	Fort Canby, Jetty 'A', Washington	NOS	9440572	46.2683000000000035	-124.037000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-01:05:00	\N	1.21999999999999997	-00:41:00	\N	0.969999999999999973	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
58393	Chinook, Baker Bay, Washington	NOS	9440573	46.2717000000000027	-123.947999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:52:00	\N	1.12000000000000011	-00:30:00	\N	0.949999999999999956	\N	\N	Chinook, Baker Bay, Wash.	WA
58394	Columbia River entrance (N. Jetty), Washington	NOS	9440574	46.273299999999999	-124.072000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-01:00:00	0.100000000000000006	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
58395	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033000000000001	-124.040000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	00:01:00	-0.100000000000000006	\N	-00:13:00	-0.800000000000000044	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
58396	Naselle River, 4 miles above swing bridge, Willapa Bay, Washington	NOS	9440662	46.388300000000001	-123.840000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	01:02:00	\N	0.930000000000000049	01:02:00	\N	1.21999999999999997	\N	\N	Naselle River, 4 miles above swing bridge	WA
58397	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.4299999999999997	-123.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:37:00	\N	1.08000000000000007	00:42:00	\N	1.21999999999999997	\N	\N	Naselle River, swing bridge	WA
58398	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4682999999999993	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:41:00	\N	1.04000000000000004	00:43:00	\N	1.14999999999999991	\N	\N	Paradise Point, Long Island	WA
58399	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5016999999999996	-124.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:28:00	\N	1.01000000000000001	00:29:00	\N	1.12999999999999989	\N	\N	Nahcotta	WA
58400	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867000000000004	-123.909999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:31:00	\N	0.959999999999999964	00:25:00	\N	1.04000000000000004	\N	\N	Palix River, south fork	WA
58401	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233000000000004	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:22:00	\N	1.03000000000000003	00:09:00	\N	1.04000000000000004	\N	\N	Bay Center, Palix River	WA
58402	South Bend, Willapa River, Willapa Bay, Washington (sub)	NOS	9440875	46.6632999999999996	-123.798000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:15:00	\N	1.05000000000000004	00:14:00	\N	1.1100000000000001	\N	\N	South Bend, Willapa River	WA
58403	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833000000000027	-123.754999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:17:00	\N	1.04000000000000004	00:27:00	\N	1.12999999999999989	\N	\N	Raymond, Willapa River	WA
58404	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.861699999999999	-124.060000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:26:00	\N	1.12999999999999989	-00:01:00	\N	1.10000000000000009	\N	\N	Bay City, South Bay	WA
58405	Markham, Grays Harbor, Washington	NOS	9441098	46.9067000000000007	-123.998000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:15:00	\N	1.02000000000000002	00:05:00	\N	1.06000000000000005	\N	\N	Markham	WA
58406	Point Brown, Grays Harbor, Washington	NOS	9441156	46.9500000000000028	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:24:00	\N	1.04000000000000004	-00:09:00	\N	1.06000000000000005	\N	\N	Point Brown	WA
58407	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.966700000000003	-123.778000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:15:00	\N	1.12000000000000011	00:26:00	\N	1.22999999999999998	\N	\N	Cosmopolis, Chehalis River	WA
58408	Point Grenville, Washington	NOS	9441627	47.3033000000000001	-124.269999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:44:00	\N	0.900000000000000022	-00:37:00	\N	0.92000000000000004	\N	\N	Point Grenville	WA
58409	James Island, Washington	NOS	9442388	47.9067000000000007	-124.647000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:32:00	\N	0.959999999999999964	-00:39:00	\N	0.92000000000000004	\N	\N	James Island	WA
58410	Makah Bay, Washington	NOS	9442861	48.2967000000000013	-124.671999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:28:00	\N	1.10000000000000009	-00:25:00	\N	0.989999999999999991	\N	\N	Makah Bay	WA
58411	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.3917007446289062	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56377	-00:10:00	\N	1	-00:08:00	\N	1.01000000000000001	\N	\N	Tatoosh Island, Cape Flattery	WA
58412	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.1749992370605469	-123.949996948242188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56377	00:59:00	\N	1.19999999999999996	00:47:00	\N	0.890000000000000013	\N	\N	Twin Rivers	WA
58413	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617000000000033	-123.724999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-02:02:00	\N	0.800000000000000044	-02:41:00	\N	0.800000000000000044	\N	\N	Crescent Bay	WA
58414	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.1400000000000006	-123.412999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-01:13:00	\N	0.900000000000000022	-01:37:00	\N	0.810000000000000053	\N	\N	Ediz Hook, Port Angeles	WA
58415	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1666999999999987	-123.117000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:38:00	\N	0.900000000000000022	-00:54:00	\N	0.900000000000000022	\N	\N	Dungeness	WA
58416	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0816999999999979	-123.043000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:07:00	\N	0.939999999999999947	-00:39:00	\N	0.939999999999999947	\N	\N	Sequim Bay entrance	WA
58417	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583000000000027	-122.917000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:17:00	\N	0.939999999999999947	-00:47:00	\N	0.939999999999999947	\N	\N	Gardiner, Discovery Bay	WA
58418	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583000000000027	-122.691999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:52:00	\N	0.989999999999999991	00:15:00	\N	0.949999999999999956	\N	\N	Mystery Bay, Marrowstone Island	WA
58419	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.091700000000003	-122.689999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:05:00	-0.100000000000000006	\N	00:02:00	0.400000000000000022	\N	\N	\N	Marrowstone Point	WA
58420	Foulweather Bluff, Washington (sub)	NOS	9445016	47.9266999999999967	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:07:00	\N	0.979999999999999982	-00:11:00	\N	0.890000000000000013	\N	\N	Foulweather Bluff	WA
58421	Port Ludlow, Washington	NOS	9445017	47.9249999999999972	-122.680000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:14:00	\N	0.949999999999999956	-00:14:00	\N	0.869999999999999996	\N	\N	Port Ludlow	WA
58422	Port Gamble, Washington	NOS	9445059	47.8582999999999998	-122.579999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:05:00	\N	0.949999999999999956	-00:09:00	\N	0.900000000000000022	\N	\N	Port Gamble	WA
58423	Lofall, Washington	NOS	9445088	47.8149999999999977	-122.656999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:06:00	\N	1.01000000000000001	-00:08:00	\N	0.939999999999999947	\N	\N	Lofall	WA
58424	Bangor Wharf, Washington (sub)	NOS	9445133	47.7483000000000004	-122.727000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:01:00	\N	1.03000000000000003	-00:06:00	\N	0.969999999999999973	\N	\N	Bangor Wharf	WA
58425	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7616999999999976	-122.849999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:02:00	\N	1.06000000000000005	-00:05:00	\N	1.01000000000000001	\N	\N	Whitney Point, Dabob Bay	WA
58426	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117000000000004	-122.822000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:05:00	\N	1.02000000000000002	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
58427	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.7999999999999972	-122.858000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:02:00	\N	1.04000000000000004	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
58428	Pleasant Harbor, Washington	NOS	9445293	47.6649999999999991	-122.912000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:01:00	\N	1.02000000000000002	-00:14:00	\N	1.01000000000000001	\N	\N	Pleasant Harbor	WA
58429	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417000000000002	-122.828000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:01:00	\N	1.06000000000000005	-00:04:00	\N	1.01000000000000001	\N	\N	Seabeck, Seabeck Bay	WA
58430	Triton Head, Washington	NOS	9445326	47.6032999999999973	-122.981999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:06:00	\N	1.02000000000000002	-00:06:00	\N	1	\N	\N	Triton Head	WA
58431	Ayock Point, Washington	NOS	9445388	47.5082999999999984	-123.052000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:05:00	\N	1.07000000000000006	-00:03:00	\N	0.989999999999999991	\N	\N	Ayock Point	WA
58432	Lynch Cove Dock, Washington	NOS	9445441	47.4183000000000021	-122.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:06:00	\N	1.08000000000000007	00:00:00	\N	1.07000000000000006	\N	\N	Lynch Cove Dock	WA
58433	Hansville, Puget Sound, Washington	NOS	9445526	47.9183000000000021	-122.545000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:08:00	\N	0.979999999999999982	-00:07:00	\N	0.92000000000000004	\N	\N	Hansville	WA
58434	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967000000000013	-122.492999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:05:00	\N	1	-00:05:00	\N	0.969999999999999973	\N	\N	Kingston, Appletree Cove	WA
58435	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.746699999999997	-122.477000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:04:00	\N	0.979999999999999982	-00:03:00	\N	0.949999999999999956	\N	\N	Port Jefferson	WA
58436	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.7250000000000014	-122.638000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:12:00	\N	1.01000000000000001	00:05:00	\N	1.03000000000000003	\N	\N	Poulsbo, Liberty Bay	WA
58437	Port Madison, Puget Sound, Washington	NOS	9445753	47.7049999999999983	-122.525000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:03:00	\N	0.989999999999999991	00:09:00	\N	1	\N	\N	Port Madison	WA
58438	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6516999999999982	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:09:00	\N	1.03000000000000003	00:07:00	\N	1.04000000000000004	\N	\N	Brownsville, Port Orchard	WA
58439	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.6199999999999974	-122.515000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:05:00	\N	1.02000000000000002	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
58440	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.6099999999999994	-122.659999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:53:00	\N	0.949999999999999956	00:28:00	\N	1.06000000000000005	\N	\N	Tracyton, Dyes Inlet	WA
58441	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5966999999999985	-122.510000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:04:00	\N	0.989999999999999991	00:04:00	\N	1.01000000000000001	\N	\N	Port Blakely	WA
58442	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733000000000033	-122.543000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:04:00	\N	1	00:03:00	\N	1.01000000000000001	\N	\N	Clam Bay, Rich Passage	WA
58443	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.5617000000000019	-122.623000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:18:00	\N	1	00:11:00	\N	1.04000000000000004	\N	\N	Bremerton, Sinclair Inlet, Port Orchard	WA
58444	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.523299999999999	-122.516999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:01:00	\N	0.989999999999999991	-00:06:00	\N	1.02000000000000002	\N	\N	Harper, Yukon Harbor	WA
58445	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5116999999999976	-122.462999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:02:00	\N	1.01000000000000001	00:02:00	\N	1.02000000000000002	\N	\N	Point Vashon, Vashon Island	WA
58446	Des Moines, East Passage, Puget Sound, Washington	NOS	9446248	47.3999999999999986	-122.328000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:08:00	\N	1.01000000000000001	00:05:00	\N	1.03000000000000003	\N	\N	Des Moines, East Passage	WA
58447	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.3950000000000031	-122.462999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:03:00	\N	1.02000000000000002	00:01:00	\N	1.06000000000000005	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
58448	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3832999999999984	-122.822999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:59:00	\N	1.07000000000000006	00:48:00	\N	1.26000000000000001	\N	\N	Allyn, Case Inlet	WA
58449	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.341700000000003	-122.775000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:57:00	\N	1.06000000000000005	00:51:00	\N	1.26000000000000001	\N	\N	Vaughn, Case Inlet	WA
58450	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.3400000000000034	-122.587999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:22:00	\N	0.989999999999999991	00:18:00	\N	1.05000000000000004	\N	\N	Gig Harbor	WA
58451	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333000000000013	-122.507000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:05:00	\N	1.01000000000000001	00:04:00	\N	1.05000000000000004	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
58452	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3016999999999967	-122.682000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:46:00	\N	1.05000000000000004	00:38:00	\N	1.19999999999999996	\N	\N	Horsehead Bay, Carr Inlet	WA
58453	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717000000000027	-122.552000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:23:00	\N	1.02000000000000002	00:28:00	\N	1.1100000000000001	\N	\N	Tacoma Narrows Bridge	WA
58454	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817000000000007	-122.923000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:55:00	\N	1.07000000000000006	00:44:00	\N	1.26000000000000001	\N	\N	Walkers Landing, Pickering Passage	WA
58455	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.2800000000000011	-122.652000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:40:00	\N	1.04000000000000004	00:31:00	\N	1.17999999999999994	\N	\N	Arletta, Hale Passage	WA
58456	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.2749999999999986	-122.757999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:45:00	\N	1.04000000000000004	00:37:00	\N	1.18999999999999995	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
58457	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.246699999999997	-122.861999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:52:00	\N	1.06000000000000005	00:40:00	\N	1.23999999999999999	\N	\N	McMicken Island, Case Inlet	WA
58458	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.2150000000000034	-123.082999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	02:05:00	\N	0.92000000000000004	01:26:00	\N	1.26000000000000001	\N	\N	Shelton, Oakland Bay	WA
58459	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.2100000000000009	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:47:00	\N	1.02000000000000002	00:38:00	\N	1.19999999999999996	\N	\N	Longbranch, Filucy Bay	WA
58460	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1966999999999999	-122.938000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	01:05:00	\N	1.06000000000000005	00:49:00	\N	1.28000000000000003	\N	\N	Arcadia, Totten Inlet	WA
58461	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1666999999999987	-122.763000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:50:00	\N	1.10000000000000009	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
58462	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1732999999999976	-122.602999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:45:00	\N	1.05000000000000004	00:37:00	\N	1.19999999999999996	\N	\N	Steilacoom, Cormorant Passage	WA
58463	Barron Point, Little Snookum Inlet Entrance, Puget Sound, Washington	NOS	9446742	47.1567000000000007	-123.007999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:59:00	\N	1.06000000000000005	00:50:00	\N	1.29000000000000004	\N	\N	Barron Point, Little Snookum Inlet Entrance	WA
58464	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.1550000000000011	-122.837999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:58:00	\N	1.06000000000000005	00:47:00	\N	1.23999999999999999	\N	\N	Henderson Inlet	WA
58465	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417000000000002	-122.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:57:00	\N	1.09000000000000008	00:44:00	\N	1.28000000000000003	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
58466	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1182999999999979	-122.665000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:49:00	\N	1.04000000000000004	00:41:00	\N	1.19999999999999996	\N	\N	Dupont Wharf, Nisqually Reach	WA
58467	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.0600000000000023	-122.903000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:57:00	\N	1.08000000000000007	00:45:00	\N	1.29000000000000004	\N	\N	Olympia, Budd Inlet	WA
58468	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.5349999999999966	-122.322000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:11:00	\N	0.949999999999999956	00:10:00	\N	0.969999999999999973	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
58469	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.5850000000000009	-122.361999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
58470	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6882999999999981	-122.403000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:01:00	\N	0.989999999999999991	00:00:00	\N	0.979999999999999982	\N	\N	Meadow Point, Shilshole Bay	WA
58471	Edmonds, Puget Sound, Washington	NOS	9447427	47.8132999999999981	-122.382999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:04:00	\N	0.989999999999999991	00:00:00	\N	0.959999999999999964	\N	\N	Edmonds	WA
58472	Glendale, Whidbey Island, Washington	NOS	9447814	47.9399999999999977	-122.356999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:03:00	\N	0.989999999999999991	00:01:00	\N	0.969999999999999973	\N	\N	Glendale, Whidbey Island	WA
58473	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.033299999999997	-122.606999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:45:00	\N	1.08000000000000007	00:10:00	\N	1.09000000000000008	\N	\N	Bush Point, Whidbey Island	WA
58474	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0266999999999982	-122.534999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:04:00	\N	0.989999999999999991	00:01:00	\N	1.01000000000000001	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
58475	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.0349999999999966	-122.376999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:01:00	\N	1	00:03:00	\N	0.989999999999999991	\N	\N	Sandy Point, Whidbey Island	WA
58476	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.158299999999997	-122.668000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:20:00	-0.100000000000000006	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
58477	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233000000000018	-122.689999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:09:00	\N	0.989999999999999991	00:15:00	\N	1.01000000000000001	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
58478	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2316999999999965	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:15:00	\N	0.92000000000000004	-00:11:00	\N	0.92000000000000004	\N	\N	Point Partridge, Whidbey Island	WA
58479	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.283299999999997	-122.727999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:16:00	\N	0.949999999999999956	-00:27:00	\N	0.869999999999999996	\N	\N	Sunset Beach, Whidbey Island	WA
58480	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867000000000033	-122.617000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:04:00	\N	0.989999999999999991	00:04:00	\N	1.03000000000000003	\N	\N	Crescent Harbor, N. Whidbey Island	WA
58481	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3166999999999973	-122.837000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:25:00	\N	0.82999999999999996	-00:13:00	\N	0.82999999999999996	\N	\N	Smith Island	WA
58482	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967000000000027	-122.587000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:26:00	\N	0.949999999999999956	00:12:00	\N	0.92000000000000004	\N	\N	Ala Spit, Whidbey Island	WA
58483	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4016999999999982	-122.623000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:26:00	\N	0.949999999999999956	00:15:00	\N	0.890000000000000013	\N	\N	Cornet Bay, Deception Pass	WA
58484	Kayak Point, Washington	NOS	9448094	48.1366999999999976	-122.367000000000004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	-00:02:00	\N	0.989999999999999991	00:00:00	\N	0.989999999999999991	\N	\N	Kayak Point	WA
58485	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917000000000002	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:39:00	\N	0.949999999999999956	00:21:00	\N	0.900000000000000022	\N	\N	La Conner, Swinomish Channel	WA
58486	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4132999999999996	-122.614999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:38:00	-0.200000000000000011	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
58487	Burrows Bay (Allan Island), Washington	NOS	9448683	48.4600000000000009	-122.694999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:03:00	\N	0.880000000000000004	00:09:00	\N	0.949999999999999956	\N	\N	Burrows Bay (Allan Island)	WA
58488	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067000000000021	-122.677000000000007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:29:00	\N	1.02000000000000002	00:18:00	\N	0.930000000000000049	\N	\N	Ship Harbor, Fidalgo Island	WA
58489	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183000000000035	-122.620000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:33:00	\N	1	00:22:00	\N	0.959999999999999964	\N	\N	Anacortes, Guemes Channel	WA
58490	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.5649999999999977	-122.721999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:52:00	\N	0.949999999999999956	00:34:00	\N	0.949999999999999956	\N	\N	Strawberry Bay, Cypress Island	WA
58491	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867000000000004	-122.748000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:41:00	\N	0.949999999999999956	00:31:00	\N	0.939999999999999947	\N	\N	Tide Point, Cypress Island	WA
58562	Lake Bay, Alaska	NOS	9450904	56.023299999999999	-132.919999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.890000000000000013	00:10:00	\N	1.03000000000000003	\N	\N	Lake Bay	AK
58492	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.7299999999999969	-122.670000000000002	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:10:00	\N	0.969999999999999973	00:41:00	\N	1.04000000000000004	\N	\N	Gooseberry Point	WA
58493	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.7449999999999974	-122.495000000000005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:11:00	\N	0.939999999999999947	00:43:00	\N	0.989999999999999991	\N	\N	Bellingham	WA
58494	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.7899999999999991	-122.707999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:24:00	\N	1.03000000000000003	00:52:00	\N	1.05000000000000004	\N	\N	Sandy Point, Lummi Bay	WA
58495	Drayton Harbor, Blaine, Strait of Georgia, Washington (sub)	NOS	9449679	48.9917000000000016	-122.765000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:27:00	\N	1.06000000000000005	00:54:00	\N	1.1100000000000001	\N	\N	Blaine, Semiahmoo Bay	WA
58496	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867000000000033	-122.969999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:30:00	0	\N	01:03:00	0.200000000000000011	\N	\N	\N	Patos Island Wharf	WA
58497	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567000000000021	-122.897000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:34:00	0	\N	01:01:00	0.100000000000000006	\N	\N	\N	Echo Bay, Sucia Islands	WA
58498	Orcas, Orcas Island, Washington	NOS	9449798	48.6000000000000014	-122.950000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:56:00	\N	0.900000000000000022	00:33:00	\N	0.900000000000000022	\N	\N	Orcas, Orcas Island	WA
58499	Turn Point, Stuart Island, Washington	NOS	9449802	48.6882999999999981	-123.236999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:47:00	\N	0.900000000000000022	00:24:00	\N	0.900000000000000022	\N	\N	Turn Point, Stuart Island	WA
58500	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.6099999999999994	-123.155000000000001	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:47:00	\N	0.989999999999999991	00:33:00	\N	0.900000000000000022	\N	\N	Roche Harbor, San Juan Island	WA
58501	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.5850000000000009	-122.927999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:56:00	\N	0.989999999999999991	00:31:00	\N	0.900000000000000022	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
58502	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.4249999999999972	-122.852999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:08:00	\N	0.880000000000000004	-00:18:00	\N	0.880000000000000004	\N	\N	Aleck Bay, Lopez Island	WA
58503	Minnie Bay, Alaska	NOS	9450041	54.726700000000001	-132.301999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:00:00	0.100000000000000006	\N	-00:05:00	2.70000000000000018	\N	\N	\N	Minnie Bay	AK
58504	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483000000000004	-132.85499999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
58505	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.8200000000000003	-130.699999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:09:00	\N	0.890000000000000013	00:01:00	\N	0.949999999999999956	\N	\N	Nakat Harbor, Alaska	AK
58506	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.8500000000000014	-132.830000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
58507	Hunter Bay, Alaska	NOS	9450139	54.871699999999997	-132.322000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:03:00	0.100000000000000006	\N	-00:02:00	2.70000000000000018	\N	\N	\N	Hunter Bay	AK
58508	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8766999999999996	-131.300000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:03:00	\N	0.959999999999999964	-00:04:00	\N	0.939999999999999947	\N	\N	Kelp Island Passage, Duke Island	AK
58509	Elbow Bay, Alaska	NOS	9450158	54.8999999999999986	-132.652999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:04:00	0.100000000000000006	\N	-00:04:00	2.60000000000000009	\N	\N	\N	Elbow Bay	AK
58510	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.9200000000000017	-131.254999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:15:00	\N	0.959999999999999964	00:03:00	\N	0.959999999999999964	\N	\N	Morse Cove, Duke Island	AK
58511	Kassa Inlet entrance, Alaska	NOS	9450176	54.9266999999999967	-132.521999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:01:00	0.100000000000000006	\N	-00:03:00	2.60000000000000009	\N	\N	\N	Kassa Inlet entrance	AK
58512	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.9799999999999969	-132.007000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:04:00	\N	0.959999999999999964	00:03:00	\N	0.930000000000000049	\N	\N	Ingraham Bay, Prince of Wales Island	AK
58513	Mabel Island, Alaska	NOS	9450226	55	-132.592000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:01:00	0.100000000000000006	\N	-00:10:00	2.79999999999999982	\N	\N	\N	Mabel Island	AK
58514	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0266999999999982	-132.013000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.890000000000000013	-00:02:00	\N	0.939999999999999947	\N	\N	Menefee Anch., Prince of Wales Island	AK
58515	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0416999999999987	-130.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:06:00	\N	0.959999999999999964	00:00:00	\N	0.969999999999999973	\N	\N	Kah Shakes Cove	AK
58516	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467000000000013	-132.576999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:05:00	0.100000000000000006	\N	-00:13:00	2.79999999999999982	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
58517	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0666999999999973	-132.120000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:09:00	\N	0.959999999999999964	00:03:00	\N	0.939999999999999947	\N	\N	Niblack Anchorage, Moira Sound	AK
58518	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0666999999999973	-133.199999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:05:00	0	\N	00:01:00	0.299999999999999989	\N	\N	\N	Sakie Bay	AK
58519	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0666999999999973	-131.542000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:08:00	\N	0.890000000000000013	-00:09:00	\N	0.979999999999999982	\N	\N	Tamgas Harbor, Annette Island	AK
58520	Keete Inlet, Alaska	NOS	9450281	55.0799999999999983	-132.490000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:01:00	0.100000000000000006	\N	-00:11:00	2.89999999999999991	\N	\N	\N	Keete Inlet	AK
58521	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0816999999999979	-132.632000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:01:00	0.100000000000000006	\N	-00:05:00	2.79999999999999982	\N	\N	\N	Mud Bay	AK
58522	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833000000000013	-133.016999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:02:00	0	\N	-00:02:00	2.79999999999999982	\N	\N	\N	View Cove	AK
58523	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167000000000016	-130.798000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:02:00	\N	0.979999999999999982	00:00:00	\N	0.979999999999999982	\N	\N	Boca de Quadra	AK
58524	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1266999999999996	-133.167000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:04:00	-0.100000000000000006	\N	-00:04:00	-0.200000000000000011	\N	\N	\N	Sea Otter Harbor	AK
58525	Metlakatla, Port Chester, Alaska (sub)	NOS	9450314	55.128300000000003	-131.567000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:07:00	\N	0.959999999999999964	-00:10:00	\N	0.949999999999999956	\N	\N	Metlakatla, Port Chester	AK
58526	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1666999999999987	-131.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:01:00	\N	0.959999999999999964	-00:01:00	\N	0.949999999999999956	\N	\N	Nehenta Bay, Gravina Island	AK
58527	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1666999999999987	-132.870000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:02:00	0.100000000000000006	\N	-00:02:00	2.89999999999999991	\N	\N	\N	South Pass, Sukkwan Strait	AK
58528	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1816999999999993	-132.794999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:05:00	0.100000000000000006	\N	-00:08:00	2.89999999999999991	\N	\N	\N	Saltery Point	AK
58529	North Pass, West End, Tlevak Strait, Alaska	NOS	9450366	55.2049999999999983	-132.939999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:06:00	0.100000000000000006	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
58530	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.2100000000000009	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:08:00	0.100000000000000006	\N	-00:10:00	2.79999999999999982	\N	\N	\N	Copper Harbor	AK
58531	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2132999999999967	-132.094999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:03:00	\N	0.959999999999999964	00:05:00	\N	0.979999999999999982	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
58532	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2282999999999973	-131.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:03:00	\N	0.959999999999999964	-00:05:00	\N	0.979999999999999982	\N	\N	Alva Bay, Revillagigedo Island	AK
58533	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2332999999999998	-133.043000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:01:00	0.100000000000000006	\N	-00:05:00	2.89999999999999991	\N	\N	\N	Natalia Point	AK
58534	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2516999999999996	-132.300000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:08:00	\N	0.959999999999999964	-00:05:00	\N	0.979999999999999982	\N	\N	Divide Head, Cholmondeley Sound	AK
58535	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.2633018493652344	-133.115005493164062	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:02:00	\N	1	00:07:00	\N	1.19999999999999996	\N	\N	Block Island, Tlevak Narrows	AK
58536	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.2749999999999986	-132.967000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:07:00	0.100000000000000006	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
58537	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.2849999999999966	-132.622000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:08:00	0.100000000000000006	\N	-00:02:00	2.89999999999999991	\N	\N	\N	Sulzer	AK
58538	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3832999999999984	-131.235000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:03:00	\N	0.979999999999999982	-00:05:00	\N	0.979999999999999982	\N	\N	Mop Point, Thorne Arm	AK
58539	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.398299999999999	-131.727000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:03:00	\N	0.959999999999999964	-00:05:00	\N	1.02000000000000002	\N	\N	Ward Cove	AK
58540	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4016999999999982	-132.328000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:02:00	\N	1.01000000000000001	00:04:00	\N	1.01000000000000001	\N	\N	Saltery Cove, Skowl Arm	AK
58541	Vallenar Point, Alaska	NOS	9450511	55.4266999999999967	-131.847000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:06:00	\N	0.959999999999999964	-00:01:00	\N	0.989999999999999991	\N	\N	Vallenar Point	AK
58542	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617000000000004	-131.504999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:07:00	\N	0.959999999999999964	-00:03:00	\N	0.989999999999999991	\N	\N	Coon Island, George Inlet	AK
58543	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.4799999999999969	-132.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:02:00	\N	1.01000000000000001	00:06:00	\N	1.03000000000000003	\N	\N	Hollis Anchorage	AK
58544	Craig, Klawock Inlet, Bucareli Bay, Alaska (sub)	NOS	9450551	55.4883000000000024	-133.141999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:08:00	\N	0.939999999999999947	-00:08:00	\N	1.02000000000000002	\N	\N	Craig, Klawock Inlet	AK
58545	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.533299999999997	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:13:00	\N	0.930000000000000049	-00:12:00	\N	1.04000000000000004	\N	\N	Steamboat Bay, Noyes Island	AK
58547	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5416999999999987	-133.314999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:12:00	-0.100000000000000006	\N	-00:15:00	0.100000000000000006	\N	\N	\N	Cruz Pass, San Fernando Island	AK
58548	Loring, Naha Bay, Alaska	NOS	9450624	55.601700000000001	-131.632000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	-00:06:00	\N	0.959999999999999964	-00:02:00	\N	1.02000000000000002	\N	\N	Loring, Naha Bay	AK
58549	Lindeman Cove, Kasaan Bay, Alaska (sub)	NOS	9450625	55.601700000000001	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:03:00	\N	1.01000000000000001	00:06:00	\N	1.02000000000000002	\N	\N	Lindeman Cove	AK
58550	Rudyerd Bay, Alaska	NOS	9450651	55.6417000000000002	-130.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:02:00	\N	0.959999999999999964	00:01:00	\N	1.02000000000000002	\N	\N	Rudyerd Bay	AK
58551	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833000000000027	-133.586999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:14:00	-0.100000000000000006	\N	-00:18:00	0.400000000000000022	\N	\N	\N	Anguilla Island	AK
58552	Davis River entrance, Alaska	NOS	9450729	55.759999999999998	-130.176999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:00:00	\N	0.959999999999999964	-00:02:00	\N	1.08000000000000007	\N	\N	Davis River entrance, Alaska	AK
58553	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117000000000019	-133.60499999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:14:00	0	\N	-00:20:00	0.900000000000000022	\N	\N	\N	Port Alice, Heceta Island	AK
58554	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.8800000000000026	-132.594999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:00:00	\N	0.989999999999999991	00:09:00	\N	1.03000000000000003	\N	\N	Ratz Harbor, Prince of Wales Island	AK
58555	Tuxekan, 0.5 mile south of, Davidson Inlet, Alaska	NOS	9450817	55.8832999999999984	-133.242999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:07:00	-0.100000000000000006	\N	-00:17:00	0.900000000000000022	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
58556	Coronation Island, Alaska	NOS	9450829	55.9033000000000015	-134.117999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:17:00	0	\N	-00:16:00	0.800000000000000044	\N	\N	\N	Coronation Island	AK
58557	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9132999999999996	-131.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.959999999999999964	00:00:00	\N	1.02000000000000002	\N	\N	Yes Cannery, Yes Bay	AK
58558	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367000000000019	-133.324999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:10:00	-0.100000000000000006	\N	-00:11:00	0.900000000000000022	\N	\N	\N	El Capitan Island	AK
58559	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.9500000000000028	-133.662000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:08:00	0	\N	-00:20:00	0.900000000000000022	\N	\N	\N	Edna Bay	AK
58560	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.9549999999999983	-133.810000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:22:00	-0.100000000000000006	\N	-00:22:00	1.39999999999999991	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
58563	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467000000000013	-132.861999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:05:00	\N	1.01000000000000001	00:10:00	\N	1.05000000000000004	\N	\N	Beck Island, Clarence Strait	AK
58564	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369000000000028	-134.115000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:06:00	\N	0.949999999999999956	-00:09:00	\N	1.09000000000000008	\N	\N	Affleck Canal entrance, Kuiu Island	AK
58565	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733000000000033	-133.312999999999988	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:02:00	-0.100000000000000006	\N	-00:05:00	0.900000000000000022	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
58566	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583000000000027	-132.967999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.979999999999999982	00:12:00	\N	1.04000000000000004	\N	\N	Thorne Island, Whale Passage	AK
58567	Point St. Albans, Alaska	NOS	9450943	56.0816999999999979	-133.969999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:13:00	0	\N	-00:17:00	1.39999999999999991	\N	\N	\N	Point St. Albans	AK
58568	Thoms Point, Zimovia Strait, Alaska (sub)	NOS	9450970	56.1182999999999979	-132.078000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.989999999999999991	00:07:00	\N	1.06000000000000005	\N	\N	Thoms Point, Zimovia Strait	AK
58569	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1266999999999996	-132.89500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:24:00	\N	0.930000000000000049	00:13:00	\N	1.03000000000000003	\N	\N	Blashke Island	AK
58570	Shakan Bay Entrance, Alaska	NOS	9450982	56.1400000000000006	-133.610000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:12:00	0	\N	-00:13:00	1.80000000000000004	\N	\N	\N	Shakan Bay Entrance	AK
58571	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.148299999999999	-133.460000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:10:00	\N	0.949999999999999956	-00:07:00	\N	1.15999999999999992	\N	\N	Shakan Strait, Kosciusko Island	AK
58572	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.1499999999999986	-134.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:01:00	0	\N	00:01:00	1.30000000000000004	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
58573	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1666999999999987	-134.245000000000005	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:13:00	0	\N	-00:15:00	1.10000000000000009	\N	\N	\N	Table Bay, Kuiu Island	AK
58574	Point Harrington, Clarence Strait, Alaska (sub)	NOS	9451005	56.1783000000000001	-132.697000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.969999999999999973	00:09:00	\N	1.04000000000000004	\N	\N	Point Harrington	AK
58575	Bradfield Canal, Alaska (sub)	NOS	9451012	56.1833000000000027	-131.572000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:05:00	\N	0.989999999999999991	00:11:00	\N	1.08000000000000007	\N	\N	Bradfield Canal, Ernest Sound	AK
58576	Village Rock, Zimovia Strait, Alaska (sub)	NOS	9451037	56.2199999999999989	-132.296999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.969999999999999973	00:09:00	\N	1.05000000000000004	\N	\N	Village Rock, Zimovia Strait	AK
58577	Port Alexander, Baranof Island, Alaska (sub)	NOS	9451054	56.246699999999997	-134.646999999999991	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:10:00	\N	1.01000000000000001	00:07:00	\N	1.1399999999999999	\N	\N	Port Alexander, Baranof Island	AK
58578	Bushy Island, Snow Passage, Alaska (sub)	NOS	9451074	56.2766999999999982	-132.985000000000014	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.930000000000000049	00:03:00	\N	0.949999999999999956	\N	\N	Bushy Island, Snow Passage	AK
58579	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2882999999999996	-133.961999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:12:00	-0.100000000000000006	\N	-00:14:00	1.89999999999999991	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
58580	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.3049999999999997	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:13:00	0.100000000000000006	\N	00:04:00	1.19999999999999996	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
58581	Port Protection, Prince of Wales Island., Alaska	NOS	9451095	56.3083000000000027	-133.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:11:00	0	\N	-00:13:00	2.39999999999999991	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
58582	Reef Point, Stikine Strait, Alaska (sub)	NOS	9451124	56.3532999999999973	-132.552999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:02:00	\N	0.959999999999999964	00:09:00	\N	1.04000000000000004	\N	\N	Reef Point, Stikine Strait	AK
58583	Reid Bay, Alaska	NOS	9451148	56.388300000000001	-133.88300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
58584	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917000000000002	-134.659999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:13:00	0.100000000000000006	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
58585	Madan Bay, Clarence Strait, Alaska (sub)	NOS	9451152	56.3922000000000025	-132.169000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:04:00	\N	0.979999999999999982	00:12:00	\N	1.05000000000000004	\N	\N	Madan Bay	AK
58586	Sumner Island, Alaska	NOS	9451163	56.4099999999999966	-133.793000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:12:00	0	\N	-00:19:00	2.60000000000000009	\N	\N	\N	Sumner Island	AK
58587	Wrangell, Wrangell Island, Alaska (sub)	NOS	9451204	56.4699999999999989	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:01:00	\N	0.959999999999999964	00:10:00	\N	1.04000000000000004	\N	\N	Wrangell, Wrangell Island	AK
58588	Greys Island, Alaska	NOS	9451238	56.5217000000000027	-132.542000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:05:00	\N	0.939999999999999947	00:11:00	\N	1.01000000000000001	\N	\N	Greys Island	AK
58589	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska (sub)	NOS	9451263	56.5583000000000027	-132.962999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:08:00	\N	0.979999999999999982	00:15:00	\N	0.979999999999999982	\N	\N	Point Lockwood, Woewodski Island	AK
58590	Beecher Pass, Wrangell Narrows, Alaska (sub)	NOS	9451287	56.5949999999999989	-132.986999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:14:00	\N	0.979999999999999982	00:22:00	\N	1	\N	\N	Beecher Pass	AK
58591	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615000000000002	-132.574999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:03:00	0	\N	-00:18:00	-0.200000000000000011	\N	\N	\N	Dry Strait	AK
58592	Anchor Point, Wrangell Narrows, Alaska (sub)	NOS	9451317	56.638300000000001	-132.926999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:40:00	\N	0.989999999999999991	00:31:00	\N	1.04000000000000004	\N	\N	Anchor Point	AK
58593	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6632999999999996	-132.61699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:05:00	\N	0.989999999999999991	-00:05:00	\N	0.979999999999999982	\N	\N	Cosmos Point	AK
58594	Papke's Landing, Wrangell Narrows, Alaska (sub)	NOS	9451346	56.6766999999999967	-132.932999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:50:00	\N	1.01000000000000001	00:33:00	\N	1	\N	\N	Papke's Landing	AK
58595	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7216999999999985	-135.074999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:02:00	\N	0.949999999999999956	-00:02:00	\N	0.969999999999999973	\N	\N	Dorothy Cove, Necker Bay	AK
58596	Turn Point, Alaska (sub)	NOS	9451434	56.7999999999999972	-132.97999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:38:00	\N	0.959999999999999964	00:25:00	\N	1.04000000000000004	\N	\N	Turn Point	AK
58597	Entrance Island, Keku Strait, Alaska (sub)	NOS	9451438	56.8117000000000019	-133.787000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:20:00	\N	0.979999999999999982	00:18:00	\N	0.939999999999999947	\N	\N	Entrance Island	AK
58598	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.8149999999999977	-132.956999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:37:00	\N	0.969999999999999973	00:28:00	\N	1.04000000000000004	\N	\N	Petersburg	AK
58599	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8566999999999965	-135.52000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:16:00	0	\N	-00:15:00	-0.100000000000000006	\N	\N	\N	Symonds Bay, Biorka Island	AK
58600	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.996699999999997	-132.784999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:07:00	-0.100000000000000006	\N	00:07:00	-0.800000000000000044	\N	\N	\N	Thomas Bay	AK
58601	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133000000000024	-134.379999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:07:00	\N	0.910000000000000031	-00:08:00	\N	0.839999999999999969	\N	\N	Herring Bay	AK
58602	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1882999999999981	-134.287000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	\N	0.92000000000000004	-00:06:00	\N	0.869999999999999996	\N	\N	Eliza Harbor, Admiralty Island	AK
58603	Kasnyku Bay, Alaska	NOS	9451717	57.216700000000003	-134.867999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:06:00	-0.100000000000000006	\N	-00:10:00	-2.39999999999999991	\N	\N	\N	Kasnyku Bay	AK
58604	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2182999999999993	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:03:00	-0.100000000000000006	\N	-00:01:00	-1.19999999999999996	\N	\N	\N	Cleveland Passage, Whitney Island	AK
58605	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2282999999999973	-135.537000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
58606	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3066999999999993	-134.13300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:06:00	\N	0.939999999999999947	-00:08:00	\N	0.900000000000000022	\N	\N	Cannery Cove, Pybus Bay	AK
58607	The Brothers, Stephens Passage, Alaska (sub)	NOS	9451785	57.2950000000000017	-133.796999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	\N	0.979999999999999982	-00:07:00	\N	0.910000000000000031	\N	\N	The Brothers	AK
58608	Scraggy Point, Alaska	NOS	9451802	57.3367000000000004	-135.723000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:00:00	0.100000000000000006	\N	-00:09:00	-0.100000000000000006	\N	\N	\N	Scraggy Point	AK
58609	Scraggy Island, Alaska (sub)	NOS	9451805	57.3400000000000034	-135.706999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:01:00	\N	1.03000000000000003	00:00:00	\N	1	\N	\N	Scraggy Island	AK
58610	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.371699999999997	-135.617999999999995	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:12:00	0.100000000000000006	\N	00:03:00	0.200000000000000011	\N	\N	\N	Haley Anchorage, Fish Bay	AK
58611	Hobart Bay, Alaska	NOS	9451851	57.4067000000000007	-133.419999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:03:00	-0.100000000000000006	\N	-00:06:00	-1.10000000000000009	\N	\N	\N	Hobart Bay	AK
58612	Sergius Narrows, Alaska (sub)	NOS	9451853	57.4099999999999966	-135.62700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:24:00	\N	1.05000000000000004	00:19:00	\N	1.33000000000000007	\N	\N	Serguis Narrows	AK
58613	Klokachef Island, Alaska	NOS	9451858	57.4166999999999987	-135.889999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:06:00	0.100000000000000006	\N	-00:10:00	-0.100000000000000006	\N	\N	\N	Klokachef Island	AK
58614	Bear Bay, Alaska	NOS	9451859	57.4183000000000021	-135.582999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:29:00	0.200000000000000011	\N	00:18:00	3.70000000000000018	\N	\N	\N	Bear Bay	AK
58615	Killisnoo, Alaska	NOS	9451895	57.4699999999999989	-134.564999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	0	\N	-00:06:00	-2.10000000000000009	\N	\N	\N	Killisnoo	AK
58616	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4832999999999998	-133.960000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	\N	0.959999999999999964	-00:01:00	\N	0.92000000000000004	\N	\N	Gambier Bay (cannery wharf)	AK
58617	Good Island, Gambier Bay, Alaska	NOS	9451909	57.486699999999999	-133.897999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	\N	0.959999999999999964	-00:05:00	\N	0.930000000000000049	\N	\N	Good Island, Gambier Bay	AK
58618	Windham Bay, Alaska	NOS	9451962	57.5433000000000021	-133.49799999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:00:00	-0.100000000000000006	\N	00:00:00	-1.10000000000000009	\N	\N	\N	Windham Bay	AK
58620	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217000000000027	-133.055000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:06:00	\N	0.989999999999999991	00:01:00	\N	0.979999999999999982	\N	\N	Upper Endicott Arm, North Shore	AK
58621	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.878300000000003	-133.189999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:06:00	\N	1.01000000000000001	00:02:00	\N	0.969999999999999973	\N	\N	Sawyer Island, Tracy Arm	AK
58622	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7182999999999993	-133.578000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:06:00	-0.100000000000000006	\N	00:03:00	-0.800000000000000044	\N	\N	\N	Holkham Bay, Wood Spit	AK
58623	Holkham Bay, Tracy Arm Entrance, Alaska	NOS	9452067	57.759999999999998	-133.603000000000009	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:02:00	\N	0.959999999999999964	00:01:00	\N	0.959999999999999964	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
58624	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0966999999999985	-133.74199999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:03:00	\N	0.969999999999999973	-00:03:00	\N	0.979999999999999982	\N	\N	Port Snettisham, Crib Point	AK
58625	Taku Harbor, Alaska	NOS	9452123	58.0683000000000007	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	\N	1	-00:03:00	\N	0.969999999999999973	\N	\N	Taku Harbor	AK
58626	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.3999999999999986	-134.014999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:13:00	0	\N	00:14:00	0.400000000000000022	\N	\N	\N	Taku Point, Taku Inlet	AK
58627	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783000000000001	-134.038000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:05:00	0.100000000000000006	\N	00:06:00	-0.699999999999999956	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
58628	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233000000000018	-134.060000000000002	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	-0.100000000000000006	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Greely Point, Taku Inlet	AK
58629	Young Bay, Alaska	NOS	9452249	58.1833000000000027	-134.586999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
58630	Auke Bay, Alaska	NOS	9452263	58.3817000000000021	-134.64500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:03:00	0	\N	-00:06:00	-0.400000000000000022	\N	\N	\N	Auke Bay	AK
58631	Hawk Inlet Entrance, Alaska (sub)	NOS	9452294	58.0850000000000009	-134.776999999999987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	\N	0.979999999999999982	-00:04:00	\N	0.939999999999999947	\N	\N	Hawk Inlet Entrance	AK
58632	Adugak Islands, Alaska	NOS	9452317	58.9117000000000033	-135.164999999999992	:America/Juneau	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:56:00	\N	1.10000000000000009	-00:33:00	\N	1.02000000000000002	\N	\N	Adugak Islands	AK
58633	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3216999999999999	-134.877999999999986	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	\N	0.989999999999999991	-00:04:00	\N	0.959999999999999964	\N	\N	Barlow Cove, Mansfield Peninsula	AK
58634	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.2550000000000026	-134.89500000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:01:00	0	\N	00:00:00	-1.10000000000000009	\N	\N	\N	Funter, Funter Bay	AK
58635	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983000000000004	-134.965000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:01:00	\N	1	-00:03:00	\N	0.979999999999999982	\N	\N	Lincoln Island	AK
58636	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7516999999999996	-135.027999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:00:00	\N	1.02000000000000002	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
58637	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.2150000000000034	-135.12700000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:11:00	\N	1.08000000000000007	00:14:00	\N	1.40999999999999992	\N	\N	Swanson Harbor	AK
58638	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.7800000000000011	-135.211999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:05:00	-0.100000000000000006	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
58639	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7132999999999967	-135.231999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
58640	Skagway, Taiya Inlet, Lynn Canal, Alaska (sub)	NOS	9452400	59.4500000000000028	-135.326999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	\N	1.01000000000000001	-00:03:00	\N	1.03000000000000003	\N	\N	Skagway, Taiya Inlet	AK
58641	Chilkat Inlet, Lynn Canal, Alaska (sub)	NOS	9452421	59.1700000000000017	-135.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	\N	1	-00:04:00	\N	1.01000000000000001	\N	\N	Chilkat Inlet	AK
58642	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3016999999999967	-135.427999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:02:00	\N	1.01000000000000001	-00:04:00	\N	1.03000000000000003	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
58643	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.2299999999999969	-135.432999999999993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
58644	Excursion Inlet Entrance, Icy Strait, Alaska	NOS	9452437	58.4166999999999987	-135.447000000000003	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:16:00	\N	1.05000000000000004	00:15:00	\N	1.37999999999999989	\N	\N	Excursion Inlet Entrance	AK
58645	Hoonah Harbor, Port Frederick, Alaska	NOS	9452441	58.128300000000003	-135.461999999999989	:America/Juneau	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:03:00	-0.100000000000000006	\N	00:01:00	-1.39999999999999991	\N	\N	\N	Hoonah Harbor, Port Frederick	AK
58646	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.496699999999997	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:24:00	\N	1.07000000000000006	00:26:00	\N	1.3600000000000001	\N	\N	Excursion Inlet, North End	AK
58647	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867000000000033	-135.802999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:35:00	\N	1.1100000000000001	00:29:00	\N	1.31000000000000005	\N	\N	Point Adolphus	AK
58648	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.4566999999999979	-135.88300000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:22:00	\N	1.1100000000000001	00:19:00	\N	1.3600000000000001	\N	\N	Bartlett Cove	AK
58649	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117000000000004	-136.034999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:06:00	\N	0.959999999999999964	00:06:00	\N	1.19999999999999996	\N	\N	Mud Bay, Goose Island	AK
58650	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133000000000024	-136.086999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:13:00	\N	1.03000000000000003	00:08:00	\N	0.979999999999999982	\N	\N	Elbow Passage, Klag Bay	AK
58651	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867000000000019	-136.106999999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:06:00	\N	1.03000000000000003	00:05:00	\N	0.92000000000000004	\N	\N	Kimshan Cove, Ogden Passage	AK
58652	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9132999999999996	-136.108000000000004	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:49:00	\N	1.18999999999999995	00:39:00	\N	1.55000000000000004	\N	\N	Muir Inlet	AK
58653	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6082999999999998	-136.11699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:50:00	\N	1.15999999999999992	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
58654	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.263300000000001	-136.324999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:03:00	\N	1.01000000000000001	00:12:00	\N	1.05000000000000004	\N	\N	Inian Cove, North Inian Pass	AK
58655	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9466999999999999	-136.332999999999998	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:50:00	\N	1.19999999999999996	00:39:00	\N	1.57000000000000006	\N	\N	Wachusett Inlet, Glacier Bay	AK
58656	Miner Island, Lisianski Strait and Inlet, Alaska	NOS	9452633	58.009999999999998	-136.342000000000013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	-00:06:00	\N	0.959999999999999964	-00:08:00	\N	0.939999999999999947	\N	\N	Miner Island	AK
58657	Canoe Cove, North Pass, Lisianski Strait and Inlet, Alaska	NOS	9452649	57.8466999999999985	-136.421999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	-00:01:00	\N	0.890000000000000013	00:02:00	\N	0.910000000000000031	\N	\N	Canoe Cove, North Pass	AK
58658	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283000000000001	-136.52000000000001	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	-00:01:00	\N	1.03000000000000003	-00:04:00	\N	0.900000000000000022	\N	\N	Takanis Bay	AK
58659	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183000000000035	-136.527999999999992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:02:00	\N	0.959999999999999964	00:00:00	\N	0.880000000000000004	\N	\N	Surge Bay	AK
58660	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.888300000000001	-136.573000000000008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:51:00	\N	1.19999999999999996	00:45:00	\N	1.54000000000000004	\N	\N	Composite Island	AK
58661	Graves Harbor, Alaska	NOS	9452704	58.2766999999999982	-136.677999999999997	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:07:00	\N	1.03000000000000003	00:04:00	\N	0.910000000000000031	\N	\N	Graves Harbor	AK
58662	Dixon Harbor, Alaska	NOS	9452747	58.3832999999999984	-136.86699999999999	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:07:00	\N	0.959999999999999964	00:07:00	\N	0.890000000000000013	\N	\N	Dixon Harbor	AK
58663	Dixon Harbor, Alaska (2)	NOS	9452748	58.3800000000000026	-136.872000000000014	:America/Juneau	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:12:00	0	\N	00:09:00	-0.100000000000000006	\N	\N	\N	Dixon Harbor	AK
58664	Lituya Bay, 2 miles inside entrance, Alaska	NOS	9452915	58.6133000000000024	-137.617999999999995	:America/Yakutat	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:41:00	-0.100000000000000006	\N	00:08:00	-0.299999999999999989	\N	\N	\N	Lituya Bay, 2 miles inside entrance	AK
58665	Lituya Bay, 2 miles inside entrance, Alaska (2)	NOS	9452928	58.6167000000000016	-137.650000000000006	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	00:36:00	\N	0.890000000000000013	00:06:00	\N	0.869999999999999996	\N	\N	Lituya Bay, 2 miles inside entrance	AK
58666	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.611699999999999	-139.580000000000013	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:00:00	\N	0.92000000000000004	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
58667	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033000000000015	-139.62700000000001	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:03:00	\N	0.930000000000000049	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
58668	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5816999999999979	-139.701999999999998	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
58669	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.0782999999999987	-141.275000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:17:00	\N	0.969999999999999973	00:20:00	\N	0.959999999999999964	\N	\N	Tyndall Glacier, Icy Bay	AK
58670	Riou Bay, Alaska	NOS	9453456	59.884999999999998	-141.456999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:03:00	\N	1.01000000000000001	00:02:00	\N	0.979999999999999982	\N	\N	Icy Bay	AK
58671	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.4650000000000034	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:16:00	-0.100000000000000006	\N	-00:11:00	-1.10000000000000009	\N	\N	\N	Shag Rock	AK
58672	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.7100000000000009	-146.085000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:06:00	-0.100000000000000006	\N	-00:16:00	-0.699999999999999956	\N	\N	\N	Comfort Cove, Port Gravina	AK
58673	Middleton Island (north end), Alaska	NOS	9454224	59.4617000000000004	-146.310000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:14:00	-0.100000000000000006	\N	-00:21:00	-2.20000000000000018	\N	\N	\N	Middleton Island (north end)	AK
58674	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8532999999999973	-146.534999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:08:00	-0.100000000000000006	\N	-00:12:00	-0.699999999999999956	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
58675	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.0399999999999991	-146.615000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56474	-00:02:00	\N	0.989999999999999991	-00:01:00	\N	0.989999999999999991	\N	\N	Jack Bay	AK
58676	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4816999999999965	-146.610000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:02:00	-0.100000000000000006	\N	-00:07:00	-0.800000000000000044	\N	\N	\N	Johnstone Point	AK
58677	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.2383000000000024	-146.647999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:03:00	\N	0.979999999999999982	-00:10:00	\N	0.880000000000000004	\N	\N	Cape Hinchinbrook	AK
58678	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.9466999999999999	-146.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56474	-00:03:00	\N	0.989999999999999991	00:00:00	\N	0.989999999999999991	\N	\N	Rocky Point	AK
58679	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.898299999999999	-146.782000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56474	-00:02:00	\N	0.979999999999999982	-00:02:00	\N	0.979999999999999982	\N	\N	Busby Island	AK
58680	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.8800000000000026	-147.223000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:02:00	0	\N	-00:10:00	-0.599999999999999978	\N	\N	\N	Jackson Cove, Glacier Island	AK
58681	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2417999999999978	-147.248999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:01:00	\N	0.969999999999999973	-00:02:00	\N	0.939999999999999947	\N	\N	Port Chalmers	AK
58682	Perch Point, Montague Island, Alaska (sub)	NOS	9454561	60.1266999999999996	-147.39500000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:03:00	\N	0.939999999999999947	-00:08:00	\N	0.92000000000000004	\N	\N	Perch Point	AK
58683	Wooded Islands, Montague Island, Alaska (sub)	NOS	9454562	59.875	-147.402999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.949999999999999956	-00:02:00	\N	0.800000000000000044	\N	\N	Wooded Islands	AK
58684	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833000000000027	-147.388000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:08:00	-0.100000000000000006	\N	-00:18:00	-0.699999999999999956	\N	\N	\N	Naked Island, McPherson Passage	AK
58685	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.2700000000000031	-147.437999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:06:00	-0.200000000000000011	\N	-00:21:00	-0.800000000000000044	\N	\N	\N	Gibbon Anchorage, Green Island	AK
58686	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067000000000007	-147.449999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:05:00	-0.100000000000000006	\N	-00:12:00	-2.29999999999999982	\N	\N	\N	Patton Bay	AK
58687	Montague Island, Alaska (sub)	NOS	9454616	60.0249999999999986	-147.592000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.959999999999999964	-00:02:00	\N	0.910000000000000031	\N	\N	5 miles NE of Point Brazil, Montague Island	AK
58688	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617000000000004	-147.671999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:03:00	\N	1.04000000000000004	00:00:00	\N	0.959999999999999964	\N	\N	Louis Bay	AK
58689	Snug Harbor, Knight Island, Alaska (sub)	NOS	9454662	60.25	-147.717000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.969999999999999973	-00:03:00	\N	0.910000000000000031	\N	\N	Snug Harbor, Knight Island	AK
58690	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533000000000015	-147.766999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:01:00	\N	1	-00:03:00	\N	0.92000000000000004	\N	\N	Point Helen	AK
58691	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3432999999999993	-147.768000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:03:00	\N	0.949999999999999956	00:00:00	\N	0.92000000000000004	\N	\N	Port Audrey	AK
58692	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.8900000000000006	-147.794999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:04:00	\N	0.959999999999999964	00:10:00	\N	0.890000000000000013	\N	\N	Macleod Harbor	AK
58693	Herring Point, Knight Island, Prince William Sound, Alaska (sub)	NOS	9454691	60.4750000000000014	-147.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	\N	1.01000000000000001	-00:04:00	\N	0.949999999999999956	\N	\N	Herring Point	AK
58694	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533000000000001	-147.907000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
58695	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483000000000033	-147.978000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:04:00	0	\N	00:01:00	-0.400000000000000022	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
58696	Guguak, Alaska (sub)	NOS	9454751	60.1000000000000014	-148.038000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:03:00	\N	0.949999999999999956	-00:07:00	\N	0.910000000000000031	\N	\N	Guguak	AK
58697	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.1966999999999999	-148.042000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	\N	0.979999999999999982	-00:06:00	\N	0.930000000000000049	\N	\N	Bainbridge Point, Bainbridge Island	AK
58698	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617000000000004	-148.044999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	1.03000000000000003	-00:11:00	\N	0.92000000000000004	\N	\N	Eshamy Lagoon	AK
58699	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0516999999999967	-148.064999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:03:00	0	\N	-00:03:00	-1.19999999999999996	\N	\N	\N	Sawmill Bay, Evans Island	AK
58700	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.283299999999997	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	1	-00:03:00	\N	0.939999999999999947	\N	\N	Chenega Island, southwest end	AK
58997	Point Loma, California	NOS	TWC0405	32.6666666666670054	-117.233333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	-00:02:00	\N	0.92000000000000004	-00:09:00	\N	0.92000000000000004	\N	\N	Point Loma	CA
58701	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.3299999999999983	-148.143000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:06:00	0	\N	-00:01:00	-0.900000000000000022	\N	\N	\N	Chenega Island, Dangerous Passage	AK
58702	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233000000000004	-148.164999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:06:00	0	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Applegate Island	AK
58703	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417000000000016	-148.171999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:01:00	0	\N	-00:15:00	-0.400000000000000022	\N	\N	\N	Culross Bay, Wells Passage	AK
58704	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767000000000024	-148.194999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:03:00	-0.100000000000000006	\N	-00:12:00	-1.89999999999999991	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
58705	Point Elrington, Elrington Island, Prince William Sound, Alaska (sub)	NOS	9454814	59.9382999999999981	-148.227000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:02:00	\N	0.939999999999999947	-00:13:00	\N	0.839999999999999969	\N	\N	Point Elrington, Elrington Island	AK
58706	Long Bay Entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6916999999999973	-148.263000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:09:00	-0.100000000000000006	\N	00:03:00	-0.900000000000000022	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
58707	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5416999999999987	-148.460000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:09:00	0	\N	-00:01:00	-0.599999999999999978	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
58708	Whittier, Prince William Sound, Alaska (sub)	NOS	9454949	60.7783000000000015	-148.664999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	0	\N	-00:05:00	-0.299999999999999989	\N	\N	\N	Whittier, Passage Canal	AK
58709	Day Harbor, Alaska	NOS	9455036	60.009999999999998	-149.062000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:00:00	\N	1.01000000000000001	-00:02:00	\N	0.989999999999999991	\N	\N	Day Harbor	AK
58710	Agnes Cove, Aialik Peninsula, Alaska (sub)	NOS	9455120	59.773299999999999	-149.587999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.910000000000000031	-00:06:00	\N	0.839999999999999969	\N	\N	Agnes Cove, Aialik Peninsula	AK
58711	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8016999999999967	-149.615000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:01:00	\N	0.969999999999999973	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
58712	Aialik Bay, north end, Alaska (sub)	NOS	9455145	59.9532999999999987	-149.715000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	\N	0.890000000000000013	-00:06:00	\N	0.82999999999999996	\N	\N	Aialik Bay, North end	AK
58713	Aialik Sill, Aialik Bay, Alaska (sub)	NOS	9455146	59.884999999999998	-149.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.900000000000000022	-00:05:00	\N	0.82999999999999996	\N	\N	Aialik Sill, Aialik Bay	AK
58714	Camp Cove, Harris Peninsula, Alaska (sub)	NOS	9455151	59.6933000000000007	-149.74799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:00:00	\N	0.900000000000000022	-00:06:00	\N	0.839999999999999969	\N	\N	Camp Cove, Aialik Bay	AK
58715	Crater Bay, Harris Bay, Alaska (sub)	NOS	9455159	59.7132999999999967	-149.787000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	\N	0.869999999999999996	-00:03:00	\N	0.839999999999999969	\N	\N	Crater Bay, Harris Bay	AK
58716	Upper Northwestern Fiord, Harris Bay, Alaska (sub)	NOS	9455204	59.7899999999999991	-150.032000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:11:00	\N	0.900000000000000022	00:01:00	\N	0.849999999999999978	\N	\N	Upper Northwestern Fiord, Harris Bay	AK
58717	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617000000000033	-150.108000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	-00:05:00	\N	0.939999999999999947	-00:10:00	\N	1.03000000000000003	\N	\N	Two Arm Bay, Harris Bay	AK
58718	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883000000000024	-150.312000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:01:00	\N	1.01000000000000001	00:00:00	\N	1.04000000000000004	\N	\N	Chance Cove (Lagoon)	AK
58719	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5266999999999982	-150.627999999999986	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:14:00	\N	1.01000000000000001	00:12:00	\N	1.08000000000000007	\N	\N	Beauty Bay, Nuka Bay	AK
58720	Nuka Passage, Alaska	NOS	9455308	59.408299999999997	-150.667000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:12:00	\N	1.01000000000000001	00:11:00	\N	1.09000000000000008	\N	\N	Nuka Passage	AK
58721	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2616999999999976	-150.981999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:18:00	\N	1.01000000000000001	00:23:00	\N	1.14999999999999991	\N	\N	Takoma Cove, Port Dick	AK
58722	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.2550000000000026	-151.419999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56487	00:21:00	\N	1.01000000000000001	00:26:00	\N	1.22999999999999998	\N	\N	Picnic Harbor, Rocky Bay	AK
58723	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2132999999999967	-151.728000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:34:00	\N	0.92000000000000004	-00:28:00	\N	0.780000000000000027	\N	\N	Port Chatham	AK
58724	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9466999999999999	-152.268000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:04:00	\N	0.760000000000000009	-00:08:00	\N	0.760000000000000009	\N	\N	Ushagat Island, Barren Islands	AK
58725	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4316999999999993	-151.356999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:01:00	0	\N	-00:01:00	0.200000000000000011	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
58726	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.490000000000002	-151.365000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:04:00	-0.100000000000000006	\N	-00:04:00	0.100000000000000006	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
58727	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5966999999999985	-151.219999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:05:00	0	\N	-00:03:00	0.699999999999999956	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
58728	Homer, Kachemak Bay, Cook Inlet, Alaska	NOS	9455557	59.6032999999999973	-151.419999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:03:00	\N	0.969999999999999973	00:05:00	\N	1.01000000000000001	\N	\N	Homer, Kachemak Bay	AK
58729	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.5549999999999997	-152.13300000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	02:04:00	\N	1.17999999999999994	01:39:00	\N	1.01000000000000001	\N	\N	Drift River Terminal	AK
58730	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.5450000000000017	-151.217999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	02:55:00	-0.100000000000000006	\N	01:54:00	1.89999999999999991	\N	\N	\N	Kenai City Pier	AK
58731	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533000000000015	-152.634999999999991	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:53:00	0.200000000000000011	\N	00:39:00	-1.30000000000000004	\N	\N	\N	Tuxedni Channel	AK
58732	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.6400000000000006	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	01:16:00	\N	0.82999999999999996	01:15:00	\N	0.770000000000000018	\N	\N	Oil Bay, Kamishak Bay	AK
58733	Nukshak Island, Shelikof Strait, Alaska (sub)	NOS	9456717	58.3917000000000002	-153.957999999999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:07:00	\N	0.949999999999999956	-00:01:00	\N	0.760000000000000009	\N	\N	Nukshak Island, Shelikof Strait	AK
58734	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783000000000001	-154.086999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:22:00	-0.200000000000000011	\N	00:10:00	-2.79999999999999982	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
58735	Kukak, Kukak Bay, Alaska	NOS	9456835	58.341700000000003	-154.11699999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:05:00	\N	0.739999999999999991	-00:08:00	\N	0.739999999999999991	\N	\N	Kukak, Kukak Bay	AK
58736	Aguchik Island, Kukak Bay, Alaska (sub)	NOS	9456901	58.2899999999999991	-154.27000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:06:00	\N	0.939999999999999947	-00:04:00	\N	0.75	\N	\N	Aguchik Island, Kukak Bay	AK
58737	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0632999999999981	-154.477000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:03:00	\N	1	-00:09:00	\N	0.729999999999999982	\N	\N	Takli Island, Shelikof Strait	AK
58738	Tonki Bay, Alaska	NOS	9457152	58.3166999999999973	-152.067000000000007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:21:00	0.200000000000000011	\N	00:12:00	2.29999999999999982	\N	\N	\N	Tonki Bay	AK
58739	Seal Bay, Alaska	NOS	9457201	58.371699999999997	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:36:00	0.299999999999999989	\N	00:29:00	2.39999999999999991	\N	\N	\N	Seal Bay	AK
58740	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183000000000035	-152.414999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:44:00	0.299999999999999989	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
58741	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.783299999999997	-152.427999999999997	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
58742	Spruce Island (north side), Alaska	NOS	9457262	57.9382999999999981	-152.417000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:08:00	0.100000000000000006	\N	00:02:00	0.400000000000000022	\N	\N	\N	Spruce Island (north side)	AK
58743	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3566999999999965	-152.448000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:39:00	0.299999999999999989	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
58744	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.7449999999999974	-152.483000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:02:00	0	\N	-00:05:00	-0.100000000000000006	\N	\N	\N	Kodiak, St. Paul Harbor	AK
58745	Ouzinkie, Spruce Island, Alaska (sub)	NOS	9457287	57.9217000000000013	-152.49799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:04:00	0	\N	-00:05:00	0.200000000000000011	\N	\N	\N	Ouzinkie, Spruce Island	AK
58746	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867000000000004	-152.513000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:07:00	\N	0.729999999999999982	00:06:00	\N	0.729999999999999982	\N	\N	Carry Inlet	AK
58747	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4532999999999987	-152.594999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:02:00	-0.200000000000000011	\N	-00:14:00	-4.40000000000000036	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
58748	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.5549999999999997	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:15:00	\N	0.770000000000000018	00:10:00	\N	0.770000000000000018	\N	\N	Big Bay	AK
58749	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4816999999999965	-152.717999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:20:00	-0.100000000000000006	\N	-00:29:00	-0.299999999999999989	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
58750	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9782999999999973	-152.754999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:37:00	0.200000000000000011	\N	00:22:00	1.19999999999999996	\N	\N	\N	Fox Bay, Whale Island	AK
58751	Kizhuyak Bay, Alaska	NOS	9457401	57.8200000000000003	-152.900000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:11:00	0	\N	00:06:00	0.800000000000000044	\N	\N	\N	Kizhuyak Bay	AK
58752	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1632999999999996	-153.151999999999987	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:06:00	0.100000000000000006	\N	-00:18:00	-0.299999999999999989	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
58753	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.1099999999999994	-153.155000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:05:00	-0.100000000000000006	\N	-00:25:00	-4.09999999999999964	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
58754	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5482999999999976	-153.735000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:00:00	\N	0.770000000000000018	-00:09:00	\N	0.770000000000000018	\N	\N	Zachar Bay	AK
58755	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.4600000000000009	-153.817000000000007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:10:00	-0.100000000000000006	\N	-00:37:00	-4.09999999999999964	\N	\N	\N	Mining Camp	AK
58756	Uyak, Uyak Bay, Alaska (sub)	NOS	9457728	57.634999999999998	-154.007000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:03:00	\N	0.979999999999999982	-00:17:00	\N	0.75	\N	\N	Uyak	AK
58757	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0016999999999996	-154.147999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56525	00:10:00	\N	1.01000000000000001	00:11:00	\N	0.989999999999999991	\N	\N	Moser Bay (Trap Point)	AK
58758	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617000000000033	-154.228000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56525	03:54:00	\N	0.0599999999999999978	03:46:00	\N	0.100000000000000006	\N	\N	Olga Bay (A. P. A. Cannery)	AK
58759	Puale Bay, Alaska (sub)	NOS	9458209	57.7066999999999979	-155.393000000000001	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:03:00	\N	0.67000000000000004	-00:22:00	\N	0.67000000000000004	\N	\N	Puale Bay	AK
58760	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.5200000000000031	-156.051999999999992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:51:00	0.299999999999999989	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
58761	Chowiet Island, Semidi Island, Alaska (sub)	NOS	9458519	56.0516999999999967	-156.698000000000008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:25:00	\N	1.29000000000000004	00:15:00	\N	1.04000000000000004	\N	\N	Chowiet Island, Semidi Island	AK
58762	Unavikshak Island, Alaska	NOS	9458762	56.4917000000000016	-157.740000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:44:00	\N	1.23999999999999999	00:31:00	\N	1.05000000000000004	\N	\N	Unavikshak Island	AK
58763	Nakchamik Island, Alaska	NOS	9458779	56.351700000000001	-157.812000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:41:00	\N	1.33000000000000007	00:29:00	\N	1.04000000000000004	\N	\N	Nakchamik Island	AK
58764	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133000000000024	-157.983000000000004	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:46:00	\N	1.35000000000000009	00:31:00	\N	1.10000000000000009	\N	\N	Kujulik Bay (North Shore)	AK
58765	Chankliut Island, Alaska	NOS	9458849	56.1467000000000027	-158.106999999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:43:00	\N	1.27000000000000002	00:32:00	\N	0.979999999999999982	\N	\N	Chankliut Island	AK
58766	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967000000000013	-158.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:44:00	\N	1.28000000000000003	00:34:00	\N	1.04000000000000004	\N	\N	Chignik, Anchorage Bay	AK
58767	Hump Island, Kuiukta Bay, Alaska (sub)	NOS	9458964	56.1133000000000024	-158.598000000000013	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:42:00	\N	1.22999999999999998	00:35:00	\N	0.910000000000000031	\N	\N	Hump Island, Kuiukta Bay	AK
58768	Mitrofania Island, Alaska (sub)	NOS	9459016	55.8900000000000006	-158.819999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:39:00	\N	1.22999999999999998	00:32:00	\N	0.880000000000000004	\N	\N	Mitrofania Island	AK
58769	Chiachi Island (east side), Alaska	NOS	9459085	55.8432999999999993	-159.10499999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:37:00	\N	1.28000000000000003	00:22:00	\N	0.890000000000000013	\N	\N	Chiachi Island (east side)	AK
58770	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.7899999999999991	-159.349999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:35:00	\N	1.28000000000000003	00:19:00	\N	0.890000000000000013	\N	\N	Kupreanof Harbor, Paul Island	AK
58771	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.783299999999997	-159.879999999999995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:33:00	\N	1.18999999999999995	00:17:00	\N	0.859999999999999987	\N	\N	Dent Point, Stepovak Bay	AK
58772	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.1550000000000011	-159.995000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	-00:03:00	\N	0.979999999999999982	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
58773	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.361699999999999	-160.360000000000014	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:03:00	\N	0.979999999999999982	00:08:00	\N	1.03000000000000003	\N	\N	Pirate Cove, Popof Island	AK
58774	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.5900000000000034	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:03:00	\N	1.05000000000000004	-00:02:00	\N	1.06000000000000005	\N	\N	Albatross Anchorage, Balboa Bay	AK
58775	Zachary Bay, Unga Island, Shumagin Islands, Alaska (sub)	NOS	9459465	55.3350000000000009	-160.61699999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:09:00	\N	0.979999999999999982	00:00:00	\N	1.03000000000000003	\N	\N	Zachary Bay, Unga Island	AK
58776	Beaver Bay, Alaska	NOS	9459522	55.4733000000000018	-160.840000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:02:00	\N	1.05000000000000004	00:03:00	\N	1.01000000000000001	\N	\N	Beaver Bay	AK
58777	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365000000000002	-161.324999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:05:00	\N	1.05000000000000004	00:00:00	\N	0.979999999999999982	\N	\N	Seal Cape, Coal Bay	AK
58778	Ukolnoi Island, Alaska	NOS	9459696	55.2582999999999984	-161.537000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:00:00	\N	0.979999999999999982	00:07:00	\N	0.969999999999999973	\N	\N	Ukolnoi Island	AK
58779	Dolgoi Harbor, Dolgoi Island, Alaska (sub)	NOS	9459758	55.121699999999997	-161.792000000000002	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:37:00	\N	1.18999999999999995	00:40:00	\N	0.760000000000000009	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
58780	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1182999999999979	-162.377999999999986	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:17:00	\N	0.979999999999999982	00:12:00	\N	0.979999999999999982	\N	\N	Lenard Harbor, Cold Bay	AK
58781	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933000000000035	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	-00:08:00	\N	1.05000000000000004	-00:05:00	\N	0.82999999999999996	\N	\N	Peterson Bay	AK
58782	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4816999999999965	-162.812000000000012	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:03:00	\N	1.05000000000000004	00:14:00	\N	0.890000000000000013	\N	\N	Sanak Harbor	AK
58783	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6032999999999973	-178.61699999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:43:00	\N	0.949999999999999956	00:01:00	\N	0.949999999999999956	\N	\N	Ogliuga Island (east coast)	AK
58784	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717000000000013	-178.044999999999987	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-01:39:00	\N	1.1399999999999999	-00:56:00	\N	1.1399999999999999	\N	\N	Lash Bay	AK
58785	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7182999999999993	-177.997000000000014	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:32:00	\N	1.08000000000000007	-00:06:00	\N	1.08000000000000007	\N	\N	Tanaga Bay	AK
58786	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783000000000015	-177.800000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:12:00	\N	0.839999999999999969	-00:40:00	\N	0.839999999999999969	\N	\N	Hot Springs Bay	AK
58787	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.6649999999999991	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-01:54:00	\N	1.1100000000000001	-01:44:00	\N	1.1100000000000001	\N	\N	Cape Chunu	AK
58788	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7182999999999993	-177.199999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-01:44:00	\N	1.05000000000000004	-01:39:00	\N	1.05000000000000004	\N	\N	Kanaga Bay	AK
58789	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.7100000000000009	-177.14500000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-01:34:00	\N	0.92000000000000004	-01:22:00	\N	0.92000000000000004	\N	\N	Cape Chlanak	AK
58790	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.8699999999999974	-177.068000000000012	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:16:00	\N	0.859999999999999987	00:01:00	\N	0.859999999999999987	\N	\N	Shoal Point	AK
58791	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417000000000002	-176.824999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:04:00	\N	0.949999999999999956	-01:20:00	\N	0.949999999999999956	\N	\N	Bay of Waterfalls	AK
58792	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.7800000000000011	-176.806999999999988	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:21:00	\N	0.969999999999999973	-00:07:00	\N	0.969999999999999973	\N	\N	Unalga Bight	AK
58793	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7132999999999967	-176.530000000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:09:00	\N	0.969999999999999973	-01:38:00	\N	0.969999999999999973	\N	\N	Boot Bay	AK
58794	Adak Bight, Adak Island, Alaska	NOS	9461406	51.7700000000000031	-176.435000000000002	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
58795	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.8250000000000028	-176.401999999999987	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	00:07:00	\N	0.969999999999999973	-00:04:00	\N	0.969999999999999973	\N	\N	Laska Cove, Kagalaska Island	AK
58796	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733000000000018	-176.085000000000008	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:20:00	\N	0.969999999999999973	-00:05:00	\N	0.969999999999999973	\N	\N	Sand Bay, Great Sitkin Island	AK
58797	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0382999999999996	-175.97999999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:05:00	\N	0.890000000000000013	00:01:00	\N	0.890000000000000013	\N	\N	Bugle Point, Great Sitkin Island	AK
58798	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.9600000000000009	-175.587999999999994	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:13:00	\N	0.890000000000000013	-00:04:00	\N	0.890000000000000013	\N	\N	Fenimore Pass	AK
58799	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067000000000021	-175.319999999999993	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:10:00	\N	1.23999999999999999	-01:07:00	\N	1.23999999999999999	\N	\N	Atka Pass, east end	AK
58800	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367000000000033	-175.115000000000009	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	00:04:00	\N	0.949999999999999956	00:11:00	\N	0.949999999999999956	\N	\N	Bechevin Bay	AK
58801	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733000000000033	-174.568000000000012	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:24:00	\N	1.23999999999999999	-02:43:00	\N	1.23999999999999999	\N	\N	Explorer Bay	AK
58848	Levelock, Kvichak River, Alaska	NOS	9465419	59.1133000000000024	-156.831999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	09:34:00	\N	0.23000000000000001	06:13:00	\N	0.900000000000000022	\N	\N	Levelock	AK
58802	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0266999999999982	-174.47999999999999	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:25:00	\N	1.23999999999999999	-01:26:00	\N	1.23999999999999999	\N	\N	Sagchudak Island	AK
58803	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.226700000000001	-174.292000000000002	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	00:21:00	\N	0.869999999999999996	00:19:00	\N	0.869999999999999996	\N	\N	Martin Harbor, Korovin Bay	AK
58804	Cape Utalug (4 miles west of), Atka Island, Alaska	NOS	9461704	52.1182999999999979	-174.206999999999994	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-02:32:00	\N	1.18999999999999995	-01:38:00	\N	1.18999999999999995	\N	\N	Cape Utalug (4 miles west of)	AK
58805	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917000000000002	-172.405000000000001	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	00:07:00	\N	0.869999999999999996	-01:00:00	\N	0.869999999999999996	\N	\N	Finch Cove, Seguam Island	AK
58806	North side, Yunaska Island, Alaska	NOS	9462144	52.6816999999999993	-170.706999999999994	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-01:29:00	\N	1.18999999999999995	-01:05:00	\N	1.02000000000000002	\N	\N	North side	AK
58807	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533000000000015	-170.562999999999988	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-02:35:00	\N	0.849999999999999978	-01:36:00	\N	0.880000000000000004	\N	\N	East Cove	AK
58808	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.861699999999999	-169.861999999999995	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:58:00	\N	1.27000000000000002	-00:21:00	\N	1.08000000000000007	\N	\N	Applegate Cove, Chuginadak Island	AK
58809	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117000000000033	-169.164999999999992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:56:00	\N	1.10000000000000009	-00:33:00	\N	1.02000000000000002	\N	\N	Adugak Island	AK
58810	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.841700000000003	-169.043000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:16:00	\N	1.02000000000000002	-03:03:00	\N	1.19999999999999996	\N	\N	Cape Sagak	AK
58811	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167000000000002	-168.835000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:43:00	\N	1.10000000000000009	-00:07:00	\N	0.989999999999999991	\N	\N	Okee Bay	AK
58812	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583000000000013	-168.719999999999999	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:22:00	\N	1.10000000000000009	-02:56:00	\N	1.35000000000000009	\N	\N	Driftwood Bay	AK
58813	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.0450000000000017	-168.442000000000007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:42:00	\N	1.27000000000000002	-03:04:00	\N	1.37000000000000011	\N	\N	Kigul Island	AK
58814	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967000000000013	-168.352000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:30:00	\N	0.930000000000000049	-00:06:00	\N	0.959999999999999964	\N	\N	Inanudak Bay	AK
58815	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.9299999999999997	-168.032999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:55:00	\N	1.10000000000000009	-00:30:00	\N	1.08000000000000007	\N	\N	Bogoslof Island	AK
58816	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967000000000027	-167.842999999999989	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:40:00	\N	0.930000000000000049	-00:27:00	\N	0.880000000000000004	\N	\N	Otter Point	AK
58817	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.3950000000000031	-167.532999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:29:00	\N	1.10000000000000009	-00:10:00	\N	1.02000000000000002	\N	\N	Chernofski Harbor	AK
58818	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.6099999999999994	-167.044999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:19:00	\N	1.10000000000000009	-00:07:00	\N	1.05000000000000004	\N	\N	Skan Bay	AK
58819	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617000000000004	-167.02000000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:35:00	\N	1.27000000000000002	-03:10:00	\N	1.45999999999999996	\N	\N	Kuliliak Bay	AK
58820	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.4750000000000014	-166.87299999999999	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:48:00	\N	1.27000000000000002	-03:16:00	\N	1.48999999999999999	\N	\N	Raven Bay	AK
58821	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783000000000001	-166.831999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	00:28:00	\N	1.10000000000000009	-00:01:00	\N	1.08000000000000007	\N	\N	Anderson Bay	AK
58822	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.5150000000000006	-166.789999999999992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:45:00	\N	1.18999999999999995	-03:30:00	\N	1.55000000000000004	\N	\N	Usof Bay	AK
58823	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7132999999999967	-166.572000000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:14:00	\N	1.10000000000000009	-02:59:00	\N	1.39999999999999991	\N	\N	Kisselen Bay, Beaver Inlet	AK
58824	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917000000000002	-166.537000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
58825	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.736699999999999	-166.294999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:59:00	\N	1.02000000000000002	-03:32:00	\N	1.37000000000000011	\N	\N	Udagak Strait	AK
58826	English Bay, Unalaska Island, Alaska	NOS	9462641	53.9249999999999972	-166.257000000000005	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:01:00	\N	0.760000000000000009	00:16:00	\N	0.790000000000000036	\N	\N	English Bay	AK
58827	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.128300000000003	-165.807999999999993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:07:00	\N	1.10000000000000009	-00:17:00	\N	1.08000000000000007	\N	\N	Akutan Harbor, Akutan Island	AK
58828	Trident Bay, Akun Island, Aleutian Islands, Alaska (sub)	NOS	9462721	54.1400000000000006	-165.526999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-04:11:00	\N	0.760000000000000009	-03:59:00	\N	0.989999999999999991	\N	\N	Trident Bay, Akun Island	AK
58829	Cape Sarichef, Unimak Island, Alaska (sub)	NOS	9462787	54.6000000000000014	-164.927999999999997	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:56:00	\N	1.27000000000000002	-00:24:00	\N	1.37000000000000011	\N	\N	Cape Sarichef	AK
58830	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283000000000001	-164.467000000000013	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	00:19:00	\N	1.3600000000000001	00:26:00	\N	1.72999999999999998	\N	\N	Cape Mordvinof	AK
58831	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.009999999999998	-163.507000000000005	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:18:00	\N	1.3600000000000001	00:04:00	\N	1.22999999999999998	\N	\N	St. Catherine Cove	AK
58832	Ikatan Bay, Alaska	NOS	9462965	54.7550000000000026	-163.314999999999998	:America/Nome	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:05:00	\N	0.979999999999999982	00:09:00	\N	0.900000000000000022	\N	\N	Ikatan Bay	AK
58833	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.7100000000000009	-163.266999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:15:00	\N	1.05000000000000004	00:15:00	\N	0.869999999999999996	\N	\N	Dora Harbor	AK
58834	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4132999999999996	-163.115000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	01:48:00	\N	1.78000000000000003	01:47:00	\N	2.12999999999999989	\N	\N	Amak Island	AK
58835	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.2700000000000031	-162.900000000000006	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	04:05:00	\N	0.849999999999999978	03:03:00	\N	1.22999999999999998	\N	\N	Grant Point, Izembek Lagoon	AK
58836	Port Heiden, Bristol Bay, Alaska	NOS	9464096	56.9333000000000027	-158.728000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	02:05:00	\N	1.17999999999999994	01:43:00	\N	1.14999999999999991	\N	\N	Port Heiden	AK
58837	Egegik, Egegik River, Alaska	NOS	9464874	58.216700000000003	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	05:36:00	\N	0.359999999999999987	03:42:00	\N	1.19999999999999996	\N	\N	Egegik	AK
58838	Egegik River entrance, Alaska	NOS	9464881	58.2383000000000024	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	03:47:00	\N	1.1399999999999999	03:16:00	\N	1.68999999999999995	\N	\N	Egegik River Ent, Bristol Bay	AK
58839	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4532999999999987	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	04:10:00	\N	1.1399999999999999	03:56:00	\N	1.84000000000000008	\N	\N	Middle Bluff, Kvichak Bay	AK
58840	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.6717000000000013	-156.657000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	09:46:00	\N	0.0899999999999999967	05:43:00	\N	0.239999999999999991	\N	\N	King Salmon Airport	AK
58841	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.7066999999999979	-156.757000000000005	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	08:35:00	\N	0.140000000000000013	04:58:00	\N	0.689999999999999947	\N	\N	Omakstalia Point	AK
58842	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.7083000000000013	-160.187999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	04:53:00	\N	0.819999999999999951	04:53:00	\N	0.800000000000000044	\N	\N	Black Rock, Walrus Islands	AK
58843	Naknek River entrance, Alaska	NOS	9465183	58.7216999999999985	-157.056999999999988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	05:26:00	\N	1	04:27:00	\N	2.14999999999999991	\N	\N	Naknek River Entrance, Kvichak B	AK
58844	Kvichak, Kvichak River, Alaska	NOS	9465342	58.9699999999999989	-156.947000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56562	07:49:00	\N	0.409999999999999976	05:21:00	\N	1.54000000000000004	\N	\N	Kvichak	AK
58845	Goodnews Bay entrance, Alaska	NOS	9465368	59.0450000000000017	-161.807999999999993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56569	00:11:00	\N	0.949999999999999956	00:04:00	\N	1.01000000000000001	\N	\N	Goodnews Bay entrance	AK
58846	Snag Point, Dillingham, Alaska (sub)	NOS	9465374	59.0399999999999991	-158.447000000000003	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56567	00:54:00	\N	0.969999999999999973	00:28:00	\N	1.03000000000000003	\N	\N	Snag Point	AK
58847	Platinum, Alaska (sub)	NOS	9465396	59.0467000000000013	-161.818000000000012	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56567	05:41:00	\N	0.25	06:17:00	\N	0.380000000000000004	\N	\N	Platinum	AK
58849	Apokak Creek entrance, Alaska	NOS	9466079	60.1366999999999976	-162.157999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56569	04:30:00	\N	0.790000000000000036	03:18:00	\N	1.46999999999999997	\N	\N	Apokak Creek entrance	AK
58850	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.3582999999999998	-172.715000000000003	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	00:50:00	\N	0.569999999999999951	00:22:00	\N	0.569999999999999951	\N	\N	St. Matthew Island	AK
58851	Bethel, Kuskokwim River, Alaska (sub)	NOS	9466477	60.7999999999999972	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56567	03:47:00	\N	0.160000000000000003	01:48:00	\N	0.149999999999999994	\N	\N	Bethel	AK
58852	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.2800000000000011	-162.602000000000004	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56586	-01:13:00	\N	1.08000000000000007	-01:13:00	\N	1.08000000000000007	\N	\N	Pikmiktalik River entrance	AK
58853	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.466700000000003	-170.016999999999996	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	-03:08:00	\N	0.67000000000000004	-03:00:00	\N	1.12999999999999989	\N	\N	Fossil River entrance	AK
58854	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.4750000000000014	-162.026999999999987	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56586	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
58855	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.6199999999999974	-171.38300000000001	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	-03:31:00	\N	0.67000000000000004	-03:27:00	\N	0.82999999999999996	\N	\N	Niyrakpak Lagoon entrance	AK
58856	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.628300000000003	-162.516999999999996	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56586	-00:28:00	\N	0.719999999999999973	-00:28:00	\N	0.719999999999999973	\N	\N	North Bay, Stuart Island	AK
58857	Carolyn Island, Golovnin Bay, Alaska	NOS	9468737	64.4549999999999983	-162.87299999999999	:America/Nome	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56583	01:19:00	\N	0.46000000000000002	01:19:00	\N	0.46000000000000002	\N	\N	Carolyn Island, Golovnin Bay	AK
58858	Point Spencer, Port Clarence, Norton Sound, Alaska (sub)	NOS	9469237	65.256699999999995	-166.847000000000008	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	05:26:00	\N	0.349999999999999978	05:15:00	\N	0.810000000000000053	\N	\N	Point Spencer, Port Clarence	AK
58859	Teller, Port Clarence, Alaska (sub)	NOS	9469239	65.2667000000000002	-166.353000000000009	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	04:13:00	\N	0.869999999999999996	04:01:00	\N	0.800000000000000044	\N	\N	Teller, Port Clarance	AK
58860	Lost River, Seward Peninsula, Alaska (sub)	NOS	9469338	65.3900000000000006	-167.14500000000001	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	05:30:00	\N	0.28999999999999998	06:43:00	\N	0.709999999999999964	\N	\N	Lost River, Seward Peninsula	AK
58861	Point Barrow, Alaska	NOS	9495048	71.3599999999999994	-156.353000000000009	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:26:00	\N	0.0400000000000000008	-00:37:00	\N	0.0400000000000000008	\N	\N	Point Barrow	AK
59133	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.2166666666670078	169.983333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
58862	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3266999999999989	-64.8516999999999939	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56618	00:44:00	\N	1.28000000000000003	-00:46:00	\N	1.28000000000000003	\N	\N	Redhook Bay, St. Thomas Island	VI
58863	Duke Marine Lab, Beaufort, North Carolina (sub)	NOS	8656483	34.7199999999999989	-76.6700000000000017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:36:00	\N	1.16999999999999993	00:39:00	\N	1.05000000000000004	\N	\N	Beaufort, Duke Marine Lab	NC
58864	Santa Monica, Municipal Pier, San Pedro Channel, California (sub)	NOS	9410840	34.0082999999999984	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:03:00	\N	0.989999999999999991	00:03:00	\N	0.989999999999999991	\N	\N	Santa Monica, Municipal Pier	CA
58865	Bear Cove, Kachemak Bay, Cook Inlet, Alaska (sub)	NOS	9455595	59.7250000000000014	-151.022999999999996	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.400000000000000022	\N	\N	\N	Bear Cove, Kachemak Bay	AK
58866	Elfin Cove, Port Althorp, Cross Sound, Alaska (sub)	NOS	9452634	58.1947199999999967	-136.346944444444432	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:05:00	\N	1.01000000000000001	00:04:00	\N	1.10000000000000009	\N	\N	Elfin Cove, Port Althorp	AK
58867	Garibaldi, Tillamook Bay, Oregon (sub)	NOS	9437540	45.5545299999999997	-123.918944444391457	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:11:00	\N	1.06000000000000005	01:19:00	\N	1.18999999999999995	\N	\N	Garibaldi	OR
58868	Annapolis (US Naval Academy), Severn River, Maryland (sub)	NOS	8575512	38.9832800000000006	-76.4815555551317061	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-01:44:00	\N	1	-01:30:00	\N	0.880000000000000004	\N	\N	Annapolis (US Naval Academy)	MD
58869	Lewisetta, Potomac River, Virginia (sub)	NOS	8635750	37.9961111111111123	-76.4644444444444389	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-07:31:00	\N	0.800000000000000044	-06:19:00	\N	0.46000000000000002	\N	\N	Lewisetta, Va.	VA
58870	Kiptopeke Beach, Chesapeake Bay, Virginia (sub)	NOS	8632200	37.1651900000000026	-75.9884444443384837	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	00:32:00	\N	0.92000000000000004	00:23:00	\N	1.01000000000000001	\N	\N	Kiptopeke Beach	VA
58871	La Jolla (Scripps Institution Wharf), California (sub)	NOS	9410230	32.8668888888888873	-117.257138888888903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	-00:04:00	\N	0.969999999999999973	00:00:00	\N	0.92000000000000004	\N	\N	La Jolla (Scripps Institution Wharf)	CA
58872	Alameda, San Francisco Bay, California (sub)	NOS	9414750	37.7717000000000027	-122.299999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:39:00	\N	0.989999999999999991	00:29:00	\N	1.1100000000000001	\N	\N	Alameda	CA
58873	Port Angeles, Strait Of Juan De Fuca, Washington (sub)	NOS	9444090	48.1247222222222319	-123.441138888888901	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-01:14:00	\N	0.770000000000000018	-01:45:00	\N	0.82999999999999996	\N	\N	Port Angeles	WA
58874	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska (sub)	NOS	9450711	55.7216666666666569	-133.349999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:14:00	\N	0.939999999999999947	-00:14:00	\N	1.05000000000000004	\N	\N	Nossuk Bay, Tonowek Bay	AK
58875	Galveston Pleasure Pier, Gulf Of Mexico, Texas (sub)	NOS	8771510	29.2852999999999994	-94.7894000000000005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:03:00	\N	1.30000000000000004	-01:33:00	\N	1.39999999999999991	\N	\N	Galveston Pleasure Pier	TX
58876	Little Talbot Island, ocean, Florida	NOS	8720194	30.4299999999999997	-81.4050000000000011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	-00:13:00	\N	1	-00:36:00	\N	0.910000000000000031	\N	\N	Little Talbot Island, ocean	FL
58877	Shell Beach, Lake Borgne, Louisiana (sub)	NOS	8761305	29.8681111111111086	-89.6732499999999959	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	05:45:00	\N	1.12999999999999989	05:45:00	\N	1.12999999999999989	\N	\N	Shell Beach, Lake Borgne	LA
58878	Provorotni Island, Alaska (sub)	NOS	9451936	57.5150000000000006	-135.555000000000007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:02:00	-0.100000000000000006	\N	-00:09:00	-1.30000000000000004	\N	\N	\N	Povorotni Island, Pogibshi Point	AK
58879	Baranof, Warm Spring Bay, Alaska (sub)	NOS	9451625	57.0883333333333312	-134.824999999999989	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:04:00	-0.100000000000000006	\N	-00:07:00	-2.79999999999999982	\N	\N	\N	Baranof, Warm Spring Bay	AK
58880	Biorka Village, Biverly Inlet, Alaska (sub)	NOS	9462645	53.8289166666666716	-166.216250000000002	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:25:00	\N	1.35000000000000009	-03:13:00	\N	1.35000000000000009	\N	\N	Udamat Bay, Sedanka Island	AK
58881	Chatham, Cape Cod, Massachusetts (sub)	NOS	8447435	41.6884722222222166	-69.9510833333333295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	01:57:00	\N	0.349999999999999978	01:08:00	\N	0.479999999999999982	\N	\N	Chatham Harbor, Aunt Lydias Cove	MA
58882	Olga Compressor Station, Grand Bay, Louisiana (sub)	NOS	8760889	29.3865555555555602	-89.3801388888888937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:56:00	\N	1.08000000000000007	02:54:00	\N	1.08000000000000007	\N	\N	Grand Bay	LA
58883	The Summit, Keku Strait, Alaska (sub)	NOS	9451349	56.6824222222222218	-133.736908333333304	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:23:00	\N	0.989999999999999991	00:19:00	\N	0.979999999999999982	\N	\N	The Summit	AK
58884	Scotch Cap, Unimak Island, Alaska (sub)	NOS	9462808	54.3936388888888871	-164.745722222222213	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-02:49:00	\N	1.27000000000000002	-02:27:00	\N	1.39999999999999991	\N	\N	Scotch Cap	AK
58885	Virginia Key, Bear Cut, Biscayne Bay, Florida (sub)	NOS	8723214	25.7314000000000007	-80.1617999999999995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	00:51:00	\N	0.859999999999999987	00:28:00	\N	0.880000000000000004	\N	\N	Bear Cut, Virginia Key	FL
58886	Delaware City, Delaware River, Delaware (sub)	NOS	8551762	39.5816999999999979	-75.5883000000000038	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55835	00:14:00	\N	1	00:11:00	\N	0.989999999999999991	\N	\N	Delaware City	DE
58887	Monte Carlo Island, Keku Strait, Alaska (sub)	NOS	9451247	56.5349999999999966	-133.766999999999996	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56421	00:03:00	\N	0.890000000000000013	00:03:00	\N	0.800000000000000044	\N	\N	Monte Carlo Island	AK
58888	Windmill Point, Rappahannock River, Virginia (sub)	NOS	8636580	37.6161999999999992	-76.2900000000000063	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	02:14:00	\N	0.82999999999999996	01:55:00	\N	0.489999999999999991	\N	\N	Windmill Point	VA
58889	Burlington, Delaware River, New Jersey (sub)	NOS	8539094	40.0799999999999983	-74.8733333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:07:00	\N	1	00:53:00	\N	1.19999999999999996	\N	\N	Burlington, N.J.	NJ
58890	Yakutat, Yakutat Bay, Alaska (sub)	NOS	9453220	59.5484999999999971	-139.733399999999989	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:16:00	\N	0.949999999999999956	00:17:00	\N	1.01000000000000001	\N	\N	Yakutat, Yakutat Bay	AK
58891	Morehead City Harbor, North Carolina	NOS	8656502	34.7199999999999989	-76.7108333333333263	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:37:00	\N	1.16999999999999993	00:35:00	\N	1.04000000000000004	\N	\N	Morehead City Harbor	NC
58892	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.3500000000000014	-151.826666666666711	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
58893	Village Cove, St. Paul Island, Bering Sea, Alaska (sub)	NOS	9464212	57.1253055555555633	-170.285166666666697	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	00:27:00	\N	1.06000000000000005	00:26:00	\N	0.930000000000000049	\N	\N	Village Cove, St. Paul Island	AK
58894	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6000000000000014	-74.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	00:37:00	\N	1.05000000000000004	00:23:00	\N	1.07000000000000006	\N	\N	Chelsea	NJ
58895	New Topsail Inlet, North Carolina	NOS	TEC2841	34.3666666666670082	-77.6333333333329989	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:00:00	\N	0.82999999999999996	00:20:00	\N	0.979999999999999982	\N	\N	New Topsail Inlet	NC
58896	North Santee River Inlet, South Carolina	NOS	TEC2991	33.1333333333329918	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:04:00	\N	0.839999999999999969	-00:09:00	\N	0.849999999999999978	\N	\N	North Santee River Inlet	SC
58897	Cape Canaveral, Florida	NOS	TEC3693	28.4333333333329925	-80.5666666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:44:00	\N	1.41999999999999993	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
58898	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8573777	37.9216666666670079	-75.7283333333329978	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	04:36:00	\N	1.16999999999999993	03:52:00	\N	0.890000000000000013	\N	\N	Saxis, Starling Creek, Pocomoke Sound	MD
58899	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.4133333333329929	-77.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55876	-02:46:00	\N	0.67000000000000004	-01:42:00	\N	0.409999999999999976	\N	\N	Clifton Beach, Smith Point, Md.	MD
58900	Oregon Inlet, North Carolina	NOS	TEC2771	35.7666666666670068	-75.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55922	-00:27:00	\N	0.709999999999999964	-00:03:00	\N	1.97999999999999998	\N	\N	Oregon Inlet	NC
58901	Cape Hatteras, North Carolina	NOS	TEC2789	35.2333333333329932	-75.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:01:00	\N	1.08000000000000007	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
58902	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2000000000000028	-75.7333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:13:00	\N	0.82999999999999996	00:08:00	\N	0.660000000000000031	\N	\N	Hatteras Inlet	NC
58903	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.066666666667011	-76.0166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:11:00	\N	0.82999999999999996	00:09:00	\N	0.630000000000000004	\N	\N	Ocracoke Inlet	NC
58904	Shell Point, Harkers Island, North Carolina	NOS	TEC2801	34.683333333332989	-76.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	02:34:00	\N	0.82999999999999996	01:52:00	\N	0.540000000000000036	\N	\N	Shell Point, Harkers Island	NC
58905	N.C. State Fisheries, North Carolina	NOS	TEC2831	34.7166666666670096	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	01:32:00	\N	0.82999999999999996	01:05:00	\N	0.660000000000000031	\N	\N	N.C. State Fisheries	NC
58906	Bogue Inlet, North Carolina	NOS	TEC2837	34.6499999999999986	-77.0999999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:15:00	\N	0.82999999999999996	00:13:00	\N	0.729999999999999982	\N	\N	Bogue Inlet	NC
58907	Cape Fear, North Carolina	NOS	TEC2847	33.8500000000000014	-77.9666666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:07:00	\N	1.33000000000000007	00:04:00	\N	1.46999999999999997	\N	\N	Cape Fear	NC
58908	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.3500000000000014	-77.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	02:54:00	\N	0.419999999999999984	02:44:00	\N	0.419999999999999984	\N	\N	Castle Hayne, Northeast River	NC
58909	Bannermans Branch, Northeast River, Cape Fear River, North Carolina	NOS	TEC2865	34.5833333333329946	-77.7666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55934	06:08:00	\N	0.309999999999999998	05:58:00	\N	0.320000000000000007	\N	\N	Bannermans Branch, Northeast River	NC
58910	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.9166666666670054	-78.2333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:15:00	\N	1	00:04:00	\N	0.839999999999999969	\N	\N	Lockwoods Folly Inlet	NC
58911	Tubbs Inlet, North Carolina	NOS	TEC2873	33.8833333333329918	-78.4833333333329932	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:15:00	\N	1	00:14:00	\N	0.890000000000000013	\N	\N	Tubbs Inlet	NC
58912	Sunset Beach Bridge, North Carolina	NOS	8659899	33.8816666666670088	-78.5100000000000051	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55941	00:56:00	\N	0.839999999999999969	00:34:00	\N	0.939999999999999947	\N	\N	Sunset Beach Bridge	NC
58913	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.1499999999999986	-79.3333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	01:31:00	\N	0.790000000000000036	00:27:00	\N	0.780000000000000027	\N	\N	Brown Island, South Santee River	SC
58914	Cape Romain, 46 miles east of, South Carolina	NOS	TEC3011	33.1000000000000014	-78.4333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-01:13:00	\N	0.790000000000000036	-01:05:00	\N	0.780000000000000027	\N	\N	Cape Romain, 46 miles east of	SC
59027	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.5833333333329946	-145.716666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	0	\N	00:01:00	-0.200000000000000011	\N	\N	\N	Orca	AK
58915	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.933333333332989	-79.5833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:15:00	\N	0.949999999999999956	-00:14:00	\N	0.949999999999999956	\N	\N	Jack Creek entrance	SC
58916	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.0333333333329904	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:12:00	\N	1.1399999999999999	00:32:00	\N	1.14999999999999991	\N	\N	Thunderbolt	GA
58917	Jekyll Island Marina, Jekyll Creek, Georgia (2)	NOS	8767832	31.0566666666670095	-81.4233333333329909	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	00:36:00	\N	1.15999999999999992	00:03:00	\N	1.12999999999999989	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
58918	Shipyard Creek, 0.8 mile above entrance., South Carolina	NOS	TEC3061	32.8333333333329946	-79.9500000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	00:20:00	\N	1	00:34:00	\N	1.01000000000000001	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
58919	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.6499999999999986	-79.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:14:00	\N	1	-00:08:00	\N	0.979999999999999982	\N	\N	Folly Island (outer coast)	SC
58920	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.9333333333329925	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:03:00	\N	1.03000000000000003	00:08:00	\N	1.03000000000000003	\N	\N	Romerly Marsh Creek	GA
58921	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:06:00	\N	1.1399999999999999	00:14:00	\N	1.12999999999999989	\N	\N	Savannah Sheraton Resort Hotel	GA
58922	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.066666666667011	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:44:00	\N	1.09000000000000008	00:40:00	\N	1.10000000000000009	\N	\N	North entrance	GA
58923	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.9833333333329932	-81.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:28:00	\N	1.12999999999999989	00:50:00	\N	1.12999999999999989	\N	\N	Isle of Hope, Skidaway River	GA
58924	Egg Islands, Georgia	NOS	TEC3413	31.8333333333329911	-81.0833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:10:00	\N	1.04000000000000004	00:04:00	\N	1.04000000000000004	\N	\N	Egg Islands	GA
58925	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.9333333333329925	-81.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:42:00	\N	1.09000000000000008	01:05:00	\N	1.09000000000000008	\N	\N	Coffee Bluff, Forest River	GA
58926	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.8833333333329918	-81.2166666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
58927	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.9833333333329932	-81.2833333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	04:25:00	\N	0.140000000000000013	03:19:00	\N	0.149999999999999994	\N	\N	Highway bridge, Ogeechee River	GA
58928	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.8166666666670075	-81.1666666666670125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:49:00	\N	0.949999999999999956	00:46:00	\N	1.09000000000000008	\N	\N	Florida Passage, Bear River	GA
58929	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.8166666666670075	-81.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:43:00	\N	1.05000000000000004	00:55:00	\N	1.05000000000000004	\N	\N	Cane Patch Creek entrance	GA
58930	North Newport River, Georgia	NOS	TEC3445	31.6666666666670089	-81.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:36:00	\N	1.09000000000000008	00:56:00	\N	1.10000000000000009	\N	\N	North Newport River	GA
58931	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.6666666666670089	-81.2666666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:54:00	\N	1.04000000000000004	01:01:00	\N	1.08000000000000007	\N	\N	South Newport Cut, N. Newport River	GA
58932	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.5833333333329911	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:04:00	\N	1.09000000000000008	00:48:00	\N	1.10000000000000009	\N	\N	Dallas Bluff, Julienton River	GA
58933	Blackbeard Island, Georgia	NOS	TEC3463	31.5333333333329904	-81.2000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
58934	Mud River, at Old Teakettle Creek, Georgia	NOS	TEC3475	31.4833333333329932	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:46:00	\N	1.09000000000000008	00:45:00	\N	1.08000000000000007	\N	\N	Mud River, at Old Teakettle Creek	GA
58935	Wolf Island, south end, Georgia	NOS	TEC3491	31.3333333333329911	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:45:00	\N	1.09000000000000008	00:25:00	\N	0.969999999999999973	\N	\N	Wolf Island, south end	GA
58936	Hampton River entrance, Georgia	NOS	TEC3495	31.2166666666670096	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:04:00	\N	0.949999999999999956	00:16:00	\N	0.959999999999999964	\N	\N	Hampton River entrance	GA
58937	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3000000000000007	-81.3333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:13:00	\N	1.05000000000000004	01:03:00	\N	1.05000000000000004	\N	\N	Jones Creek entrance, Hampton River	GA
58938	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1000000000000014	-81.3166666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:02:00	\N	0.949999999999999956	-00:01:00	\N	0.949999999999999956	\N	\N	St. Simons Sound Bar	GA
58939	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.1833333333329925	-81.5166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:42:00	\N	1.09000000000000008	01:03:00	\N	1.10000000000000009	\N	\N	Allied Chemical Corp. docks	GA
58940	Euhaw Creek, 2.5 mi. above entrance, Broad River, South Carolina	NOS	TEC3327	32.4350000000000023	-80.8516666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:09:00	\N	0.910000000000000031	01:33:00	\N	1.1399999999999999	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
58941	Tybee Creek entrance, Georgia	NOS	TEC3399	31.9833333333329932	-80.8499999999999943	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:05:00	\N	1	-00:09:00	\N	0.989999999999999991	\N	\N	Tybee Creek entrance	GA
58942	Beach Hammock, Georgia	NOS	TEC3401	31.9499999999999993	-80.9333333333329961	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
58943	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.7666666666670068	-79.8333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:12:00	\N	1	-00:08:00	\N	0.989999999999999991	\N	\N	Sullivans Island (outer coast)	SC
58944	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.1666666666670089	-81.6166666666670011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	01:31:00	\N	1.22999999999999998	01:09:00	\N	1.22999999999999998	\N	\N	Below Spring Bluff	GA
58945	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.9499999999999993	-81.9000000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55985	05:05:00	\N	0.530000000000000027	03:55:00	\N	0.530000000000000027	\N	\N	Burnt Fort	GA
58946	Winyah Bay Entrance (South Jetty), South Carolina	NOS	TEC2929	33.183333333332989	-79.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	-00:24:00	\N	0.890000000000000013	-00:21:00	\N	0.869999999999999996	\N	\N	Winyah Bay Entrance (South Jetty)	SC
58947	Frazier Point, South Carolina	NOS	TEC2937	33.316666666667011	-79.2833333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55960	02:07:00	\N	0.680000000000000049	01:26:00	\N	0.660000000000000031	\N	\N	Frazier Point	SC
58948	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.1499999999999986	-81.5666666666670039	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:49:00	\N	1.09000000000000008	01:07:00	\N	1.10000000000000009	\N	\N	Highway bridge, South Brunswick River	GA
58949	Jupiter Inlet, U.S. Highway 1 Bridge, Florida	NOS	TEC3783	26.9483333333329931	-80.0849999999999937	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:05:00	\N	1.1399999999999999	00:28:00	\N	0.859999999999999987	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
58950	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.9499999999999993	-80.1016666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:58:00	\N	1.1399999999999999	00:59:00	\N	0.800000000000000044	\N	\N	Tequesta	FL
58951	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.9516666666670091	-80.1016666666670147	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:42:00	\N	0.92000000000000004	00:51:00	\N	0.780000000000000027	\N	\N	Tequesta, North Fork entrance	FL
59134	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.81666666666670373	169.316666666670073	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:01:00	0	\N	00:00:00	0.100000000000000006	\N	\N	\N	Likiep Atoll	MH
58952	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.1133333333329922	-80.4166666666670125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	01:49:00	\N	0.640000000000000013	00:23:00	\N	0.660000000000000031	\N	\N	Key Largo, South Sound, Key Largo	FL
58953	Whitewater Bay, Florida	NOS	TEC4169	25.3166666666670075	-81.0333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	04:38:00	\N	0.330000000000000016	03:53:00	\N	0.260000000000000009	\N	\N	Whitewater Bay	FL
58954	Cape Sable, East Cape, Florida	NOS	TEC4165	25.1166666666670082	-81.0833333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:50:00	\N	0.979999999999999982	01:33:00	\N	1.30000000000000004	\N	\N	Cape Sable, East Cape	FL
58955	Indian Key, Florida	NOS	TEC4183	25.8000000000000007	-81.4666666666670096	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:19:00	\N	0.979999999999999982	00:55:00	\N	1.47999999999999998	\N	\N	Indian Key	FL
58956	Round Key, Florida	NOS	TEC4185	25.8333333333329911	-81.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56068	01:12:00	\N	0.979999999999999982	00:54:00	\N	1.47999999999999998	\N	\N	Round Key	FL
58957	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.4499999999999993	-82.0166666666670068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:12:00	\N	1.20999999999999996	-01:50:00	\N	1.20999999999999996	\N	\N	Point Ybel, San Carlos Bay entrance	FL
58958	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.6833333333329925	-82.7333333333329932	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-01:30:00	\N	0.869999999999999996	-01:34:00	\N	0.869999999999999996	\N	\N	Pass-a-Grille Beach	FL
58959	Suwannee River entrance, Florida	NOS	TEC4299	29.2833333333329904	-83.1500000000000057	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:18:00	\N	0.949999999999999956	00:06:00	\N	0.880000000000000004	\N	\N	Suwannee River entrance	FL
58960	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.3666666666670011	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56110	00:24:00	\N	0.949999999999999956	00:12:00	\N	0.880000000000000004	\N	\N	Pepperfish Keys	FL
58961	Fishermans Rest, Florida	NOS	TEC4305	29.7333333333329932	-83.5333333333329904	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	-00:02:00	\N	0.859999999999999987	-00:14:00	\N	0.930000000000000049	\N	\N	Fishermans Rest	FL
58962	Rock Islands, Florida	NOS	TEC4309	29.9666666666670096	-83.8333333333329875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56113	00:04:00	\N	0.910000000000000031	-00:03:00	\N	0.930000000000000049	\N	\N	Rock Islands	FL
58963	Lower Anchorage, Apalachicola Bay, Florida	NOS	TEC4343	29.6000000000000014	-85.0499999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56124	-00:35:00	\N	1	-00:17:00	\N	0.930000000000000049	\N	\N	Lower Anchorage	FL
58964	Panama City Beach (outside), St. Andrew Bay, Florida (sub)	NOS	8728210	30.2133333333329936	-85.8783333333329892	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-02:44:00	\N	1.05000000000000004	-02:17:00	\N	1.05000000000000004	\N	\N	Panama City Beach (outside)	FL
58965	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.6166666666670082	-87.0333333333329904	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	01:47:00	\N	1.19999999999999996	01:40:00	\N	1.19999999999999996	\N	\N	Milton, Blackwater River	FL
58966	Fowl River, Mobile Bay Entrance, Alabama	NOS	TEC4393	30.4333333333329925	-88.1166666666670011	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56150	-00:09:00	\N	1	-00:19:00	\N	1	\N	\N	Fowl River, Mobile Bay Entrance	AL
58967	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.3583333333329932	-89.2733333333329853	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:51:00	\N	1.3600000000000001	03:18:00	\N	1.3600000000000001	\N	\N	Wolf River, Henderson Avenue bridge	MS
58968	Borden Highway Bridge, San Joaquin River, San Joaquin River, California	NOS	9414367	37.9366666666670085	-121.333333333330046	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:48:00	\N	0.640000000000000013	04:28:00	\N	0.780000000000000027	\N	\N	Borden Highway Bridge, San Joaquin River	CA
58969	Point Arena, California	NOS	TWC0771	38.9500000000000028	-123.733333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56330	00:01:00	\N	0.949999999999999956	00:03:00	\N	0.979999999999999982	\N	\N	Point Arena	CA
58970	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.2999999999999972	-123.799999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56330	00:01:00	\N	0.949999999999999956	00:07:00	\N	0.979999999999999982	\N	\N	Mendocino, Mendocino Bay	CA
58971	Noyo River, California	NOS	TWC0781	39.4166666666670054	-123.799999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56330	00:05:00	\N	1.03000000000000003	00:09:00	\N	1.02000000000000002	\N	\N	Noyo River	CA
58972	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.433333333332989	-124.416666666669954	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:16:00	\N	0.92000000000000004	00:09:00	\N	0.949999999999999956	\N	\N	Wedderburn, Rogue River	OR
58973	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.9333333333329961	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	05:58:00	\N	1.04000000000000004	05:53:00	\N	1.04000000000000004	\N	\N	Paris Road Bridge (ICWW)	LA
58974	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.2666666666670068	-89.9666666666670096	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56198	00:46:00	\N	0.939999999999999947	01:32:00	\N	0.939999999999999947	\N	\N	Bayou Rigaud, Grand Isle	LA
58975	Weeks Bay, Vermilion Bay, Louisiana (sub)	NOS	TEC4493	29.8000000000000007	-91.8333333333329875	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	02:32:00	\N	1.07000000000000006	01:44:00	\N	1.07000000000000006	\N	\N	Weeks Bay, Vermilion Bay	LA
58976	Mermentau River entrance, Louisiana	NOS	TEC4495	29.75	-93.0999999999999943	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:59:00	\N	1.79000000000000004	-01:54:00	\N	1.79000000000000004	\N	\N	Mermentau River entrance	LA
58978	Sabine Bank Lighthouse, Texas	NOS	TEC4499	29.4666666666670096	-93.7166666666670096	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:31:00	\N	2	-01:46:00	\N	2	\N	\N	Sabine Bank Lighthouse	TX
58979	Galveston Bay entrance, south jetty, Texas	NOS	TEC4507	29.3333333333329911	-94.7000000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:05:00	\N	1.42999999999999994	-00:39:00	\N	1.42999999999999994	\N	\N	Galveston Bay entrance, south jetty	TX
58980	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.3833333333329918	-94.8833333333329989	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
58981	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.5166666666670068	-94.4833333333329932	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	04:18:00	\N	0.859999999999999987	03:16:00	\N	0.859999999999999987	\N	\N	Gilchrist, East Bay	TX
58982	San Luis Pass, Texas	NOS	TEC4535	29.0833333333329911	-95.1166666666670011	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:09:00	\N	0.859999999999999987	-00:09:00	\N	0.859999999999999987	\N	\N	San Luis Pass	TX
58983	Guanica, Puerto Rico	NOS	TEC4731	17.9666666666670096	-66.9166666666670125	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	00:18:00	\N	1	-01:22:00	\N	1	\N	\N	Guanica	PR
58984	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.9666666666670096	-66.6166666666670011	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	-00:13:00	\N	1.1399999999999999	-00:39:00	\N	1.1399999999999999	\N	\N	Playa de Ponce	PR
58985	Playa Cortada, Puerto Rico	NOS	TEC4735	17.9833333333329932	-66.4500000000000028	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	-00:37:00	\N	1.1399999999999999	00:16:00	\N	1.1399999999999999	\N	\N	Playa Cortada	PR
58986	Arroyo, Puerto Rico	NOS	TEC4737	17.9666666666670096	-66.0666666666670039	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	00:13:00	\N	1.1399999999999999	00:52:00	\N	1.1399999999999999	\N	\N	Arroyo	PR
58987	Puerto Maunabo, Puerto Rico	NOS	TEC4739	18	-65.8833333333329989	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	01:13:00	\N	1	-00:56:00	\N	1	\N	\N	Puerto Maunabo	PR
58988	Culebrita, Isla, Puerto Rico	NOS	TEC4741	18.3166666666670075	-65.2333333333329932	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	02:40:00	\N	1.57000000000000006	-02:34:00	\N	1.57000000000000006	\N	\N	Culebrita, Isla	PR
58989	Puerto Ferro, Isla de Vieques, Puerto Rico	NOS	TEC4743	18.1000000000000014	-65.4333333333329961	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56633	03:01:00	\N	1.1399999999999999	-02:26:00	\N	1.1399999999999999	\N	\N	Puerto Ferro, Isla de Vieques	PR
58990	Punta Mulas, Isla de Vieques, Puerto Rico	NOS	TEC4745	18.1499999999999986	-65.4333333333329961	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	-00:17:00	\N	0.719999999999999973	-00:14:00	\N	0.719999999999999973	\N	\N	Punta Mulas, Isla de Vieques	PR
58991	Roosevelt Roads, Puerto Rico	NOS	TEC4747	18.2333333333329932	-65.6166666666670011	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	00:20:00	\N	0.630000000000000004	00:02:00	\N	0.630000000000000004	\N	\N	Roosevelt Roads	PR
58992	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3000000000000007	-65.2833333333329904	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	-00:15:00	\N	0.630000000000000004	-00:34:00	\N	0.630000000000000004	\N	\N	Ensenada Honda, Culebra Island	PR
58993	Playa de Fajardo, Puerto Rico	NOS	TEC4751	18.3333333333329911	-65.6333333333329989	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	-00:13:00	\N	0.989999999999999991	-00:10:00	\N	0.989999999999999991	\N	\N	Playa de Fajardo	PR
58994	Puerto Real, Puerto Rico (sub)	NOS	TEC4757	18.0833333333329911	-67.1833333333329961	:America/Puerto_Rico	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	-00:26:00	\N	0.719999999999999973	-00:33:00	\N	0.719999999999999973	\N	\N	Puerto Real	PR
58995	Magens Bay, St. Thomas, Virgin Islands	NOS	TEC4759	18.3666666666670082	-64.9166666666670125	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56618	-00:17:00	\N	1.59000000000000008	-00:06:00	\N	1.59000000000000008	\N	\N	Magens Bay, St. Thomas Island	VI
58996	Christiansted, St. Croix Island, Virgin Islands	NOS	TEC4763	17.75	-64.7000000000000028	:America/St_Thomas	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56612	01:06:00	\N	1	-02:43:00	\N	1.07000000000000006	\N	\N	Christiansted, St. Croix Island	VI
58998	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.7666666666670068	-117.233333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	00:04:00	\N	0.949999999999999956	00:05:00	\N	0.949999999999999956	\N	\N	Quivira Basin, Mission Bay	CA
58999	San Clemente, California	NOS	TWC0419	33.4166666666670054	-117.616666666669957	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56275	-00:11:00	\N	0.92000000000000004	-00:15:00	\N	0.92000000000000004	\N	\N	San Clemente	CA
59000	Los Patos (highway bridge), California	NOS	TWC0427	33.7166666666670096	-118.049999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	01:12:00	\N	0.599999999999999978	01:00:00	\N	0.82999999999999996	\N	\N	Los Patos (highway bridge)	CA
59001	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.266666666669948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:02:00	0	\N	00:04:00	-0.100000000000000006	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
59002	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1000000000000014	-119.099999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:11:00	\N	0.959999999999999964	00:03:00	\N	0.959999999999999964	\N	\N	Mugu Lagoon (ocean pier)	CA
59003	Santa Barbara Island, California	NOS	TWC0463	33.4833333333329932	-119.033333333330049	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:04:00	\N	0.92000000000000004	-00:02:00	\N	0.92000000000000004	\N	\N	Santa Barbara Island	CA
59004	Point Arguello, California	NOS	TWC0473	34.5833333333329946	-120.650000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56286	-00:08:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Point Arguello	CA
59005	San Francisco Bar, California	NOS	TWC0509	37.7666666666670068	-122.633333333330043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	-00:31:00	0	\N	-00:35:00	-0.200000000000000011	\N	\N	\N	San Francisco Bar	CA
59006	Roberts Landing, 1.3 miles west of, San Francisco Bay, California	NOS	TWC0547	37.6666666666670054	-122.200000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:28:00	0.100000000000000006	\N	00:52:00	1.39999999999999991	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
59007	Redwood Creek entrance (inside), San Francisco Bay, California	NOS	TWC0573	37.5166666666670068	-122.200000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:38:00	0.100000000000000006	\N	01:06:00	2.10000000000000009	\N	\N	\N	Redwood Creek entrance (inside)	CA
59008	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2000000000000028	-122.566666666669946	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:50:00	\N	0.810000000000000053	01:59:00	\N	1.1100000000000001	\N	\N	Lakeville, Petaluma River	CA
59009	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.7333333333329932	-124.116666666669957	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	01:09:00	\N	0.800000000000000044	00:56:00	\N	0.880000000000000004	\N	\N	Gardiner	OR
59010	Newport, Oregon	NOS	TWC0843	44.6333333333329918	-124.049999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:42:00	\N	1.08000000000000007	00:44:00	\N	1.15999999999999992	\N	\N	Newport	OR
59011	Winant, Oregon	NOS	TWC0849	44.5833333333329946	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:16:00	\N	1	01:03:00	\N	1.18999999999999995	\N	\N	Winant	OR
59012	Port Townsend (Point Hudson), Washington	NOS	TWC0997	48.1166666666670082	-122.75	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	-00:06:00	0	\N	-00:11:00	0.200000000000000011	\N	\N	\N	Port Townsend (Point Hudson)	WA
59013	Oak Bay, Washington	NOS	TWC1005	48.0166666666670068	-122.716666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:27:00	0	\N	00:08:00	0.900000000000000022	\N	\N	\N	Oak Bay	WA
59014	Toledo, Oregon	NOS	TWC0851	44.6166666666670082	-123.933333333330054	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:39:00	\N	0.92000000000000004	01:29:00	\N	1.16999999999999993	\N	\N	Toledo	OR
59015	Tah Bay, Alaska	NOS	TWC1487	54.8333333333329946	-132.333333333329932	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:03:00	0.100000000000000006	\N	-00:04:00	2.60000000000000009	\N	\N	\N	Tah Bay	AK
59016	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.0166666666670068	-132.783333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:05:00	0	\N	-00:13:00	2.79999999999999982	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
59017	Point Elizabeth, Alaska	NOS	TWC1783	57.5166666666670068	-135.283333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:05:00	0	\N	-00:15:00	-1.60000000000000009	\N	\N	\N	Point Elizabeth	AK
59018	Lindenburg Head, Alaska	NOS	TWC1785	57.4500000000000028	-135.033333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:05:00	0	\N	-00:15:00	-1.80000000000000004	\N	\N	\N	Lindenburg Head	AK
59019	Fairway Island, Alaska	NOS	TWC1787	57.4500000000000028	-134.883333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:05:00	0	\N	-00:15:00	-2.10000000000000009	\N	\N	\N	Fairway Island	AK
59135	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.46666666666670409	170.233333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:11:00	-0.200000000000000011	\N	-00:11:00	-0.200000000000000011	\N	\N	\N	Wotje Atoll	MH
59020	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.5499999999999972	-135.933333333329927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56470	-00:07:00	\N	1.10000000000000009	-00:05:00	\N	0.959999999999999964	\N	\N	Falcon Arm, Slocum Arm	AK
59021	Point Adolphus, Alaska	NOS	TWC1825	58.2833333333329904	-135.783333333329921	:America/Juneau	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:01:00	-0.100000000000000006	\N	-00:03:00	-1.80000000000000004	\N	\N	\N	Point Adolphus	AK
59022	Flynn Cove, Alaska	NOS	TWC1827	58.2000000000000028	-135.583333333329932	:America/Juneau	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:01:00	-0.100000000000000006	\N	-00:05:00	-1.39999999999999991	\N	\N	\N	Flynn Cove	AK
59023	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.0499999999999972	-144.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56472	00:08:00	\N	1.01000000000000001	00:05:00	\N	0.989999999999999991	\N	\N	Wingham Island, Controller Bay	AK
59024	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.3833333333329918	-145.400000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:38:00	0	\N	00:06:00	-2.39999999999999991	\N	\N	\N	Pete Dahl Slough	AK
59025	Eyak River entrance, Alaska	NOS	TWC1869	60.4666666666670096	-145.666666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:58:00	-0.100000000000000006	\N	00:14:00	-1.60000000000000009	\N	\N	\N	Eyak River entrance	AK
59026	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.4666666666670096	-145.966666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:31:00	0	\N	00:01:00	-0.100000000000000006	\N	\N	\N	Gravel Point	AK
59028	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.566666666667011	-145.966666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
59029	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.3333333333329946	-146.550000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	00:01:00	-0.200000000000000011	\N	-00:09:00	-1.30000000000000004	\N	\N	\N	Port Etches	AK
59030	Macleod Harbor, Alaska	NOS	TWC1891	59.8833333333329918	-147.766666666670091	:America/Anchorage	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:16:00	-0.100000000000000006	\N	-00:33:00	-1.39999999999999991	\N	\N	\N	Macleod Harbor	AK
59031	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.9500000000000028	-147.683333333329927	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:05:00	-0.100000000000000006	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
59032	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.6166666666670082	-153.583333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:16:00	\N	0.819999999999999951	00:12:00	\N	0.800000000000000044	\N	\N	Iliamna Bay	AK
59033	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.2333333333329932	-151.866666666670085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:07:00	0	\N	00:18:00	0.900000000000000022	\N	\N	\N	Marmot Island, Marmot Strait	AK
59034	Izhut Bay, Alaska	NOS	TWC2023	58.2166666666670096	-152.316666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:21:00	0	\N	00:12:00	0.100000000000000006	\N	\N	\N	Izhut Bay	AK
59035	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.1333333333329918	-152.566666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:06:00	0.200000000000000011	\N	00:04:00	0.599999999999999978	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
59036	Kizhuyak Point, Alaska	NOS	TWC2031	57.8999999999999986	-152.650000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:09:00	0.100000000000000006	\N	00:05:00	0.599999999999999978	\N	\N	\N	Kizhuyak Point	AK
59037	Three Saints Bay, Alaska	NOS	TWC2047	57.1166666666670082	-153.516666666670091	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:13:00	0.100000000000000006	\N	-00:22:00	-0.200000000000000011	\N	\N	\N	Three Saints Bay	AK
59038	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.133333333329915	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:07:00	0.200000000000000011	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
59039	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.7833333333329904	-153.550000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:02:00	\N	0.800000000000000044	-00:15:00	\N	0.800000000000000044	\N	\N	Village Islands	AK
59040	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.7333333333329932	-153.333333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:01:00	\N	0.770000000000000018	-00:12:00	\N	0.770000000000000018	\N	\N	Northeast Arm	AK
59041	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.7999999999999972	-153.300000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:02:00	\N	0.810000000000000053	-00:07:00	\N	0.810000000000000053	\N	\N	Uganik Passage	AK
59042	Viekoda Bay, Alaska	NOS	TWC2073	57.8999999999999986	-153.166666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:03:00	\N	0.800000000000000044	-00:11:00	\N	0.800000000000000044	\N	\N	Viekoda Bay	AK
59043	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.0499999999999972	-153.233333333329909	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	-00:01:00	\N	0.800000000000000044	00:00:00	\N	0.800000000000000044	\N	\N	Onion Bay	AK
59044	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.9500000000000028	-153.033333333329921	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:13:00	\N	0.770000000000000018	00:02:00	\N	0.770000000000000018	\N	\N	Dry Spruce Island	AK
59045	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.183333333332989	-152.949999999999989	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:00:00	\N	0.810000000000000053	-00:14:00	\N	0.810000000000000053	\N	\N	Malina Bay, Shelikof Strait	AK
59046	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.983333333329909	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:01:00	\N	0.709999999999999964	-00:14:00	\N	0.709999999999999964	\N	\N	Katmai Bay, Shelikof Strait	AK
59047	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.433333333332989	-156.300000000000011	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:32:00	0.200000000000000011	\N	00:21:00	3.20000000000000018	\N	\N	\N	Lees Cabins, Wide Bay	AK
59048	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.1666666666670054	-123.966666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:12:00	\N	0.92000000000000004	00:55:00	\N	1.10000000000000009	\N	\N	Nestucca Bay entrance	OR
59049	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.5499999999999972	-123.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	01:26:00	\N	0.92000000000000004	01:15:00	\N	1.06000000000000005	\N	\N	Miami Cove	OR
59050	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.5166666666670068	-123.900000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	02:00:00	\N	0.82999999999999996	01:33:00	\N	1.02000000000000002	\N	\N	Bay City	OR
59051	Point Adams, Oregon	NOS	TWC0881	46.2000000000000028	-123.950000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:38:00	0.100000000000000006	\N	-00:25:00	-0.200000000000000011	\N	\N	\N	Point Adams, Oreg.	OR
59053	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.1666666666670054	-123.916666666669954	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:19:00	0.100000000000000006	\N	-00:13:00	-0.100000000000000006	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
59054	Harrington Point, Washington	NOS	TWC0895	46.2666666666670068	-123.650000000000006	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	00:52:00	-0.200000000000000011	\N	00:21:00	-0.800000000000000044	\N	\N	\N	Harrington Point, Wash.	WA
59055	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.3699999999999974	-124.004999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	01:14:00	\N	1.05000000000000004	00:45:00	\N	1.05000000000000004	\N	\N	Tarlatt Slough	WA
59056	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.6883333333329915	-123.816666666669946	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	00:11:00	\N	1.02000000000000002	00:18:00	\N	1.07000000000000006	\N	\N	Mailboat Slough, Willapa River	WA
59057	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.9683333333329927	-123.599999999999994	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	01:45:00	\N	0.939999999999999947	01:34:00	\N	0.939999999999999947	\N	\N	Montesano, Chehalis River	WA
59058	Destruction Island, Washington	NOS	TWC0965	47.6666666666670054	-124.483333333330052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:43:00	\N	1.02000000000000002	-00:37:00	\N	0.979999999999999982	\N	\N	Destruction Island	WA
59059	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.316666666667011	-134.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:05:00	-0.100000000000000006	\N	-00:01:00	-0.299999999999999989	\N	\N	\N	Fritz Cove, Douglas Island	AK
59060	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.4166666666670054	-134.133333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	00:11:00	0.100000000000000006	\N	00:04:00	1.80000000000000004	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
59061	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.2333333333329932	-134.599999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:15:00	0.299999999999999989	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
59062	Point Thatcher, Alaska	NOS	TWC1735	57.4166666666670054	-134.849999999999994	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:11:00	0.200000000000000011	\N	-00:15:00	-1.89999999999999991	\N	\N	\N	Point Thatcher	AK
59063	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.4833333333329932	-134.550000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:15:00	0.299999999999999989	\N	00:11:00	-2.79999999999999982	\N	\N	\N	Favorite Bay	AK
59064	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.5333333333329904	-134.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	01:31:00	\N	0.619999999999999996	01:22:00	\N	0.67000000000000004	\N	\N	Mitchell Bay	AK
59065	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.8500000000000014	-135.016666666670091	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:00:00	0.299999999999999989	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
59066	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.7166666666670096	-170.150000000000006	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-01:51:00	\N	0.930000000000000049	-01:40:00	\N	1.1399999999999999	\N	\N	Herbert Island, west side	AK
59067	Zapadni Bay, St. George Island, Bering Sea, Alaska	NOS	TWC2375	56.566666666667011	-169.683333333329927	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	01:18:00	\N	0.890000000000000013	01:15:00	\N	0.890000000000000013	\N	\N	Zapadni Bay, St. George Island	AK
59068	Apoon Mouth, Yukon River, Norton Sound, Alaska	NOS	TWC2405	63.0499999999999972	-163.383333333329915	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56586	-01:30:00	\N	1.03000000000000003	-01:30:00	\N	1.03000000000000003	\N	\N	Apoon Mouth, Yukon River	AK
59069	Kiwalik, Kotzebue Sound, Alaska	NOS	TWC2419	66.1333333333329989	-161.866666666670085	:America/Anchorage	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	06:07:00	\N	0.280000000000000027	06:16:00	\N	0.299999999999999989	\N	\N	Kiwalik, Kotzebue Sound	AK
59070	Flaxman Island, Alaska	NOS	TWC2423	70.1833333333329961	-145.833333333329932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	-00:28:00	\N	0.0899999999999999967	-00:57:00	\N	0.0800000000000000017	\N	\N	Flaxman Island	AK
59071	Burns Point, Totten Inlet, Puget Sound, Washington	NOS	TWC1113	47.1216666666670108	-123.056666666669955	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	01:07:00	\N	1.06000000000000005	00:54:00	\N	1.33000000000000007	\N	\N	Burns Point, Totten Inlet	WA
59072	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.0816666666670045	-123.004999999999995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:56:00	\N	1.10000000000000009	00:39:00	\N	1.31000000000000005	\N	\N	Rocky Point, Eld Inlet	WA
59073	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.0450000000000017	-122.211666666669956	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	00:29:00	\N	0.890000000000000013	00:09:00	\N	0.949999999999999956	\N	\N	Marysville, Quilceda Creek	WA
59074	Peavine Pass, Washington	NOS	TWC1165	48.6000000000000014	-122.799999999999997	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:18:00	\N	0.92000000000000004	00:34:00	\N	0.979999999999999982	\N	\N	Peavine Pass	WA
59075	Eagle Harbor, Cypress Island, Washington	NOS	TWC1167	48.5833333333329946	-122.700000000000003	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:48:00	\N	0.92000000000000004	00:36:00	\N	0.979999999999999982	\N	\N	Eagle Harbor, Cypress Island	WA
59076	Chuckanut Bay, Bellingham Bay, Washington	NOS	TWC1169	48.6666666666670054	-122.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:53:00	-0.100000000000000006	\N	00:33:00	0	\N	\N	\N	Chuckanut Bay	WA
59077	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.716666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:51:00	0	\N	00:56:00	0.100000000000000006	\N	\N	\N	Point Migley	WA
59078	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.8333333333329946	-122.716666666669951	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	01:20:00	0	\N	00:49:00	0.5	\N	\N	\N	Ferndale	WA
59079	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.9166666666670054	-133.400000000000006	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:12:00	0	\N	-00:16:00	1.10000000000000009	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
59080	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.466666666670079	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:15:00	-0.100000000000000006	\N	-00:19:00	0.800000000000000044	\N	\N	\N	Marble Island	AK
59081	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.066666666667011	-134.116666666670085	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56454	-00:07:00	-0.100000000000000006	\N	-00:11:00	0.599999999999999978	\N	\N	\N	Port McArthur, Kuiu Island	AK
59082	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.6666666666670054	-132.633333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:05:00	0	\N	-00:09:00	-0.200000000000000011	\N	\N	\N	Ideal Cove, Mitkof Island	AK
59083	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.8833333333329918	-132.800000000000011	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:10:00	-0.100000000000000006	\N	-00:14:00	-0.299999999999999989	\N	\N	\N	Brown Cove	AK
59084	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.316666666670073	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:15:00	0	\N	-00:19:00	-0.699999999999999956	\N	\N	\N	Portage Bay, Kupreanof Island	AK
59085	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.1666666666670054	-134.283333333329921	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:19:00	-0.100000000000000006	\N	-00:19:00	-1.89999999999999991	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
59086	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.2999999999999972	-133.466666666670079	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:17:00	-0.100000000000000006	\N	-00:21:00	-0.800000000000000044	\N	\N	\N	Port Houghton, Robert Islands	AK
59087	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.8666666666670082	-134.266666666670091	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	00:18:00	0	\N	00:14:00	-0.200000000000000011	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
59088	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.9666666666670096	-133.883333333329915	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56462	-00:06:00	-0.100000000000000006	\N	-00:12:00	-0.400000000000000022	\N	\N	\N	Port Snettisham, Point Styleman	AK
59089	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.5333333333329904	-147.316666666670073	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:04:00	-0.100000000000000006	\N	-00:05:00	-0.800000000000000044	\N	\N	\N	Smith Island	AK
59090	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.7333333333329932	-146.650000000000006	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:06:00	0	\N	-00:07:00	-0.599999999999999978	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
59091	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.0166666666670068	-151.716666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:54:00	0.200000000000000011	\N	00:41:00	1.19999999999999996	\N	\N	\N	Cape Ninilchik	AK
59092	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.5499999999999972	-151.283333333329921	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	02:18:00	0.5	\N	01:52:00	2.70000000000000018	\N	\N	\N	Kenai River entrance	AK
59093	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.7166666666670096	-151.416666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
59094	Three Star Point, Alaska	NOS	TWC2105	55.8999999999999986	-159.166666666670068	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:37:00	\N	1.28000000000000003	00:28:00	\N	0.900000000000000022	\N	\N	Three Star Point	AK
59095	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.6333333333329918	-159.616666666670085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:33:00	\N	1.18999999999999995	00:18:00	\N	0.859999999999999987	\N	\N	Fox Bay, Kupreanof Peninsula	AK
59096	Korovin Island (east side), Alaska	NOS	TWC2115	55.3999999999999986	-160.150000000000006	:America/Anchorage	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:49:00	\N	1.28000000000000003	00:22:00	\N	0.890000000000000013	\N	\N	Korovin Island (east side)	AK
59097	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.1333333333329918	-159.849999999999994	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	-00:01:00	\N	0.900000000000000022	00:01:00	\N	0.969999999999999973	\N	\N	Mist Harbor, Nagai Island	AK
59098	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.466666666670079	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56535	00:08:00	\N	0.900000000000000022	00:09:00	\N	0.979999999999999982	\N	\N	Settlement Point, Pavlof Bay	AK
59099	Canoe Bay, Pavlof Bay, Alaska	NOS	TWC2139	55.5833333333329946	-161.266666666670091	:America/Anchorage	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	01:27:00	\N	1.10000000000000009	01:32:00	\N	0.739999999999999991	\N	\N	Canoe Bay, Pavlof Bay	AK
59100	Morzhovoi Bay, Alaska	NOS	TWC2147	55.0166666666670068	-162.966666666670079	:America/Nome	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:40:00	\N	1.18999999999999995	00:46:00	\N	0.760000000000000009	\N	\N	Morzhovoi Bay	AK
59102	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.9833333333329932	-166.166666666670068	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-01:05:00	\N	0.930000000000000049	-00:18:00	\N	0.849999999999999978	\N	\N	Malga Bay, Unalga Island	AK
59103	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.4666666666670096	-167.083333333329932	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:24:00	\N	1.18999999999999995	-00:08:00	\N	1.08000000000000007	\N	\N	Kashega Bay	AK
59104	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.4833333333329932	-166.933333333329927	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-03:16:00	\N	1.02000000000000002	-02:56:00	\N	1.45999999999999996	\N	\N	Eagle Bay	AK
59105	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.5166666666670068	-171.233333333329909	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-02:03:00	\N	1.10000000000000009	-01:32:00	\N	0.939999999999999947	\N	\N	Amukta Island, north side	AK
59106	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.800000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
59107	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.4166666666670054	179.283333333329921	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:06:00	\N	0.760000000000000009	00:19:00	\N	0.760000000000000009	\N	\N	Constantine Harbor, Amchitka Island	AK
59108	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.933333333332989	177.449999999999989	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:19:00	\N	0.859999999999999987	00:02:00	\N	0.859999999999999987	\N	\N	Gertrude Cove, Kiska Island	AK
59109	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.9833333333329932	177.550000000000011	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56541	-00:13:00	\N	0.969999999999999973	00:24:00	\N	0.969999999999999973	\N	\N	Kiska Harbor, Kiska Island	AK
59110	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.1999999999999993	145.716666666670079	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55626	00:07:00	\N	0.800000000000000044	00:02:00	\N	0.800000000000000044	\N	\N	Saipan Harbor, Saipan Island	MP
59111	Tinian Island, Marianas	NOS	TPT2625	14.9666666666670078	145.616666666670085	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55626	-00:23:00	\N	0.330000000000000016	-00:02:00	\N	0.739999999999999991	\N	\N	Tinian Island	MP
59112	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.449999999999989	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55626	-00:13:00	\N	1.33000000000000007	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
59113	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.63333333333330444	149.416666666670068	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:43:00	\N	0.739999999999999991	-00:53:00	\N	0.739999999999999991	\N	\N	Pulap Atoll	FM
59114	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.58333333333329662	149.650000000000006	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:21:00	\N	0.689999999999999947	-01:23:00	\N	0.689999999999999947	\N	\N	Namonuito Atoll	FM
59115	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45000000000000018	151.849999999999994	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:11:00	\N	0.849999999999999978	00:10:00	\N	0.849999999999999978	\N	\N	Moen Island, Truk Islands	FM
59116	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.36666666666670444	151.883333333329915	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:30:00	\N	1.07000000000000006	00:02:00	\N	1.07000000000000006	\N	\N	Dublon Island, Truk Islands	FM
59117	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.44999999999999929	151.783333333329921	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:20:00	\N	0.800000000000000044	-00:08:00	\N	0.800000000000000044	\N	\N	Nomwin Atoll, Hall Islands	FM
59118	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.59999999999999964	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:00:00	\N	0.849999999999999978	-00:28:00	\N	0.849999999999999978	\N	\N	Murilo Atoll, Hall Islands	FM
59119	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.90000000000000036	152.733333333329909	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:25:00	\N	0.800000000000000044	-00:03:00	\N	0.800000000000000044	\N	\N	Losap Atoll	FM
59120	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.90000000000000036	153.133333333329915	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:27:00	\N	0.800000000000000044	-00:01:00	\N	0.800000000000000044	\N	\N	Namoluk Atoll	FM
59121	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.33333333333330373	153.733333333329909	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55631	00:25:00	\N	0.959999999999999964	-00:03:00	\N	0.959999999999999964	\N	\N	Satawan Anchorage, Nomoi Islands	FM
59122	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.5999999999999996	165.550000000000011	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
59123	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.333333333329932	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:16:00	\N	0.849999999999999978	-00:15:00	\N	0.849999999999999978	\N	\N	Eniirikku Island, Bikini Atoll	MH
59124	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.1500000000000004	166.900000000000006	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:07:00	\N	0.959999999999999964	-00:07:00	\N	0.959999999999999964	\N	\N	Rongelap Island, Rongelap Atoll	MH
59125	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.3833333333330078	167.516666666670091	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:15:00	0	\N	-00:14:00	0.100000000000000006	\N	\N	\N	Rongerik Atoll	MH
59126	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.03333333333329591	165.599999999999994	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
59127	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.40000000000000036	167.483333333329909	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
59128	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.28333333333330391	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	00:07:00	0.299999999999999989	\N	00:08:00	0.400000000000000022	\N	\N	\N	Ailinglapalap Atoll	MH
59129	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.91666666666669627	169.650000000000006	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:08:00	-0.100000000000000006	\N	-00:12:00	-0.100000000000000006	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
59130	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.59999999999999964	168.683333333329927	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:10:00	0.100000000000000006	\N	-00:10:00	0.100000000000000006	\N	\N	\N	Ebon (Boston) Atoll	MH
59131	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.5666666666670075	168.949999999999989	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
59132	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.133333333329915	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
59136	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.19999999999999929	169.916666666670068	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
59137	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.71666666666670409	171.233333333329909	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.100000000000000006	\N	\N	\N	Maloelap Atoll	MH
59138	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.11666666666670444	171.366666666670085	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:06:00	0.100000000000000006	\N	-00:05:00	0.299999999999999989	\N	\N	\N	Majuro Atoll	MH
59139	Arno Atoll, Marshall Islands	NOS	TPT2723	7.13333333333330444	171.699999999999989	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	-00:05:00	-0.100000000000000006	\N	-00:04:00	0.599999999999999978	\N	\N	\N	Arno Atoll	MH
59140	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.23333333333329609	171.800000000000011	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55630	00:04:00	0	\N	00:04:00	0.699999999999999956	\N	\N	\N	Port Rhin, Mili Atoll	MH
59141	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.849999999999994	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55619	-00:04:00	\N	1	-00:22:00	\N	1.12999999999999989	\N	\N	Waikane, Kaneohe Bay	HI
59142	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.6499999999999986	-157.933333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55619	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
59143	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.5166666666670068	-156.683333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	00:03:00	0	\N	-00:15:00	0.200000000000000011	\N	\N	\N	Smuggler Cove	HI
59144	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.7833333333329904	-156.466666666670079	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55621	01:19:00	\N	0.540000000000000036	01:52:00	\N	0.939999999999999947	\N	\N	Kihei, Maalaea Bay	HI
59145	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.8833333333329918	-156.683333333329927	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55621	01:01:00	\N	0.810000000000000053	01:18:00	\N	0.890000000000000013	\N	\N	Lahaina	HI
59146	Palmyra Island	NOS	TPT2739	5.88333333333330444	-162.083333333329932	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	01:13:00	-0.200000000000000011	\N	01:19:00	0.599999999999999978	\N	\N	\N	Palmyra Island	\N
59147	Howland Island	NOS	TPT2737	0.800000000000000044	-176.633333333329915	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55616	03:46:00	0.400000000000000022	\N	03:48:00	4.20000000000000018	\N	\N	\N	Howland Island	\N
59148	Newbold, Delaware River, Pennsylvania (sub)	NOS	8548989	40.1373000000000033	-74.7519000000000062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	01:31:00	\N	1	01:10:00	\N	1.30000000000000004	\N	\N	Newbold, Pa.	PA
59149	Anchor Point, Cook Inlet, Alaska (sub)	NOS	9455606	59.7719722222222316	-151.867027777777793	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	00:21:00	0	\N	00:29:00	0.400000000000000022	\N	\N	\N	Anchor Point	AK
59150	Sabine Pass (north), Texas (sub)	NOS	8770570	29.7284000000000006	-93.8700999999999937	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-00:38:00	\N	1.1399999999999999	-01:18:00	\N	1.1399999999999999	\N	\N	Sabine Pass	TX
59151	Kawaihae, Hawaii Island, Hawaii (sub)	NOS	1617433	20.0366	-155.829399999999993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55623	00:57:00	\N	0.599999999999999978	01:01:00	\N	0.82999999999999996	\N	\N	Kawaihae	HI
59152	Plum Island Sound (south end), Massachusetts (sub)	NOS	8441241	42.710138888888892	-70.7886111111111092	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:37:00	\N	0.939999999999999947	00:12:00	\N	0.939999999999999947	\N	\N	Plum Island Sound (south end)	MA
59153	La Push, Quillayute River, Washington (sub)	NOS	9442396	47.9132999999999996	-124.637	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56371	-00:34:00	\N	0.939999999999999947	-00:39:00	\N	0.910000000000000031	\N	\N	La Push, Quillayute River	WA
59154	Provincetown, Cape Cod, Massachusetts (sub)	NOS	8446121	42.0495916666666574	-70.1821583333333336	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55680	00:18:00	\N	0.949999999999999956	00:16:00	\N	0.949999999999999956	\N	\N	Provincetown	MA
59155	Bristol Ferry, Narragansett Bay, Rhode Island (sub)	NOS	8451552	41.6366999999999976	-71.2549999999999955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:00:00	\N	1.1399999999999999	00:15:00	\N	1.16999999999999993	\N	\N	Bristol Ferry	RI
59156	Hatteras (USCG Station), North Carolina (sub)	NOS	8654467	35.2086388888888919	-75.7041666666666657	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	-00:13:00	\N	1.66999999999999993	-00:15:00	\N	1.1399999999999999	\N	\N	Hatteras (ocean)	NC
59157	Tin City, Bering Sea, Alaska (sub)	NOS	9469439	65.5583333333333371	-167.974999999999994	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56588	06:14:00	\N	0.320000000000000007	07:30:00	\N	0.609999999999999987	\N	\N	Tin City	AK
59158	Friday Harbor, San Juan Island, San Juan Channel, Washington (sub)	NOS	9449880	48.5453055555555579	-123.012888888888895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56381	00:51:00	\N	0.92000000000000004	00:33:00	\N	0.910000000000000031	\N	\N	Friday Harbor, San Juan Island	WA
59159	Alitak, Lazy Bay, Alaska (sub)	NOS	9457804	56.8973999999999975	-154.24799999999999	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56512	00:19:00	\N	1.41999999999999993	00:02:00	\N	1.37999999999999989	\N	\N	Alitak, Lazy Bay	AK
59160	Bay Waveland Yacht Club, Bay St. Louis, Mississippi (sub)	NOS	8747437	30.3249999999999993	-89.3250000000000028	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	02:57:00	\N	1.3600000000000001	03:17:00	\N	1.3600000000000001	\N	\N	St. Louis Bay entrance	MS
59161	Wells, Webhannet River, Maine (sub)	NOS	8419317	43.3200000000000003	-70.5633055555555586	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:02:00	\N	0.969999999999999973	00:06:00	\N	0.959999999999999964	\N	\N	Wells, Webhannet River	ME
59162	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.7166666666666686	174.066666666666691	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	-00:03:00	\N	1.03000000000000003	00:00:00	\N	1.03000000000000003	\N	\N	Alcan Harbor, Shemya Island	AK
59163	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.3666666666666671	173.616666666666703	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	-00:13:00	\N	1.03000000000000003	-00:14:00	\N	1.03000000000000003	\N	\N	Otkriti Bay, Agattu Island	AK
59164	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.9166666666666572	173.216666666666697	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	00:16:00	\N	1.09000000000000008	00:13:00	\N	1.09000000000000008	\N	\N	Chichagof Harbor	AK
59165	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.9166666666666572	173.166666666666714	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	00:18:00	\N	1.12000000000000011	-00:04:00	\N	1.12000000000000011	\N	\N	Holtz Bay	AK
59166	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.9666666666666686	172.900000000000006	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	00:11:00	\N	1.12000000000000011	-00:13:00	\N	1.12000000000000011	\N	\N	Steller Cove	AK
59167	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.9166666666666572	172.616666666666703	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56540	00:03:00	\N	1.12000000000000011	-00:17:00	\N	1.12000000000000011	\N	\N	Etienne Bay	AK
59168	Troy, Hudson River, New York	NOS	TEC1603	42.7166666666666686	-73.7000000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55802	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
59169	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.2166666666666686	-122.366666666666703	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56390	02:14:00	\N	0.28999999999999998	00:23:00	\N	0.619999999999999996	\N	\N	Stanwood, Stillaguamish River	WA
59170	Yorktown USCG Training Center, York River, Virginia (sub)	NOS	8637689	37.2265000000000015	-76.4788000000000068	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:15:00	\N	1.08000000000000007	00:10:00	\N	0.949999999999999956	\N	\N	Yorktown, USCG Training Center	VA
59171	Chevron Oil Company Pier, Richmond, San Francisco Bay, California (sub)	NOS	9414863	37.9230000000000018	-122.409583333333302	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:38:00	\N	0.979999999999999982	00:24:00	\N	1.04000000000000004	\N	\N	Chevron Oil Company Pier, Richmond	CA
59172	Port Isabel, Laguna Madre, Texas (sub)	NOS	8779770	26.0611666666666686	-97.2155277777777798	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56270	00:26:00	\N	1	00:10:00	\N	0.92000000000000004	\N	\N	Port Isabel	TX
59173	Clarendon Plantation, South Carolina (sub)	NOS	8667633	32.5024999999999977	-80.7840999999999951	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	01:25:00	\N	0.770000000000000018	01:37:00	\N	1.14999999999999991	\N	\N	Corning Landing, Whale Branch	SC
59174	Rockdedundy River (Daymark 185), Georgia (sub)	NOS	8675761	31.3738611111111112	-81.333944444444441	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55967	00:41:00	\N	1.01000000000000001	00:29:00	\N	1	\N	\N	Rockdedundy River (Daymark 185)	GA
59175	Wachapreague, Wachapreague Channel, Virginia (sub)	NOS	8631044	37.6077777777777769	-75.6858333333333348	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55840	00:56:00	\N	1.06000000000000005	01:10:00	\N	1.18999999999999995	\N	\N	Wachapreague, Wachapreague Channel	VA
59176	CSX Rockport, Mckay Bay Entrance, Florida (sub)	NOS	8726667	27.9133333333333304	-82.4249999999999972	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:28:00	\N	1.26000000000000001	00:02:00	\N	1.18999999999999995	\N	\N	McKay Bay entrance	FL
59177	Panama City, St. Andrew Bay, Florida (sub)	NOS	8729108	30.1522777777777797	-85.6669444444444395	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:11:00	\N	1.65999999999999992	-00:57:00	\N	1.05000000000000004	\N	\N	Panama City	FL
59178	Redwood City, Wharf 5, San Francisco Bay, California (sub)	NOS	9414523	37.5067777777777778	-122.211527777777803	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:15:00	\N	1.05000000000000004	00:48:00	\N	1.44999999999999996	\N	\N	Redwood City, Wharf 5	CA
59179	Pagan Island, Marianas	NOS	TPT2621	18.1332999999999984	145.766660000000002	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55626	00:01:00	\N	0.939999999999999947	00:05:00	\N	0.939999999999999947	\N	\N	Pagan Island	MP
59180	Rota Island, Marianas	NOS	TPT2627	14.1333000000000002	145.133299999999991	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55626	-00:06:00	\N	0.939999999999999947	-00:03:00	\N	0.939999999999999947	\N	\N	Rota Island	MP
59181	Cutler (Farris Wharf), Little River, Maine (sub)	NOS	8411060	44.6570281982421875	-67.2046661376953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55633	-00:19:00	\N	0.739999999999999991	-00:10:00	\N	0.739999999999999991	\N	\N	Cutler, Little River	ME
59182	Wrightsville Beach, North Carolina (sub)	NOS	8658163	34.2133055555555572	-77.7866944444444499	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55925	00:23:00	\N	1.25	00:18:00	\N	1.27000000000000002	\N	\N	Wrightsville Beach	NC
59183	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York (sub)	NOS	8512769	40.8185555555555624	-72.586611111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55806	01:45:00	\N	0.550000000000000044	01:01:00	\N	0.550000000000000044	\N	\N	Shinnecock Yacht Club, Penniman Creek	NY
59184	Santa Barbara, California (sub)	NOS	9411340	34.4031111111111088	-119.692805555555594	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56279	00:21:00	\N	1.04000000000000004	00:23:00	\N	0.979999999999999982	\N	\N	Santa Barbara	CA
59185	Coyote Creek, Alviso Slough, San Francisco Bay, California (sub)	NOS	9414575	37.4650000000000034	-122.022999999999996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	01:49:00	\N	1.09000000000000008	00:59:00	\N	1.6100000000000001	\N	\N	Coyote Creek, Alviso Slough	CA
59186	Fort Point, Portsmouth Harbor, New Hampshire (sub)	NOS	8423898	43.0713882446289062	-70.7105560302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55658	00:07:00	\N	0.939999999999999947	00:03:00	\N	0.939999999999999947	\N	\N	Fort Point	NH
59187	Bolinas, Bolinas Lagoon, California (sub)	NOS	9414958	37.9077796936035156	-122.678611755371094	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	00:38:00	\N	0.609999999999999987	-00:10:00	\N	0.699999999999999956	\N	\N	Bolinas Lagoon	CA
59188	Cape May Canal, Cape May, Delaware Bay, New Jersey (sub)	NOS	8536110	38.9677777777777834	-74.9597222222222257	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55838	-00:05:00	\N	1	-00:06:00	\N	1.17999999999999994	\N	\N	Cape May, ferry terminal	NJ
59189	Alabama Point, Perdido Bay, Alabama	NOS	8730067	30.2666666666666693	-87.5499999999999972	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-01:24:00	\N	0.67000000000000004	-01:26:00	\N	0.67000000000000004	\N	\N	Alabama Point, Perdido Bay	AL
59190	Port Saint Joe, St. Joseph Bay, Florida (sub)	NOS	8728912	29.8150000000000013	-85.3132999999999981	:America/New_York	USA	feet	\N	\N	\N	Reference is in time zone :America/Chicago; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56137	-02:45:00	\N	1.1100000000000001	-02:06:00	\N	1.1100000000000001	\N	\N	Port Saint Joe, St. Joseph Bay	FL
59191	New Canal USCG station, Lake Pontchartrain, Louisiana (sub)	NOS	8761927	30.0272222222222211	-90.1133333333333297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56186	12:09:00	\N	0.429999999999999993	11:47:00	\N	0.429999999999999993	\N	\N	New Canal USCG station, Lake Pontchartrain	LA
59192	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.2166666666666703	-169.533333333333303	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55629	-00:24:00	\N	1	-00:25:00	\N	1.42999999999999994	\N	\N	Tau Island, Manua Islands	AS
59193	Barbours Cut, Morgans Point, Galveston Bay, Texas (sub)	NOS	8770613	29.6816944444444495	-94.9849999999999994	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	04:17:00	\N	0.400000000000000022	05:11:00	\N	0.949999999999999956	\N	\N	Morgans Point, Barbours Cut	TX
59194	Bridesburg, Philadelphia, Pennsylvania (sub)	NOS	8546252	39.9833333333333272	-75.0750000000000028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	00:15:00	\N	0.900000000000000022	00:12:00	\N	1.06000000000000005	\N	\N	Bridesburg, Philadelphia, Pa.	PA
59195	Fort Myers, Caloosahatchee River, Florida (sub)	NOS	8725520	26.6477000000000004	-81.8712000000000018	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	02:23:00	\N	0.390000000000000013	01:56:00	\N	0.560000000000000053	\N	\N	Fort Myers	FL
59196	Mayagez, Puerto Rico (sub)	NOS	9759394	18.2175555555555597	-67.1588333333333338	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56628	-00:11:00	\N	0.760000000000000009	-00:09:00	\N	0.930000000000000049	\N	\N	Mayaguez	PR
59197	Blackslough Landing, San Joaquin River, California (sub)	NOS	9415021	37.9946944444444412	-121.419044444444395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	04:15:00	\N	0.619999999999999996	04:00:00	\N	0.75	\N	\N	Blackslough Landing	CA
59198	Wards Island, Little Connection Slough, San Joaquin River, California (sub)	NOS	9415105	38.0500252777777774	-121.496855555555598	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56319	03:51:00	\N	0.609999999999999987	03:45:00	\N	0.680000000000000049	\N	\N	Wards Island, Little Connection Slough	CA
59199	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.1153055555555582	-122.505666666666698	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56291	02:08:00	\N	0.859999999999999987	01:23:00	\N	1.06000000000000005	\N	\N	Petaluma River entrance	CA
59200	Seward, Resurrection Bay, Alaska (sub)	NOS	9455090	60.1199999999999974	-149.426666699999998	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56473	-00:13:00	\N	0.910000000000000031	-00:06:00	\N	0.82999999999999996	\N	\N	Seward, Resurrection Bay	AK
59201	Providence, State Pier no.1, Narragansett Bay, Rhode Island (sub)	NOS	8454000	41.806666700000001	-71.4005556000000041	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:00:00	\N	1.29000000000000004	00:13:00	\N	1.27000000000000002	\N	\N	Providence, State Pier no.1	RI
59202	Lake Worth Pier, Florida (sub)	NOS	8722670	26.6127777999999999	-80.0341667000000001	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56045	-00:19:00	\N	1	-00:45:00	\N	1.15999999999999992	\N	\N	Lake Worth Pier (ocean)	FL
59203	Port Tampa, Old Tampa Bay, Florida (sub)	NOS	8726607	27.8577778000000009	-82.5527778000000012	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	00:39:00	\N	1.17999999999999994	00:25:00	\N	1.10000000000000009	\N	\N	Old Port Tampa	FL
59204	Port Manatee, Tampa Bay, Florida (sub)	NOS	8726384	27.6383332999999993	-82.5625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56089	-00:48:00	\N	0.949999999999999956	-01:00:00	\N	0.969999999999999973	\N	\N	Port Manatee	FL
59205	Marcus Hook, Pennsylvania (sub)	NOS	8540433	39.8116667000000035	-75.4094443999999982	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55830	-01:07:00	\N	0.949999999999999956	-01:23:00	\N	0.92000000000000004	\N	\N	Marcus Hook, Pa.	PA
59206	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.1074722222222206	-152.581666666666706	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56494	01:15:00	0	\N	01:04:00	-2.29999999999999982	\N	\N	\N	Snug Harbor, Cook Inlet	AK
59207	Reedsport, Umpqua River, Oregon	NOS	9433501	43.7049999999999983	-124.094999999999999	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56340	01:24:00	\N	0.800000000000000044	01:11:00	\N	0.880000000000000004	\N	\N	Reedsport	OR
59208	Eagle Point, Galveston Bay, Texas (sub)	NOS	8771013	29.4800000000000004	-94.9183055555555626	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	02:38:00	\N	0.800000000000000044	05:34:00	\N	0.800000000000000044	\N	\N	Eagle Point	TX
59209	Cambridge, Choptank River, Maryland (sub)	NOS	8571892	38.5741666999999993	-76.0722221999999988	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-02:28:00	\N	0.949999999999999956	-02:42:00	\N	1.22999999999999998	\N	\N	Cambridge	MD
59210	Solomons Island, Patuxent River, Maryland (sub)	NOS	8577330	38.3172222000000033	-76.4508332999999993	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55868	-04:46:00	\N	0.729999999999999982	-04:38:00	\N	0.979999999999999982	\N	\N	Solomons Island	MD
59211	Bishops Head, Hooper Strait, Maryland (sub)	NOS	8571421	38.2203888888888912	-76.0386666666666713	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55914	06:04:00	\N	1.08000000000000007	05:32:00	\N	0.699999999999999956	\N	\N	Bishops Head, Hooper Strait	MD
59212	Money Point, South Bridge, Elizabeth River, Virginia (sub)	NOS	8639348	36.778305555555562	-76.3016944444444505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55911	00:12:00	\N	1.16999999999999993	00:16:00	\N	1.17999999999999994	\N	\N	Money Point	VA
59213	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas (sub)	NOS	8770733	29.7648611111111094	-95.0788611111111095	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	04:51:00	\N	0.569999999999999951	04:55:00	\N	1.05000000000000004	\N	\N	Lynchburg Landing, San Jacinto River	TX
59214	Houston Ship Channel, Galveston Bay, Manchester, Texas (sub)	NOS	8770777	29.7262222222222192	-95.265777777777771	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	05:05:00	\N	0.82999999999999996	04:55:00	\N	1.14999999999999991	\N	\N	Manchester, Houston Ship Channel	TX
59215	Fall River, Narragansett Bay, Massachusetts (sub)	NOS	8447386	41.7043055555555569	-71.1641111111111115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	55716	00:03:00	\N	1.20999999999999996	00:18:00	\N	1.25	\N	\N	Fall River, Massachusetts	MA
58374	Bar at entrance, Yaquina Bay, Oregon	NOS	9435361	44.6167000000000016	-124.082999999999998	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56336	00:39:00	\N	1.08000000000000007	00:34:00	\N	1.1399999999999999	\N	\N	Bar at entrance	OR
58977	Calcasieu Pass, Lighthouse Wharf, Louisiana	NOS	TEC4497	29.7833333333329904	-93.3499999999999943	:America/Chicago	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56242	-01:24:00	\N	1.42999999999999994	-02:14:00	\N	1.42999999999999994	\N	\N	Calcasieu Pass, Lighthouse wharf	LA
59101	Akun Bay, Akun Island, Alaska	NOS	TWC2171	54.2333333333329932	-165.533333333329921	:America/Nome	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56544	-00:34:00	\N	0.930000000000000049	-00:02:00	\N	0.790000000000000036	\N	\N	1262 Bay, 1262 Island	AK
59216	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.2266699999999986	-69.9833299999999952	:America/New_York	USA	knots	225	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:14:00	\N	0.900000000000000022	01:03:00	\N	0.900000000000000022	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
59217	Miacomet Pond, 3.0 miles SSE of, Massachusetts Current	NOS	ACT1596_1	41.1899999999999977	-70.0966700000000031	:America/New_York	USA	knots	280	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:16:00	\N	0.800000000000000044	02:03:00	\N	0.599999999999999978	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
59218	Tuckernuck Island, 4.2 miles SSW of, Massachusetts Current	NOS	ACT1601_1	41.2261700000000033	-70.2816700000000054	:America/New_York	USA	knots	280	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:56:00	\N	0.599999999999999978	03:13:00	\N	0.299999999999999989	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
59219	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.5649999999999977	-69.9233300000000071	:America/New_York	USA	knots	212	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:38:00	\N	1.10000000000000009	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
59220	Monomoy Pt., channel 0.2 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.5499999999999972	-70.0216700000000003	:America/New_York	USA	knots	346	170	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:23:00	\N	1.19999999999999996	00:39:00	\N	0.800000000000000044	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
59221	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.6566699999999983	-69.9749999999999943	:America/New_York	USA	knots	144	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:28:00	\N	0.599999999999999978	01:29:00	\N	0.299999999999999989	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
59222	Dennis Port, 2.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.6166699999999992	-70.1149999999999949	:America/New_York	USA	knots	269	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:04:00	\N	0.200000000000000011	00:52:00	\N	0.200000000000000011	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
59223	Monomoy Point, 6 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.558329999999998	-70.1500000000000057	:America/New_York	USA	knots	275	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:22:00	\N	0.299999999999999989	01:52:00	\N	0.200000000000000011	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
59224	Handkerchief Lighted Whistle Buoy 'H', Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.4883299999999977	-70.066670000000002	:America/New_York	USA	knots	251	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:59:00	\N	0.800000000000000044	01:10:00	\N	0.599999999999999978	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
59225	Halfmoon Shoal, 1.9 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.4841699999999989	-70.1924999999999955	:America/New_York	USA	knots	265	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:44:00	\N	0.299999999999999989	01:49:00	\N	0.400000000000000022	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
59226	Halfmoon Shoal, 3.5 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.4683300000000017	-70.1533299999999969	:America/New_York	USA	knots	295	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:11:00	\N	0.599999999999999978	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
59227	Great Point, 0.5 mile west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.3933299999999988	-70.0616700000000066	:America/New_York	USA	knots	195	29	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:33:00	\N	0.699999999999999956	01:37:00	\N	0.599999999999999978	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
59228	Great Point, 3 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.3900000000000006	-70.1133300000000048	:America/New_York	USA	knots	248	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:08:00	\N	0.5	01:23:00	\N	0.400000000000000022	01:15:00	00:51:00	Great Point, 3 miles west of	MA
59229	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.4050000000000011	-70.1733300000000071	:America/New_York	USA	knots	287	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
59230	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.3066699999999969	-70.0999999999999943	:America/New_York	USA	knots	350	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:58:00	\N	0.900000000000000022	01:55:00	\N	0.599999999999999978	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
59231	Eel Pt., Nantucket I. 2.5 miles NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.3216699999999975	-70.1700000000000017	:America/New_York	USA	knots	284	94	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:15:00	\N	0.200000000000000011	01:12:00	\N	0.299999999999999989	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
59232	Muskeget I., channel 1 mile northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.3500000000000014	-70.2849999999999966	:America/New_York	USA	knots	295	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:56:00	\N	0.900000000000000022	00:45:00	\N	0.599999999999999978	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
59233	Muskeget Rock, 1.3 miles southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.3200000000000003	-70.393330000000006	:America/New_York	USA	knots	192	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:18:00	\N	0.599999999999999978	00:23:00	\N	0.599999999999999978	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
59234	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.3483299999999971	-70.4200000000000017	:America/New_York	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	1.89999999999999991	00:38:00	\N	1.89999999999999991	01:40:00	01:29:00	Muskeget Channel	MA
59235	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.4083299999999994	-70.3333300000000037	:America/New_York	USA	knots	260	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:13:00	\N	0.599999999999999978	01:12:00	\N	0.699999999999999956	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
59236	Cape Poge Lt., 1.7 miles SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.3999999999999986	-70.4266700000000014	:America/New_York	USA	knots	215	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	00:48:00	\N	0.699999999999999956	-00:07:00	\N	0.800000000000000044	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
59237	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.4483299999999986	-70.2916699999999963	:America/New_York	USA	knots	272	91	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:59:00	\N	0.5	01:48:00	\N	0.599999999999999978	01:48:00	01:55:00	Cross Rip Channel	MA
59238	Cape Poge Lt., 3.2 miles northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.4583299999999966	-70.4000000000000057	:America/New_York	USA	knots	300	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:37:00	\N	0.699999999999999956	02:03:00	\N	0.800000000000000044	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
59239	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.5499999999999972	-70.2849999999999966	:America/New_York	USA	knots	276	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
59240	Point Gammon, 1.2 miles south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.5883299999999991	-70.2566699999999997	:America/New_York	USA	knots	260	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:02:00	\N	0.599999999999999978	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
59241	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.6316699999999997	-70.2733300000000014	:America/New_York	USA	knots	184	4	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:22:00	\N	0.800000000000000044	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
59242	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.6099999999999994	-70.4300000000000068	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	03:35:00	\N	0.400000000000000022	02:33:00	\N	0.299999999999999989	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
59243	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.5333299999999994	-70.4283300000000025	:America/New_York	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:45:00	\N	0.800000000000000044	01:32:00	\N	0.800000000000000044	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
59244	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.4716700000000031	-70.4833299999999952	:America/New_York	USA	knots	268	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:44:00	\N	0.699999999999999956	02:34:00	\N	0.699999999999999956	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
59245	Cape Poge Light, 1.4 miles west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.4241699999999966	-70.4833299999999952	:America/New_York	USA	knots	250	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:39:00	\N	0.100000000000000006	01:54:00	\N	0.200000000000000011	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
59246	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.4650000000000034	-70.5366700000000009	:America/New_York	USA	knots	329	131	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:04:00	\N	1.10000000000000009	00:55:00	\N	0.699999999999999956	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
59247	East Chop, 1 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.4849999999999994	-70.558329999999998	:America/New_York	USA	knots	297	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.30000000000000004	01:52:00	\N	1.10000000000000009	02:40:00	02:17:00	East Chop, 1 mile north of	MA
59248	West Chop, 0.8 mile north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.4933300000000003	-70.5949999999999989	:America/New_York	USA	knots	282	96	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:35:00	\N	1.80000000000000004	01:58:00	\N	1.60000000000000009	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
59249	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.5050000000000026	-70.5366700000000009	:America/New_York	USA	knots	276	106	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:52:00	\N	1.30000000000000004	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
59250	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.5300000000000011	:America/New_York	USA	knots	203	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	04:01:00	\N	0.800000000000000044	02:14:00	\N	0.800000000000000044	03:21:00	03:40:00	Waquoit Bay entrance	MA
59251	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.5266700000000029	-70.5766699999999929	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	1.39999999999999991	02:03:00	\N	1.19999999999999996	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
59252	Nobska Point, 1.8 miles east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.5183299999999988	-70.6183300000000003	:America/New_York	USA	knots	240	63	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:49:00	\N	1	01:45:00	\N	1.19999999999999996	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
59253	West Chop, 0.2 mile west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.4833300000000023	-70.6099999999999994	:America/New_York	USA	knots	241	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	0.800000000000000044	01:34:00	\N	1.30000000000000004	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
59254	Nobska Point, 1 mile southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.5016699999999972	-70.643330000000006	:America/New_York	USA	knots	259	71	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:19:00	\N	1.39999999999999991	02:15:00	\N	1.30000000000000004	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
59255	Norton Point, 0.5 mile north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.4683300000000017	-70.6650000000000063	:America/New_York	USA	knots	240	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:12:00	\N	1.39999999999999991	01:44:00	\N	1.69999999999999996	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
59256	Tarpaulin Cove, 1.5 miles east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.4716700000000031	-70.7249999999999943	:America/New_York	USA	knots	232	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:33:00	\N	1.39999999999999991	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
59257	Robinsons Hole, 1.2 miles southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.4350000000000023	-70.7800000000000011	:America/New_York	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:02:00	\N	1.19999999999999996	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
59258	Gay Head, 3 miles northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.384999999999998	-70.7833300000000065	:America/New_York	USA	knots	238	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	02:11:00	\N	0.800000000000000044	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
59259	Gay Head, 3 miles north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.4016700000000029	-70.8533299999999997	:America/New_York	USA	knots	255	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:17:00	\N	0.699999999999999956	01:24:00	\N	0.599999999999999978	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
59260	Gay Head, 1.5 miles northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.3633299999999977	-70.8633300000000048	:America/New_York	USA	knots	249	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	01:16:00	\N	1.19999999999999996	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
59261	Black Point, SW of, Sakonnet River (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.5066699999999997	-71.2199999999999989	:America/New_York	USA	knots	194	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:26:00	\N	0.200000000000000011	-01:55:00	\N	0.200000000000000011	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
59262	Almy Point Bridge, south of, Sakonnet River (Depth 15ft), Rhode Island Current	NOS	ACT2076_1	41.6216700000000017	-71.2199999999999989	:America/New_York	USA	knots	180	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-03:13:00	\N	0.800000000000000044	-02:10:00	\N	0.200000000000000011	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
59263	Brenton Point, 1.4 n.mi. southwest of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.4316699999999969	-71.3766700000000043	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.400000000000000022	-00:38:00	\N	0.200000000000000011	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
59264	Castle Hill, west of, East Passage (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.4566700000000026	-71.3783300000000054	:America/New_York	USA	knots	237	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:29:00	\N	0.699999999999999956	-00:42:00	\N	0.400000000000000022	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
59265	Bull Point, east of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.4799999999999969	-71.3499999999999943	:America/New_York	USA	knots	206	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:33:00	\N	0.800000000000000044	-00:47:00	\N	0.599999999999999978	-01:10:00	-01:10:00	Bull Point, east of	RI
59266	Rose Island, northeast of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.5033299999999983	-71.3316700000000026	:America/New_York	USA	knots	124	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:08:00	\N	0.5	-00:07:00	\N	0.400000000000000022	-01:57:00	-01:17:00	Rose Island, northeast of	RI
59267	Rose Island, northwest of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.5066699999999997	-71.3516699999999986	:America/New_York	USA	knots	190	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:39:00	\N	0.5	-00:26:00	\N	0.400000000000000022	-01:38:00	-01:38:00	Rose Island, northwest of	RI
59268	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.4966700000000017	-71.3499999999999943	:America/New_York	USA	knots	172	1	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:28:00	\N	0.599999999999999978	-00:34:00	\N	0.400000000000000022	-00:42:00	-01:20:00	Rose Island, west of	RI
59269	Gould Island, southeast of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.5249999999999986	-71.336669999999998	:America/New_York	USA	knots	217	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.400000000000000022	-01:28:00	\N	0.299999999999999989	-01:40:00	-01:14:00	Gould Island, southeast of	RI
59270	Gould Island, west of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.5316699999999983	-71.3583299999999952	:America/New_York	USA	knots	193	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:07:00	\N	0.400000000000000022	-00:32:00	\N	0.299999999999999989	-00:16:00	-01:13:00	Gould Island, west of	RI
59271	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.5750000000000028	-71.296670000000006	:America/New_York	USA	knots	236	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:37:00	\N	0.400000000000000022	-01:13:00	\N	0.400000000000000022	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
59272	Conanicut Point, ENE of (Depth 15ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.5750000000000028	-71.3416699999999935	:America/New_York	USA	knots	183	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.200000000000000011	-00:24:00	\N	0.200000000000000011	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
59273	Dyer Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.586669999999998	-71.308329999999998	:America/New_York	USA	knots	216	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:34:00	\N	0.599999999999999978	-00:46:00	\N	0.400000000000000022	-01:04:00	-00:53:00	Dyer Island, west of	RI
59274	Mount Hope Bridge (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.6400000000000006	-71.2583300000000008	:America/New_York	USA	knots	230	47	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:58:00	\N	0.800000000000000044	-01:34:00	\N	0.599999999999999978	-01:22:00	-01:08:00	Mount Hope Bridge	RI
59275	Hog Island, northwest of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.6466700000000003	-71.2950000000000017	:America/New_York	USA	knots	199	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:04:00	\N	0.200000000000000011	-00:04:00	\N	0.200000000000000011	-02:16:00	-00:30:00	Hog Island, northwest of	RI
59276	Common Fence Point, west of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.6499999999999986	-71.2450000000000045	:America/New_York	USA	knots	224	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:37:00	\N	0.400000000000000022	00:08:00	\N	0.200000000000000011	-01:13:00	-01:00:00	Common Fence Point, west of	RI
59277	Mount Hope Point, northeast of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.6799999999999997	-71.211669999999998	:America/New_York	USA	knots	217	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:57:00	\N	0.200000000000000011	-00:20:00	\N	0.200000000000000011	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
59278	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.7283299999999997	-71.288330000000002	:America/New_York	USA	knots	171	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
59279	Beavertail Point, 0.8 mile northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.4583299999999966	-71.4116700000000009	:America/New_York	USA	knots	188	3	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-00:19:00	\N	0.599999999999999978	-00:54:00	\N	0.299999999999999989	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
59280	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.4966700000000017	-71.4033299999999969	:America/New_York	USA	knots	233	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:47:00	\N	0.599999999999999978	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
59281	Dutch Island, west of (Depth 7ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.5050000000000026	-71.4099999999999966	:America/New_York	USA	knots	206	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:16:00	\N	0.699999999999999956	-01:49:00	\N	0.699999999999999956	-01:33:00	-01:21:00	Dutch Island, west of	RI
59282	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.6583299999999994	-71.3533299999999997	:America/New_York	USA	knots	157	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-02:37:00	\N	0.5	-02:29:00	\N	0.400000000000000022	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
59283	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.663330000000002	-71.3733299999999957	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:13:00	\N	0.5	-01:21:00	\N	0.299999999999999989	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
59284	Nayatt Point, WNW of (Depth 10ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.7283299999999997	-71.3599999999999994	:America/New_York	USA	knots	128	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16157	-01:11:00	\N	0.100000000000000006	00:47:00	\N	0.100000000000000006	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
59285	Cryders Point, 0.4 mile NNW of, East River, New York Current	NOS	ACT3341_1	40.8003300000000024	-73.7986700000000013	:America/New_York	USA	knots^2	285	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.200000000000000011	-00:43:00	\N	0.400000000000000022	-00:29:00	-00:30:00	Cryders Point, 0.4 mile NNW of	NY
59286	Bronx-Whitestone Bridge, East of (Depth 14ft), East River, New York Current	NOS	ACT3346_1	40.8016700000000014	-73.8266699999999929	:America/New_York	USA	knots^2	247	76	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:27:00	\N	0.200000000000000011	-00:46:00	\N	0.5	-00:34:00	-00:10:00	Bronx-Whitestone Bridge, East of	NY
59287	College Point Reef, 0.25 n.mi. NW of (Depth 15ft), East River, New York Current	NOS	ACT3356_1	40.8010000000000019	-73.8546699999999987	:America/New_York	USA	knots^2	261	74	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:00:00	\N	0.299999999999999989	-00:47:00	\N	0.400000000000000022	-00:27:00	-00:32:00	College Point Reef, 0.25 n.mi. NW of	NY
59288	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.7833299999999994	-73.8833300000000008	:America/New_York	USA	knots^2	261	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.299999999999999989	-00:04:00	\N	0.299999999999999989	00:04:00	00:04:00	Rikers I. chan., off La Guardia Field	NY
59289	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.7999999999999972	-73.8833300000000008	:America/New_York	USA	knots^2	280	108	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:05:00	\N	0.299999999999999989	-00:10:00	\N	0.5	00:01:00	00:01:00	Hunts Point, southwest of	NY
59290	South Brother Island, NW of (Depth 15ft), East River, New York Current	NOS	ACT3381_1	40.7966699999999989	-73.9016699999999958	:America/New_York	USA	knots^2	252	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:12:00	\N	0.299999999999999989	00:04:00	\N	0.400000000000000022	-00:17:00	-00:06:00	South Brother Island, NW of	NY
59291	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.7866700000000009	-73.9166699999999963	:America/New_York	USA	knots^2	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.5	00:02:00	\N	1	00:04:00	-00:01:00	Off Winthrop Ave., Astoria	NY
59292	Mill Rock, northeast of, East River, New York Current	NOS	ACT3391_1	40.7816699999999983	-73.9366700000000066	:America/New_York	USA	knots^2	288	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:32:00	\N	0.100000000000000006	00:05:00	\N	0.699999999999999956	-00:23:00	-00:29:00	Mill Rock, northeast of	NY
59293	Mill Rock, west of, East River, New York Current	NOS	ACT3396_1	40.7800000000000011	-73.941670000000002	:America/New_York	USA	knots^2	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:17:00	\N	0.200000000000000011	00:08:00	\N	0.400000000000000022	-00:26:00	-00:02:00	Mill Rock, west of	NY
59294	Roosevelt Island, west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.7666699999999977	-73.9500000000000028	:America/New_York	USA	knots^2	215	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	1	-00:04:00	\N	1.10000000000000009	-00:02:00	-00:08:00	west of, off 75th Street	NY
59295	Roosevelt Island, east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.7666699999999977	-73.9500000000000028	:America/New_York	USA	knots^2	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.699999999999999956	-00:04:00	\N	1	-00:08:00	-00:08:00	east of, off 36th Avenue	NY
59296	Roosevelt Island, west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.7623299999999986	-73.9539999999999935	:America/New_York	USA	knots^2	230	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:11:00	\N	0.900000000000000022	-00:08:00	\N	1.10000000000000009	00:13:00	00:06:00	west of, off 67th Street	NY
59297	Roosevelt Island, west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.7596699999999998	-73.9544999999999959	:America/New_York	USA	knots^2	223	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.599999999999999978	-00:08:00	\N	0.800000000000000044	-00:10:00	00:00:00	west of, off 63rd Street	NY
59298	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.7581699999999998	-73.9513299999999987	:America/New_York	USA	knots^2	200	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.599999999999999978	-00:06:00	\N	0.800000000000000044	00:00:00	00:02:00	east of	NY
59299	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.7396699999999967	-73.9694999999999965	:America/New_York	USA	knots^2	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:36:00	\N	0.5	-00:11:00	\N	0.400000000000000022	00:09:00	-00:02:00	Manhattan, off 31st Street	NY
59300	Pier 67, off 19th Street, East River, New York Current	NOS	ACT3441_1	40.7333300000000023	-73.9666699999999935	:America/New_York	USA	knots^2	179	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:07:00	\N	0.400000000000000022	00:08:00	\N	0.5	-00:08:00	-00:08:00	Pier 67, off 19th Street	NY
59301	Williamsburg Bridge, 0.3 mile north of, East River, New York Current	NOS	ACT3446_1	40.7180000000000035	-73.9706699999999984	:America/New_York	USA	knots^2	220	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:10:00	\N	0.599999999999999978	00:12:00	\N	0.800000000000000044	-00:05:00	-00:01:00	Williamsburg Bridge, 0.3 mile north of	NY
59302	Manhattan Bridge, East of (Depth 15ft), East River, New York Current	NOS	ACT3451_1	40.7083299999999966	-73.9899999999999949	:America/New_York	USA	knots^2	259	83	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:03:00	\N	0.5	00:19:00	\N	0.699999999999999956	-00:28:00	-00:13:00	Manhattan Bridge, East of	NY
59303	Brooklyn Bridge, 0.1 mile southwest of, East River, New York Current	NOS	ACT3461_1	40.7033300000000011	-74	:America/New_York	USA	knots^2	222	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:07:00	\N	0.800000000000000044	00:08:00	\N	0.900000000000000022	-00:18:00	-00:04:00	Brooklyn Bridge, 0.1 mile southwest of	NY
59304	East 107th Street (Depth 15ft), Harlem River, New York Current	NOS	ACT3476_1	40.7899999999999991	-73.9350000000000023	:America/New_York	USA	knots^2	30	206	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-01:39:00	\N	0.200000000000000011	-00:03:00	\N	0.200000000000000011	-00:08:00	-01:09:00	East 107th Street	NY
59305	Willis Ave. Bridge, 0.1 mile NW of, Harlem River, New York Current	NOS	ACT3481_1	40.8049999999999997	-73.9300000000000068	:America/New_York	USA	knots^2	330	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:13:00	\N	0.299999999999999989	00:00:00	\N	0.400000000000000022	-00:30:00	-00:12:00	Willis Ave. Bridge, 0.1 mile NW of	NY
59306	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.8133300000000006	-73.9350000000000023	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:14:00	\N	0.400000000000000022	00:18:00	\N	0.5	-00:20:00	-00:21:00	Madison Ave. Bridge	NY
59307	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.8283300000000011	-73.9350000000000023	:America/New_York	USA	knots^2	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:11:00	\N	0.299999999999999989	00:14:00	\N	0.5	-00:20:00	-00:22:00	Macombs Dam Bridge	NY
59308	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.8416700000000006	-73.9316699999999969	:America/New_York	USA	knots^2	15	189	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:08:00	\N	0.400000000000000022	00:08:00	\N	0.599999999999999978	-00:20:00	-00:23:00	High Bridge	NY
59309	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.8633299999999977	-73.9150000000000063	:America/New_York	USA	knots^2	35	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	-00:02:00	\N	0.400000000000000022	00:05:00	\N	0.599999999999999978	-00:22:00	-00:22:00	West 207th Street Bridge	NY
59310	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.8733300000000028	-73.9116700000000009	:America/New_York	USA	knots^2	299	116	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:04:00	\N	0.5	00:08:00	\N	0.599999999999999978	-00:23:00	-00:20:00	Broadway Bridge	NY
59311	Henry Hudson Bridge, 0.7 nmi. SE of (Depth 16ft), Harlem River, New York Current	NOS	ACT3511_1	40.8766699999999972	-73.921670000000006	:America/New_York	USA	knots^2	326	137	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16151	00:41:00	\N	0.299999999999999989	00:31:00	\N	0.200000000000000011	00:12:00	-00:31:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
59312	Bergen Point Reach (Bayonne Bridge) (Depth 29ft), Kill Van Kull, New York Current	NOS	ACT3951_2	40.6416699999999977	-74.143330000000006	:America/New_York	USA	knots	79	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16145	-00:04:00	\N	0.900000000000000022	00:02:00	\N	0.800000000000000044	-00:15:00	00:14:00	BERGEN POINT REACH (BAYONNE BRIDGE)	NY
59313	Cedar Point, 2.9 n.mi. ENE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.3108300000000028	-76.3133299999999934	:America/New_York	USA	knots	164	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:55:00	\N	0.800000000000000044	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
59314	Cedar Point, 2.9 n.mi. ENE of (Depth 50ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.3108300000000028	-76.3133299999999934	:America/New_York	USA	knots	141	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:15:00	\N	0.299999999999999989	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
59315	Cedar Point, 1.1 miles ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3044999999999973	-76.3516699999999986	:America/New_York	USA	knots	185	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.800000000000000044	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
59316	Cove Point, 1.1 n.mi. east of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.3813299999999984	-76.3603300000000047	:America/New_York	USA	knots	165	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:14:00	\N	0.900000000000000022	-02:42:00	\N	0.900000000000000022	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
59317	Cove Point, 1.1 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.3813299999999984	-76.3603300000000047	:America/New_York	USA	knots	165	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:26:00	\N	0.699999999999999956	-03:19:00	\N	0.800000000000000044	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
59318	Cove Point, 2.7 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	169	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.900000000000000022	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
59319	Cove Point, 2.7 n.mi. east of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	170	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:40:00	\N	0.599999999999999978	-02:39:00	\N	0.900000000000000022	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
59320	Cove Point, 2.7 n.mi. east of (Depth 98ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.3800000000000026	-76.3253299999999939	:America/New_York	USA	knots	165	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:36:00	\N	0.5	-04:02:00	\N	0.699999999999999956	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
59321	Cove Point, 3.9 n.mi. east of (Depth 11ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.3753299999999982	-76.2986700000000013	:America/New_York	USA	knots	171	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:44:00	\N	0.599999999999999978	-03:36:00	\N	0.400000000000000022	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
59322	Cove Point, 4.9 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	159	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.699999999999999956	-02:29:00	\N	0.699999999999999956	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
59323	Cove Point, 4.9 n.mi. NNE of (Depth 40ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	149	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.400000000000000022	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
59324	Cove Point, 4.9 n.mi. NNE of (Depth 67ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.467170000000003	-76.3766700000000043	:America/New_York	USA	knots	135	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:58:00	\N	0.400000000000000022	-03:38:00	\N	0.599999999999999978	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
59325	Kenwood Beach, 1.5 miles northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.5183299999999988	-76.481669999999994	:America/New_York	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:37:00	\N	0.400000000000000022	-02:41:00	\N	0.200000000000000011	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
59326	James Island, 3.4 miles west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.5249999999999986	-76.4200000000000017	:America/New_York	USA	knots	175	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:02:00	\N	0.400000000000000022	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
59327	James Island, 2.5 miles WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.5333299999999994	-76.393330000000006	:America/New_York	USA	knots	175	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:36:00	\N	0.599999999999999978	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
59328	Plum Point, 1.4 miles ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6124999999999972	-76.4775000000000063	:America/New_York	USA	knots	155	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.699999999999999956	-01:37:00	\N	0.200000000000000011	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
59329	Sharp Island Lt., 2.3 n.mi. SE of (Depth 20ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.6071700000000035	-76.347999999999999	:America/New_York	USA	knots	203	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:54:00	\N	0.699999999999999956	-03:34:00	\N	0.800000000000000044	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
59330	Sharp Island Lt., 2.1 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.6433299999999988	-76.420330000000007	:America/New_York	USA	knots	183	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:33:00	\N	0.5	-01:36:00	\N	0.400000000000000022	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
59331	Sharp Island Lt., 3.4 n.mi. west of (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.6438300000000012	-76.4479999999999933	:America/New_York	USA	knots	186	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:43:00	\N	0.5	-01:41:00	\N	0.400000000000000022	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
59332	Sharp Island Lt., 3.4 n.mi. west of (Depth 35ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.6438300000000012	-76.4479999999999933	:America/New_York	USA	knots	183	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:24:00	\N	0.400000000000000022	-02:23:00	\N	0.400000000000000022	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
59333	Plum Point, 2.1 n.mi. NNE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.6450000000000031	-76.4871700000000061	:America/New_York	USA	knots	174	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:01:00	\N	0.5	-01:51:00	\N	0.400000000000000022	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
59334	Poplar Island, 2.2 n.mi. WSW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.7561699999999973	-76.4295000000000044	:America/New_York	USA	knots	185	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:49:00	\N	0.800000000000000044	-01:26:00	\N	0.599999999999999978	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
59335	Poplar Island, 3.0 n.mi. WSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.7496700000000018	-76.4454999999999956	:America/New_York	USA	knots	189	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:08:00	\N	0.5	-01:22:00	\N	0.599999999999999978	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
59336	Poplar Island, 3.0 n.mi. WSW of (Depth 48ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.7496700000000018	-76.4454999999999956	:America/New_York	USA	knots	172	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:13:00	\N	0.400000000000000022	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
59337	Holland Point, 2.0 n.mi east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.7516699999999972	-76.4988299999999981	:America/New_York	USA	knots	180	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:39:00	\N	0.400000000000000022	-01:24:00	\N	0.200000000000000011	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
59338	Kent Point, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.7916700000000034	-76.433329999999998	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:05:00	\N	0.599999999999999978	-01:04:00	\N	0.599999999999999978	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
59339	Kent Point, 1.3 miles south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.816670000000002	-76.3641700000000014	:America/New_York	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:47:00	\N	0.5	-03:38:00	\N	0.599999999999999978	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
59340	Horseshoe Point, 1.7 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.8383299999999991	-76.453329999999994	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:10:00	\N	0.599999999999999978	-00:39:00	\N	0.599999999999999978	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
59341	Bloody Point Bar Light, 0.6 mi. NW of (Depth 19ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.839500000000001	-76.4028299999999945	:America/New_York	USA	knots	190	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.599999999999999978	-00:23:00	\N	0.900000000000000022	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
59342	Thomas Pt. Shoal Lt., 1.8 mi. SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.461669999999998	:America/New_York	USA	knots	190	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:17:00	\N	0.400000000000000022	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
59343	Thomas Pt. Shoal Lt., 2.0 n.mi. east of (Depth 22ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.8958299999999966	-76.3868300000000033	:America/New_York	USA	knots	186	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:20:00	\N	0.599999999999999978	-00:14:00	\N	0.599999999999999978	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
59344	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.8909999999999982	-76.4270000000000067	:America/New_York	USA	knots	191	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:41:00	\N	1.30000000000000004	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
59345	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of (Depth 33ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.8909999999999982	-76.4270000000000067	:America/New_York	USA	knots	196	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:20:00	\N	0.699999999999999956	-01:18:00	\N	0.699999999999999956	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
59346	Tolly Point, 1.6 miles east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9344999999999999	-76.4170000000000016	:America/New_York	USA	knots	190	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:24:00	\N	0.900000000000000022	-00:19:00	\N	0.599999999999999978	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
59347	Chesapeake Bay Bridge, main channel, Chesapeake Bay, Maryland Current	NOS	ACT4981_1	38.9916699999999992	-76.3850000000000051	:America/New_York	USA	knots	230	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:13:00	\N	1.10000000000000009	00:08:00	\N	0.900000000000000022	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
59348	Sandy Point, 2.3 n.mi. east of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.0026700000000019	-76.3488300000000066	:America/New_York	USA	knots	199	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:29:00	\N	0.900000000000000022	00:15:00	\N	1.10000000000000009	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
59349	Sandy Point, 2.3 n.mi. east of (Depth 41ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.0026700000000019	-76.3488300000000066	:America/New_York	USA	knots	210	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:39:00	\N	0.599999999999999978	-01:14:00	\N	0.800000000000000044	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
59350	Sandy Point, 0.8 n.mi. ESE of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.0039999999999978	-76.3799999999999955	:America/New_York	USA	knots	199	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	1.5	00:24:00	\N	1.19999999999999996	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
59351	Sandy Point, 0.8 n.mi. ESE of (Depth 43ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.0039999999999978	-76.3799999999999955	:America/New_York	USA	knots	197	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
59352	Craighill Channel entrance, Buoy '2C' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.0403299999999973	-76.377830000000003	:America/New_York	USA	knots	182	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:09:00	\N	0.900000000000000022	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
59353	Craighill Channel entrance, Buoy '2C' (Depth 38ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.0403299999999973	-76.377830000000003	:America/New_York	USA	knots	147	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:18:00	\N	0.599999999999999978	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
59354	Love Point, 2.5 miles north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.0796700000000001	-76.3121699999999947	:America/New_York	USA	knots	240	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:07:00	\N	0.5	00:19:00	\N	0.800000000000000044	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
59390	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.6450000000000031	-77.1274999999999977	:America/New_York	USA	knots	149	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:15:00	\N	1.39999999999999991	-00:05:00	\N	1.39999999999999991	00:12:00	-00:24:00	Hallowing Point	MD
59355	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.0813300000000012	-76.3944999999999936	:America/New_York	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:34:00	\N	0.900000000000000022	00:40:00	\N	0.800000000000000044	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
59356	Craighill Channel, Belvidere Shoal (Depth 18ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.0946700000000007	-76.3930000000000007	:America/New_York	USA	knots	186	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:19:00	\N	0.599999999999999978	00:46:00	\N	0.699999999999999956	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
59357	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.1283299999999983	-76.3878299999999939	:America/New_York	USA	knots	170	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:23:00	\N	0.599999999999999978	00:27:00	\N	0.599999999999999978	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
59358	Swan Point, 2.7 n.mi. SW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.107999999999997	-76.3053299999999979	:America/New_York	USA	knots	170	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.5	00:42:00	\N	0.599999999999999978	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
59359	Swan Point, 2.7 n.mi. SW of (Depth 27ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.107999999999997	-76.3053299999999979	:America/New_York	USA	knots	142	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.400000000000000022	00:30:00	\N	0.599999999999999978	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
59360	Swan Point, 1.6 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625000000000014	-76.3046700000000016	:America/New_York	USA	knots	215	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:57:00	\N	0.900000000000000022	00:44:00	\N	0.800000000000000044	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
59361	Brewerton Channel Eastern Ext., Buoy '7' (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.1629999999999967	-76.3896699999999953	:America/New_York	USA	knots	175	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:05:00	\N	0.400000000000000022	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
59362	Tolchester Channel, SW of Bouy '58B' (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1824999999999974	-76.281170000000003	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:54:00	\N	1.10000000000000009	00:20:00	\N	1.10000000000000009	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
59363	Tolchester Channel, SW of Bouy '58B' (Depth 25ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1824999999999974	-76.281170000000003	:America/New_York	USA	knots	217	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:48:00	\N	0.699999999999999956	00:02:00	\N	0.900000000000000022	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
59364	Tolchester Channel, Buoy '22' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.1911699999999996	-76.265829999999994	:America/New_York	USA	knots	231	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:23:00	\N	0.800000000000000044	01:10:00	\N	0.900000000000000022	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
59365	Tolchester Channel, south of Buoy '38B' (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.1928300000000007	-76.2878299999999996	:America/New_York	USA	knots	208	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:50:00	\N	0.800000000000000044	01:08:00	\N	0.699999999999999956	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
59366	North Point, 2.5 miles northeast of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.214500000000001	-76.3953300000000013	:America/New_York	USA	knots	225	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:06:00	\N	0.5	01:00:00	\N	0.400000000000000022	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
59367	Tolchester Beach, 0.33 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.217170000000003	-76.2483299999999957	:America/New_York	USA	knots	201	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:24:00	\N	1.10000000000000009	01:20:00	\N	1.19999999999999996	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
59368	Pooles Island, 4 miles southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.2266699999999986	-76.3313299999999941	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:12:00	\N	0.800000000000000044	00:48:00	\N	0.599999999999999978	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
59369	Pooles Island 2.0 n.mi. SSW of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.2463300000000004	-76.296670000000006	:America/New_York	USA	knots	238	38	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:29:00	\N	0.699999999999999956	00:58:00	\N	0.699999999999999956	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
59370	Pooles Island, 0.8 mile south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.2616700000000023	-76.2733300000000014	:America/New_York	USA	knots	255	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:20:00	\N	1.19999999999999996	01:24:00	\N	0.900000000000000022	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
59371	Miller Island, 1.5 miles ENE of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.2749999999999986	-76.3316700000000026	:America/New_York	USA	knots	185	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:25:00	\N	0.299999999999999989	00:15:00	\N	0.599999999999999978	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
59427	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.4383299999999934	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:10:00	\N	0.5	-00:10:00	\N	0.699999999999999956	00:00:00	00:00:00	Lynch Point, Back River	MD
59372	Pooles Island, 1.6 n.mi. east of (Depth 16ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745000000000033	-76.2261699999999962	:America/New_York	USA	knots	208	14	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:03:00	\N	1.10000000000000009	01:34:00	\N	1.10000000000000009	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
59373	Robins Point, 0.7 mile ESE of (Depth 5ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.2958300000000023	-76.268330000000006	:America/New_York	USA	knots	210	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:13:00	\N	1	-00:14:00	\N	1.39999999999999991	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
59374	Worton Point, 1.5 n.mi. WSW of (Depth 17ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.3116699999999994	-76.2171699999999959	:America/New_York	USA	knots	211	23	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:36:00	\N	1.10000000000000009	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
59375	Worton Point, 1.1 miles northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.3316700000000026	-76.2000000000000028	:America/New_York	USA	knots	245	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1.5	01:43:00	\N	1.39999999999999991	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
59376	Howell Point, 0.8 n.mi. west of (Depth 15ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3704999999999998	-76.1299999999999955	:America/New_York	USA	knots	235	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:33:00	\N	1.30000000000000004	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
59377	Howell Point, 0.4 mile NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.3766699999999972	-76.1149999999999949	:America/New_York	USA	knots	245	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:18:00	\N	1.10000000000000009	01:24:00	\N	1.10000000000000009	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
59378	Grove Point, 0.7 n.mi.NW of (Depth 14ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.396329999999999	-76.0503300000000024	:America/New_York	USA	knots	211	34	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:03:00	\N	1	02:01:00	\N	0.599999999999999978	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
59379	Turkey Point, 1.2 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.4433300000000031	-76.0338299999999947	:America/New_York	USA	knots	193	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:00:00	\N	0.800000000000000044	01:30:00	\N	0.599999999999999978	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
59380	Spesutie Island, channel north of (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4804999999999993	-76.0816700000000026	:America/New_York	USA	knots	100	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:40:00	\N	0.599999999999999978	01:20:00	\N	0.800000000000000044	01:42:00	01:49:00	Spesutie Island, channel north of	MD
59381	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of (Depth 9ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.4883299999999977	-75.9975000000000023	:America/New_York	USA	knots	196	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:49:00	\N	0.699999999999999956	01:28:00	\N	0.599999999999999978	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
59382	Red Point, 0.2 mile W of, Northeast River (Depth 7ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.5291700000000006	-75.9846699999999942	:America/New_York	USA	knots	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:47:00	\N	0.599999999999999978	01:28:00	\N	0.900000000000000022	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
59383	Swan Point, Potomac River, Virginia Current	NOS	ACT5846_1	38.2733300000000014	-76.9449999999999932	:America/New_York	USA	knots	140	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:09:00	\N	1	-02:04:00	\N	0.400000000000000022	-01:54:00	-02:32:00	Swan Point	VA
59384	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.3683300000000003	-76.9899999999999949	:America/New_York	USA	knots	175	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:24:00	\N	1.80000000000000004	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
59385	Potomac River Bridge, 0.4 mile south of, Potomac River, Maryland Current	NOS	ACT5866_1	38.3563299999999998	-76.9866700000000037	:America/New_York	USA	knots	165	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:17:00	\N	1.80000000000000004	-01:28:00	\N	1.10000000000000009	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
59386	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.3466700000000031	-77.1966699999999975	:America/New_York	USA	knots	80	270	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:19:00	\N	1.80000000000000004	-01:14:00	\N	1.39999999999999991	-01:04:00	-01:42:00	Maryland Point	MD
59387	Quantico, Potomac River, Virginia Current	NOS	ACT5881_1	38.5216700000000003	-77.2766699999999958	:America/New_York	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:09:00	\N	1.10000000000000009	-01:04:00	\N	0.900000000000000022	-00:54:00	-01:32:00	Quantico	VA
59388	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.5283299999999969	-77.288330000000002	:America/New_York	USA	knots	115	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:34:00	\N	0.599999999999999978	-01:29:00	\N	0.599999999999999978	-01:19:00	-01:57:00	Quantico Creek entrance	VA
59389	Freestone Point, 2.3 miles east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.5963300000000018	-77.1979999999999933	:America/New_York	USA	knots	229	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:06:00	\N	0.900000000000000022	-00:01:00	\N	0.900000000000000022	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
59391	Jones Point, Alexandria, Potomac River, Virginia Current	NOS	ACT5901_1	38.7936699999999988	-77.0371700000000033	:America/New_York	USA	knots	171	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:07:00	\N	1.10000000000000009	00:01:00	\N	1.19999999999999996	00:36:00	00:09:00	Jones Point, Alexandria	VA
59392	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.8513299999999973	-77.0220000000000056	:America/New_York	USA	knots	176	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.400000000000000022	00:31:00	\N	0.800000000000000044	00:20:00	00:04:00	Hains Point	DC
59393	Hog Point, 0.6 n.mi. north of (Depth 13ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.3179999999999978	-76.4011699999999934	:America/New_York	USA	knots	70	258	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:00:00	\N	0.599999999999999978	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
59394	Hog Point, 0.6 n.mi. north of (Depth 41ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.3179999999999978	-76.4011699999999934	:America/New_York	USA	knots	61	263	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:38:00	\N	0.299999999999999989	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
59395	Drum Point, 0.3 mile SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155000000000001	-76.419169999999994	:America/New_York	USA	knots	65	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
59396	Sandy Point, 0.5 mile south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.308329999999998	-76.4549999999999983	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:55:00	\N	0.599999999999999978	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
59397	Point Patience, 0.1 mile southwest of (Depth 15ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.3283300000000011	-76.4866700000000037	:America/New_York	USA	knots	145	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-06:01:00	\N	1	-06:12:00	\N	0.599999999999999978	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
59398	Broomes Island, 0.4 mile south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.3950000000000031	-76.5541699999999992	:America/New_York	USA	knots	110	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-05:02:00	\N	0.599999999999999978	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
59399	Sheridan Point, 0.1 mile southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.4661699999999982	-76.6479999999999961	:America/New_York	USA	knots	135	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:16:00	\N	0.800000000000000044	-04:54:00	\N	0.800000000000000044	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
59400	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.5116700000000023	-76.6721699999999942	:America/New_York	USA	knots	190	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:35:00	\N	0.599999999999999978	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
59401	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.7466700000000017	-76.6850000000000023	:America/New_York	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:29:00	\N	1.10000000000000009	-03:24:00	\N	1.39999999999999991	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
59402	Ragged Point, 1.5 miles east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.5300000000000011	-76.2441699999999969	:America/New_York	USA	knots	235	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:57:00	\N	0.200000000000000011	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
59403	Cook Point, 1.4 n.mi. NNW of (Depth 15ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.6471700000000027	-76.3066699999999969	:America/New_York	USA	knots	241	49	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:24:00	\N	0.699999999999999956	-04:06:00	\N	0.800000000000000044	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
59404	Cook Point, 1.4 n.mi. NNW of (Depth 45ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.6471700000000027	-76.3066699999999969	:America/New_York	USA	knots	232	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:12:00	\N	0.599999999999999978	-04:05:00	\N	0.599999999999999978	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
59405	Holland Point, 2.0 n.mi. SSW of (Depth 14ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.6738300000000024	-76.2574999999999932	:America/New_York	USA	knots	262	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:00:00	\N	0.200000000000000011	-04:21:00	\N	0.299999999999999989	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
59406	Chlora Point, 0.5 n.mi. SSW of (Depth 17ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.6283299999999983	-76.1516699999999958	:America/New_York	USA	knots	332	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:58:00	\N	0.5	-03:32:00	\N	0.599999999999999978	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
59407	Chlora Point, 0.5 n.mi. SSW of (Depth 24ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.6283299999999983	-76.1516699999999958	:America/New_York	USA	knots	323	143	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.400000000000000022	-03:33:00	\N	0.400000000000000022	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
59408	Martin Point, 0.6 n.mi. west of (Depth 18ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.6271699999999996	-76.1358299999999986	:America/New_York	USA	knots	341	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:34:00	\N	0.200000000000000011	-03:42:00	\N	0.299999999999999989	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
59409	Howell Point, 0.5 n.mi. south of (Depth 7ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.6038300000000021	-76.1145000000000067	:America/New_York	USA	knots	274	122	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:42:00	\N	0.5	-04:04:00	\N	0.400000000000000022	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
59410	Cambridge hwy. bridge, W. of Swing Span (Depth 18ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.5796700000000001	-76.0611700000000042	:America/New_York	USA	knots	316	132	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:13:00	\N	0.299999999999999989	-03:05:00	\N	0.599999999999999978	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
59411	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.6096700000000013	-75.982830000000007	:America/New_York	USA	knots	205	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:26:00	\N	0.800000000000000044	-02:32:00	\N	0.599999999999999978	-02:13:00	-02:44:00	Off Jamaica Point	MD
59412	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.6753300000000024	-75.9663299999999992	:America/New_York	USA	knots	100	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
59413	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.7566699999999997	-75.9986700000000042	:America/New_York	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:47:00	\N	1	-01:50:00	\N	1.10000000000000009	-01:19:00	-01:25:00	Dover Bridge	MD
59414	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.7291700000000034	-76.3050000000000068	:America/New_York	USA	knots	175	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
59415	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.7483300000000028	-76.3533299999999997	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:20:00	\N	0.800000000000000044	-02:20:00	\N	1.19999999999999996	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
59416	Kent Point, 1.4 n.mi. east of (Depth 15ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.8388300000000015	-76.3375000000000057	:America/New_York	USA	knots	233	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:12:00	\N	0.400000000000000022	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
59417	Long Point, 1 mile southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.8433300000000017	-76.3266699999999929	:America/New_York	USA	knots	235	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:40:00	\N	0.5	-03:40:00	\N	0.599999999999999978	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
59418	Wye River, west of Bruffs Island (Depth 9ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.8546699999999987	-76.1979999999999933	:America/New_York	USA	knots	190	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-03:00:00	\N	0.900000000000000022	-03:18:00	\N	0.800000000000000044	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
59419	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055000000000021	-76.2091700000000003	:America/New_York	USA	knots	25	215	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-04:14:00	\N	0.599999999999999978	-03:52:00	\N	0.599999999999999978	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
59420	Greenbury Point, 1.8 miles east of (Depth 8ft), Maryland Current	NOS	ACT6106_1	38.9733299999999971	-76.4166699999999963	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:47:00	\N	0.800000000000000044	-01:05:00	\N	0.800000000000000044	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
59421	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.0578300000000027	-76.4371699999999947	:America/New_York	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:04:00	\N	0.400000000000000022	-02:00:00	\N	0.800000000000000044	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
59422	Love Point, 1.6 n.mi. east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6126_1	39.0341700000000031	-76.2678300000000036	:America/New_York	USA	knots	341	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-01:15:00	\N	0.400000000000000022	-01:15:00	\N	0.599999999999999978	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
59423	Kent Island Narrows (highway bridge) (Depth 4ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705000000000013	-76.247169999999997	:America/New_York	USA	knots	190	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-02:56:00	\N	1.10000000000000009	-02:25:00	\N	1.19999999999999996	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
59424	Hail Point, 0.7 n.mi.east of (Depth 16ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105000000000004	-76.1825000000000045	:America/New_York	USA	knots	168	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:37:00	\N	0.599999999999999978	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
59425	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.1063299999999998	-76.1205000000000069	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:18:00	\N	0.900000000000000022	-00:33:00	\N	0.599999999999999978	-00:31:00	-00:32:00	Deep Point	MD
59426	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.2071699999999979	-76.0611700000000042	:America/New_York	USA	knots	220	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	-00:17:00	\N	0.599999999999999978	00:05:00	\N	0.800000000000000044	-00:21:00	-00:02:00	Chestertown	MD
59428	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.3116699999999994	-76.308329999999998	:America/New_York	USA	knots	205	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:05:00	\N	0.400000000000000022	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
59429	Bush River, 0.4 mi. SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.3566700000000012	-76.2566699999999997	:America/New_York	USA	knots	165	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:20:00	\N	0.599999999999999978	-00:24:00	\N	0.800000000000000044	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
59430	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.3783299999999983	-76.0433299999999974	:America/New_York	USA	knots	288	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:44:00	\N	0.400000000000000022	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
59431	Ordinary Point, 0.4 mile west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.3741699999999994	-75.9874999999999972	:America/New_York	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	00:58:00	\N	0.5	00:37:00	\N	0.599999999999999978	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
59432	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.3611700000000013	-75.886170000000007	:America/New_York	USA	knots	200	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:25:00	\N	0.5	00:25:00	\N	0.400000000000000022	01:00:00	00:56:00	Georgetown	MD
59433	Arnold Point, 0.4 mile west of, Elk River, Maryland Current	NOS	ACT6216_1	39.4638300000000015	-75.9741700000000009	:America/New_York	USA	knots	215	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
59434	Old Town Point Wharf, northwest of (Depth 17ft), Elk River, Maryland Current	NOS	ACT6221_1	39.5038300000000007	-75.9186700000000059	:America/New_York	USA	knots	242	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.60000000000000009	01:53:00	\N	1.30000000000000004	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
59435	Old Town Point Wharf, northwest of (Depth 29ft), Elk River, Maryland Current	NOS	ACT6221_2	39.5038300000000007	-75.9186700000000059	:America/New_York	USA	knots	237	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	01:45:00	\N	1.39999999999999991	02:04:00	\N	1.19999999999999996	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
59436	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.5533300000000025	-75.8599999999999994	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16144	02:05:00	\N	0.900000000000000022	02:05:00	\N	0.599999999999999978	02:05:00	02:05:00	Hendersons Point	MD
59437	Bodie Island-Pea Island, between (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_1	35.7766700000000029	-75.5349999999999966	:America/New_York	USA	knots	28	202	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:52:00	\N	0.599999999999999978	02:20:00	\N	1.19999999999999996	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
59438	Bodie Island-Pea Island, between (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6271_2	35.7766700000000029	-75.5349999999999966	:America/New_York	USA	knots	36	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.599999999999999978	02:36:00	\N	1.19999999999999996	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
59439	Coast Guard Tower, southwest of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_1	35.7616700000000023	-75.5316700000000054	:America/New_York	USA	knots	28	205	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:18:00	\N	0.800000000000000044	02:30:00	\N	0.800000000000000044	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
59440	Coast Guard Tower, southwest of (Depth 12ft), Oregon Inlet, North Carolina Current	NOS	ACT6276_2	35.7616700000000023	-75.5316700000000054	:America/New_York	USA	knots	33	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.699999999999999956	02:33:00	\N	0.800000000000000044	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
59441	Herbert C. Bonner Bridge, WSW of (Depth 6ft), Oregon Inlet, North Carolina Current	NOS	ACT6281_1	35.7700000000000031	-75.546670000000006	:America/New_York	USA	knots	87	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:46:00	\N	0.900000000000000022	02:55:00	\N	0.599999999999999978	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
59442	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2000000000000028	-75.75	:America/New_York	USA	knots	148	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:38:00	\N	1	02:42:00	\N	1.19999999999999996	02:42:00	02:18:00	Hatteras Inlet	NC
59443	Channel entrance, Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.065330000000003	-76.0188299999999941	:America/New_York	USA	knots	145	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:40:00	\N	1.19999999999999996	02:24:00	\N	1	02:48:00	01:43:00	channel entrance	NC
59444	Teaches Hole Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.0791699999999977	-76.0046700000000044	:America/New_York	USA	knots	195	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:47:00	\N	0.800000000000000044	02:27:00	\N	0.599999999999999978	02:49:00	01:42:00	Teaches Hole Channel	NC
59445	Blair Channel (Depth 10ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.0813300000000012	-76.0338299999999947	:America/New_York	USA	knots	140	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:03:00	\N	0.900000000000000022	02:33:00	\N	0.599999999999999978	02:52:00	01:48:00	Blair Channel	NC
59446	Wallace Channel (Depth 9ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.0796700000000001	-76.0520000000000067	:America/New_York	USA	knots	140	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:13:00	\N	0.900000000000000022	02:57:00	\N	0.900000000000000022	02:51:00	02:03:00	Wallace Channel	NC
59447	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.066670000000002	-76.0999999999999943	:America/New_York	USA	knots	95	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:56:00	\N	0.200000000000000011	03:18:00	\N	0.100000000000000006	02:33:00	01:35:00	Sheep Island Slue	NC
59448	Shackleford Banks, 0.8 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.6663300000000021	-76.6555000000000035	:America/New_York	USA	knots	145	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.699999999999999956	01:16:00	\N	0.800000000000000044	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
59449	Approach, Beaufort Inlet, North Carolina Current	NOS	ACT6331_1	34.6716699999999989	-76.6700000000000017	:America/New_York	USA	knots	161	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:57:00	\N	0.699999999999999956	01:19:00	\N	0.200000000000000011	02:03:00	00:37:00	Approach	NC
59450	Fort Macon, 0.6 mile SE of, Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.6858300000000028	-76.6683299999999974	:America/New_York	USA	knots	154	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:38:00	\N	0.900000000000000022	01:47:00	\N	0.699999999999999956	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
59451	Fort Macon, 0.2 mile NE of (Depth 10ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.6996699999999976	-76.6753300000000024	:America/New_York	USA	knots	151	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:21:00	\N	0.900000000000000022	01:20:00	\N	1.10000000000000009	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
59452	Fort Macon, 0.2 mile NE of (Depth 20ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.6996699999999976	-76.6753300000000024	:America/New_York	USA	knots	153	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	0.900000000000000022	01:18:00	\N	1.10000000000000009	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
59453	Tombstone Point, 0.1 mile E of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.7038300000000035	-76.6861700000000042	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:27:00	\N	0.800000000000000044	01:25:00	\N	0.900000000000000022	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
59454	Turning Basin (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713000000000001	-76.6941699999999997	:America/New_York	USA	knots	144	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.800000000000000044	01:11:00	00:50:00	Turning Basin	NC
59455	Turning Basin (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713000000000001	-76.6941699999999997	:America/New_York	USA	knots	138	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:32:00	\N	0.5	01:34:00	\N	0.699999999999999956	01:09:00	00:59:00	Turning Basin	NC
59456	Sugarloaf Island, 0.2 mile S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7124999999999986	-76.7138300000000015	:America/New_York	USA	knots	94	266	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:14:00	\N	0.800000000000000044	01:39:00	\N	0.699999999999999956	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
59457	Morehead City, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.7166700000000006	-76.732830000000007	:America/New_York	USA	knots	110	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	0.699999999999999956	01:47:00	\N	0.800000000000000044	02:12:00	01:29:00	Morehead City, S of	NC
59458	Morehead City, RR. bridge, N of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.7228300000000019	-76.6938300000000055	:America/New_York	USA	knots	185	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.5	01:01:00	\N	0.599999999999999978	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
59459	Newport Marshes, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.7313299999999998	-76.683329999999998	:America/New_York	USA	knots	215	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.599999999999999978	01:02:00	\N	0.800000000000000044	00:57:00	00:18:00	Newport Marshes, SE of	NC
59460	Newport Marshes, SE of (Depth 15ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.7313299999999998	-76.683329999999998	:America/New_York	USA	knots	226	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:08:00	\N	0.599999999999999978	01:15:00	\N	0.800000000000000044	00:53:00	00:21:00	Newport Marshes, SE of	NC
59461	Newport Marshes, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.7378300000000024	-76.680499999999995	:America/New_York	USA	knots	224	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.5	00:11:00	\N	0.599999999999999978	00:07:00	-00:37:00	Newport Marshes, E of	NC
59462	Radio Island, E of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.711669999999998	-76.6796700000000016	:America/New_York	USA	knots	202	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.599999999999999978	00:55:00	\N	0.699999999999999956	00:55:00	00:20:00	Radio Island, E of	NC
59463	Bird Shoal, SE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7004999999999981	-76.6538299999999992	:America/New_York	USA	knots	304	126	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.400000000000000022	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
59464	Shackleford Point, NE of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.6921699999999973	-76.6521699999999981	:America/New_York	USA	knots	305	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.599999999999999978	01:28:00	\N	0.800000000000000044	01:32:00	01:10:00	Shackleford Point, NE of	NC
59465	Carrot Island (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.7021700000000024	-76.6175000000000068	:America/New_York	USA	knots	262	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:49:00	\N	0.699999999999999956	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
59466	Middle Marshes, S of (Depth 6ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.6783300000000025	-76.613829999999993	:America/New_York	USA	knots	275	123	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	0.5	01:04:00	\N	0.800000000000000044	00:59:00	01:03:00	Middle Marshes, S of	NC
59467	Winyah Bay entrance, Winyah Bay, South Carolina Current	NOS	ACT6531_1	33.2071699999999979	-79.1844999999999999	:America/New_York	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:20:00	\N	1	01:35:00	\N	1.10000000000000009	01:47:00	01:05:00	Winyah Bay entrance	SC
59468	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.2441699999999969	-79.205830000000006	:America/New_York	USA	knots	130	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:42:00	\N	1.10000000000000009	01:57:00	\N	1.19999999999999996	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
59469	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.2950000000000017	-79.272829999999999	:America/New_York	USA	knots	115	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:59:00	\N	0.5	01:52:00	\N	1.10000000000000009	01:52:00	02:20:00	Frazier Point, south of	SC
59470	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.309669999999997	-79.2866700000000009	:America/New_York	USA	knots	170	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:41:00	\N	1	02:19:00	\N	0.900000000000000022	02:23:00	02:01:00	Frazier Point, west of	SC
59471	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.339500000000001	-79.281329999999997	:America/New_York	USA	knots	215	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.900000000000000022	02:46:00	\N	1.19999999999999996	02:39:00	02:14:00	Rabbit Island, northwest of	SC
59472	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.3513299999999973	-79.2803300000000064	:America/New_York	USA	knots	135	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.699999999999999956	01:20:00	\N	0.599999999999999978	01:33:00	01:39:00	Sampit River entrance	SC
59473	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.3591699999999989	-79.2874999999999943	:America/New_York	USA	knots	80	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.599999999999999978	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
59474	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3704999999999998	-79.2638299999999987	:America/New_York	USA	knots	210	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:43:00	\N	0.5	03:13:00	\N	0.400000000000000022	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
59475	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.3686700000000016	-79.2519999999999953	:America/New_York	USA	knots	200	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:31:00	\N	0.599999999999999978	03:04:00	\N	0.400000000000000022	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
59476	Butler Island, 0.3 mile south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.4166700000000034	-79.2120000000000033	:America/New_York	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:55:00	\N	0.5	03:34:00	\N	0.400000000000000022	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
59477	North Santee River entrance (Depth 6ft), South Carolina Current	NOS	ACT6581_1	33.1358299999999986	-79.2408300000000025	:America/New_York	USA	knots	165	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:01:00	\N	0.900000000000000022	00:33:00	\N	0.900000000000000022	01:00:00	00:03:00	North Santee River entrance	SC
59478	South Santee River entrance (Depth 5ft), South Carolina Current	NOS	ACT6586_1	33.1199999999999974	-79.2750000000000057	:America/New_York	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.800000000000000044	00:38:00	\N	0.900000000000000022	00:20:00	00:27:00	South Santee River entrance	SC
59479	Fort Sumter Range, Buoy '2', Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.6829999999999998	-79.7259999999999991	:America/New_York	USA	knots	104	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:03:00	\N	0.200000000000000011	-00:51:00	\N	0.200000000000000011	-01:05:00	-01:11:00	Fort Sumter Range, Buoy '2'	SC
59480	Fort Sumter Range, Buoy '4', Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.6976700000000022	-79.755669999999995	:America/New_York	USA	knots	117	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.200000000000000011	-00:59:00	\N	0.299999999999999989	-00:49:00	-01:10:00	Fort Sumter Range, Buoy '4'	SC
59481	Fort Sumter Range, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.7150000000000034	-79.7923300000000069	:America/New_York	USA	knots	128	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	-00:16:00	\N	0.400000000000000022	-00:15:00	00:17:00	Fort Sumter Range, Buoy '8'	SC
59482	Fort Sumter Range, Buoy '14', Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.7243300000000019	-79.8100000000000023	:America/New_York	USA	knots	116	287	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.800000000000000044	-00:04:00	\N	0.599999999999999978	-00:10:00	00:16:00	Fort Sumter Range, Buoy '14'	SC
59483	North Jetty, 0.8 mile southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175000000000011	-79.7999999999999972	:America/New_York	USA	knots	110	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:16:00	\N	0.599999999999999978	-00:48:00	\N	0.200000000000000011	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
59484	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.7333300000000023	-79.8333300000000037	:America/New_York	USA	knots	121	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.900000000000000022	00:04:00	\N	1.10000000000000009	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
59485	Fort Sumter Range, Buoy '20', Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.7404999999999973	-79.8444999999999965	:America/New_York	USA	knots	128	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:51:00	\N	0.900000000000000022	-00:15:00	\N	0.900000000000000022	-00:33:00	-00:33:00	Fort Sumter Range, Buoy '20'	SC
59486	South Jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.7311699999999988	-79.8503299999999996	:America/New_York	USA	knots	204	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.39999999999999991	00:31:00	\N	0.699999999999999956	00:38:00	00:06:00	South Jetty, break in	SC
59487	Ft. Sumter, 0.6 n.mi. NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.7611699999999999	-79.8671700000000016	:America/New_York	USA	knots	138	322	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:24:00	\N	0.900000000000000022	-00:03:00	\N	0.900000000000000022	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
59488	South Chan., 0.8 mi. ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.7586700000000022	-79.8846699999999998	:America/New_York	USA	knots	115	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	1.30000000000000004	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
59489	South Chan., 0.4 mi. NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.7580000000000027	-79.906329999999997	:America/New_York	USA	knots	104	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1	00:58:00	\N	0.400000000000000022	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
59490	Sullivans I., 0.7 mi. NE of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6671_1	32.7620000000000005	-79.8675000000000068	:America/New_York	USA	knots	132	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.800000000000000044	00:37:00	\N	0.800000000000000044	00:17:00	00:01:00	Sullivans I., 0.7 mi. NE of Ft. Sumter	SC
59491	Castle Pinckney, 0.4 mile south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767000000000003	-79.9116700000000009	:America/New_York	USA	knots	98	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:58:00	\N	0.900000000000000022	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
59492	South Channel, Buoy '32', Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.7621699999999976	-79.9110000000000014	:America/New_York	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy '32'	SC
59493	Castle Pinckney, 0.6 mile southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.7663300000000035	-79.9194999999999993	:America/New_York	USA	knots	156	318	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.699999999999999956	01:20:00	\N	0.400000000000000022	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
59494	Shutes Folly Island, 0.4 mile west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.7763300000000015	-79.9208299999999952	:America/New_York	USA	knots	164	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:08:00	\N	1.10000000000000009	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
59495	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.7794999999999987	-79.9224999999999994	:America/New_York	USA	knots	190	9	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:23:00	\N	0.699999999999999956	01:03:00	\N	0.599999999999999978	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
59496	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7824999999999989	-79.9200000000000017	:America/New_York	USA	knots	153	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.900000000000000022	00:37:00	\N	0.599999999999999978	00:46:00	00:37:00	Customhouse Reach	SC
59497	Town Creek Lower Reach, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7924999999999969	-79.9244999999999948	:America/New_York	USA	knots	172	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	1.10000000000000009	00:24:00	\N	0.599999999999999978	00:34:00	00:02:00	Town Creek Lower Reach	SC
59498	Town Creek, 0.2 mile above bridge, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.8053299999999979	-79.9316699999999969	:America/New_York	USA	knots	166	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	1.30000000000000004	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
59499	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.7663300000000035	-79.8733299999999957	:America/New_York	USA	knots	143	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:48:00	\N	0.400000000000000022	00:27:00	\N	0.400000000000000022	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
59500	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7674999999999983	-79.8719999999999999	:America/New_York	USA	knots	151	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	01:14:00	\N	0.699999999999999956	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
59501	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.781170000000003	-79.8763299999999958	:America/New_York	USA	knots	125	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.400000000000000022	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
59502	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.7696699999999979	-79.9011699999999934	:America/New_York	USA	knots	104	301	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:59:00	\N	0.599999999999999978	-00:03:00	\N	0.699999999999999956	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
59503	Folly Reach, Buoy '5', Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.7763300000000015	-79.899169999999998	:America/New_York	USA	knots	110	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:13:00	\N	0.800000000000000044	00:35:00	\N	0.699999999999999956	00:02:00	00:18:00	Folly Reach, Buoy '5'	SC
59504	Shutes Reach, Buoy '8', Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.7821700000000007	-79.9108300000000042	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.800000000000000044	00:22:00	\N	0.699999999999999956	00:18:00	00:15:00	Shutes Reach, Buoy '8'	SC
59505	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.7861699999999985	-79.9150000000000063	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	1	00:23:00	\N	0.800000000000000044	00:36:00	-00:12:00	Horse Reach	SC
59506	Hog Island Reach, Buoy '12', Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.7944999999999993	-79.9150000000000063	:America/New_York	USA	knots	193	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.699999999999999956	00:28:00	\N	0.699999999999999956	00:13:00	00:14:00	Hog Island Reach, Buoy '12'	SC
59507	Drum Island, 0.4 mile SSE of, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7944999999999993	-79.9208299999999952	:America/New_York	USA	knots	155	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.900000000000000022	00:53:00	\N	0.800000000000000044	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
59508	Drum Island, east of (bridge), Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8044999999999973	-79.9153299999999973	:America/New_York	USA	knots	183	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:06:00	\N	1	00:42:00	\N	0.699999999999999956	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
59509	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.8118300000000005	-79.9120000000000061	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	0.699999999999999956	00:44:00	\N	0.699999999999999956	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
59510	Drum Island Reach, off Drum I., Buoy '45', Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.8161699999999996	-79.9228300000000047	:America/New_York	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:00:00	\N	0.5	01:00:00	\N	0.400000000000000022	00:26:00	01:06:00	Drum Island Reach, off Drum I., Buoy '45'	SC
59511	Drum Island, 0.2 mile above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.8196700000000021	-79.9291699999999992	:America/New_York	USA	knots	152	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	1.19999999999999996	01:09:00	\N	0.599999999999999978	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
59512	Daniel Island Reach, Buoy '48', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.8271700000000024	-79.9288300000000049	:America/New_York	USA	knots	182	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:55:00	\N	0.699999999999999956	01:29:00	\N	0.699999999999999956	01:01:00	00:53:00	Daniel Island Reach, Buoy '48'	SC
59513	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.8299999999999983	-79.9350000000000023	:America/New_York	USA	knots	197	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.800000000000000044	01:06:00	\N	0.299999999999999989	00:41:00	-00:29:00	Shipyard Creek entrance	SC
59514	Daniel Island Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.8328300000000013	-79.9300000000000068	:America/New_York	USA	knots	190	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:51:00	\N	1.19999999999999996	01:49:00	\N	0.800000000000000044	01:29:00	00:42:00	Daniel Island Reach	SC
59515	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.8483299999999971	-79.9291699999999992	:America/New_York	USA	knots	153	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:39:00	\N	1.10000000000000009	01:29:00	\N	0.699999999999999956	00:55:00	00:55:00	Daniel Island Bend	SC
59516	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.863669999999999	-79.9588300000000061	:America/New_York	USA	knots	142	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.900000000000000022	02:28:00	\N	0.599999999999999978	01:26:00	01:04:00	North Charleston	SC
59517	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.8886699999999976	-79.9653299999999945	:America/New_York	USA	knots	180	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:27:00	\N	0.900000000000000022	02:06:00	\N	0.699999999999999956	01:31:00	01:08:00	Filbin Creek Reach	SC
59518	Filbin Creek Reach, 0.2 mile east of, Cooper River, South Carolina Current	NOS	ACT6816_1	32.8879999999999981	-79.9604999999999961	:America/New_York	USA	knots	197	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:29:00	\N	0.699999999999999956	01:47:00	\N	0.400000000000000022	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
59519	Filbin Creek Reach, Buoy '58', Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.896329999999999	-79.9611699999999956	:America/New_York	USA	knots	214	31	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:09:00	\N	0.699999999999999956	02:04:00	\N	0.599999999999999978	01:18:00	01:24:00	Filbin Creek Reach, Buoy '58'	SC
59520	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.906329999999997	-79.9528300000000058	:America/New_York	USA	knots	242	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:07:00	\N	0.599999999999999978	02:34:00	\N	0.599999999999999978	01:35:00	01:05:00	Ordnance Reach	SC
59521	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.9088300000000018	-79.9363299999999981	:America/New_York	USA	knots	270	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.699999999999999956	02:41:00	\N	0.400000000000000022	02:06:00	00:57:00	Yellow House Creek	SC
59522	Yellow House Landing, 1 mile NW of, Cooper River, South Carolina Current	NOS	ACT6836_1	32.9196700000000035	-79.930499999999995	:America/New_York	USA	knots	170	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:06:00	\N	0.900000000000000022	02:43:00	\N	0.400000000000000022	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
59523	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.9258308410644531	-79.932830810546875	:America/New_York	USA	knots	157	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
59524	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.9316699999999969	-79.9383299999999934	:America/New_York	USA	knots	201	2	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.699999999999999956	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
59525	Snow Point, 0.5 mile north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.9300000000000068	:America/New_York	USA	knots	210	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:33:00	\N	0.699999999999999956	02:36:00	\N	0.599999999999999978	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
59526	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.9683300000000017	-79.933329999999998	:America/New_York	USA	knots	67	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:34:00	\N	0.599999999999999978	00:45:00	\N	0.599999999999999978	00:46:00	00:48:00	Back River entrance	SC
59527	Amoco Pier, off, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.9591700000000003	-79.9180000000000064	:America/New_York	USA	knots	191	24	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.5	02:49:00	\N	0.400000000000000022	02:09:00	02:10:00	Amoco Pier, off	SC
59528	Moreland, 0.5 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005000000000024	-79.9046699999999959	:America/New_York	USA	knots	216	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:19:00	\N	1	02:58:00	\N	1.10000000000000009	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
59529	Hagan Island, 1 n.mi. below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.0333299999999994	-79.913330000000002	:America/New_York	USA	knots	134	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.699999999999999956	03:52:00	\N	0.800000000000000044	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
59530	The Tee, 0.4 mile southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.0633300000000006	-79.9296700000000016	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:20:00	\N	0.900000000000000022	04:20:00	\N	0.599999999999999978	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
59531	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.0658299999999983	-79.9230000000000018	:America/New_York	USA	knots	161	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:43:00	\N	0.5	03:09:00	\N	0.599999999999999978	03:00:00	02:36:00	The Tee	SC
59532	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.093829999999997	-79.9424999999999955	:America/New_York	USA	knots	141	309	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:34:00	\N	0.900000000000000022	04:27:00	\N	0.400000000000000022	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
59533	East Branch, 0.2 mile above entrance, Cooper River, South Carolina Current	NOS	ACT6891_1	33.0683300000000031	-79.9200000000000017	:America/New_York	USA	knots	262	84	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:06:00	\N	0.900000000000000022	03:07:00	\N	1.10000000000000009	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
59534	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.0716699999999975	-79.8833300000000008	:America/New_York	USA	knots	197	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:36:00	\N	0.400000000000000022	03:10:00	\N	0.400000000000000022	03:27:00	02:44:00	Bonneau Ferry, east of	SC
59535	Remley Point, 0.2 mile northwest of, Wando River, South Carolina Current	NOS	ACT6901_1	32.8161699999999996	-79.9094999999999942	:America/New_York	USA	knots	191	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:04:00	\N	0.900000000000000022	00:36:00	\N	0.800000000000000044	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
59536	Wando River Upper Reach, Turning Basin, Wando River, South Carolina Current	NOS	ACT6906_1	32.8333299999999966	-79.8966700000000003	:America/New_York	USA	knots	192	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.599999999999999978	-00:12:00	\N	0.599999999999999978	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
59537	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.859499999999997	-79.8961699999999979	:America/New_York	USA	knots	216	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.900000000000000022	00:35:00	\N	0.800000000000000044	00:25:00	00:18:00	Rathall Creek entrance	SC
59538	Horlbeck Creek, 0.2 mile above entrance, Wando River, South Carolina Current	NOS	ACT6916_1	32.884999999999998	-79.8449999999999989	:America/New_York	USA	knots	218	26	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.5	00:29:00	\N	0.599999999999999978	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
59539	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.8783299999999983	-79.875	:America/New_York	USA	knots	171	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:39:00	\N	0.599999999999999978	00:42:00	\N	0.400000000000000022	-00:02:00	-00:12:00	Nowell Creek entrance	SC
59540	Buoy '19', off Nowell Creek, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.8719999999999999	-79.8654999999999973	:America/New_York	USA	knots	261	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Buoy '19', off Nowell Creek	SC
59541	Horlbeck Creek, 2.5 miles north of, Wando River, South Carolina Current	NOS	ACT6931_1	32.9183299999999974	-79.8383299999999991	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:28:00	\N	0.699999999999999956	00:41:00	\N	0.5	00:30:00	00:26:00	Horlbeck Creek, 2.5 miles north of	SC
59542	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.7671700000000001	-79.9338300000000004	:America/New_York	USA	knots	114	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.900000000000000022	00:09:00	\N	0.699999999999999956	00:16:00	-00:24:00	Battery, southwest of	SC
59543	Wappoo Creek, off of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.7730000000000032	-79.9500000000000028	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:41:00	\N	0.599999999999999978	-00:05:00	\N	0.699999999999999956	00:07:00	-00:06:00	Wappoo Creek, off of	SC
59544	Highway Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.7819999999999965	-79.9599999999999937	:America/New_York	USA	knots	138	321	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:18:00	\N	0.599999999999999978	00:30:00	\N	0.699999999999999956	-00:09:00	-00:03:00	Highway Bridge	SC
59545	S.C.L. RR. bridge, 0.1 mile below, Ashley River, South Carolina Current	NOS	ACT6951_1	32.795499999999997	-79.9733300000000042	:America/New_York	USA	knots	150	353	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:28:00	\N	0.599999999999999978	00:44:00	\N	0.599999999999999978	-00:06:00	-00:12:00	S.C.L. RR. bridge, 0.1 mile below	SC
59546	S.C.L. RR. bridge, 1.5 miles above, Ashley River, South Carolina Current	NOS	ACT6956_1	32.8200000000000003	-79.9650000000000034	:America/New_York	USA	knots	178	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:09:00	\N	0.800000000000000044	00:19:00	\N	0.699999999999999956	00:22:00	00:17:00	S.C.L. RR. bridge, 1.5 miles above	SC
59547	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.8371700000000004	-79.9819999999999993	:America/New_York	USA	knots	114	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:05:00	\N	0.5	-00:04:00	\N	0.599999999999999978	00:06:00	00:05:00	State Hwy. 7 bridge	SC
59548	West Marsh Island, 0.1 mile east of, Ashley River, South Carolina Current	NOS	ACT6966_1	32.8283300000000011	-80.0083300000000008	:America/New_York	USA	knots	86	250	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:25:00	\N	0.5	00:30:00	\N	0.400000000000000022	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
59549	Bees Ferry Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.8466700000000031	-80.0499999999999972	:America/New_York	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	1.19999999999999996	00:44:00	\N	1.10000000000000009	01:13:00	00:37:00	Bees Ferry Bridge	SC
59550	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.6266699999999972	-79.9933300000000003	:America/New_York	USA	knots	136	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:45:00	\N	1.39999999999999991	00:44:00	\N	1.10000000000000009	-00:14:00	-00:09:00	Stono Inlet	SC
59551	Snake Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.6400000000000006	-80.019999999999996	:America/New_York	USA	knots	179	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:38:00	\N	0.5	-00:42:00	\N	0.699999999999999956	-00:44:00	-00:30:00	Snake Island	SC
59552	Johns Island Airport, south of (Depth 12ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.683329999999998	-80.0033300000000054	:America/New_York	USA	knots	192	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.800000000000000044	-00:46:00	\N	0.900000000000000022	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
59553	Johns Island Bridge (Depth 14ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.7533299999999983	-80.0100000000000051	:America/New_York	USA	knots	182	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
59554	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.7666699999999977	-80	:America/New_York	USA	knots	80	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:18:00	\N	1	-01:00:00	\N	0.900000000000000022	00:10:00	-00:46:00	Elliott Cut, west end	SC
59555	Johns Island (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.7866700000000009	-80.106669999999994	:America/New_York	USA	knots	68	249	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:32:00	\N	0.400000000000000022	01:48:00	\N	0.400000000000000022	-00:24:00	00:29:00	Johns Island	SC
59556	Pleasant Point (Depth 12ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.1333300000000008	:America/New_York	USA	knots	196	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	03:37:00	\N	0.400000000000000022	00:34:00	\N	0.299999999999999989	02:04:00	03:54:00	Pleasant Point	SC
59557	Deveaux Banks, off North Edisto River entrance (Depth 12ft), South Carolina Current	NOS	ACT7021_1	32.5450000000000017	-80.1566700000000054	:America/New_York	USA	knots	126	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:26:00	\N	1	-00:01:00	\N	0.800000000000000044	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
59558	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.5616699999999994	-80.1866700000000066	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	1.89999999999999991	01:10:00	\N	1.69999999999999996	00:56:00	01:11:00	North Edisto River entrance	SC
59559	Wadmalaw Island, Wadmalaw River entrance (Depth 12ft), South Carolina Current	NOS	ACT7031_1	32.6649999999999991	-80.2349999999999994	:America/New_York	USA	knots	165	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.400000000000000022	00:11:00	\N	0.699999999999999956	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
59560	Goshen Point, SE of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7036_1	32.7100000000000009	-80.171670000000006	:America/New_York	USA	knots	249	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:48:00	\N	0.400000000000000022	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
59561	Goshen Point, south of, Wadmalaw River (Depth 12ft), South Carolina Current	NOS	ACT7041_1	32.7133299999999991	-80.1866700000000066	:America/New_York	USA	knots	235	48	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:53:00	\N	0.5	02:03:00	\N	0.400000000000000022	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
59562	White Point, south of, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.2816700000000054	:America/New_York	USA	knots	44	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:15:00	\N	0.400000000000000022	00:02:00	\N	0.400000000000000022	00:31:00	00:29:00	White Point, south of, Dawho River	SC
59563	Whooping Island, Dawho River (Depth 12ft), South Carolina Current	NOS	ACT7051_1	32.6366700000000023	-80.3400000000000034	:America/New_York	USA	knots	70	246	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:37:00	\N	0.299999999999999989	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
59564	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.4883299999999977	-80.3483300000000042	:America/New_York	USA	knots	146	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	1.10000000000000009	-00:14:00	\N	1.10000000000000009	00:19:00	-00:09:00	South Edisto River entrance	SC
59565	Pine Island, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7061_1	32.5066699999999997	-80.3616700000000037	:America/New_York	USA	knots	163	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:37:00	\N	0.5	-00:09:00	\N	0.699999999999999956	00:00:00	00:12:00	Pine Island, South Edisto River	SC
59566	Fenwick Island Cut, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7066_1	32.5349999999999966	-80.413330000000002	:America/New_York	USA	knots	23	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:26:00	\N	0.400000000000000022	-00:55:00	\N	0.400000000000000022	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
59567	Sampson Island, S end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7071_1	32.5633300000000006	-80.3916700000000048	:America/New_York	USA	knots	244	37	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.800000000000000044	00:34:00	\N	0.800000000000000044	00:59:00	00:59:00	Sampson Island, S end, South Edisto River	SC
59568	Sampson Island, NE end, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7076_1	32.6166699999999992	-80.3866699999999952	:America/New_York	USA	knots	156	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.800000000000000044	01:15:00	\N	0.800000000000000044	01:35:00	01:02:00	Sampson Island, NE end, South Edisto River	SC
59569	Jehossee Island, S tip, South Edisto River (Depth 15ft), South Carolina Current	NOS	ACT7081_1	32.6033299999999997	-80.4200000000000017	:America/New_York	USA	knots	69	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:05:00	\N	0.699999999999999956	00:48:00	\N	0.699999999999999956	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
59570	Smuggedy Swamp, South Edisto River (Depth 6ft), South Carolina Current	NOS	ACT7086_1	32.6599999999999966	-80.4116700000000009	:America/New_York	USA	knots	166	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:25:00	\N	0.699999999999999956	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
59571	Hutchinson Island, Ashepoo River (Depth 10ft), South Carolina Current	NOS	ACT7091_1	32.5316699999999983	-80.4350000000000023	:America/New_York	USA	knots	68	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:56:00	\N	0.699999999999999956	01:14:00	\N	0.599999999999999978	01:21:00	00:54:00	Hutchinson Island, Ashepoo River	SC
59572	Ashepoo Coosaw Cutoff (Depth 6ft), South Carolina Current	NOS	ACT7096_1	32.5249999999999986	-80.453329999999994	:America/New_York	USA	knots	265	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:12:00	\N	0.599999999999999978	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff	SC
59573	Pelican Bank, St. Helena Sound (Depth 15ft), South Carolina Current	NOS	ACT7101_1	32.4549999999999983	-80.4283300000000025	:America/New_York	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:35:00	\N	0.800000000000000044	-00:33:00	\N	0.900000000000000022	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
59574	Ashepoo River, off Jefford Creek entrance, South Carolina Current	NOS	ACT7106_1	32.5066699999999997	-80.4099999999999966	:America/New_York	USA	knots	197	16	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:43:00	\N	0.800000000000000044	00:46:00	\N	0.900000000000000022	01:04:00	01:00:00	Ashepoo River, off Jefford Creek entrance	SC
59575	Egg Bank, St. Helena Sound (Depth 10ft), South Carolina Current	NOS	ACT7111_1	32.4350000000000023	-80.4433300000000031	:America/New_York	USA	knots	128	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:20:00	\N	0.800000000000000044	-01:24:00	\N	0.800000000000000044	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
59576	Morgan Island, NE of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7116_1	32.4883299999999977	-80.4733300000000042	:America/New_York	USA	knots	125	303	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:19:00	\N	1	00:27:00	\N	0.800000000000000044	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
59577	Ashe Island Cut, SW of, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7121_1	32.509999999999998	-80.5049999999999955	:America/New_York	USA	knots	134	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.599999999999999978	-00:09:00	\N	0.599999999999999978	00:32:00	00:43:00	Ashe Island Cut, SW of, Coosaw River	SC
59578	Ashe Island Cut, St. Helena Sound (Depth 6ft), South Carolina Current	NOS	ACT7126_1	32.5200000000000031	-80.4883300000000048	:America/New_York	USA	knots	34	232	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:13:00	\N	0.400000000000000022	01:41:00	\N	0.5	00:31:00	01:01:00	Ashe Island Cut, St. Helena Sound	SC
59579	Combahee River (Depth 8ft), South Carolina Current	NOS	ACT7131_1	32.5266700000000029	-80.5366700000000009	:America/New_York	USA	knots	147	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:53:00	\N	0.800000000000000044	00:59:00	\N	0.599999999999999978	00:55:00	01:04:00	Combahee River	SC
59580	Combahee River (Depth 15ft), South Carolina Current	NOS	ACT7136_1	32.5499999999999972	-80.5633299999999934	:America/New_York	USA	knots	73	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:03:00	\N	1	01:35:00	\N	0.800000000000000044	01:36:00	01:33:00	Combahee River	SC
59581	Parrot Creek, Coosaw Island (Depth 15ft), South Carolina Current	NOS	ACT7141_1	32.4733299999999971	-80.5450000000000017	:America/New_York	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:54:00	\N	0.599999999999999978	-00:48:00	\N	0.699999999999999956	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
59582	Morgan Island, North end, Coosaw River (Depth 15ft), South Carolina Current	NOS	ACT7146_1	32.5033299999999983	-80.5366700000000009	:America/New_York	USA	knots	85	271	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:30:00	\N	0.900000000000000022	00:41:00	\N	0.800000000000000044	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
59583	Williman Creek (Depth 10ft), South Carolina Current	NOS	ACT7151_1	32.5616699999999994	-80.5916699999999935	:America/New_York	USA	knots	160	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:04:00	\N	0.800000000000000044	01:27:00	\N	0.599999999999999978	00:40:00	01:02:00	Williman Creek	SC
59584	Coosaw Island, South of, Morgan River (Depth 10ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.5833300000000037	:America/New_York	USA	knots	58	252	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:03:00	\N	0.699999999999999956	00:55:00	\N	0.699999999999999956	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
59585	Sams Point, Northwest of, Coosaw River (Depth 10ft), South Carolina Current	NOS	ACT7161_1	32.4933300000000003	-80.5933299999999946	:America/New_York	USA	knots	117	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:24:00	\N	0.599999999999999978	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northwest of, Coosaw River	SC
59586	Whale Branch River (Depth 10ft), South Carolina Current	NOS	ACT7166_1	32.5266700000000029	-80.691670000000002	:America/New_York	USA	knots	111	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:09:00	\N	0.699999999999999956	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
59587	Fripps Inlet, Fripps Island (Depth 15ft), South Carolina Current	NOS	ACT7171_1	32.3400000000000034	-80.4650000000000034	:America/New_York	USA	knots	104	299	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-01:29:00	\N	0.599999999999999978	01:12:00	\N	0.699999999999999956	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
59588	Southeast Channel entrance, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.1333300000000008	-80.5833300000000037	:America/New_York	USA	knots	150	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:12:00	\N	0.800000000000000044	-00:38:00	\N	0.800000000000000044	-00:30:00	-00:09:00	Southeast Channel entrance	SC
59589	Port Royal Plantation Tower, east of (Depth 15ft), South Carolina Current	NOS	ACT7186_1	32.2233299999999971	-80.6566700000000054	:America/New_York	USA	knots	147	347	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	1	-00:16:00	\N	0.900000000000000022	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
59590	Bay Point Island, S of, Broad River entrance (Depth 15ft), South Carolina Current	NOS	ACT7191_1	32.2333300000000023	-80.6299999999999955	:America/New_York	USA	knots	128	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:46:00	\N	0.900000000000000022	-01:09:00	\N	0.699999999999999956	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
59591	Broad River Entrance, Point Royal Sound (Depth 15ft), South Carolina Current	NOS	ACT7196_1	32.2316700000000012	-80.6400000000000006	:America/New_York	USA	knots	138	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:25:00	\N	0.900000000000000022	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
59592	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.6666699999999963	:America/New_York	USA	knots	146	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:01:00	\N	0.900000000000000022	00:49:00	\N	1.10000000000000009	00:16:00	00:32:00	Hilton Head	SC
59593	Beaufort River Entrance (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.288330000000002	-80.6516699999999958	:America/New_York	USA	knots	195	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:03:00	\N	0.699999999999999956	01:11:00	\N	0.699999999999999956	00:19:00	00:20:00	Beaufort River Entrance	SC
59594	Parris Island, Beaufort River (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7211_1	32.32667	-80.6566700000000054	:America/New_York	USA	knots	175	356	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:00:00	\N	0.800000000000000044	01:12:00	\N	0.699999999999999956	00:29:00	00:11:00	Parris Island, Beaufort River	SC
59595	Chowan Creek (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.3699999999999974	-80.6383299999999963	:America/New_York	USA	knots	246	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:34:00	\N	0.599999999999999978	01:53:00	\N	0.599999999999999978	00:24:00	00:23:00	Chowan Creek	SC
59596	Parris Island, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7221_1	32.3599999999999994	-80.6749999999999972	:America/New_York	USA	knots	149	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:22:00	\N	0.699999999999999956	01:19:00	\N	0.699999999999999956	00:56:00	00:51:00	Parris Island, Beaufort River	SC
59597	Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.4033299999999969	-80.671670000000006	:America/New_York	USA	knots	200	12	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Beaufort River	SC
59598	Beaufort, Beaufort River (Depth 12ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.4299999999999997	-80.6766700000000014	:America/New_York	USA	knots	257	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:17:00	\N	0.599999999999999978	01:18:00	\N	0.699999999999999956	00:55:00	01:08:00	Beaufort, Beaufort River	SC
59599	Beaufort Airport, Beaufort River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.4500000000000028	-80.663330000000002	:America/New_York	USA	knots	152	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
59600	Brickyard Creek (Depth 10ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.4733299999999971	-80.691670000000002	:America/New_York	USA	knots	171	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	02:58:00	\N	0.400000000000000022	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
59601	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.2633300000000034	-80.7416699999999992	:America/New_York	USA	knots	35	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-02:14:00	\N	0.599999999999999978	-01:20:00	\N	0.400000000000000022	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
59602	Daws Island, SE of, Broad River (Depth 15ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.3016700000000014	-80.7249999999999943	:America/New_York	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.800000000000000044	00:05:00	\N	0.800000000000000044	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
59603	Parris Island Lookout Tower, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7256_1	32.3116699999999994	-80.7066700000000026	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:16:00	\N	0.699999999999999956	-00:07:00	\N	0.699999999999999956	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
59604	Daws Island, south of, Chechessee River (Depth 15ft), South Carolina Current	NOS	ACT7261_1	32.2866700000000009	-80.7433300000000003	:America/New_York	USA	knots	142	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:31:00	\N	0.699999999999999956	-00:22:00	\N	0.599999999999999978	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
59605	Lemon Island South, Chechessee River (Depth 10ft), South Carolina Current	NOS	ACT7266_1	32.3500000000000014	-80.8066699999999969	:America/New_York	USA	knots	175	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	-00:02:00	\N	0.699999999999999956	01:19:00	\N	0.599999999999999978	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
59606	Broad River Bridge, S of, Broad River (Depth 15ft), South Carolina Current	NOS	ACT7271_1	32.3816699999999997	-80.7766699999999958	:America/New_York	USA	knots	156	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:07:00	\N	0.800000000000000044	-00:15:00	\N	0.599999999999999978	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
59607	Byrd Creek Entrance, SE of, Broad River (Depth 12ft), South Carolina Current	NOS	ACT7276_1	32.4566700000000026	-80.8183300000000031	:America/New_York	USA	knots	174	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:52:00	\N	0.5	00:51:00	\N	0.599999999999999978	01:27:00	01:32:00	Byrd Creek Entrance, SE of, Broad River	SC
59608	Little Barnwell I., E of, Whale Branch River (Depth 6ft), South Carolina Current	NOS	ACT7281_1	32.5016699999999972	-80.7866700000000009	:America/New_York	USA	knots	175	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16148	00:40:00	\N	0.400000000000000022	03:03:00	\N	0.599999999999999978	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
59609	Braddock Point, SW of, Calibogue Sound (Depth 10ft), South Carolina Current	NOS	ACT7286_1	32.1049999999999969	-80.836669999999998	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:04:00	\N	1	00:16:00	\N	0.800000000000000044	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
59610	Haig Point Light, NW of, Cooper River (Depth 10ft), South Carolina Current	NOS	ACT7291_1	32.1483300000000014	-80.8416699999999935	:America/New_York	USA	knots	94	278	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.699999999999999956	-00:05:00	\N	0.400000000000000022	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
59611	Ramshorn Creek Light, E of, Cooper River (Depth 6ft), South Carolina Current	NOS	ACT7296_1	32.1300000000000026	-80.8816699999999997	:America/New_York	USA	knots	98	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:17:00	\N	0.699999999999999956	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
59612	Spanish Wells, Calibogue Sound (Depth 30ft), Calibogue Sound, South Carolina Current	NOS	ACT7301_1	32.1866699999999994	-80.7849999999999966	:America/New_York	USA	knots	204	28	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.699999999999999956	00:51:00	\N	0.699999999999999956	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
59613	Skull Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.2233299999999971	-80.7849999999999966	:America/New_York	USA	knots	231	53	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:55:00	\N	0.400000000000000022	02:57:00	\N	0.400000000000000022	00:38:00	01:23:00	Skull Creek, south entrance	SC
59614	MacKay Creek, south entrance (Depth 10ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.2199999999999989	-80.7900000000000063	:America/New_York	USA	knots	212	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:26:00	\N	0.599999999999999978	00:03:00	\N	0.299999999999999989	00:06:00	00:12:00	MacKay Creek, south entrance	SC
59615	Bloody Pt., 0.5 mile north of, New River, South Carolina Current	NOS	ACT7316_1	32.0883299999999991	-80.8799999999999955	:America/New_York	USA	knots	147	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:13:00	\N	0.599999999999999978	00:00:00	\N	0.599999999999999978	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
59616	Bloody Pt., 0.5 mile west of, New River, South Carolina Current	NOS	ACT7321_1	32.0816700000000026	-80.8833300000000008	:America/New_York	USA	knots	92	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.900000000000000022	-00:21:00	\N	0.900000000000000022	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
59617	Wright R., 0.2 mile above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.0850000000000009	-80.921670000000006	:America/New_York	USA	knots	142	332	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.800000000000000044	-00:16:00	\N	0.599999999999999978	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
59618	Walls Cut, Turtle Island (Depth 6ft), South Carolina Current	NOS	ACT7336_1	32.0816700000000026	-80.9166699999999963	:America/New_York	USA	knots	100	294	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
59619	Daufuskie Landing Light, south of (Depth 10ft), South Carolina Current	NOS	ACT7341_1	32.1016699999999986	-80.8983300000000014	:America/New_York	USA	knots	226	43	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:45:00	\N	0.800000000000000044	01:04:00	\N	0.699999999999999956	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
59620	Fort Pulaski, Savannah River, Georgia Current	NOS	ACT7356_1	32.0366700000000009	-80.9016699999999958	:America/New_York	USA	knots	98	283	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:09:00	\N	1.5	00:51:00	\N	0.900000000000000022	00:42:00	00:15:00	Fort Pulaski	GA
59621	Fort Pulaski, 1.8 miles above, Savannah River, Georgia Current	NOS	ACT7361_1	32.0450000000000017	-80.9316699999999969	:America/New_York	USA	knots	140	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:12:00	\N	1.39999999999999991	00:18:00	\N	1.10000000000000009	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
59622	Fort Pulaski, 4.8 miles above, Savannah River, Georgia Current	NOS	ACT7366_1	32.0750000000000028	-80.9766699999999986	:America/New_York	USA	knots	116	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:16:00	\N	1.5	00:31:00	\N	1.10000000000000009	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
59623	McQueen Island Cut (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.0649999999999977	-80.9866700000000037	:America/New_York	USA	knots	69	251	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.599999999999999978	-02:45:00	\N	0.299999999999999989	-02:39:00	-01:04:00	McQueen Island Cut	GA
59624	Elba Island Cut, NE of, Savannah River (Depth 10ft), South Carolina Current	NOS	ACT7376_1	32.0733299999999986	-80.9650000000000034	:America/New_York	USA	knots	104	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:14:00	\N	1.30000000000000004	00:15:00	\N	0.699999999999999956	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
59625	Elba Island, NE of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7381_1	32.0900000000000034	-80.9933300000000003	:America/New_York	USA	knots	149	329	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	1.19999999999999996	00:40:00	\N	0.599999999999999978	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
59626	Elba Island, west of, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7386_1	32.0949999999999989	-81.019999999999996	:America/New_York	USA	knots	40	219	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.800000000000000044	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	GA
59627	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.0850000000000009	-81.0499999999999972	:America/New_York	USA	knots	94	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.699999999999999956	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
59628	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.0883299999999991	-81.0166700000000048	:America/New_York	USA	knots	122	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:35:00	\N	0.699999999999999956	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
59629	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.0016700000000043	:America/New_York	USA	knots	206	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:25:00	\N	0.800000000000000044	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
59630	Savannah, southeast of highway bridge (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.086669999999998	-81.0966700000000031	:America/New_York	USA	knots	146	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:05:00	\N	1.30000000000000004	00:41:00	\N	0.599999999999999978	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
59631	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.0833299999999966	-81.0833300000000037	:America/New_York	USA	knots	106	279	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:18:00	\N	1.10000000000000009	00:45:00	\N	0.800000000000000044	01:12:00	00:01:00	Savannah	GA
59632	Kings Island Channel, Savannah River (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7416_1	32.1266699999999972	-81.1366699999999952	:America/New_York	USA	knots	152	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	1	00:45:00	\N	0.800000000000000044	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
59633	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.1033299999999997	-81.1183300000000003	:America/New_York	USA	knots	150	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:59:00	\N	1.69999999999999996	00:45:00	\N	1.19999999999999996	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
59634	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.1233300000000028	-81.1350000000000051	:America/New_York	USA	knots	160	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:48:00	\N	1	00:54:00	\N	0.699999999999999956	01:21:00	00:33:00	King Island, west of	GA
59635	Port Wentworth, 0.2 mile above, Savannah River, Georgia Current	NOS	ACT7431_1	32.1466700000000003	-81.1400000000000006	:America/New_York	USA	knots	210	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	01:19:00	\N	0.699999999999999956	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
59636	Wassaw Island, N of E end, Wassaw Sound (Depth 10ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.9149999999999991	-80.9383299999999934	:America/New_York	USA	knots	108	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	1	-00:50:00	\N	0.699999999999999956	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
59637	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.9416699999999985	-80.9316699999999969	:America/New_York	USA	knots	156	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1.10000000000000009	-01:00:00	\N	0.900000000000000022	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
59638	Wilmington Island, SSE of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.9666700000000006	-80.9300000000000068	:America/New_York	USA	knots	218	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:00:00	\N	0.699999999999999956	00:38:00	\N	0.400000000000000022	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
59639	Lazaretto Creek Entrance, N of, Bull River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.9283300000000025	:America/New_York	USA	knots	207	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:04:00	\N	0.699999999999999956	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
59640	Bull River, 2 miles below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.0183299999999988	-80.9399999999999977	:America/New_York	USA	knots	151	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:57:00	\N	0.800000000000000044	-00:18:00	\N	0.599999999999999978	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
59641	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.9166699999999999	-80.9466699999999975	:America/New_York	USA	knots	105	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.900000000000000022	-01:11:00	\N	0.699999999999999956	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
59642	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.9383300000000006	-80.9766699999999986	:America/New_York	USA	knots	138	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.800000000000000044	-00:36:00	\N	0.599999999999999978	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
59643	Joe's Cut, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.9433299999999996	-80.9849999999999994	:America/New_York	USA	knots	123	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:44:00	\N	1	-00:48:00	\N	0.599999999999999978	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
59644	Wilmington R., 0.5 mi. S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.0050000000000026	-81.0033300000000054	:America/New_York	USA	knots	154	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.699999999999999956	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
59645	Thunderbolt, SE of, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.0233300000000014	-81.0450000000000017	:America/New_York	USA	knots	121	298	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:25:00	\N	0.5	-01:04:00	\N	0.400000000000000022	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
59646	Oatland Island, north tip (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.0733299999999986	-81.0100000000000051	:America/New_York	USA	knots	138	317	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:32:00	\N	0.5	-02:14:00	\N	0.299999999999999989	-03:20:00	-00:43:00	Oatland Island, north tip	GA
59647	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.0083300000000008	-81.0166700000000048	:America/New_York	USA	knots	16	204	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.699999999999999956	-00:02:00	\N	0.599999999999999978	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
59648	Skidaway Island, N End, Wilmington River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.009999999999998	-81.0083300000000008	:America/New_York	USA	knots	119	307	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.900000000000000022	00:16:00	\N	0.599999999999999978	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
59649	Dutch Island, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.9916699999999992	-81.019999999999996	:America/New_York	USA	knots	61	245	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:02:00	\N	0.599999999999999978	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
59650	Isle of Hope City, SE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.9766699999999986	-81.046670000000006	:America/New_York	USA	knots	72	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:40:00	\N	0.299999999999999989	-00:30:00	\N	0.200000000000000011	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
59651	Isle of Hope City, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.9800000000000004	-81.0550000000000068	:America/New_York	USA	knots	28	212	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.299999999999999989	00:00:00	\N	0.400000000000000022	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
59652	Burntpot Island, west of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.9683300000000017	-81.0533300000000025	:America/New_York	USA	knots	18	194	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
59653	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.9533300000000011	-81.0649999999999977	:America/New_York	USA	knots	42	218	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
59654	Long Island, NNE of, Skidaway River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.956669999999999	-81.0600000000000023	:America/New_York	USA	knots	47	226	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:17:00	\N	0.400000000000000022	-01:09:00	\N	0.400000000000000022	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
59655	Long Island, south of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.9433299999999996	-81.0733299999999986	:America/New_York	USA	knots	258	75	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-08:05:00	\N	0.299999999999999989	-04:43:00	\N	0.200000000000000011	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
59656	Pigeon Island, SSE of, Skidaway River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.9366699999999994	-81.0766699999999929	:America/New_York	USA	knots	150	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:16:00	\N	0.5	-02:43:00	\N	0.200000000000000011	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
59657	Burnside Island, SE of, Burnside River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.9216699999999989	-81.0799999999999983	:America/New_York	USA	knots	295	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.599999999999999978	00:53:00	\N	0.400000000000000022	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
59658	Little Don Island, east of, Vernon River (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.870000000000001	-81.0733299999999986	:America/New_York	USA	knots	153	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.699999999999999956	-01:16:00	\N	0.699999999999999956	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
59659	Little Ogeechee River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.8883299999999998	-81.0983300000000042	:America/New_York	USA	knots	71	259	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:06:00	\N	1	-00:59:00	\N	0.699999999999999956	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
59660	Little Ogeechee River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.8883299999999998	-81.0983300000000042	:America/New_York	USA	knots	73	244	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	0.900000000000000022	-00:50:00	\N	0.599999999999999978	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
59697	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.3449999999999989	-81.2349999999999994	:America/New_York	USA	knots	114	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:53:00	\N	0.699999999999999956	-00:29:00	\N	0.699999999999999956	-00:29:00	-00:09:00	Bar	GA
59661	Montgomery, Vernon River (Depth 6ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.9349999999999987	-81.1283300000000054	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:30:00	\N	0.599999999999999978	00:00:00	\N	0.299999999999999989	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
59662	Odingsell River Entrance (Depth 10ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.8683300000000003	-81	:America/New_York	USA	knots	212	32	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:14:00	\N	0.900000000000000022	00:44:00	\N	0.699999999999999956	-00:54:00	-00:48:00	Odingsell River Entrance	GA
59663	Odingsell River Entrance (Depth 20ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.8683300000000003	-81	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:12:00	\N	0.800000000000000044	00:42:00	\N	0.599999999999999978	-01:19:00	-00:42:00	Odingsell River Entrance	GA
59664	Wassaw Island, SSW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.8566700000000012	-81.0083300000000008	:America/New_York	USA	knots	123	316	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	1.10000000000000009	-01:04:00	\N	0.800000000000000044	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
59665	Wassaw Island, SSW of (Depth 20ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.8566700000000012	-81.0083300000000008	:America/New_York	USA	knots	132	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:01:00	\N	0.900000000000000022	-00:58:00	\N	0.699999999999999956	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
59666	Bradley Point, NNE of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.831669999999999	-81.038330000000002	:America/New_York	USA	knots	125	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.800000000000000044	-00:58:00	\N	0.599999999999999978	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
59667	Raccoon Key (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.8616700000000002	-81.0550000000000068	:America/New_York	USA	knots	117	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:35:00	\N	0.900000000000000022	-01:23:00	\N	0.800000000000000044	-00:45:00	-00:36:00	Raccoon Key	GA
59668	Little Wassaw Island, SW of (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.870000000000001	-81.0499999999999972	:America/New_York	USA	knots	116	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.699999999999999956	-00:17:00	\N	0.900000000000000022	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
59669	Vernon R., 1.2 miles S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.8983300000000014	-81.0983300000000042	:America/New_York	USA	knots	166	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:33:00	\N	0.800000000000000044	00:02:00	\N	0.599999999999999978	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
59670	Little Ogeechee River Entrance, north of (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.8966700000000003	-81.0949999999999989	:America/New_York	USA	knots	156	324	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:03:00	\N	0.800000000000000044	00:29:00	\N	0.599999999999999978	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
59671	Raccoon Key & Egg Island Shoal, between (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.8428299999999993	-81.0674999999999955	:America/New_York	USA	knots	129	254	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:57:00	\N	1	00:17:00	\N	0.800000000000000044	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
59672	Florida Passage, N of, Ogeechee River (Depth 10ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.8566700000000012	-81.143330000000006	:America/New_York	USA	knots	127	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:05:00	\N	1	00:01:00	\N	0.699999999999999956	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
59673	Florida Passage (south) (Depth 6ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.8296700000000001	-81.1578300000000041	:America/New_York	USA	knots	18	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.699999999999999956	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
59674	610 Statute Mile Mark (Depth 6ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105000000000011	-81.1766700000000014	:America/New_York	USA	knots	175	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	0.699999999999999956	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
59675	North of Big Tom Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7621_1	31.7833299999999994	-81.1603300000000019	:America/New_York	USA	knots	179	11	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:25:00	\N	0.699999999999999956	-00:13:00	\N	0.599999999999999978	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
59676	South of Kilkenny Creek Entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.7583300000000008	-81.1733300000000071	:America/New_York	USA	knots	190	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	1	01:25:00	\N	0.599999999999999978	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
59677	Northwest of Newell Creek Entrance (Depth 10ft), Bear River, Georgia Current	NOS	ACT7631_1	31.7488300000000017	-81.1654999999999944	:America/New_York	USA	knots	149	349	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:12:00	\N	0.900000000000000022	00:12:00	\N	0.599999999999999978	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
59678	Medway River at Marsh Island (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.7433300000000003	-81.2199999999999989	:America/New_York	USA	knots	117	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:56:00	\N	0.800000000000000044	-00:18:00	\N	0.299999999999999989	00:20:00	-00:15:00	Medway River at Marsh Island	GA
59679	St. Catherines Sound Entrance (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7641_1	31.7149999999999999	-81.140500000000003	:America/New_York	USA	knots	126	291	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.800000000000000044	-00:31:00	\N	0.900000000000000022	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
59680	Medway River, northwest of Cedar Point (Depth 10ft), Georgia Current	NOS	ACT7646_1	31.714500000000001	-81.1908300000000054	:America/New_York	USA	knots	146	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.800000000000000044	-00:43:00	\N	0.699999999999999956	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
59681	N. Newport River, NE of Vandyke Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7651_1	31.6911699999999996	-81.1869999999999976	:America/New_York	USA	knots	45	233	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.800000000000000044	00:12:00	\N	0.699999999999999956	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
59682	N. Newport River, above Walburg Creek (Depth 6ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.6738299999999988	-81.1953299999999984	:America/New_York	USA	knots	11	195	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:40:00	\N	0.800000000000000044	00:30:00	\N	0.599999999999999978	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
59683	N. Newport River, NW of Johnson Creek (Depth 10ft), St. Catherines Sound, Georgia Current	NOS	ACT7661_1	31.6630000000000003	-81.2104999999999961	:America/New_York	USA	knots	138	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:27:00	\N	0.900000000000000022	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
59684	N. Newport River, ESE of S. Newport Cut (Depth 6ft), Georgia Current	NOS	ACT7666_1	31.6653300000000009	-81.2644999999999982	:America/New_York	USA	knots	147	319	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:15:00	\N	0.699999999999999956	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
59685	S. Newport River, below S. Newport Cut (Depth 10ft), Georgia Current	NOS	ACT7671_1	31.6503300000000003	-81.3020000000000067	:America/New_York	USA	knots	134	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
59686	S. Newport River, above Swain River Ent (Depth 10ft), Georgia Current	NOS	ACT7676_1	31.6245000000000012	-81.2166699999999935	:America/New_York	USA	knots	156	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.599999999999999978	-01:13:00	\N	0.599999999999999978	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
59687	Entrance (Depth 19ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.5399999999999991	-81.1800000000000068	:America/New_York	USA	knots	118	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.10000000000000009	00:28:00	\N	0.900000000000000022	-00:30:00	-00:06:00	Entrance	GA
59688	Entrance (Depth 29ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.5399999999999991	-81.1800000000000068	:America/New_York	USA	knots	116	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:02:00	\N	0.900000000000000022	-00:36:00	\N	0.699999999999999956	-00:48:00	-00:17:00	Entrance	GA
59689	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.6266700000000007	-81.1883299999999934	:America/New_York	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:59:00	\N	0.400000000000000022	-01:08:00	\N	0.400000000000000022	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
59690	Cedar Hammock, south of (Depth 12ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.5450000000000017	-81.2466699999999946	:America/New_York	USA	knots	96	277	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:38:00	\N	0.599999999999999978	-01:00:00	\N	0.699999999999999956	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
59691	Sapelo River Entrance (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.5350000000000001	-81.2716700000000003	:America/New_York	USA	knots	58	234	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:43:00	\N	0.599999999999999978	-01:05:00	\N	0.599999999999999978	-00:23:00	-00:13:00	Sapelo River Entrance	GA
59692	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.3333300000000037	:America/New_York	USA	knots	104	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.599999999999999978	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
59693	Front River (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.5133299999999998	-81.2983300000000071	:America/New_York	USA	knots	56	227	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:05:00	\N	0.5	01:16:00	\N	0.400000000000000022	-00:33:00	-00:25:00	Front River	GA
59694	New Teakettle Cr., 0.8 mi. N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.4966700000000017	-81.2900000000000063	:America/New_York	USA	knots	53	236	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:11:00	\N	0.5	-00:29:00	\N	0.400000000000000022	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
59695	Crescent River (Depth 11ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.4866700000000002	-81.3066699999999969	:America/New_York	USA	knots	133	293	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:21:00	\N	0.5	01:07:00	\N	0.200000000000000011	-01:27:00	-00:34:00	Crescent River	GA
59696	Old Teakettle Creek (north) (Depth 13ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.4783299999999997	-81.328329999999994	:America/New_York	USA	knots	256	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:37:00	\N	0.599999999999999978	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
59698	Entrance (Depth 14ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.3416700000000006	-81.2633299999999963	:America/New_York	USA	knots	106	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:49:00	\N	0.900000000000000022	-00:10:00	\N	0.800000000000000044	-00:32:00	-00:24:00	Entrance	GA
59699	Entrance (Depth 22ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.3416700000000006	-81.2633299999999963	:America/New_York	USA	knots	99	276	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:26:00	\N	0.800000000000000044	-00:05:00	\N	0.800000000000000044	-00:56:00	-00:20:00	Entrance	GA
59700	Old Teakettle Creek Entrance, south of (Depth 15ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.4200000000000017	-81.3149999999999977	:America/New_York	USA	knots	159	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
59701	Old Teakettle Creek (south) (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.4366699999999994	-81.308329999999998	:America/New_York	USA	knots	207	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-02:44:00	\N	0.400000000000000022	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
59702	Folly River and Cardigan River, between (Depth 10ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.4416699999999985	-81.336669999999998	:America/New_York	USA	knots	150	327	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	0.299999999999999989	-00:56:00	\N	0.299999999999999989	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
59703	South River (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.3666699999999992	-81.3116700000000066	:America/New_York	USA	knots	95	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.699999999999999956	-00:25:00	\N	0.599999999999999978	-00:22:00	-00:32:00	South River	GA
59704	South River (Depth 21ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.3666699999999992	-81.3116700000000066	:America/New_York	USA	knots	95	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:24:00	\N	0.400000000000000022	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
59705	North River at Darien River (Depth 9ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.3833300000000008	-81.3349999999999937	:America/New_York	USA	knots	29	247	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.200000000000000011	-00:33:00	\N	0.200000000000000011	-00:10:00	00:08:00	North River at Darien River	GA
59706	Doboy Island (North River) (Depth 12ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.4033300000000004	-81.328329999999994	:America/New_York	USA	knots	37	224	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:13:00	\N	0.5	-00:06:00	\N	0.599999999999999978	-00:14:00	00:47:00	Doboy Island (North River)	GA
59707	Doboy Island (North River) (Depth 20ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.4033300000000004	-81.328329999999994	:America/New_York	USA	knots	43	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:22:00	\N	0.299999999999999989	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
59708	Buzzard Roost Creek (Depth 13ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.4149999999999991	-81.375	:America/New_York	USA	knots	2	177	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:28:00	\N	0.200000000000000011	00:12:00	\N	0.299999999999999989	00:22:00	00:56:00	Buzzard Roost Creek	GA
59709	Little Egg Island, northwest of (Depth 12ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.3183299999999996	-81.3050000000000068	:America/New_York	USA	knots	110	296	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:10:00	\N	0.599999999999999978	-00:53:00	\N	0.599999999999999978	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
59710	Little Mud River Range (Depth 9ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.3183300000000031	:America/New_York	USA	knots	116	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:06:00	\N	0.5	-01:05:00	\N	0.299999999999999989	-00:38:00	-00:23:00	Little Mud River Range	GA
59711	Little St. Simon Island (north) (Depth 11ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.3116699999999994	-81.3533299999999997	:America/New_York	USA	knots	89	267	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:29:00	\N	0.800000000000000044	00:06:00	\N	0.599999999999999978	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
59712	Onemile Cut, 1 mile southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.3133300000000006	-81.3516699999999986	:America/New_York	USA	knots	92	272	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:32:00	\N	0.900000000000000022	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
59713	Broughton Island (south) (Depth 9ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.3099999999999987	-81.413330000000002	:America/New_York	USA	knots	30	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:51:00	\N	0.400000000000000022	00:12:00	\N	0.400000000000000022	-02:06:00	-00:01:00	Broughton Island (south)	GA
59714	Bar Channel (Depth 12ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.1050000000000004	-81.3383299999999991	:America/New_York	USA	knots	119	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.800000000000000044	-00:44:00	\N	0.400000000000000022	-00:13:00	00:09:00	Bar Channel	GA
59715	Entrance, north of channel (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335000000000015	-81.4039999999999964	:America/New_York	USA	knots	107	290	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:11:00	\N	0.599999999999999978	00:18:00	\N	0.900000000000000022	-00:32:00	00:07:00	Entrance, north of channel	GA
59716	Entrance, south of channel (Depth 11ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.1266700000000007	-81.4033299999999969	:America/New_York	USA	knots	80	262	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:59:00	\N	1.10000000000000009	-00:32:00	\N	0.800000000000000044	-00:27:00	-00:21:00	Entrance, south of channel	GA
59717	Entrance, south of channel (Depth 29ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.1266700000000007	-81.4033299999999969	:America/New_York	USA	knots	92	257	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:21:00	\N	0.800000000000000044	-00:03:00	\N	0.599999999999999978	-00:18:00	00:06:00	Entrance, south of channel	GA
59718	Back River entrance (Depth 10ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.1483300000000014	-81.441670000000002	:America/New_York	USA	knots	111	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
59719	Back River entrance (Depth 18ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.1483300000000014	-81.441670000000002	:America/New_York	USA	knots	109	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:15:00	\N	0.400000000000000022	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
59720	Mackay R., 0.5 mi. N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.2250000000000014	-81.433329999999998	:America/New_York	USA	knots	166	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	00:24:00	\N	0.699999999999999956	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
59721	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.1116700000000002	-81.4733300000000042	:America/New_York	USA	knots	125	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:39:00	\N	1	-00:03:00	\N	0.699999999999999956	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
59722	Brunswick River Bridge, southeast of (Depth 13ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.1149999999999984	-81.4766699999999986	:America/New_York	USA	knots	132	308	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:09:00	\N	0.699999999999999956	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
59723	Brunswick River Bridge, southeast of (Depth 21ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.1149999999999984	-81.4766699999999986	:America/New_York	USA	knots	129	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:02:00	\N	0.699999999999999956	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
59724	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.1383299999999998	-81.4966699999999946	:America/New_York	USA	knots	166	342	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:08:00	\N	0.599999999999999978	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
59725	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.1766700000000014	-81.5250000000000057	:America/New_York	USA	knots	165	348	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:33:00	\N	0.800000000000000044	00:18:00	\N	0.699999999999999956	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
59726	Turtle River, off Andrews Island (Depth 20ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.1433299999999988	-81.5266699999999958	:America/New_York	USA	knots	153	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:23:00	\N	0.699999999999999956	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
59727	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.9866700000000002	-81.4050000000000011	:America/New_York	USA	knots	103	268	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:00:00	\N	1.10000000000000009	00:13:00	\N	1.10000000000000009	-00:18:00	00:02:00	Entrance	GA
59728	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.0350000000000001	-81.433329999999998	:America/New_York	USA	knots	232	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:20:00	\N	0.699999999999999956	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
59729	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.9583300000000001	-81.4316699999999969	:America/New_York	USA	knots	18	191	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-01:18:00	\N	0.699999999999999956	00:32:00	\N	0.699999999999999956	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
59730	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.8816699999999997	-81.5133299999999963	:America/New_York	USA	knots	355	171	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16162	-00:45:00	\N	0.599999999999999978	01:29:00	\N	0.699999999999999956	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
59731	Mayport (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-00:04:00	\N	1.60000000000000009	01:02:00	\N	1.10000000000000009	00:06:00	00:15:00	Mayport	FL
59732	Mayport (Depth 17ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:05:00	\N	1.30000000000000004	00:38:00	\N	1.10000000000000009	-00:03:00	00:12:00	Mayport	FL
59733	Mayport (Depth 27ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.3933299999999988	-81.433329999999998	:America/New_York	USA	knots	26	211	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:14:00	\N	0.900000000000000022	00:26:00	\N	0.900000000000000022	-00:27:00	00:15:00	Mayport	FL
59734	Mile Point, southeast of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT7976_1	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:44:00	\N	1.60000000000000009	00:38:00	\N	1.5	00:06:00	00:48:00	Mile Point, southeast of	FL
59735	Mile Point, southeast of (Depth 18ft), St. Johns River, Florida Current	NOS	ACT7976_2	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:56:00	\N	1.19999999999999996	00:38:00	\N	1.19999999999999996	-00:12:00	00:54:00	Mile Point, southeast of	FL
59736	Mile Point, southeast of (Depth 29ft), St. Johns River, Florida Current	NOS	ACT7976_3	30.3816699999999997	-81.4449999999999932	:America/New_York	USA	knots	73	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:38:00	\N	0.900000000000000022	00:38:00	\N	1.10000000000000009	-00:42:00	01:00:00	Mile Point, southeast of	FL
59737	Pablo Creek bascule bridge (Depth 3ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.3233299999999986	-81.4383299999999934	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	00:59:00	\N	2.5	-00:18:00	\N	1.69999999999999996	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
59738	Sisters Creek entrance (bridge) (Depth 4ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.3900000000000006	-81.461669999999998	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.800000000000000044	-03:14:00	\N	0.800000000000000044	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
59739	Sisters Creek entrance (bridge) (Depth 10ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.3900000000000006	-81.461669999999998	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	-02:34:00	\N	0.599999999999999978	-03:04:00	\N	0.599999999999999978	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
59740	Drummond Point, channel south of (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	60	241	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:00:00	\N	0.800000000000000044	02:32:00	\N	0.699999999999999956	01:51:00	02:44:00	Drummond Point, channel south of	FL
59741	Drummond Point, channel south of (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	61	222	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:01:00	\N	0.699999999999999956	02:35:00	\N	0.699999999999999956	01:34:00	02:51:00	Drummond Point, channel south of	FL
59742	Drummond Point, channel south of (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.4091699999999996	-81.6028299999999973	:America/New_York	USA	knots	57	243	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	02:51:00	\N	0.5	02:20:00	\N	0.599999999999999978	01:21:00	02:46:00	Drummond Point, channel south of	FL
59743	Terminal Channel (north end) (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.599999999999999978	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
59744	Terminal Channel (north end) (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	183	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:33:00	\N	0.5	03:06:00	\N	0.599999999999999978	02:16:00	03:20:00	Terminal Channel (north end)	FL
59745	Terminal Channel (north end) (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.3569999999999993	-81.617999999999995	:America/New_York	USA	knots	1	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.299999999999999989	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
59746	Commodore Point, terminal channel (Depth 7ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	72	197	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
59747	Commodore Point, terminal channel (Depth 17ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	51	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:25:00	\N	0.400000000000000022	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
59748	Commodore Point, terminal channel (Depth 27ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.317499999999999	-81.6263299999999958	:America/New_York	USA	knots	35	221	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:08:00	\N	0.400000000000000022	02:30:00	\N	0.599999999999999978	01:43:00	03:38:00	Commodore Point, terminal channel	FL
59749	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.321670000000001	-81.6533299999999969	:America/New_York	USA	knots	118	281	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:23:00	\N	0.900000000000000022	03:10:00	\N	0.900000000000000022	02:59:00	02:54:00	Jacksonville, off Washington St	FL
59750	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.3083300000000015	-81.6749999999999972	:America/New_York	USA	knots	15	200	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:59:00	\N	0.5	03:22:00	\N	0.599999999999999978	02:59:00	04:04:00	Winter Point	FL
59751	Mandarin Point (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.400000000000000022	03:39:00	\N	0.299999999999999989	03:07:00	03:24:00	Mandarin Point	FL
59752	Mandarin Point (Depth 15ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:38:00	\N	0.299999999999999989	03:33:00	\N	0.299999999999999989	03:13:00	03:24:00	Mandarin Point	FL
59753	Mandarin Point (Depth 24ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.1550000000000011	-81.6850000000000023	:America/New_York	USA	knots	13	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	03:32:00	\N	0.299999999999999989	03:33:00	\N	0.299999999999999989	02:48:00	03:24:00	Mandarin Point	FL
59754	Red Bay Point, draw bridge (Depth 4ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:02:00	\N	0.299999999999999989	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
59755	Red Bay Point, draw bridge (Depth 6ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.299999999999999989	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
59756	Red Bay Point, draw bridge (Depth 14ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.9849999999999994	-81.6299999999999955	:America/New_York	USA	knots	300	115	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16163	04:08:00	\N	0.200000000000000011	03:57:00	\N	0.400000000000000022	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
59757	Point Ybel, 0.4 mile northwest of, Florida Current	NOS	ACT8306_1	26.456669999999999	-82.0186700000000002	:America/New_York	USA	knots	80	255	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:35:00	\N	0.699999999999999956	-00:52:00	\N	0.800000000000000044	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
59758	Captiva Pass, Florida Current	NOS	ACT8311_1	26.6093299999999999	-82.2223299999999995	:America/New_York	USA	knots	251	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:23:00	\N	0.900000000000000022	-01:29:00	\N	1.39999999999999991	-00:53:00	-01:14:00	Captiva Pass	FL
59759	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.7143300000000004	-82.2566699999999997	:America/New_York	USA	knots	251	57	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:05:00	\N	1.30000000000000004	-00:37:00	\N	1.69999999999999996	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
59760	Cape Haze, 2.3 mi. S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745000000000001	-82.1516699999999958	:America/New_York	USA	knots	268	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	01:18:00	\N	0.400000000000000022	00:41:00	\N	0.400000000000000022	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
59761	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.8123299999999993	-82.2810000000000059	:America/New_York	USA	knots	236	66	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:41:00	\N	0.800000000000000044	-01:13:00	\N	0.800000000000000044	-01:15:00	-00:35:00	Gasparilla Pass	FL
59762	Venice Inlet, Florida Current	NOS	ACT8351_1	27.1133300000000013	-82.4666699999999935	:America/New_York	USA	knots	262	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:59:00	\N	0.699999999999999956	-02:08:00	\N	0.800000000000000044	-02:05:00	-01:57:00	Venice Inlet	FL
59763	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.1233299999999993	-82.4699999999999989	:America/New_York	USA	knots	180	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:10:00	\N	0.5	-01:20:00	\N	0.699999999999999956	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
59764	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.1799999999999997	-82.4950000000000045	:America/New_York	USA	knots	357	167	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.5	-00:56:00	\N	1.10000000000000009	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
59765	Midnight Pass entrance, Florida Current	NOS	ACT8366_1	27.206669999999999	-82.5100000000000051	:America/New_York	USA	knots	242	61	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:13:00	\N	1.10000000000000009	-01:59:00	\N	1.39999999999999991	-01:43:00	-01:49:00	Midnight Pass entrance	FL
59766	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3000000000000007	-82.5633299999999934	:America/New_York	USA	knots	183	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-02:03:00	\N	0.800000000000000044	-01:49:00	\N	1.19999999999999996	-01:54:00	-01:34:00	Big Sarasota Pass	FL
59767	Sarasota Bay, south end, bridge, Sarasota Bay, Florida Current	NOS	ACT8376_1	27.3016700000000014	-82.546670000000006	:America/New_York	USA	knots	13	196	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:32:00	\N	0.200000000000000011	-01:39:00	\N	0.200000000000000011	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
59768	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.331669999999999	-82.5816700000000026	:America/New_York	USA	knots	231	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:25:00	\N	0.800000000000000044	-02:48:00	\N	1.19999999999999996	-02:06:00	-01:18:00	New Pass	FL
59769	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.3283300000000011	-82.5566699999999969	:America/New_York	USA	knots	159	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:19:00	\N	0.200000000000000011	-01:57:00	\N	0.299999999999999989	-01:38:00	-01:25:00	Golden Gate Point, off	FL
59770	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.4416699999999985	-82.6899999999999977	:America/New_York	USA	knots	267	88	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:56:00	\N	1.19999999999999996	-02:42:00	\N	1.39999999999999991	-02:32:00	-01:51:00	Longboat Pass	FL
59771	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.4699999999999989	-82.6933300000000031	:America/New_York	USA	knots	162	346	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:11:00	\N	0.100000000000000006	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
59772	Egmont Channel, marker '10' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005000000000003	-82.8676700000000039	:America/New_York	USA	knots	259	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:31:00	\N	0.200000000000000011	-03:17:00	\N	0.200000000000000011	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
59773	Egmont Channel (3 mi. W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.6083299999999987	-82.8183300000000031	:America/New_York	USA	knots	260	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:29:00	\N	0.5	-00:28:00	\N	0.400000000000000022	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
59774	Southwest Channel (S of Egmont Key) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.5616699999999994	-82.7673300000000012	:America/New_York	USA	knots	269	87	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:30:00	\N	0.900000000000000022	-00:53:00	\N	0.599999999999999978	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
59775	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045000000000016	-82.7238300000000066	:America/New_York	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:08:00	\N	0.800000000000000044	-00:01:00	\N	0.800000000000000044	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
59776	Passage Key Inlet (off Bean Pt.) (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.5393299999999996	-82.7476699999999994	:America/New_York	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:08:00	\N	0.699999999999999956	-01:50:00	\N	0.599999999999999978	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
59777	Rattlesnake Key, 3.1 miles west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.553329999999999	-82.6883299999999934	:America/New_York	USA	knots	250	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:04:00	\N	0.400000000000000022	-00:05:00	\N	0.299999999999999989	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
59778	Rattlesnake Key, 1.1 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.5708300000000008	-82.6438299999999941	:America/New_York	USA	knots	210	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:09:00	\N	0.100000000000000006	-00:34:00	\N	0.200000000000000011	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
59779	Mullet Key Channel, marker '24' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.6083299999999987	-82.6940000000000026	:America/New_York	USA	knots	255	73	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:06:00	\N	0.699999999999999956	-00:07:00	\N	0.699999999999999956	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
59780	Bunces Pass (West of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.6469999999999985	-82.7395000000000067	:America/New_York	USA	knots	315	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:02:00	\N	0.699999999999999956	-00:46:00	\N	0.800000000000000044	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
59781	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.692499999999999	-82.7171699999999959	:America/New_York	USA	knots	280	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:00:00	\N	0.599999999999999978	-00:29:00	\N	0.299999999999999989	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
59782	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.7083300000000001	-82.7246700000000033	:America/New_York	USA	knots	150	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
59783	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.6388299999999987	-82.6255000000000024	:America/New_York	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:46:00	\N	0.699999999999999956	00:07:00	\N	0.800000000000000044	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
59784	Joe Island, 1.8 miles northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125000000000007	-82.625	:America/New_York	USA	knots	245	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:02:00	\N	0.699999999999999956	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
59785	Harbor Key, 1.3 miles west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.6111700000000013	-82.5944999999999965	:America/New_York	USA	knots	160	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:38:00	\N	0.299999999999999989	-00:56:00	\N	0.200000000000000011	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
59786	2.6 miles south of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8486_1	27.660499999999999	-82.6416700000000048	:America/New_York	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:34:00	\N	0.699999999999999956	-00:23:00	\N	0.599999999999999978	-00:46:00	-00:16:00	2.6 miles south of	FL
59787	0.5 mile southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8491_1	27.6969999999999992	-82.6324999999999932	:America/New_York	USA	knots	220	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:57:00	\N	0.200000000000000011	-01:19:00	\N	0.200000000000000011	-01:28:00	-01:53:00	0.5 mile southeast of	FL
59788	1.9 miles SE of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8496_1	27.6846700000000006	-82.6096699999999942	:America/New_York	USA	knots	180	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:20:00	\N	0.599999999999999978	-00:32:00	\N	0.5	00:29:00	-00:06:00	1.9 miles SE of	FL
59789	3 miles southeast of, Pinellas Point, Tampa Bay, Florida Current	NOS	ACT8501_1	27.6729999999999983	-82.5930000000000035	:America/New_York	USA	knots	200	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:47:00	\N	0.599999999999999978	00:23:00	\N	0.599999999999999978	00:29:00	00:20:00	3 miles southeast of	FL
59790	Port Manatee Channel entrance (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8506_1	27.661999999999999	-82.5991700000000009	:America/New_York	USA	knots	216	33	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.599999999999999978	00:08:00	\N	0.599999999999999978	-00:01:00	00:24:00	Port Manatee Channel entrance	FL
59791	Port Manatee Channel, marker '4' (Depth 15ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535000000000011	-82.5898300000000063	:America/New_York	USA	knots	242	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.299999999999999989	-00:11:00	\N	0.200000000000000011	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
59792	Piney Point, 0.6 mile NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.6536700000000017	-82.5621699999999947	:America/New_York	USA	knots	215	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:01:00	\N	0.400000000000000022	-00:29:00	\N	0.299999999999999989	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
59793	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.6849999999999987	-82.7349999999999994	:America/New_York	USA	knots	186	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:17:00	\N	1	-00:43:00	\N	0.900000000000000022	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
59794	Bridge, 0.8 mi. south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.6933299999999996	-82.6800000000000068	:America/New_York	USA	knots	255	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:50:00	\N	1	-01:22:00	\N	0.900000000000000022	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
59795	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.7566699999999997	-82.7616699999999952	:America/New_York	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:12:00	\N	0.299999999999999989	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
59796	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.8766708374023438	-82.8499984741210938	:America/New_York	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:54:00	\N	0.100000000000000006	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
59797	Clearwater Pass, 0.2 mi. NE of Sand Key, Florida Current	NOS	ACT8656_1	27.956669999999999	-82.8233299999999986	:America/New_York	USA	knots	348	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-01:50:00	\N	0.800000000000000044	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
59798	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.0466699999999989	-84.1800000000000068	:America/New_York	USA	knots	170	339	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:08:00	\N	0.400000000000000022	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
59799	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.1116700000000002	-84.203329999999994	:America/New_York	USA	knots	187	358	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	-00:26:00	\N	0.299999999999999989	-00:14:00	\N	0.299999999999999989	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
59800	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.1550000000000011	-84.2016699999999929	:America/New_York	USA	knots	247	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16165	00:23:00	\N	0.299999999999999989	01:10:00	\N	0.200000000000000011	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
59801	Bolivar Roads (Depth 8ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.3433300000000017	-94.781329999999997	:America/Chicago	USA	knots	125	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:01:00	\N	1.10000000000000009	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
59802	Bolivar Roads (Depth 31ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.3433300000000017	-94.781329999999997	:America/Chicago	USA	knots	115	306	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-00:08:00	\N	0.599999999999999978	-00:11:00	\N	0.800000000000000044	-00:32:00	00:17:00	Bolivar Roads	TX
59803	Galveston Channel, west end, Galveston Bay, Texas Current	NOS	ACT8866_1	29.3099999999999987	-94.8199999999999932	:America/Chicago	USA	knots	103	272	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:11:00	\N	1.19999999999999996	-00:54:00	\N	1	-00:30:00	-02:30:00	Galveston Channel, west end	TX
59804	Houston Channel, W of Port Bolivar (Depth 3ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	135	313	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	1	-00:18:00	\N	1.10000000000000009	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
59805	Houston Channel, W of Port Bolivar (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:55:00	\N	0.900000000000000022	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
59806	Houston Channel, W of Port Bolivar (Depth 26ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.3646700000000003	-94.796670000000006	:America/Chicago	USA	knots	133	312	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	-01:41:00	\N	0.800000000000000044	-00:14:00	\N	0.900000000000000022	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
59807	Houston Ship Channel (Red Fish Bar) (Depth 7ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	154	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
59808	Houston Ship Channel (Red Fish Bar) (Depth 14ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	148	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:10:00	\N	0.699999999999999956	01:28:00	\N	0.699999999999999956	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
59809	Houston Ship Channel (Red Fish Bar) (Depth 24ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.5073299999999996	-94.8746699999999947	:America/Chicago	USA	knots	144	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
59810	Morgans Point (Depth 6ft), Galveston Bay, Texas Current	NOS	ACT8886_1	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	163	336	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:16:00	\N	0.5	01:43:00	\N	0.299999999999999989	02:15:00	-01:05:00	Morgans Point	TX
59811	Morgans Point (Depth 15ft), Galveston Bay, Texas Current	NOS	ACT8886_2	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	159	341	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:11:00	\N	0.400000000000000022	01:23:00	\N	0.299999999999999989	01:44:00	-00:50:00	Morgans Point	TX
59812	Morgans Point (Depth 25ft), Galveston Bay, Texas Current	NOS	ACT8886_3	29.679829999999999	-94.981669999999994	:America/Chicago	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16146	01:20:00	\N	0.299999999999999989	00:58:00	\N	0.200000000000000011	00:47:00	-01:02:00	Morgans Point	TX
59813	Aransas Pass (Depth 15ft), Texas Current	NOS	ACT8896_1	27.833829999999999	-97.044169999999994	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	1.5	00:00:00	\N	1.10000000000000009	00:00:00	00:00:00	Aransas Pass	TX
59814	Aransas Pass (Depth 50ft), Texas Current	NOS	ACT8896_3	27.833829999999999	-97.044169999999994	:America/Chicago	USA	knots	118	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	00:00:00	\N	0.800000000000000044	00:00:00	\N	0.900000000000000022	00:00:00	00:00:00	Aransas Pass	TX
59815	Port Ingleside (Depth 5ft), Texas Current	NOS	ACT8901_1	27.8150000000000013	-97.230000000000004	:America/Chicago	USA	knots	102	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16143	01:09:00	\N	0.5	01:48:00	\N	0.699999999999999956	00:24:00	02:11:00	Port Ingleside	TX
59816	Punta Ostiones, 1.5 miles west of, Puerto Rico Current	NOS	ACT8921_1	18.0866700000000016	-67.2266699999999986	:America/Puerto_Rico	USA	knots	1	187	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-00:35:00	\N	1.30000000000000004	-00:52:00	\N	1.69999999999999996	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
59817	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645000000000017	-65.5699999999999932	:America/Puerto_Rico	USA	knots	355	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:05:00	\N	0.900000000000000022	-01:16:00	\N	0.699999999999999956	-00:44:00	-01:28:00	Vieques Sound	PR
59818	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.3166699999999985	-65.5833300000000037	:America/Puerto_Rico	USA	knots	330	186	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:08:00	\N	1	-01:28:00	\N	0.699999999999999956	-00:52:00	-01:33:00	Largo Shoals, west of	PR
59819	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.3333300000000001	-65.6166699999999992	:America/Puerto_Rico	USA	knots	339	162	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16171	-01:45:00	\N	1.60000000000000009	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
59820	Point Loma Light, 0.8 nmi. east of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0026_1	32.6658299999999997	-117.226169999999996	:America/Los_Angeles	USA	knots	174	328	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:45:00	\N	0.400000000000000022	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
59821	Point Loma Light, 0.8 nmi. east of (Depth 33ft), San Diego Bay, California Current	NOS	PCT0026_2	32.6658299999999997	-117.226169999999996	:America/Los_Angeles	USA	knots	166	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:23:00	\N	0.200000000000000011	-00:46:00	\N	0.400000000000000022	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
59822	Ballast Point, south of (Depth 5ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6844999999999999	-117.232169999999996	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-02:03:00	\N	0.200000000000000011	-01:02:00	\N	0.400000000000000022	-01:04:00	-01:01:00	Ballast Point, south of	CA
59823	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.683329999999998	-117.233329999999995	:America/Los_Angeles	USA	knots	133	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:02:00	\N	0.900000000000000022	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
59824	Ballast Point, 0.55 nmi. north of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0046_1	32.6958300000000008	-117.232500000000002	:America/Los_Angeles	USA	knots	193	354	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:24:00	\N	0.400000000000000022	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
59989	The Narrows, Alaska Current	NOS	PCT3081_1	56.3678299999999979	-132.102669999999989	:America/Juneau	USA	knots	45	225	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.39999999999999991	00:23:00	\N	0.900000000000000022	00:31:00	00:13:00	The Narrows	AK
59825	Ballast Point, 0.55 nmi. north of (Depth 34ft), San Diego Bay, California Current	NOS	PCT0046_2	32.6958300000000008	-117.232500000000002	:America/Los_Angeles	USA	knots	147	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.200000000000000011	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
59826	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7000000000000028	-117.233329999999995	:America/Los_Angeles	USA	knots	200	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:20:00	\N	0.800000000000000044	00:15:00	\N	0.800000000000000044	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
59827	North Island (Depth 14ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713000000000001	-117.212829999999997	:America/Los_Angeles	USA	knots	245	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:03:00	\N	0.400000000000000022	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
59828	North Island (Depth 34ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713000000000001	-117.212829999999997	:America/Los_Angeles	USA	knots	241	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:33:00	\N	0.200000000000000011	-01:05:00	\N	0.299999999999999989	-00:43:00	-00:44:00	North Island	CA
59829	Harbor Island (east end), SSW of (Depth 15ft), San Diego Bay, California Current	NOS	PCT0061_1	32.7191699999999983	-117.191670000000002	:America/Los_Angeles	USA	knots	293	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:23:00	\N	0.299999999999999989	00:09:00	\N	0.299999999999999989	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
59830	San Diego, 0.5 mile west of, San Diego Bay, California Current	NOS	PCT0066_1	32.7166700000000006	-117.183329999999998	:America/Los_Angeles	USA	knots	304	121	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:12:00	\N	0.5	-00:08:00	\N	0.599999999999999978	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
59831	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0081_1	32.7083299999999966	-117.177499999999995	:America/Los_Angeles	USA	knots	304	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:41:00	\N	0.299999999999999989	00:20:00	\N	0.299999999999999989	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
59832	G St. Pier (San Diego), 0.22 nmi. SW of (Depth 37ft), San Diego Bay, California Current	NOS	PCT0081_2	32.7083299999999966	-117.177499999999995	:America/Los_Angeles	USA	knots	301	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.200000000000000011	00:21:00	\N	0.299999999999999989	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
59833	Coronado, off northeast end (Depth 14ft), San Diego Bay, California Current	NOS	PCT0091_1	32.6980000000000004	-117.163830000000004	:America/Los_Angeles	USA	knots	317	128	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:09:00	\N	0.5	-00:58:00	\N	0.699999999999999956	-00:24:00	-00:51:00	Coronado, off northeast end	CA
59834	Coronado, off northeast end (Depth 38ft), San Diego Bay, California Current	NOS	PCT0091_2	32.6980000000000004	-117.163830000000004	:America/Los_Angeles	USA	knots	319	130	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:03:00	\N	0.400000000000000022	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
59835	28th St. Pier (San Diego), 0.92 nmi. SW (Depth 7ft), San Diego Bay, California Current	NOS	PCT0096_1	32.674669999999999	-117.149500000000003	:America/Los_Angeles	USA	knots	351	182	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	-00:05:00	\N	0.100000000000000006	-01:17:00	\N	0.200000000000000011	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
59836	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 14ft), San Diego Bay, California Current	NOS	PCT0101_1	32.6828300000000027	-117.142830000000004	:America/Los_Angeles	USA	knots	317	133	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:13:00	\N	0.200000000000000011	00:15:00	\N	0.299999999999999989	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
59837	28th St. Pier (San Diego), 0.35 nmi. SW (Depth 28ft), San Diego Bay, California Current	NOS	PCT0101_2	32.6828300000000027	-117.142830000000004	:America/Los_Angeles	USA	knots	328	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:35:00	\N	0.200000000000000011	00:24:00	\N	0.200000000000000011	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
59838	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.6499999999999986	-117.116669999999999	:America/Los_Angeles	USA	knots	2	166	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:50:00	\N	0.400000000000000022	00:00:00	\N	0.400000000000000022	00:23:00	-00:02:00	National City	CA
59839	National City, WSW of Pier 12 (Depth 32ft), San Diego Bay, California Current	NOS	PCT0111_1	32.6621700000000033	-117.125500000000002	:America/Los_Angeles	USA	knots	351	178	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:58:00	\N	0.200000000000000011	00:34:00	\N	0.200000000000000011	00:22:00	00:34:00	National City, WSW of Pier 12	CA
59840	Sweetwater Channel, southwest of (Depth 14ft), San Diego Bay, California Current	NOS	PCT0116_1	32.6450000000000031	-117.122829999999993	:America/Los_Angeles	USA	knots	348	203	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16159	00:46:00	\N	0.200000000000000011	-00:33:00	\N	0.100000000000000006	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
59841	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.1216700000000017	-124.419669999999996	:America/Los_Angeles	USA	knots	290	91	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:17:00	\N	0.599999999999999978	-01:25:00	\N	0.400000000000000022	-01:00:00	-01:27:00	Coquille River entrance	OR
59859	Point Adams, NNE OF (Depth 14ft), Oregon Current	NOS	PCT1166_1	46.2278299999999973	-123.967500000000001	:America/Los_Angeles	USA	knots	297	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:11:00	\N	0.900000000000000022	00:13:00	\N	0.800000000000000044	01:16:00	00:26:00	Point Adams, NNE OF	OR
59842	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.3549999999999969	-124.341170000000005	:America/Los_Angeles	USA	knots	280	100	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.10000000000000009	-00:42:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Coos Bay entrance	OR
59843	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.6783300000000025	-124.193330000000003	:America/Los_Angeles	USA	knots	190	10	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.5	-00:32:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Umpqua River entrance	OR
59844	Heceta Head, Oregon Current	NOS	PCT1071_1	44.1333300000000008	-124.133330000000001	:America/Los_Angeles	USA	knots	185	5	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.699999999999999956	-00:12:00	\N	0.400000000000000022	00:06:00	-00:12:00	Heceta Head	OR
59845	Yaquina Bay entrance, Yaquina Bay, Oregon Current	NOS	PCT1076_1	44.6166699999999992	-124.066670000000002	:America/Los_Angeles	USA	knots	235	50	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:55:00	\N	1.10000000000000009	-01:04:00	\N	0.800000000000000044	-01:20:00	-01:17:00	Yaquina Bay entrance	OR
59846	Highway Bridge, Yaquina Bay, Oregon Current	NOS	PCT1081_1	44.6233300000000028	-124.057000000000002	:America/Los_Angeles	USA	knots	222	44	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:53:00	\N	1	-00:50:00	\N	0.599999999999999978	-01:31:00	-01:40:00	Highway Bridge	OR
59847	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.6019999999999968	-124.011330000000001	:America/Los_Angeles	USA	knots	2	184	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:33:00	\N	0.5	-00:50:00	\N	0.299999999999999989	-01:09:00	-01:33:00	Yaquina, Yaquina River	OR
59848	Yaquina River, 1 mile below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.6004999999999967	-123.941670000000002	:America/Los_Angeles	USA	knots	132	332	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:02:00	\N	0.699999999999999956	-00:13:00	\N	0.400000000000000022	-00:27:00	-00:46:00	Yaquina River, 1 mile below Toledo	OR
59849	Tillamook Bay entrance, Tillamook Bay, Oregon Current	NOS	PCT1096_1	45.5621700000000018	-123.938329999999993	:America/Los_Angeles	USA	knots	305	141	\N	Reference is in time zone :America/Anchorage; adjusted offsets -1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	1.30000000000000004	-00:47:00	\N	0.900000000000000022	-00:20:00	-01:05:00	Tillamook Bay entrance	OR
59850	Sand Island Tower, 1nm SE of (midchannel) (Depth 15ft), Washington Current	NOS	PCT1106_1	46.252830000000003	-123.990830000000003	:America/Los_Angeles	USA	knots	275	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:07:00	\N	1.60000000000000009	01:03:00	\N	1.60000000000000009	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	WA
59851	Sand Island Tower, 0.9nm SE of (north channel) (Depth 15ft), Washington Current	NOS	PCT1111_1	46.2578299999999984	-123.994500000000002	:America/Los_Angeles	USA	knots	262	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:44:00	\N	0.699999999999999956	00:33:00	\N	1.10000000000000009	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	WA
59852	Baker Bay entrance, E of Sand Island Tower (Depth 23ft), Washington Current	NOS	PCT1116_1	46.2620000000000005	-123.998000000000005	:America/Los_Angeles	USA	knots	202	8	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:14:00	\N	0.299999999999999989	00:08:00	\N	0.599999999999999978	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	WA
59853	Clatsop Spit, NNE of (Depth 15ft), Washington Current	NOS	PCT1121_1	46.2461699999999993	-123.994169999999997	:America/Los_Angeles	USA	knots	289	114	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:20:00	\N	1.10000000000000009	00:56:00	\N	1.39999999999999991	00:45:00	00:56:00	Clatsop Spit, NNE of	WA
59854	Sand Island, SSE of (Depth 12ft), Washington Current	NOS	PCT1126_1	46.2554999999999978	-123.968000000000004	:America/Los_Angeles	USA	knots	265	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:32:00	\N	0.400000000000000022	-00:25:00	\N	0.299999999999999989	00:18:00	-00:16:00	Sand Island, SSE of	WA
59855	Youngs Bay Bridge (Depth 9ft), Oregon Current	NOS	PCT1146_1	46.1778300000000002	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:28:00	\N	0.299999999999999989	-00:14:00	\N	0.400000000000000022	00:10:00	00:50:00	Youngs Bay Bridge	OR
59856	Hammond, northeast of ship channel (Depth 15ft), Oregon Current	NOS	PCT1151_1	46.2111700000000027	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:01:00	\N	0.599999999999999978	00:24:00	\N	0.400000000000000022	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
59857	McGowan, SSW of (Depth 14ft), Washington Current	NOS	PCT1156_1	46.2394999999999996	-123.915329999999997	:America/Los_Angeles	USA	knots	282	107	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:23:00	\N	1.60000000000000009	01:14:00	\N	0.900000000000000022	01:28:00	00:21:00	McGowan, SSW of	WA
59858	Point Ellice, east of (Depth 17ft), Washington Current	NOS	PCT1161_1	46.2416699999999992	-123.848330000000004	:America/Los_Angeles	USA	knots	254	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:11:00	\N	0.900000000000000022	00:25:00	\N	0.800000000000000044	00:55:00	00:51:00	Point Ellice, east of	WA
59860	Chinook Point, WSW of (Depth 14ft), Washington Current	NOS	PCT1171_1	46.2421700000000016	-123.964169999999996	:America/Los_Angeles	USA	knots	287	117	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	0.900000000000000022	00:25:00	\N	1.19999999999999996	00:29:00	00:45:00	Chinook Point, WSW of	WA
59861	Tongue Point, northwest of (Depth 15ft), Oregon Current	NOS	PCT1176_1	46.2191699999999983	-123.766670000000005	:America/Los_Angeles	USA	knots	249	77	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:46:00	\N	0.900000000000000022	01:09:00	\N	0.400000000000000022	02:31:00	00:24:00	Tongue Point, northwest of	OR
59862	Woody Island Channel (Depth 15ft), Washington Current	NOS	PCT1186_1	46.2394999999999996	-123.673330000000007	:America/Los_Angeles	USA	knots	298	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:15:00	\N	0.299999999999999989	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
59863	Woody Island Channel (off Seal Island) (Depth 12ft), Oregon Current	NOS	PCT1191_1	46.2175000000000011	-123.629170000000002	:America/Los_Angeles	USA	knots	247	81	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:53:00	\N	0.400000000000000022	01:53:00	\N	0.299999999999999989	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
59864	Quinn Island, Prairie Channel (Depth 8ft), Washington Current	NOS	PCT1201_1	46.237169999999999	-123.503330000000005	:America/Los_Angeles	USA	knots	281	97	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	01:53:00	\N	0.5	01:52:00	\N	0.299999999999999989	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
59865	Clifton Channel (Depth 10ft), Washington Current	NOS	PCT1206_1	46.2178299999999993	-123.465329999999994	:America/Los_Angeles	USA	knots	301	118	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	02:17:00	\N	0.400000000000000022	02:27:00	\N	0.299999999999999989	03:41:00	01:21:00	Clifton Channel	WA
59866	Hunting Island, south of (Depth 20ft), Washington Current	NOS	PCT1216_1	46.2071699999999979	-123.404169999999993	:America/Los_Angeles	USA	knots	295	125	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	03:20:00	\N	0.400000000000000022	02:56:00	\N	0.200000000000000011	04:20:00	01:38:00	Hunting Island, south of	WA
59867	Cathlamet Channel, SE of Nassa Point (Depth 19ft), Washington Current	NOS	PCT1231_1	46.156170000000003	-123.314999999999998	:America/Los_Angeles	USA	knots	278	103	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:38:00	\N	0.599999999999999978	03:23:00	\N	0.100000000000000006	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
59868	Walker Island, south of (Depth 12ft), Washington Current	NOS	PCT1251_1	46.1411700000000025	-123.045829999999995	:America/Los_Angeles	USA	knots	330	148	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	05:09:00	\N	0.400000000000000022	04:15:00	\N	0.200000000000000011	05:46:00	02:41:00	Walker Island, south of	WA
59869	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.664670000000001	-123.801329999999993	:America/Los_Angeles	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:06:00	\N	0.5	00:20:00	\N	0.599999999999999978	00:19:00	00:24:00	South Bend, Willapa River	WA
59870	Entrance, 0.2 mile south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.9263300000000001	-124.161330000000007	:America/Los_Angeles	USA	knots	243	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:47:00	\N	0.599999999999999978	00:16:00	\N	1.30000000000000004	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
59871	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.9083299999999994	-124.155500000000004	:America/Los_Angeles	USA	knots	268	92	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:21:00	\N	1.10000000000000009	-00:11:00	\N	0.900000000000000022	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
59872	Entrance, 0.6 mile WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.914670000000001	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:00:00	\N	0.699999999999999956	00:00:00	\N	1.19999999999999996	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
59873	Entrance, 1.1 miles NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.9166700000000034	-124.133330000000001	:America/Los_Angeles	USA	knots	233	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:23:00	\N	0.900000000000000022	-00:06:00	\N	0.900000000000000022	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
59874	Channel, 1.5 miles north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.933329999999998	-124.099999999999994	:America/Los_Angeles	USA	knots	226	36	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:25:00	\N	0.599999999999999978	-00:04:00	\N	0.699999999999999956	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
59875	Channel, 2.1 miles NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.933329999999998	-124.083330000000004	:America/Los_Angeles	USA	knots	249	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	00:02:00	\N	0.5	00:00:00	\N	0.599999999999999978	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
59876	Westport, channel 0.4 mile NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.9141699999999986	-124.108329999999995	:America/Los_Angeles	USA	knots	310	113	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16150	-00:36:00	\N	0.699999999999999956	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
59877	Cattle Point, 2.8 miles SSW of, Straight of Juan de Fuca, Washington Current	NOS	PCT1416_1	48.4000015258789062	-123	:America/Los_Angeles	USA	knots	187	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	-00:10:00	\N	0.160000000000000003	01:28:00	\N	0.23000000000000001	-00:35:00	00:50:00	Cattle Point, 2.8 miles SSW of	WA
59878	Cattle Point, 5 miles SSW of, Straight of Juan de Fuca, Washington Current	NOS	PCT1421_1	48.383331298828125	-123.016670227050781	:America/Los_Angeles	USA	knots	210	120	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:16:00	\N	0.330000000000000016	01:47:00	\N	0.349999999999999978	01:56:00	01:06:00	Cattle Point, 5 miles SSW of	WA
59879	Port Townsend Canal, Admiralty Inlet, Washington Current	NOS	PCT1561_1	48.0333299999999994	-122.733329999999995	:America/Los_Angeles	USA	knots^2	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	-00:31:00	\N	0.400000000000000022	-00:40:00	\N	0.5	00:06:00	-00:46:00	Port Townsend Canal	WA
59880	Skagit Bay, 1 mi. S of Goat Island, Washington Current	NOS	PCT1941_1	48.3444999999999965	-122.543670000000006	:America/Los_Angeles	USA	knots^2	312	139	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	-00:53:00	\N	0.200000000000000011	-01:26:00	\N	0.299999999999999989	-01:07:00	-00:53:00	Skagit Bay, 1 mi. S of Goat Island	WA
59881	Yokeko Point, Deception Pass, Rosario Strait, Washington Current	NOS	PCT1951_1	48.4128299999999996	-122.613669999999999	:America/Los_Angeles	USA	knots^2	222	64	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16149	00:17:00	\N	0.400000000000000022	-00:24:00	\N	0.400000000000000022	00:04:00	-00:25:00	Yokeko Point, Deception Pass	WA
59882	Iceberg Point, 2.1 miles SSW of, Rosario Strait, Washington Current	NOS	PCT1966_1	48.3833300000000008	-122.916669999999996	:America/Los_Angeles	USA	knots	260	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:10:00	\N	0.400000000000000022	-00:05:00	\N	1	-00:34:00	01:21:00	Iceberg Point, 2.1 miles SSW of	WA
59883	Colville Island, 1 mile SSE of, Rosario Strait, Washington Current	NOS	PCT1971_1	48.3999999999999986	-122.816670000000002	:America/Los_Angeles	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:07:00	\N	1.19999999999999996	00:31:00	\N	1	00:19:00	00:46:00	Colville Island, 1 mile SSE of	WA
59884	Colville Island, 1.4 miles east of, Rosario Strait, Washington Current	NOS	PCT1976_1	48.4166700000000034	-122.783330000000007	:America/Los_Angeles	USA	knots	215	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:14:00	\N	1	00:14:00	\N	1.39999999999999991	00:03:00	00:17:00	Colville Island, 1.4 miles east of	WA
59885	Deception Island, 2.7 miles west of, Rosario Strait, Washington Current	NOS	PCT1981_1	48.4125000000000014	-122.739500000000007	:America/Los_Angeles	USA	knots	190	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:34:00	\N	0.699999999999999956	00:50:00	\N	0.800000000000000044	01:08:00	00:38:00	Deception Island, 2.7 miles west of	WA
59886	Lopez Pass, Rosario Strait, Washington Current	NOS	PCT2001_1	48.4796699999999987	-122.818669999999997	:America/Los_Angeles	USA	knots	85	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-01:16:00	\N	1	-01:33:00	\N	1.39999999999999991	-01:13:00	-00:39:00	Lopez Pass	WA
59887	Burrows Bay, 0.5 mile east of Allan I, Rosario Strait, Washington Current	NOS	PCT2006_1	48.4628299999999967	-122.682829999999996	:America/Los_Angeles	USA	knots	209	22	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:43:00	\N	0.200000000000000011	-00:48:00	\N	0.900000000000000022	-03:01:00	00:22:00	Burrows Bay, 0.5 mile east of Allan I	WA
59888	Burrows I.-Allan I., Passage between, Rosario Strait, Washington Current	NOS	PCT2011_1	48.4716700000000031	-122.699669999999998	:America/Los_Angeles	USA	knots	96	304	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:57:00	\N	0.699999999999999956	-00:34:00	\N	2	-02:05:00	00:09:00	Burrows I.-Allan I., Passage between	WA
59889	Burrows Island Light, 0.8 miles WNW of, Rosario Strait, Washington Current	NOS	PCT2016_1	48.4833300000000023	-122.733329999999995	:America/Los_Angeles	USA	knots	200	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:16:00	\N	1.10000000000000009	00:30:00	\N	1	00:29:00	00:13:00	Burrows Island Light, 0.8 miles WNW of	WA
59890	Green Point, 0.8 mile northwest of, Rosario Strait, Washington Current	NOS	PCT2026_1	48.5046699999999973	-122.70617	:America/Los_Angeles	USA	knots	190	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-01:02:00	\N	1	-00:30:00	\N	1.80000000000000004	-00:55:00	-00:08:00	Green Point, 0.8 mile northwest of	WA
59891	Shannon Point, 2.0 miles west of, Rosario Strait, Washington Current	NOS	PCT2031_1	48.5105000000000004	-122.730500000000006	:America/Los_Angeles	USA	knots	190	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:16:00	\N	1	00:49:00	\N	1.19999999999999996	-00:19:00	00:50:00	Shannon Point, 2.0 miles west of	WA
59892	Fauntleroy Point Light, 0.8 mile ESE of, Rosario Strait, Washington Current	NOS	PCT2036_1	48.5200000000000031	-122.769670000000005	:America/Los_Angeles	USA	knots	125	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:33:00	\N	0.699999999999999956	00:16:00	\N	1.10000000000000009	00:08:00	-01:10:00	Fauntleroy Point Light, 0.8 mile ESE of	WA
59893	Thatcher Pass, Rosario Strait, Washington Current	NOS	PCT2041_1	48.5275000000000034	-122.802999999999997	:America/Los_Angeles	USA	knots	75	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:51:00	\N	0.5	01:01:00	\N	0.400000000000000022	00:43:00	01:26:00	Thatcher Pass	WA
59894	Frost-Willow Island, between, Rosario Strait, Washington Current	NOS	PCT2046_1	48.5391699999999986	-122.830830000000006	:America/Los_Angeles	USA	knots	126	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:29:00	\N	0.400000000000000022	01:14:00	\N	0.599999999999999978	00:46:00	00:19:00	Frost-Willow Island, between	WA
59895	Strawberry Island, 0.8 mile west of, Rosario Strait, Washington Current	NOS	PCT2051_1	48.5611699999999971	-122.754170000000002	:America/Los_Angeles	USA	knots	190	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:30:00	\N	1.39999999999999991	00:46:00	\N	1.39999999999999991	00:43:00	00:37:00	Strawberry Island, 0.8 mile west of	WA
59896	Peavine Pass, west entrance, Rosario Strait, Washington Current	NOS	PCT2056_1	48.5870000000000033	-122.819999999999993	:America/Los_Angeles	USA	knots	285	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:52:00	\N	1.19999999999999996	-00:41:00	\N	1.60000000000000009	-00:42:00	-00:26:00	Peavine Pass, west entrance	WA
59897	Obstruction Pass Light, 0.4 mile NW of, Rosario Strait, Washington Current	NOS	PCT2061_1	48.603670000000001	-122.813329999999993	:America/Los_Angeles	USA	knots	270	100	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:49:00	\N	0.5	-00:44:00	\N	1.19999999999999996	-00:59:00	-00:38:00	Obstruction Pass Light, 0.4 mile NW of	WA
59898	Peapod Rocks Light, 1.2 miles south of, Rosario Strait, Washington Current	NOS	PCT2066_1	48.622169999999997	-122.747169999999997	:America/Los_Angeles	USA	knots	215	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:15:00	\N	1	01:12:00	\N	1.19999999999999996	00:08:00	00:49:00	Peapod Rocks Light, 1.2 miles south of	WA
59899	Barnes Island, 0.8 mile southwest of, Rosario Strait, Washington Current	NOS	PCT2071_1	48.6858300000000028	-122.788830000000004	:America/Los_Angeles	USA	knots	140	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:08:00	\N	0.5	01:20:00	\N	0.599999999999999978	00:37:00	-00:07:00	Barnes Island, 0.8 mile southwest of	WA
59900	Raccoon Point, 0.6 mile NNE of, Rosario Strait, Washington Current	NOS	PCT2076_1	48.7063300000000012	-122.829170000000005	:America/Los_Angeles	USA	knots	101	286	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:20:00	\N	0.400000000000000022	-00:45:00	\N	0.599999999999999978	-00:36:00	-01:41:00	Raccoon Point, 0.6 mile NNE of	WA
59901	Parker Reef Light, 0.5 mile north of, Rosario Strait, Washington Current	NOS	PCT2081_1	48.732999999999997	-122.890000000000001	:America/Los_Angeles	USA	knots	278	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	01:02:00	\N	0.800000000000000044	01:02:00	\N	1	01:31:00	01:14:00	Parker Reef Light, 0.5 mile north of	WA
59902	Matia Island, 0.8 mile west of, Rosario Strait, Washington Current	NOS	PCT2086_1	48.7488299999999981	-122.865830000000003	:America/Los_Angeles	USA	knots	206	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:14:00	\N	0.800000000000000044	00:26:00	\N	1.10000000000000009	00:22:00	-00:26:00	Matia Island, 0.8 mile west of	WA
59903	Guemes Channel, west entrance, Rosario Strait, Washington Current	NOS	PCT2091_1	48.5211699999999979	-122.652169999999998	:America/Los_Angeles	USA	knots	255	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:36:00	\N	1.10000000000000009	-00:33:00	\N	0.800000000000000044	-00:21:00	-01:24:00	Guemes Channel, west entrance	WA
59904	Huckleberry Island, 0.5 mile north of, Rosario Strait, Washington Current	NOS	PCT2106_1	48.5458300000000023	-122.566329999999994	:America/Los_Angeles	USA	knots	253	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-01:10:00	\N	0.299999999999999989	00:18:00	\N	0.699999999999999956	-03:17:00	00:36:00	Huckleberry Island, 0.5 mile north of	WA
59905	Bellingham Channel, off Cypress I. Light, Rosario Strait, Washington Current	NOS	PCT2121_1	48.5603300000000004	-122.663669999999996	:America/Los_Angeles	USA	knots	185	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:51:00	\N	1.19999999999999996	00:08:00	\N	1.10000000000000009	-00:48:00	-00:49:00	Bellingham Channel, off Cypress I. Light	WA
59906	Towhead Island, 0.4 mile east of, Rosario Strait, Washington Current	NOS	PCT2126_1	48.612169999999999	-122.702169999999995	:America/Los_Angeles	USA	knots	125	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:01:00	\N	0.200000000000000011	01:13:00	\N	0.699999999999999956	-01:55:00	02:43:00	Towhead Island, 0.4 mile east of	WA
59907	Sinclair Island Light, 0.6 mile SE of, Rosario Strait, Washington Current	NOS	PCT2131_1	48.6028299999999973	-122.648669999999996	:America/Los_Angeles	USA	knots	210	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:18:00	\N	0.800000000000000044	00:48:00	\N	1.30000000000000004	00:16:00	00:22:00	Sinclair Island Light, 0.6 mile SE of	WA
59908	Lawrence Point, Orcas I., 1.3 mi. NE of, Rosario Strait, Washington Current	NOS	PCT2141_1	48.6783300000000025	-122.714500000000001	:America/Los_Angeles	USA	knots	145	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:55:00	\N	0.800000000000000044	00:58:00	\N	1.19999999999999996	00:56:00	00:59:00	Lawrence Point, Orcas I., 1.3 mi. NE of	WA
59909	Hale Passage, 0.5 mile SE of Lummi Point, Rosario Strait, Washington Current	NOS	PCT2146_1	48.7313299999999998	-122.67783	:America/Los_Angeles	USA	knots	145	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:11:00	\N	0.5	00:05:00	\N	1	-00:43:00	00:20:00	Hale Passage, 0.5 mile SE of Lummi Point	WA
59910	Clark Island, 1.6 miles north of, Rosario Strait, Washington Current	NOS	PCT2151_1	48.7313299999999998	-122.773330000000001	:America/Los_Angeles	USA	knots	150	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:02:00	\N	0.599999999999999978	01:14:00	\N	0.599999999999999978	00:47:00	00:44:00	Clark Island, 1.6 miles north of	WA
59911	Matia Island, 1.4 miles north of, Rosario Strait, Washington Current	NOS	PCT2156_1	48.7721700000000027	-122.849500000000006	:America/Los_Angeles	USA	knots	190	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:08:00	\N	0.299999999999999989	00:57:00	\N	0.599999999999999978	00:02:00	00:59:00	Matia Island, 1.4 miles north of	WA
59912	Puffin Island Light, 4.8 miles north of, Rosario Strait, Washington Current	NOS	PCT2166_1	48.8221699999999998	-122.808329999999998	:America/Los_Angeles	USA	knots	210	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	00:11:00	\N	0.400000000000000022	01:30:00	\N	0.400000000000000022	00:18:00	00:55:00	Puffin Island Light, 4.8 miles north of	WA
59913	Cattle Point, 1.2 miles southeast of, San Juan Channel, Washington Current	NOS	PCT2181_1	48.4338300000000004	-122.947000000000003	:America/Los_Angeles	USA	knots	195	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	-00:01:00	\N	0.900000000000000022	-00:20:00	\N	0.299999999999999989	00:11:00	00:34:00	Cattle Point, 1.2 miles southeast of	WA
59914	Kings Point, Lopez Island, 1 mile NNW of, San Juan Channel, Washington Current	NOS	PCT2191_1	48.4833300000000023	-122.955830000000006	:America/Los_Angeles	USA	knots	185	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	00:36:00	\N	0.5	-00:07:00	\N	0.599999999999999978	00:51:00	00:27:00	Kings Point, Lopez Island, 1 mile NNW of	WA
59915	Pear Point, 1.1 miles east of, San Juan Channel, Washington Current	NOS	PCT2196_1	48.511330000000001	-122.952830000000006	:America/Los_Angeles	USA	knots	203	359	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:01:00	\N	0.5	01:09:00	\N	0.400000000000000022	00:40:00	-00:10:00	Pear Point, 1.1 miles east of	WA
59916	Turn Rock Light, 1.9 miles northwest of, San Juan Channel, Washington Current	NOS	PCT2201_1	48.5566699999999969	-122.998329999999996	:America/Los_Angeles	USA	knots	135	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	-00:01:00	\N	0.5	01:22:00	\N	0.400000000000000022	01:19:00	00:20:00	Turn Rock Light, 1.9 miles northwest of	WA
59917	Crane Island, south of, Wasp Passage, San Juan Channel, Washington Current	NOS	PCT2206_1	48.589500000000001	-122.998670000000004	:America/Los_Angeles	USA	knots	75	288	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	00:07:00	\N	0.100000000000000006	00:35:00	\N	0.200000000000000011	-00:10:00	00:29:00	Crane Island, south of, Wasp Passage	WA
59918	Wasp Passage Light, 0.5 mile WSW of, San Juan Channel, Washington Current	NOS	PCT2211_1	48.592170000000003	-122.989500000000007	:America/Los_Angeles	USA	knots	110	300	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	-00:15:00	\N	0.400000000000000022	00:28:00	\N	0.5	00:19:00	00:15:00	Wasp Passage Light, 0.5 mile WSW of	WA
59919	Spring Passage, south entrance, San Juan Channel, Washington Current	NOS	PCT2216_1	48.6113300000000024	-123.034170000000003	:America/Los_Angeles	USA	knots	150	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	-00:13:00	\N	0.400000000000000022	-01:09:00	\N	0.400000000000000022	00:04:00	-00:43:00	Spring Passage, south entrance	WA
59920	Limestone Point, Spieden Channel, San Juan Channel, Washington Current	NOS	PCT2221_1	48.6263300000000029	-123.109170000000006	:America/Los_Angeles	USA	knots	283	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	00:26:00	\N	1.19999999999999996	-00:12:00	\N	0.699999999999999956	00:23:00	-01:00:00	Limestone Point, Spieden Channel	WA
59921	Point Disney, 1.6 miles east of, San Juan Channel, Washington Current	NOS	PCT2226_1	48.6728299999999976	-123.006169999999997	:America/Los_Angeles	USA	knots	230	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:51:00	\N	0.800000000000000044	01:31:00	\N	0.200000000000000011	02:36:00	00:48:00	Point Disney, 1.6 miles east of	WA
59922	Harney Channel, San Juan Channel, Washington Current	NOS	PCT2231_1	48.5908299999999969	-122.920500000000004	:America/Los_Angeles	USA	knots	120	250	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	00:05:00	\N	0.299999999999999989	00:21:00	\N	0.200000000000000011	00:15:00	00:11:00	Harney Channel	WA
59923	Johns Island, 0.8 mile north of, Washington Current	NOS	PCT2266_1	48.683329999999998	-123.150000000000006	:America/Los_Angeles	USA	knots	350	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	00:49:00	\N	0.200000000000000011	-00:31:00	\N	0.200000000000000011	-00:15:00	00:06:00	Johns Island, 0.8 mile north of	WA
59924	Waldron Island, 1.7 miles west of, Washington Current	NOS	PCT2271_1	48.7041699999999977	-123.108670000000004	:America/Los_Angeles	USA	knots	260	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:05:00	\N	0.400000000000000022	00:36:00	\N	0.5	00:37:00	01:10:00	Waldron Island, 1.7 miles west of	WA
59925	Skipjack Island, 1.5 miles northwest of, Washington Current	NOS	PCT2276_1	48.7494999999999976	-123.060829999999996	:America/Los_Angeles	USA	knots	290	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:12:00	\N	0.5	01:19:00	\N	0.299999999999999989	01:17:00	01:08:00	Skipjack Island, 1.5 miles northwest of	WA
59926	Point Hammond, 1.1 miles northwest of, Washington Current	NOS	PCT2281_1	48.7319999999999993	-123.025329999999997	:America/Los_Angeles	USA	knots	255	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16161	01:13:00	\N	0.900000000000000022	01:05:00	\N	0.200000000000000011	01:11:00	00:27:00	Point Hammond, 1.1 miles northwest of	WA
59927	Alden Point, Patos Island, 2 miles S of, Washington Current	NOS	PCT2286_1	48.7578299999999984	-122.980329999999995	:America/Los_Angeles	USA	knots	185	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:53:00	\N	1.10000000000000009	-00:26:00	\N	0.900000000000000022	00:09:00	00:15:00	Alden Point, Patos Island, 2 miles S of	WA
59928	Patos Island Light, 1.4 miles west of, Washington Current	NOS	PCT2291_1	48.7888299999999973	-123.003330000000005	:America/Los_Angeles	USA	knots	180	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:02:00	\N	1	00:30:00	\N	0.800000000000000044	00:19:00	00:40:00	Patos Island Light, 1.4 miles west of	WA
59929	Toe Point, Patos Island, 0.5 mile S of, Washington Current	NOS	PCT2296_1	48.7783299999999969	-122.940830000000005	:America/Los_Angeles	USA	knots	270	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16158	-00:47:00	\N	0.800000000000000044	00:49:00	\N	1.39999999999999991	-02:31:00	00:51:00	Toe Point, Patos Island, 0.5 mile S of	WA
59930	Cape Muzon, 4 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6000000000000014	-132.683330000000012	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.19999999999999996	-00:47:00	\N	0.800000000000000044	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
59931	Point Marsh, 5 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.6333300000000008	-132.300000000000011	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	1.10000000000000009	-00:47:00	\N	0.699999999999999956	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
59932	West Devil Rock, 2 miles north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7000000000000028	-131.599999999999994	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1.19999999999999996	-00:42:00	\N	0.800000000000000044	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
59933	Barren Island Light, 2 miles south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7000000000000028	-131.349999999999994	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.10000000000000009	-00:37:00	\N	0.699999999999999956	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
59934	East Devil Rock, 1 mile north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7000000000000028	-131.083329999999989	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.10000000000000009	00:23:00	\N	0.699999999999999956	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
59935	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7000000000000028	-130.833329999999989	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.39999999999999991	00:18:00	\N	0.599999999999999978	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
59936	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.7823300000000017	-130.737169999999992	:America/Juneau	USA	knots	157	326	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:31:00	\N	0.599999999999999978	-02:40:00	\N	0.299999999999999989	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
59937	Boston Islands, 1 mile south from, Dixon Entrance, Alaska Current	NOS	PCT2661_1	54.683329999999998	-130.566669999999988	:America/Juneau	USA	knots	265	85	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.10000000000000009	-00:37:00	\N	0.699999999999999956	-00:29:00	-00:47:00	Boston Islands, 1 mile south from	AK
59938	Portland Inlet, 2 miles S. of Wales Pt, Dixon Entrance, Alaska Current	NOS	PCT2666_1	54.6666700000000034	-130.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.19999999999999996	00:28:00	\N	0.800000000000000044	00:36:00	00:18:00	Portland Inlet, 2 miles S. of Wales Pt	AK
59939	Haystack Island, Tongass Passage, Pearse Canal, Alaska Current	NOS	PCT2671_1	54.7166700000000006	-130.616669999999999	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.19999999999999996	00:23:00	\N	0.800000000000000044	00:31:00	00:13:00	Haystack Island, Tongass Passage	AK
59940	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.7833299999999994	-130.633330000000001	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.30000000000000004	00:23:00	\N	0.900000000000000022	00:31:00	00:13:00	Point Phipp	AK
59941	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.8346700000000027	-130.485500000000002	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:47:00	\N	1.30000000000000004	00:26:00	\N	0.900000000000000022	00:34:00	00:31:00	Narrows	AK
59942	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.0333299999999994	-130.216669999999993	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Blaine Point	AK
59943	Wales Point, 2 miles south from, Portland Canal, Alaska Current	NOS	PCT2691_1	54.6666700000000034	-130.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.19999999999999996	00:28:00	\N	0.800000000000000044	00:36:00	00:18:00	Wales Point, 2 miles south from	AK
59944	Cliff Point, 1 mile east from, Portland Canal, Alaska Current	NOS	PCT2696_1	54.7999999999999972	-130.316669999999988	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:49:00	\N	1.10000000000000009	00:28:00	\N	0.699999999999999956	00:36:00	00:18:00	Cliff Point, 1 mile east from	AK
59945	Flat Point , 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2701_1	54.9166700000000034	-130.166670000000011	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	1	00:33:00	\N	0.599999999999999978	00:41:00	00:23:00	Flat Point , 1 mile east of	AK
59946	Tree Point, 1 mile east of, Portland Canal, Alaska Current	NOS	PCT2706_1	55.0333299999999994	-130.166670000000011	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.900000000000000022	00:33:00	\N	0.599999999999999978	00:41:00	00:23:00	Tree Point, 1 mile east of	AK
59947	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.1499999999999986	-130.150000000000006	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.699999999999999956	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
59948	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.566670000000002	-130.116669999999999	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:59:00	\N	0.5	00:38:00	\N	0.299999999999999989	00:46:00	00:28:00	White Point	AK
59949	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.2833299999999994	-129.983329999999995	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.599999999999999978	-00:22:00	\N	0.400000000000000022	-00:14:00	-00:32:00	Camp Point	AK
59950	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.7166700000000006	-130.150000000000006	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.400000000000000022	-00:17:00	\N	0.299999999999999989	-00:09:00	-00:27:00	Miners Point	AK
59951	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.8833300000000008	-130.033330000000007	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.200000000000000011	-00:17:00	\N	0.200000000000000011	-00:09:00	-00:27:00	Lion Point	AK
59952	Race Point, 0.7 mile ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.2858299999999971	-131.545999999999992	:America/Juneau	USA	knots	300	145	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.200000000000000011	00:22:00	\N	0.200000000000000011	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
59953	Saxman Spire, 0.2 mile south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155000000000001	-131.602669999999989	:America/Juneau	USA	knots	110	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:12:00	\N	0.299999999999999989	-02:00:00	\N	0.200000000000000011	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
59954	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.3361700000000027	-131.644170000000003	:America/Juneau	USA	knots	120	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:41:00	\N	0.100000000000000006	00:08:00	\N	0.299999999999999989	-00:50:00	00:04:00	Ketchikan	AK
59955	Hotspur Island, 0.5 mile southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.9666700000000006	-131.483329999999995	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:56:00	\N	0.400000000000000022	-01:29:00	\N	0.299999999999999989	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
59956	Point Davidson, 1 mile south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.9833300000000023	-131.599999999999994	:America/Juneau	USA	knots	240	60	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.599999999999999978	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
59957	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.533330000000007	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1.80000000000000004	-00:37:00	\N	1.30000000000000004	-00:29:00	-00:47:00	Harris Island	AK
59958	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.466669999999993	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.39999999999999991	-00:32:00	\N	0.900000000000000022	-00:24:00	-00:42:00	Ajax Reef	AK
59959	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.383330000000001	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.80000000000000004	-00:27:00	\N	1.30000000000000004	-00:19:00	-00:37:00	Snipe Island	AK
59960	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.0216700000000003	-131.522330000000011	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.19999999999999996	-00:32:00	\N	0.800000000000000044	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
59961	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.0333299999999994	-131.349999999999994	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.60000000000000009	-00:27:00	\N	1.10000000000000009	-00:19:00	-00:37:00	Indian Reef	AK
59962	Customhouse Cove, 1 mile west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1000000000000014	-131.266670000000005	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
59963	Hid Reef, 2.7 miles south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.0333299999999994	-131.666670000000011	:America/Juneau	USA	knots	190	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:12:00	\N	0.200000000000000011	-00:54:00	\N	0.200000000000000011	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
59964	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.1166699999999992	-131.699999999999989	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Point McCartey Light	AK
59965	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.133499999999998	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1.10000000000000009	-00:32:00	\N	0.699999999999999956	-00:24:00	-00:42:00	Wharburton Island	AK
59966	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.183329999999998	-131.599999999999994	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.900000000000000022	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Driest Point	AK
59967	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.2486699999999971	-131.669330000000002	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	1.10000000000000009	-00:22:00	\N	0.699999999999999956	-00:14:00	-00:32:00	Blank Point	AK
59968	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2000000000000028	-131.116669999999999	:America/Juneau	USA	knots	220	40	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Point Sykes	AK
59969	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.9136700000000033	-131.532000000000011	:America/Juneau	USA	knots	264	62	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-02:58:00	\N	0.599999999999999978	-03:07:00	\N	0.100000000000000006	-01:41:00	-03:41:00	Behm Narrows	AK
59970	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6000000000000014	-131.833329999999989	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.599999999999999978	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Helm Point	AK
59971	Guard Islands, 2 miles northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.4666700000000006	-131.900000000000006	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
59972	Grass Rock, 1 mile south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.550000000000011	:America/Juneau	USA	knots	235	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:22:00	\N	0.599999999999999978	-00:29:00	\N	0.200000000000000011	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
59973	Moira Rock, 2 miles east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.0833299999999966	-131.933330000000012	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
59974	Skin Island, 3 miles east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.2999999999999972	-131.983329999999995	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
59975	Guard Island Lighthouse, 5.1 miles SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.3999999999999986	-132	:America/Juneau	USA	knots	164	6	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:20:00	\N	0.299999999999999989	-00:03:00	\N	0.200000000000000011	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
59976	Guard Islands, 2 miles west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.4500000000000028	-131.949999999999989	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.400000000000000022	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
59977	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6000000000000014	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.699999999999999956	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
59978	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.7833299999999994	-132.416670000000011	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.699999999999999956	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
59979	Mabel Island, 3 miles west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.9166700000000034	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	0.699999999999999956	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
59980	Lincoln Rock Light, 1 mile west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.0499999999999972	-132.716669999999993	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
59981	McHenry Ledge, 1 mile north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.7999999999999972	-132.300000000000011	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	1	-00:17:00	\N	0.599999999999999978	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
59982	Vixen Point, 3 miles west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.8500000000000014	-132.183330000000012	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.800000000000000044	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
59983	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.9528299999999987	-132.090000000000003	:America/Juneau	USA	knots	195	15	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.699999999999999956	00:01:00	-00:17:00	Eaton Point	AK
59984	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.0333299999999994	-132.083329999999989	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.699999999999999956	00:06:00	-00:12:00	Niblack Islands	AK
59985	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.0833299999999966	-132.083329999999989	:America/Juneau	USA	knots	215	35	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Blanche Rock	AK
59986	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.183329999999998	-131.966669999999993	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	1	00:08:00	\N	0.599999999999999978	00:16:00	-00:02:00	Point Warde	AK
59987	Blake Island, Alaska Current	NOS	PCT3071_1	56.222999999999999	-131.908829999999995	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1.19999999999999996	00:13:00	\N	0.800000000000000044	00:21:00	00:03:00	Blake Island	AK
59988	Berg Bay, Alaska Current	NOS	PCT3076_1	56.343670000000003	-132.00766999999999	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	1.10000000000000009	00:18:00	\N	0.699999999999999956	00:26:00	00:08:00	Berg Bay	AK
59990	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.3751699999999971	-132.169669999999996	:America/Juneau	USA	knots	320	140	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1	00:23:00	\N	0.599999999999999978	00:31:00	00:13:00	Channel Island, north of	AK
59991	Mill Creek, Alaska Current	NOS	PCT3091_1	56.4500000000000028	-132.216669999999993	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	0.900000000000000022	00:23:00	\N	0.599999999999999978	00:31:00	00:13:00	Mill Creek	AK
59992	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.383330000000001	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.699999999999999956	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
59993	Found Island, 1 mile northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.1166699999999992	-132.099999999999994	:America/Juneau	USA	knots	140	320	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.800000000000000044	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
59994	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.1499999999999986	-132.150000000000006	:America/Juneau	USA	knots	150	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.800000000000000044	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
59995	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.2166700000000006	-132.316669999999988	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
59996	Young Rock, 2 miles south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.3333299999999966	-132.383330000000001	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.800000000000000044	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
59997	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.3833300000000008	-132.400000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.800000000000000044	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
59998	Wrangell Harbor, 1.6 miles west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.4666700000000006	-132.449999999999989	:America/Juneau	USA	knots	235	50	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:33:00	\N	0.400000000000000022	03:36:00	\N	0.299999999999999989	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
59999	Cape Muzon, 5 miles east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.6666700000000034	-132.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:26:00	\N	0.599999999999999978	-00:47:00	\N	0.400000000000000022	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
60000	Dewey Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.299999999999999989	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
60001	Boat Rocks, 2 miles west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.816670000000002	-132.566669999999988	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	0.5	-00:42:00	\N	0.299999999999999989	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
60002	Webster Point, 1 mile west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.9666700000000006	-132.633330000000001	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.800000000000000044	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
60003	Mellen Rock, 1 mile east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.0333299999999994	-132.650000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	1	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
60004	Shoe Rock, 1 mile north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.9666700000000006	-132.733329999999995	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.800000000000000044	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
60005	Grand Island, 2 miles north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.866669999999999	:America/Juneau	USA	knots	115	295	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
60006	High Point, 1 mile east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.0166699999999977	-132.933330000000012	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.900000000000000022	-00:32:00	\N	0.599999999999999978	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
60007	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.066670000000002	-132.949999999999989	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.800000000000000044	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
60008	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.1333300000000008	-132.966669999999993	:America/Juneau	USA	knots	165	345	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
60009	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.1983299999999986	-132.824000000000012	:America/Juneau	USA	knots	130	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:09:00	\N	0.599999999999999978	-00:45:00	\N	0.400000000000000022	-00:29:00	-00:20:00	Sukkwan Narrows	AK
60010	The Sentinels, 1 mile west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.183329999999998	-133.016670000000005	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.800000000000000044	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
60011	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.2578299999999984	-133.182829999999996	:America/Juneau	USA	knots	270	90	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.699999999999999956	-00:19:00	-00:37:00	Meares Island, south of	AK
60012	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2000000000000028	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.599999999999999978	-00:37:00	\N	0.400000000000000022	-00:29:00	-00:47:00	Millar Rocks	AK
60013	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.183329999999998	-133.283330000000007	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.5	-00:37:00	\N	0.299999999999999989	-00:29:00	-00:47:00	Diver Islands	AK
60014	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.3500000000000014	-133.316669999999988	:America/Juneau	USA	knots	330	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1.10000000000000009	-00:27:00	\N	0.699999999999999956	-00:19:00	-00:37:00	Cape Flores	AK
60015	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.2999999999999972	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	1	-00:27:00	\N	0.599999999999999978	-00:19:00	-00:37:00	Waterfall Cannery	AK
60016	Cape Bartolome, 2 miles east of, Alaska Current	NOS	PCT3316_1	55.2333300000000023	-133.550000000000011	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	0.599999999999999978	-00:37:00	\N	0.400000000000000022	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
60017	Point Arboleda, 1 mile west of, Alaska Current	NOS	PCT3326_1	55.316670000000002	-133.483329999999995	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.699999999999999956	-00:32:00	\N	0.400000000000000022	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
60018	Cabras Islands, 1 mile west of, Alaska Current	NOS	PCT3331_1	55.3500000000000014	-133.416670000000011	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:11:00	\N	0.599999999999999978	-00:32:00	\N	0.400000000000000022	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
60019	Cape Flores, 1 mile north of, Alaska Current	NOS	PCT3336_1	55.3666699999999992	-133.300000000000011	:America/Juneau	USA	knots	235	55	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
60020	Toti Island, 1.1 miles west of, Alaska Current	NOS	PCT3346_1	55.4166700000000034	-133.150000000000006	:America/Juneau	USA	knots	250	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
60021	Coronados Islands, 2 miles west of, Alaska Current	NOS	PCT3351_1	55.433329999999998	-133.166670000000011	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
60022	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.4833300000000023	-133.150000000000006	:America/Juneau	USA	knots	190	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Craig Cannery	AK
60023	Tuxekan Passage, 0.2 mile S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.8826699999999974	-133.24233000000001	:America/Juneau	USA	knots	137	323	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-03:05:00	\N	0.200000000000000011	-03:32:00	\N	0.299999999999999989	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
60024	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.914670000000001	-133.312330000000003	:America/Juneau	USA	knots	207	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:03:00	\N	1	-00:19:00	\N	0.699999999999999956	-00:06:00	-00:11:00	Skookumchuck Pass	AK
60025	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.9668300000000016	-133.30483000000001	:America/Juneau	USA	knots	182	351	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:31:00	\N	0.200000000000000011	00:43:00	\N	0.100000000000000006	00:28:00	-00:13:00	Brockman Island, east of	AK
60026	Tenass Island, 0.3 mile  SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.9866699999999966	-133.30483000000001	:America/Juneau	USA	knots	220	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:05:00	\N	0.299999999999999989	-00:48:00	\N	0.200000000000000011	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
60027	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.1601700000000008	-133.337999999999994	:America/Juneau	USA	knots	248	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	05:37:00	\N	0.100000000000000006	05:37:00	\N	0.200000000000000011	04:57:00	05:54:00	The Narrows, west of	AK
60028	Cora Point, 2 miles east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.9166700000000034	-134.050000000000011	:America/Juneau	USA	knots	200	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:21:00	\N	1	-00:42:00	\N	0.100000000000000006	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
60029	Point St. Albans, 3 miles SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.0333299999999994	-133.949999999999989	:America/Juneau	USA	knots	232	78	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:28:00	\N	0.400000000000000022	-01:14:00	\N	0.200000000000000011	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
60030	Point St. Albans, 4 miles east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.0833299999999966	-133.849999999999994	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:16:00	\N	1	-00:37:00	\N	0.100000000000000006	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
60031	Ruins Point, 2 miles west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.066670000000002	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:49:00	\N	0.299999999999999989	00:38:00	\N	0.200000000000000011	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
60032	Shakan Light, 2.8 miles WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.1666700000000034	-133.699999999999989	:America/Juneau	USA	knots	182	19	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:36:00	\N	0.299999999999999989	-01:48:00	\N	0.200000000000000011	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
60033	Beauclerc Island Light, 1 mile east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.816669999999988	:America/Juneau	USA	knots	205	70	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:28:00	\N	0.400000000000000022	-00:41:00	\N	0.100000000000000006	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
60034	Sumner Island, 1.8 miles south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.3666699999999992	-133.816669999999988	:America/Juneau	USA	knots	240	10	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.299999999999999989	-03:33:00	\N	0.299999999999999989	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
60035	Blaquiere Point, 1 mile SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.5499999999999972	-132.566669999999988	:America/Juneau	USA	knots	240	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:23:00	\N	0.5	00:23:00	\N	0.299999999999999989	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
60036	Southern entrance to Keku Strait, Keku Strait, Alaska Current	NOS	PCT3701_1	56.566670000000002	-133.716669999999993	:America/Juneau	USA	knots	184	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:32:00	\N	0.599999999999999978	00:13:00	\N	0.299999999999999989	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
60037	Eagle Island, 0.5 mile southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.6073299999999975	-133.682170000000013	:America/Juneau	USA	knots	130	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
60038	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.6361699999999999	-133.68950000000001	:America/Juneau	USA	knots	90	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.800000000000000044	-00:09:00	\N	0.800000000000000044	-00:18:00	-00:41:00	Devils Elbow	AK
60039	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6764999999999972	-133.732499999999987	:America/Juneau	USA	knots	10	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:46:00	\N	1.19999999999999996	01:43:00	\N	0.699999999999999956	01:48:00	02:10:00	Summit Island, west of	AK
60040	High Island, 1.1 miles south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.7023300000000035	-133.733000000000004	:America/Juneau	USA	knots	10	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:30:00	\N	0.5	00:40:00	\N	0.299999999999999989	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
60041	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.733329999999995	:America/Juneau	USA	knots	325	210	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:18:00	\N	0.400000000000000022	00:49:00	\N	0.299999999999999989	00:07:00	00:34:00	High Island, northwest of	AK
60042	Cucumber Reef, 0.2 mile northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.7899999999999991	-133.766999999999996	:America/Juneau	USA	knots	325	110	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:11:00	\N	0.800000000000000044	00:16:00	\N	0.400000000000000022	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
60043	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.5103300000000033	-132.958329999999989	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.299999999999999989	00:06:00	-00:12:00	Point Alexander	AK
60044	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.5333299999999994	-132.966669999999993	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	0.5	-00:02:00	\N	0.299999999999999989	00:06:00	-00:12:00	Point Deception	AK
60045	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.5558300000000003	-132.961829999999992	:America/Juneau	USA	knots	180	0	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.39999999999999991	-00:02:00	\N	0.900000000000000022	00:06:00	-00:12:00	Point Lockwood	AK
60046	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.6009999999999991	-132.975999999999999	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	2.10000000000000009	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
60047	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6394999999999982	-132.931170000000009	:America/Juneau	USA	knots	225	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.60000000000000009	-00:02:00	\N	1.10000000000000009	00:06:00	-00:12:00	Anchor Point	AK
60048	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.657829999999997	-132.926999999999992	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1.19999999999999996	-00:02:00	\N	0.800000000000000044	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
60049	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7000000000000028	-132.949999999999989	:America/Juneau	USA	knots	5	185	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.299999999999999989	00:11:00	-00:07:00	Green Point	AK
60050	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.7333300000000023	-132.949999999999989	:America/Juneau	USA	knots	345	165	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	1	00:13:00	\N	0.599999999999999978	00:21:00	00:03:00	Mountain Point	AK
60051	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.7783299999999969	-132.979330000000004	:America/Juneau	USA	knots	340	160	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.60000000000000009	00:23:00	\N	1.10000000000000009	00:31:00	00:13:00	Blunt Point	AK
60052	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.8078300000000027	-132.983499999999992	:America/Juneau	USA	knots	40	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.80000000000000004	00:23:00	\N	1.39999999999999991	00:31:00	00:13:00	Turn Point	AK
60053	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.8223300000000009	-132.948329999999999	:America/Juneau	USA	knots	60	240	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:44:00	\N	1.60000000000000009	00:23:00	\N	1.10000000000000009	00:31:00	00:13:00	Prolewy Rocks	AK
60054	Cosmos Point, 0.5 mile east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.6666700000000034	-132.599999999999994	:America/Juneau	USA	knots	305	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:42:00	\N	0.200000000000000011	01:15:00	\N	0.100000000000000006	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
60055	The Brothers, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.2999999999999972	-133.716669999999993	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.5	00:03:00	\N	0.299999999999999989	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
60056	Point Gambier, 2 miles east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.433329999999998	-133.766670000000005	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.200000000000000011	00:08:00	\N	0.200000000000000011	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
60057	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.6166699999999992	-133.766670000000005	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.299999999999999989	00:21:00	00:03:00	Point Hugh	AK
60058	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.8333299999999966	-133.833329999999989	:America/Juneau	USA	knots	155	335	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:34:00	\N	0.5	00:13:00	\N	0.299999999999999989	00:21:00	00:03:00	Midway Island	AK
60059	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.1499999999999986	-134.133330000000001	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:39:00	\N	0.5	00:18:00	\N	0.299999999999999989	00:26:00	00:08:00	Point Arden	AK
60060	0.2 mile off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.3333299999999966	-134.050000000000011	:America/Juneau	USA	knots	200	39	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:07:00	\N	0.5	00:11:00	\N	0.200000000000000011	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
60061	0.2 mile off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.3999999999999986	-134.016670000000005	:America/Juneau	USA	knots	203	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:08:00	\N	0.400000000000000022	00:34:00	\N	0.400000000000000022	00:53:00	00:10:00	0.2 mile off Taku Point	AK
60062	Douglas, north of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.2830000000000013	-134.393669999999986	:America/Juneau	USA	knots	144	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:32:00	\N	0.200000000000000011	00:44:00	\N	0.100000000000000006	02:12:00	00:11:00	Douglas, north of	AK
60063	Douglas, north of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.2830000000000013	-134.393669999999986	:America/Juneau	USA	knots	136	302	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:08:00	\N	0.299999999999999989	00:41:00	\N	0.100000000000000006	01:33:00	00:27:00	Douglas, north of	AK
60064	Juneau Harbor, S of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.291170000000001	-134.407000000000011	:America/Juneau	USA	knots	102	334	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:05:00	\N	0.299999999999999989	02:03:00	\N	0.100000000000000006	03:19:00	00:34:00	Juneau Harbor, S of	AK
60065	West Juneau, NE of (Depth 25ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.2963299999999975	-134.424499999999995	:America/Juneau	USA	knots	137	314	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:21:00	\N	0.200000000000000011	00:49:00	\N	0.100000000000000006	00:24:00	00:32:00	West Juneau, NE of	AK
60066	Aurora Basin, SW of (Depth 15ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.3049999999999997	-134.440830000000005	:America/Juneau	USA	knots	163	289	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:51:00	\N	0.400000000000000022	00:34:00	\N	0.200000000000000011	01:01:00	00:10:00	Aurora Basin, SW of	AK
60067	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.8833300000000008	-134.599999999999994	:America/Juneau	USA	knots	205	25	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Hazy Islands	AK
60068	Cape Ommaney Light, 5 miles east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.1666700000000034	-134.516670000000005	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:01:00	\N	0.5	-00:22:00	\N	0.299999999999999989	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
60069	Port Walter Light, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.3833300000000008	-134.533330000000007	:America/Juneau	USA	knots	185	5	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:04:00	\N	0.699999999999999956	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
60070	Point Ellis, 4 miles west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.566670000000002	-134.449999999999989	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:09:00	\N	0.699999999999999956	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
60071	Kingsmill Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.8333299999999966	-134.516670000000005	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:14:00	\N	1	-00:07:00	\N	0.599999999999999978	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
60072	Point Gardner Light, 2 miles west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.0166699999999977	-134.666670000000011	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
60073	Point Caution, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.733329999999995	:America/Juneau	USA	knots	175	355	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
60074	Point Thatcher, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.4166700000000034	-134.733329999999995	:America/Juneau	USA	knots	160	340	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
60075	Danger Point Light, 3 miles west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.5166699999999977	-134.699999999999989	:America/Juneau	USA	knots	170	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
60076	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.583329999999989	:America/Juneau	USA	knots	285	105	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:09:00	\N	2.89999999999999991	00:48:00	\N	2.20000000000000018	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
60077	South Passage Point, 3 miles east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.7666699999999977	-134.833329999999989	:America/Juneau	USA	knots	355	175	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:29:00	\N	0.699999999999999956	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
60078	Point Augusta, ESE of (Depth 70ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.0249999999999986	-134.87333000000001	:America/Juneau	USA	knots	164	344	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:54:00	\N	0.299999999999999989	-00:04:00	\N	0.200000000000000011	-00:02:00	00:01:00	Point Augusta, ESE of	AK
60079	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.8333299999999966	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:13:00	\N	0.200000000000000011	00:20:00	\N	0.100000000000000006	00:47:00	00:15:00	Biorka Channel	AK
60080	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.0499999999999972	-135.333329999999989	:America/Juneau	USA	knots	156	333	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-01:16:00	\N	0.200000000000000011	-01:17:00	\N	0.100000000000000006	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
60081	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.1499999999999986	-135.583329999999989	:America/Juneau	USA	knots	64	242	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:30:00	\N	0.5	-00:51:00	\N	0.400000000000000022	-00:43:00	-01:01:00	West Channel (narrows)	AK
60082	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.1666700000000034	-135.550000000000011	:America/Juneau	USA	knots	229	51	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:23:00	\N	0.699999999999999956	-00:32:00	\N	0.400000000000000022	-00:30:00	-00:48:00	East Channel (narrows)	AK
60083	Allan Pt., 1.5mile W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.433330000000012	:America/Juneau	USA	knots	82	260	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:40:00	\N	0.800000000000000044	-01:06:00	\N	0.599999999999999978	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
60084	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.2666699999999977	-135.583329999999989	:America/Juneau	USA	knots	323	150	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:13:00	\N	0.699999999999999956	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
60085	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.2833299999999994	-135.599999999999994	:America/Juneau	USA	knots	330	144	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:34:00	\N	0.699999999999999956	-00:29:00	\N	0.299999999999999989	-00:15:00	-00:11:00	Highwater Island, west of	AK
60086	Sea Rock, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.3500000000000014	-135.883330000000001	:America/Juneau	USA	knots	245	65	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
60087	Kalinin Point, 1 mile north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.3500000000000014	-135.800000000000011	:America/Juneau	USA	knots	260	80	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.5	-00:27:00	\N	0.299999999999999989	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
60088	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.3500000000000014	-135.766670000000005	:America/Juneau	USA	knots	275	95	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	-00:06:00	\N	0.699999999999999956	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
60089	Otstoia Island Light, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.5833299999999966	-135.449999999999989	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
60090	Nismeni Point, 1 mile north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.5833299999999966	-135.416670000000011	:America/Juneau	USA	knots	105	285	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
60091	Peschani Point, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.5333299999999994	-135.300000000000011	:America/Juneau	USA	knots	145	325	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
60092	Point Elizabeth, 1 mile northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.5166699999999977	-135.266670000000005	:America/Juneau	USA	knots	135	315	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
60093	Point Benham, 1 mile east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.4833300000000023	-135.183330000000012	:America/Juneau	USA	knots	130	310	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
60094	False Linderberg Head, 1 mile south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.4500000000000028	-135.083329999999989	:America/Juneau	USA	knots	125	305	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
60095	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.4500000000000028	-135.033330000000007	:America/Juneau	USA	knots	100	280	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:19:00	\N	1	-00:02:00	\N	0.599999999999999978	00:06:00	-00:12:00	Lindenberg Head	AK
60096	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.4500000000000028	-134.933330000000012	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.599999999999999978	00:03:00	\N	0.400000000000000022	00:11:00	-00:07:00	Eva Islands	AK
60097	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.4500000000000028	-134.883330000000001	:America/Juneau	USA	knots	85	265	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	1	00:03:00	\N	0.599999999999999978	00:11:00	-00:07:00	Fairway Island	AK
60098	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.4500000000000028	-134.816669999999988	:America/Juneau	USA	knots	95	275	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:24:00	\N	0.699999999999999956	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
60099	Claybluff Point Light, 3.5 nmi. south of (Depth 75ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.9099999999999966	-141.594999999999999	:America/Anchorage	USA	knots	209	104	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:20:00	\N	0.200000000000000011	-02:09:00	\N	0.200000000000000011	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
60100	Claybluff Point Light, 2.3 nmi. SE of (Depth 206ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.9466699999999975	-141.52000000000001	:America/Anchorage	USA	knots	215	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:14:00	\N	0.100000000000000006	-02:44:00	\N	0.100000000000000006	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
60101	Carson Creek Entrance, 1.4 nmi. ESE of (Depth 15ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.9833300000000023	-141.469999999999999	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:09:00	\N	0.00100000000000000002	-00:36:00	\N	0.200000000000000011	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
60102	Carson Creek Entrance, 3.3 nmi. SE of (Depth 78ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.9699999999999989	-141.413330000000002	:America/Anchorage	USA	knots	232	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:03:00	\N	0.200000000000000011	-01:45:00	\N	0.299999999999999989	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
60103	Carson Creek Entrance, 2.4 nmi. ESE of (Depth 50ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.9866699999999966	-141.436669999999992	:America/Anchorage	USA	knots	244	54	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:06:00	\N	0.299999999999999989	-01:38:00	\N	0.200000000000000011	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
60104	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.0499999999999972	-144.383330000000001	:America/Anchorage	USA	knots	288	68	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	01:06:00	\N	0.599999999999999978	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
60105	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.0833299999999966	-144.300000000000011	:America/Anchorage	USA	knots	255	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	25446	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
60106	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.3333299999999966	-160.516670000000005	:America/Anchorage	USA	knots	199	357	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:11:00	\N	0.200000000000000011	-02:05:00	\N	0.100000000000000006	-02:32:00	-01:28:00	Popof Strait	AK
60107	Unga Strait (1.4 miles N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.433329999999998	-160.733329999999995	:America/Anchorage	USA	knots	114	282	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	05:06:00	\N	0.100000000000000006	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
60108	Amak Island, 5 miles north of, Alaska Current	NOS	PCT5426_1	55.5	-163.166670000000011	:America/Nome	USA	knots^2	139	337	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	05:09:00	\N	0.200000000000000011	05:31:00	\N	0.200000000000000011	04:52:00	04:50:00	Amak Island, 5 miles north of	AK
60109	Amak Island, 5 miles southeast of, Alaska Current	NOS	PCT5431_1	55.3500000000000014	-163.016670000000005	:America/Nome	USA	knots^2	200	350	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	04:35:00	\N	0.200000000000000011	04:45:00	\N	0.200000000000000011	04:24:00	04:32:00	Amak Island, 5 miles southeast of	AK
60110	Otter Point, off of, north side, Unimak Island, Alaska Current	NOS	PCT5441_1	55.066670000000002	-163.783330000000007	:America/Nome	USA	knots^2	258	89	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	03:53:00	\N	0.299999999999999989	03:36:00	\N	0.200000000000000011	03:36:00	03:35:00	Otter Point, off of, north side	AK
60111	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.9833300000000023	-163.433330000000012	:America/Nome	USA	knots^2	139	331	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16152	00:02:00	\N	0.5	-00:26:00	\N	0.5	-00:55:00	00:14:00	Bechevin Bay, off Rocky Point	AK
60112	Cape Lieskof, 3 miles west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.199999999999989	:America/Nome	USA	knots	248	56	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:53:00	\N	0.299999999999999989	-04:39:00	\N	0.299999999999999989	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
60113	Entrance Point, 3 miles west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.650000000000006	:America/Anchorage	USA	knots	2	174	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:34:00	\N	0.800000000000000044	-04:28:00	\N	0.699999999999999956	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
60114	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.9833300000000023	-160.583329999999989	:America/Anchorage	USA	knots	0	180	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:27:00	\N	0.599999999999999978	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
60115	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.9166700000000034	-160.599999999999994	:America/Anchorage	USA	knots	335	158	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:26:00	\N	0.800000000000000044	-04:03:00	\N	0.400000000000000022	-04:28:00	-04:59:00	Harbor Point	AK
60116	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.8999999999999986	-160.766670000000005	:America/Anchorage	USA	knots	33	220	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-05:21:00	\N	0.599999999999999978	-04:39:00	\N	0.900000000000000022	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
60117	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.8333299999999966	-160.783330000000007	:America/Anchorage	USA	knots	337	179	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
60118	Port Heiden, Alaska Current	NOS	PCT5771_1	56.9833300000000023	-158.883330000000001	:America/Anchorage	USA	knots	233	67	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:15:00	\N	0.400000000000000022	-01:05:00	\N	0.400000000000000022	-02:23:00	-01:14:00	Port Heiden	AK
60119	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.7333300000000023	-156.933330000000012	:America/Anchorage	USA	knots	294	111	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	01:15:00	\N	0.900000000000000022	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
60120	Cape Constantine, 4 miles Southeast of, Alaska Current	NOS	PCT5791_1	58.3333299999999966	-158.766670000000005	:America/Anchorage	USA	knots	238	59	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:52:00	\N	0.699999999999999956	-01:38:00	\N	0.599999999999999978	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
60121	Protection Point, 2.5 miles east of, Alaska Current	NOS	PCT5796_1	58.5	-158.616669999999999	:America/Anchorage	USA	knots	180	13	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
60122	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.566670000000002	-158.416670000000011	:America/Anchorage	USA	knots	180	343	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
60123	Etolin Point, 8.5 miles west of, Alaska Current	NOS	PCT5806_1	58.6333300000000008	-158.583329999999989	:America/Anchorage	USA	knots	173	352	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:05:00	\N	1.19999999999999996	00:13:00	\N	0.900000000000000022	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
60124	Clarks Point, 1 mile west of, Alaska Current	NOS	PCT5811_1	58.8333299999999966	-158.583329999999989	:America/Anchorage	USA	knots	213	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-00:02:00	\N	1.39999999999999991	00:34:00	\N	1.30000000000000004	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
60125	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.066670000000002	-161.783330000000007	:America/Anchorage	USA	knots	213	20	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:02:00	\N	0.900000000000000022	-06:05:00	\N	0.900000000000000022	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
60126	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.2833299999999994	-162.366669999999999	:America/Nome	USA	knots	212	21	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-04:21:00	\N	0.599999999999999978	-04:29:00	\N	0.599999999999999978	-05:10:00	-03:44:00	Carter Bay, west of	AK
60127	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.7833299999999994	-162.233329999999995	:America/Nome	USA	knots	188	7	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-03:45:00	\N	0.800000000000000044	-03:21:00	\N	0.599999999999999978	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
60128	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.1333300000000008	-162.166670000000011	:America/Nome	USA	knots	205	30	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:51:00	\N	1.10000000000000009	-03:42:00	\N	1.10000000000000009	-05:04:00	-02:04:00	Apokak Creek entrance	AK
60129	Walrus Island, 0.5 mile west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.183329999999998	-169.949999999999989	:America/Nome	USA	knots	210	18	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-06:38:00	\N	0.5	-06:47:00	\N	0.400000000000000022	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
60130	SW Point, St. Paul Island, 1 mile off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.1499999999999986	-170.449999999999989	:America/Nome	USA	knots	170	330	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-08:10:00	\N	0.299999999999999989	-08:10:00	\N	0.800000000000000044	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
60131	Hooper Bay entrance, Alaska Current	NOS	PCT5866_1	61.5	-166.050000000000011	:America/Nome	USA	knots	223	46	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	11:03:00	\N	0.800000000000000044	11:16:00	\N	0.699999999999999956	10:08:00	11:14:00	Hooper Bay entrance	AK
60132	St. Mathew I., southwest coast, Alaska Current	NOS	PCT5871_1	60.3500000000000014	-172.716669999999993	:America/Nome	USA	knots	119	292	\N	\N	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	03:07:00	\N	0.400000000000000022	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
60133	Apavawook Cape, 1 mile south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.1166699999999992	-168.933330000000012	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	-02:23:00	\N	0.400000000000000022	-02:14:00	\N	0.200000000000000011	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
60134	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.3333299999999966	-168.833329999999989	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.\n	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	16154	00:10:00	\N	0.299999999999999989	00:57:00	\N	0.299999999999999989	-00:41:00	01:16:00	Off Northeast Cape	AK
59052	Hammond, Oregon (sub)	NOS	9449011	46.2016666666670091	-123.944999999999993	:America/Los_Angeles	USA	feet	\N	\N	\N	Station type is undocumented type X; maybe a deleted record; use with caution.	\N	CO-OPS Metadata API	Public domain	2017-12-31	Credit:NOAA data processed by David Flater for XTide\n http://www.flaterco.com/xtide/	\N	\N	\N	\N	\N	56353	-00:30:00	\N	1.08000000000000007	-00:38:00	\N	0.959999999999999964	\N	\N	Hammond, Oreg.	OR
\.



SELECT pg_catalog.setval('public.data_sets_index_seq', 64579, true);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_pkey PRIMARY KEY (format, alias);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_pkey PRIMARY KEY (index, name);



ALTER TABLE ONLY public.constituents
    ADD CONSTRAINT constituents_pkey PRIMARY KEY (name);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_pkey PRIMARY KEY (index);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_index_fkey FOREIGN KEY (index) REFERENCES public.data_sets(index) ON DELETE CASCADE;



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_ref_index_fkey FOREIGN KEY (ref_index) REFERENCES public.data_sets(index);



